(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   7172925,     138666]
NotebookOptionsPosition[   7129700,     137373]
NotebookOutlinePosition[   7130168,     137393]
CellTagsIndexPosition[   7130125,     137390]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Genetic paths to evolutionary rescue and the distribution of fitness effects \
along them\
\>", "Title",
 CellChangeTimes->{{3.743875248008654*^9, 3.743875284879614*^9}, {
   3.743875320682399*^9, 3.743875324176907*^9}, 3.751638326750587*^9, {
   3.756740547708156*^9, 3.7567405603138638`*^9}, {3.760616370312804*^9, 
   3.760616378141963*^9}}],

Cell["\<\
Matthew Osmond, Sarah Otto, Guillaume Martin\
\>", "Subtitle",
 CellChangeTimes->{{3.743875335225277*^9, 3.743875349456738*^9}, {
   3.751638414849802*^9, 3.751638419213266*^9}, 3.769460973729196*^9, {
   3.771691345853272*^9, 3.771691347993198*^9}}],

Cell["mmosmond@zoology.ubc.ca", "Subsubtitle",
 CellChangeTimes->{{3.74387536214701*^9, 3.743875368090391*^9}, {
  3.782252189312375*^9, 3.782252193588619*^9}}],

Cell[CellGroupData[{

Cell["Dependencies", "Section",
 InitializationCell->True,
 CellChangeTimes->{{3.7438763798595457`*^9, 3.743876392968668*^9}, 
   3.745607138503605*^9, {3.751646190812544*^9, 3.751646195922906*^9}, {
   3.751646308993361*^9, 3.751646310374289*^9}, 3.769340689829412*^9, {
   3.7693407904087*^9, 3.769340794450663*^9}, 3.7709998625108643`*^9}],

Cell[CellGroupData[{

Cell["Directories", "Subsection",
 InitializationCell->True,
 CellChangeTimes->{{3.751646285847581*^9, 3.7516462885738497`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SetDirectory", "[", 
    RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "sets", " ", "current", " ", "directory", " ", "to", " ", "be", " ", 
    "location", " ", "of", " ", "this", " ", "file"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"datadir", "=", "\"\<data/\>\""}], ";", 
   RowBox[{"(*", 
    RowBox[{"directory", " ", "with", " ", "simulation", " ", "data"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"figdir", "=", "\"\<../main/\>\""}], ";", 
   RowBox[{"(*", 
    RowBox[{"directory", " ", "to", " ", "save", " ", "figures", " ", "in"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"supfigdir", "=", "\"\<../supplementary/\>\""}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "directory", " ", "to", " ", "save", " ", "supplementary", " ", "figures", 
    " ", "in"}], "*)"}]}], "\[IndentingNewLine]"}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.743876396100422*^9, 3.74387642443712*^9}, {
   3.751031889914995*^9, 3.751031890801373*^9}, {3.769188757435524*^9, 
   3.769188758035563*^9}, {3.76945855524566*^9, 3.769458555409338*^9}, {
   3.77154282628419*^9, 3.7715428624775476`*^9}, 3.782238485368215*^9, {
   3.7848553229967327`*^9, 3.784855327129277*^9}, {3.7849003160758657`*^9, 
   3.784900332333178*^9}, {3.784900990667635*^9, 3.784901022987645*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot styles", "Subsection",
 InitializationCell->True,
 CellChangeTimes->{{3.751646295143355*^9, 3.7516463190252457`*^9}, 
   3.7693408038192797`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"labelstyle", "=", 
   RowBox[{"Directive", "[", 
    RowBox[{"12", ",", 
     RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"defaultcolors", "=", 
   RowBox[{"ColorData", "[", 
    RowBox[{"1", ",", "\"\<ColorList\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"braceLabel", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p1_", ",", "p2_"}], "}"}], ",", "lbl_", ",", 
    RowBox[{"scale_:", " ", ".02"}]}], "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Arrowheads", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"scale", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Graphics", "@", 
            RowBox[{"Circle", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"-", "1"}]}], "}"}], ",", "1", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Pi", "/", "2"}], ",", "Pi"}], "}"}]}], "]"}]}], ",", 
           
           RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"scale", ",", "1", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Graphics", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Circle", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "1", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "Pi"}], "/", "2"}], ",", "0"}], "}"}]}], 
               "]"}], ",", 
              RowBox[{"Inset", "[", 
               RowBox[{"lbl", ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "2"}], "}"}]}], "]"}]}], "}"}], "]"}], ",",
            "1"}], "}"}]}], "}"}]}], "}"}], "]"}], ",", 
    RowBox[{"Arrow", "[", 
     RowBox[{"{", 
      RowBox[{"p1", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"p1", "+", "p2"}], ")"}], "/", "2"}]}], "}"}], "]"}], ",", 
    RowBox[{"Arrowheads", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"scale", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Graphics", "@", 
            RowBox[{"Circle", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", "1"}], "}"}], ",", "1", ",", 
              RowBox[{"{", 
               RowBox[{"Pi", ",", 
                RowBox[{"3", " ", 
                 RowBox[{"Pi", "/", "2"}]}]}], "}"}]}], "]"}]}], ",", 
           RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"scale", ",", "1", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Graphics", "@", 
            RowBox[{"Circle", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", 
                RowBox[{"-", "1"}]}], "}"}], ",", "1", ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"Pi", "/", "2"}]}], "}"}]}], "]"}]}], ",", "1"}], 
          "}"}]}], "}"}]}], "}"}], "]"}], ",", 
    RowBox[{"Arrow", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"p1", "+", "p2"}], ")"}], "/", "2"}], ",", "p2"}], "}"}], 
     "]"}]}], "}"}]}], "\[IndentingNewLine]"}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7516432075661077`*^9, 3.751643212701147*^9}, {
  3.769256334056542*^9, 3.769256404655002*^9}, {3.7822381267153063`*^9, 
  3.78223812689358*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Functions (derived below)", "Subsection",
 InitializationCell->True,
 CellChangeTimes->{{3.7516463015747013`*^9, 3.751646302320106*^9}, {
   3.7691887392568808`*^9, 3.7691887517922173`*^9}, 3.7715430034664392`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fs", "[", 
   RowBox[{"s_", ",", "so_", ",", "\[Lambda]_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   FractionBox["2", "\[Lambda]"], 
   RowBox[{"PDF", "[", 
    RowBox[{
     RowBox[{"NoncentralChiSquareDistribution", "[", 
      RowBox[{"n", ",", 
       FractionBox[
        RowBox[{"2", "so", " "}], "\[Lambda]"]}], "]"}], ",", 
     RowBox[{
      FractionBox["2", "\[Lambda]"], 
      RowBox[{"(", 
       RowBox[{"so", "-", "s"}], ")"}]}]}], "]"}], 
   RowBox[{"HeavisideTheta", "[", 
    RowBox[{"so", "-", "s"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fm", "[", 
    RowBox[{"m_", ",", "mwt_", ",", "mmax_", ",", "\[Lambda]_", ",", "n_"}], 
    "]"}], ":=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"fs", "[", 
        RowBox[{"s", ",", "so", ",", "\[Lambda]", ",", "n"}], "]"}], "/.", 
       RowBox[{"s", "\[Rule]", 
        RowBox[{"m", "-", "mwt"}]}]}], "/.", 
      RowBox[{"so", "\[Rule]", 
       RowBox[{"mmax", "-", "mwt"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"mmax", ">", "m"}], ",", 
       RowBox[{"\[Lambda]", ">", "0"}]}], "}"}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"prescue", "=", 
   RowBox[{"1", "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "p0"}], ")"}], "N0"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"prescueApp", "=", 
    RowBox[{"1", "-", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "N0"}], " ", "p0"}]]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pest", "[", "m_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "2"}], "m"}], "]"}]}], ")"}], 
    RowBox[{"HeavisideTheta", "[", "m", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"prescuem", "[", 
    RowBox[{"m_", ",", "\[CapitalLambda]_"}], "]"}], ":=", 
   RowBox[{"1", "-", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SqrtBox[
         RowBox[{"1", "+", 
          FractionBox[
           RowBox[{"2", " ", "\[CapitalLambda]"}], 
           SuperscriptBox[
            RowBox[{"Abs", "[", "m", "]"}], "2"]]}]]}], ")"}], " ", 
      RowBox[{"Abs", "[", "m", "]"}]}]]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalLambda]1", "[", 
   RowBox[{
    RowBox[{"m0_", "?", "NumericQ"}], ",", "mmax_", ",", "\[Lambda]_", ",", 
    "n_", ",", "U_"}], "]"}], ":=", 
  RowBox[{"U", " ", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"pest", "[", "m", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "0", ",", "mmax"}], "}"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PR1", "[", 
   RowBox[{"m0_", "?", "NumericQ"}], "]"}], ":=", 
  RowBox[{"prescue", "/.", 
   RowBox[{"p0", "\[Rule]", 
    RowBox[{"prescuem", "[", 
     RowBox[{"m0", ",", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PR1App", "[", 
    RowBox[{"m0_", "?", "NumericQ"}], "]"}], ":=", 
   RowBox[{"prescueApp", "/.", 
    RowBox[{"p0", "\[Rule]", 
     RowBox[{"prescuem", "[", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "]"}]}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f\[Psi]", "=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}]], " ", 
     SqrtBox["\[Rho]max"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"2", "-", "\[Psi]"}], 
        RowBox[{"2", "-", "\[Psi]wt"}]], ")"}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], "+", "\[Theta]"}]]}], 
    RowBox[{"2", " ", 
     SqrtBox["\[Pi]"]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AnciauxEqnA12", "=", 
    RowBox[{"U", " ", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox["\[Psi]wt", "2"]}], ")"}], 
       RowBox[{
        FractionBox["1", "2"], "-", "\[Theta]"}]], 
      RowBox[{"1", "-", 
       FractionBox["\[Psi]wt", "4"]}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"Exp", "[", 
         RowBox[{"-", "\[Alpha]"}], "]"}], 
        SqrtBox[
         RowBox[{"\[Pi]", " ", "\[Alpha]"}]]], "-", 
       RowBox[{"Erfc", "[", 
        SqrtBox["\[Alpha]"], "]"}]}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalLambda]2", "[", 
    RowBox[{
     RowBox[{"m0_", "?", "NumericQ"}], ",", "mmax_", ",", "\[Lambda]_", ",", 
     "n_", ",", "U_"}], "]"}], ":=", 
   RowBox[{"U", " ", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"fm", "[", 
        RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
        "]"}], 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
       RowBox[{"prescuem", "[", 
        RowBox[{"m", ",", 
         RowBox[{"\[CapitalLambda]1", "[", 
          RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
          "]"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "\[Infinity]"}], ",", "mmax"}], "}"}]}], "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalLambda]0approx", "=", 
   FractionBox[
    RowBox[{"2", " ", "U", " ", 
     SqrtBox[
      RowBox[{"mmax", " ", "\[Lambda]"}]]}], 
    SqrtBox["\[Pi]"]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"small\[Psi]approxRescue", "=", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"mmax", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SqrtBox[
               RowBox[{"1", "-", 
                FractionBox["mwt", "mmax"]}]]}], ")"}], "2"]}], 
          "\[Lambda]"]}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox["mwt", "mmax"]}], ")"}], 
        FractionBox[
         RowBox[{"1", "-", "n"}], "2"]], " ", "U", " ", 
       RowBox[{"Log", "[", 
        FractionBox[
         RowBox[{"1", "-", 
          SqrtBox[
           RowBox[{"1", "+", 
            FractionBox[
             SqrtBox[
              RowBox[{"U", " ", 
               SqrtBox[
                RowBox[{"mmax", " ", "\[Lambda]"}]]}]], 
             RowBox[{"mmax", " ", 
              SuperscriptBox["\[Pi]", 
               RowBox[{"1", "/", "4"}]]}]]}]]}], 
         RowBox[{"1", "-", 
          SqrtBox[
           RowBox[{"1", "-", 
            FractionBox["mwt", "mmax"]}]]}]], "]"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SqrtBox[
             RowBox[{"1", "-", 
              FractionBox["mwt", "mmax"]}]]}], ")"}]}]}], ")"}], " ", 
       "\[Pi]"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"verylarge\[Rho]approxRescue", "=", 
   RowBox[{"-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"mmax", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SqrtBox[
               RowBox[{"1", "-", 
                FractionBox["mwt", "mmax"]}]]}], ")"}], "2"]}], 
          RowBox[{"2", " ", "\[Lambda]"}]]}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox["mwt", "mmax"]}], ")"}], 
        FractionBox[
         RowBox[{"1", "-", "n"}], "2"]], " ", 
       SqrtBox[
        FractionBox["2", "\[Pi]"]], " ", "U"}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SqrtBox[
           RowBox[{"1", "-", 
            FractionBox["mwt", "mmax"]}]]}], ")"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SqrtBox[
             RowBox[{"1", "-", 
              FractionBox["mwt", "mmax"]}]]}], ")"}]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["mmax", "\[Lambda]"], ")"}], 
        RowBox[{"3", "/", "2"}]]}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"small\[Psi]approxRescueSuper", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"mmax", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SqrtBox[
              RowBox[{"1", "-", 
               FractionBox["mwt", "mmax"]}]]}], ")"}], "2"]}], 
         "\[Lambda]"]}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox["mwt", "mmax"]}], ")"}], 
       FractionBox[
        RowBox[{"1", "-", "n"}], "2"]], " ", "U", " ", 
      RowBox[{"Log", "[", 
       FractionBox["1", 
        RowBox[{
         SqrtBox["2"], " ", 
         SqrtBox[
          FractionBox["mmax", "\[Lambda]"]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SqrtBox[
            RowBox[{"1", "-", 
             FractionBox[
              SqrtBox[
               RowBox[{"U", " ", 
                SqrtBox[
                 RowBox[{"mmax", " ", "\[Lambda]"}]]}]], 
              RowBox[{"mmax", " ", 
               SuperscriptBox["\[Pi]", 
                RowBox[{"1", "/", "4"}]]}]]}]]}], ")"}]}]], "]"}]}], ")"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SqrtBox[
            RowBox[{"1", "-", 
             FractionBox["mwt", "mmax"]}]]}], ")"}]}]}], ")"}], " ", 
      "\[Pi]"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g1m", "=", 
   FractionBox[
    RowBox[{"U", " ", 
     RowBox[{"fm", "[", 
      RowBox[{"m", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     RowBox[{"pest", "[", "m", "]"}]}], 
    RowBox[{"\[CapitalLambda]1", "[", 
     RowBox[{"mwt", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
     "]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g1mApp", "=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[Alpha]", "-", 
       RowBox[{
        FractionBox["1", "4"], " ", "\[Rho]max", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}]}]], " ", 
     SqrtBox[
      RowBox[{"\[Alpha]", " ", "\[Rho]max"}]], " ", "\[Psi]"}], 
    RowBox[{
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox["m", "mmax"]}]], " ", "mmax", " ", "\[Psi]wt", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", "\[Alpha]"], " ", 
        SqrtBox["\[Pi]"], " ", 
        SqrtBox["\[Alpha]"], " ", 
        RowBox[{"Erfc", "[", 
         SqrtBox["\[Alpha]"], "]"}]}]}], ")"}]}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g2numerator", "[", 
    RowBox[{"m0_", ",", 
     RowBox[{"m2_", "?", "NumericQ"}]}], "]"}], ":=", 
   RowBox[{"U", " ", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"fm", "[", 
        RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
        "]"}], 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
       RowBox[{"prescuem", "[", 
        RowBox[{"m", ",", 
         RowBox[{"U", " ", 
          RowBox[{"fm", "[", 
           RowBox[{"m2", ",", "m", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
           "]"}], 
          RowBox[{"pest", "[", "m2", "]"}]}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "\[Infinity]"}], ",", "mmax"}], "}"}]}], "]"}]}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"g2denominator", "[", 
    RowBox[{"m0_", "?", "NumericQ"}], "]"}], ":=", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{"U", " ", 
      RowBox[{"fm", "[", 
       RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
      RowBox[{"prescuem", "[", 
       RowBox[{"m", ",", 
        RowBox[{"U", " ", 
         RowBox[{"fm", "[", 
          RowBox[{"m2", ",", "m", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
          "]"}], 
         RowBox[{"pest", "[", "m2", "]"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"-", "\[Infinity]"}], ",", "mmax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m2", ",", "0", ",", "mmax"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7516462139186897`*^9, 3.751646270467125*^9}, {
   3.751646343078753*^9, 3.75164634328763*^9}, {3.751646387551614*^9, 
   3.751646408979447*^9}, {3.7516470220518427`*^9, 3.751647049372202*^9}, {
   3.7516831535947723`*^9, 3.751683153847217*^9}, {3.769187813917276*^9, 
   3.769187859997877*^9}, {3.769187932316402*^9, 3.769187948508359*^9}, {
   3.769188061381556*^9, 3.769188074119193*^9}, {3.769188674983728*^9, 
   3.7691886867466908`*^9}, {3.769195370972764*^9, 3.769195403146743*^9}, {
   3.7691955874069967`*^9, 3.769195587557735*^9}, {3.769197181945507*^9, 
   3.7691972749247723`*^9}, {3.769197518485766*^9, 3.769197518957025*^9}, {
   3.769260843863697*^9, 3.769260867902547*^9}, {3.769260898890201*^9, 
   3.769260900723514*^9}, {3.76926613788595*^9, 3.769266147158663*^9}, {
   3.769266892958633*^9, 3.769266897395494*^9}, {3.769340844650063*^9, 
   3.769340845071418*^9}, {3.769379116715665*^9, 3.76937911740809*^9}, {
   3.769428979974194*^9, 3.769429009063814*^9}, {3.769429148371941*^9, 
   3.7694291781420507`*^9}, {3.7694292398790493`*^9, 
   3.7694292403976603`*^9}, {3.769966120453506*^9, 3.7699661340190268`*^9}, {
   3.7699678698986073`*^9, 3.769967872371583*^9}, {3.771522993023322*^9, 
   3.7715230084002857`*^9}, 3.771542915848775*^9, {3.771610158490685*^9, 
   3.771610163945397*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example simulations", "Section",
 CellChangeTimes->{{3.743875391299705*^9, 3.743875393002556*^9}, {
  3.7438791079605513`*^9, 3.743879110685647*^9}}],

Cell[CellGroupData[{

Cell["1-step rescue (figure 1)", "Subsection",
 CellChangeTimes->{{3.75164329223779*^9, 3.751643297069648*^9}, {
  3.769379733975573*^9, 3.769379737423662*^9}}],

Cell[CellGroupData[{

Cell["\<\
Population size dynamics (panel A)\
\>", "Subsubsection",
 CellChangeTimes->{{3.7438774983109217`*^9, 3.7438775220275097`*^9}, {
  3.745607089801744*^9, 3.745607101814826*^9}, {3.7516382859549313`*^9, 
  3.751638297943594*^9}, {3.7516433022941217`*^9, 3.751643327190428*^9}, {
  3.751646090090925*^9, 3.751646090327998*^9}, {3.7849030926967077`*^9, 
  3.7849030952939777`*^9}}],

Cell["\<\
Total population size for many replicates\
\>", "Text",
 CellChangeTimes->{{3.7438784984416523`*^9, 3.7438785071610107`*^9}, 
   3.771542891953083*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"n0", "=", "\"\<10000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "\"\<4\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", "\"\<0.000100\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "\"\<0.01000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "\"\<0.50\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", "\"\<-0.10\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mutmax", "=", "\"\<2\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nreps", "=", "100"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Import", "[", 
        RowBox[{
        "datadir", "<>", "\"\<alleles_N\>\"", "<>", "n0", "<>", "\"\<_n\>\"", 
         "<>", "n", "<>", "\"\<_U\>\"", "<>", "U", "<>", "\"\<_Es\>\"", "<>", 
         "Es", "<>", "\"\<_mmax\>\"", "<>", "mmax", "<>", "\"\<_mwt\>\"", "<>",
          "mwt", "<>", "\"\<_mutmax\>\"", "<>", "mutmax", "<>", 
         "\"\<_rep\>\"", "<>", 
         RowBox[{"ToString", "[", "rep", "]"}], "<>", "\"\<.csv\>\""}], "]"}],
        "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"rep", ",", "1", ",", "nreps"}], "}"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rescued", "=", 
   RowBox[{"Select", "[", 
    RowBox[{"data", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", 
         RowBox[{"-", "1"}], "]"}], "]"}], ">", "1000"}], "&"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"extinct", "=", 
    RowBox[{"Select", "[", 
     RowBox[{"data", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", 
          RowBox[{"-", "1"}], "]"}], "]"}], "<", "1000"}], "&"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"genmax", "=", "500"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nmax", "=", "n0"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fig1a", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
      RowBox[{"extinct", ",", "\[IndentingNewLine]", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "genmax"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "nmax"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\>\"", ",", "\"\<Number of individuals\>\""}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", "Gray"}], ",", 
       RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"FrameTicksStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontColor", "\[Rule]", "White"}], ",", "Automatic", ",", 
          "Automatic", ",", "Automatic"}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<A\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
      RowBox[{"rescued", ",", "\[IndentingNewLine]", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Thickness", "[", "0.005", "]"}]}]}], "\[IndentingNewLine]", 
      "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "genmax"}], "}"}], ",", 
        RowBox[{"Log", "@", 
         RowBox[{"{", 
          RowBox[{"2", ",", 
           SuperscriptBox["10", "4"]}], "}"}]}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "n0", ",", "n", ",", "U", ",", "Es", ",", "mmax", ",", "mwt", ",", "r", ",",
    "mutmax", ",", "nreps", ",", "genmax", ",", "nmax"}], "]"}]}], "Input",
 CellChangeTimes->{{3.74267566307705*^9, 3.742675738028081*^9}, {
   3.742675793382869*^9, 3.7426757941699123`*^9}, {3.7426758242657747`*^9, 
   3.7426758650463943`*^9}, {3.7426786610125723`*^9, 3.742678707278528*^9}, {
   3.742678865359585*^9, 3.7426788708994293`*^9}, {3.7431786248700647`*^9, 
   3.74317867251116*^9}, {3.743178774984033*^9, 3.743178793853217*^9}, {
   3.7431788660578403`*^9, 3.743178966613968*^9}, {3.743179006583357*^9, 
   3.743179036592964*^9}, {3.743179072719985*^9, 3.743179135126026*^9}, {
   3.743179179293623*^9, 3.743179217109619*^9}, {3.7431792852033854`*^9, 
   3.7431793547671432`*^9}, {3.7431795886138687`*^9, 3.743179665943205*^9}, {
   3.7431796963860826`*^9, 3.743179703976123*^9}, {3.743180184364689*^9, 
   3.743180184726823*^9}, {3.7432776211771593`*^9, 3.743277700536654*^9}, {
   3.7432777376714373`*^9, 3.743277919986001*^9}, 3.743278353152574*^9, {
   3.743278802125987*^9, 3.743278805400436*^9}, {3.743279048593625*^9, 
   3.743279076393252*^9}, {3.743279166224839*^9, 3.743279168335823*^9}, {
   3.7432792160679407`*^9, 3.743279240129554*^9}, {3.7432795039697323`*^9, 
   3.743279517934054*^9}, {3.743279693387833*^9, 3.7432797386881723`*^9}, {
   3.7438764370845757`*^9, 3.7438764425864573`*^9}, {3.743876481903409*^9, 
   3.743876520919177*^9}, 3.743876570192697*^9, {3.74387660075054*^9, 
   3.7438766008485327`*^9}, {3.743876634210388*^9, 3.7438767564934883`*^9}, {
   3.743876792932558*^9, 3.743876860830018*^9}, {3.743876897126893*^9, 
   3.743876900159235*^9}, {3.743876940413685*^9, 3.743877121718658*^9}, {
   3.7438771591939993`*^9, 3.743877232237978*^9}, 3.7438773082588673`*^9, {
   3.743877547277384*^9, 3.743877581979311*^9}, {3.743878040253003*^9, 
   3.743878115025879*^9}, {3.743878153740271*^9, 3.7438781782680902`*^9}, {
   3.743878209228674*^9, 3.743878461775881*^9}, {3.75103191731129*^9, 
   3.751031946777342*^9}, {3.75155630482299*^9, 3.751556328719026*^9}, {
   3.75155641555247*^9, 3.7515564205085783`*^9}, {3.7516414838450537`*^9, 
   3.7516415597450857`*^9}, {3.7516416023225527`*^9, 
   3.7516418107211227`*^9}, {3.751641890150548*^9, 3.7516419155466537`*^9}, {
   3.7516419540124702`*^9, 3.751641980568632*^9}, {3.751642106989456*^9, 
   3.751642203311761*^9}, 3.751642319950035*^9, {3.7516423842680273`*^9, 
   3.751642394889182*^9}, {3.7516425865310793`*^9, 3.7516427109381866`*^9}, {
   3.7516427579487143`*^9, 3.7516428369101048`*^9}, {3.7516428710629587`*^9, 
   3.7516429178936234`*^9}, {3.7516429810890017`*^9, 
   3.7516429811931343`*^9}, {3.751643218147315*^9, 3.751643229546649*^9}, {
   3.7516449097766542`*^9, 3.7516449333128557`*^9}, {3.751645014129705*^9, 
   3.751645119418666*^9}, 3.756492270929235*^9, {3.7642008760338583`*^9, 
   3.7642009512696867`*^9}, 3.7691834737136097`*^9, {3.771542938304673*^9, 
   3.771542971870872*^9}, 3.771543055184936*^9, 3.771543217952118*^9, 
   3.782251398171514*^9, {3.784899675098295*^9, 3.7848996808746443`*^9}, 
   3.784903099056809*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzX9MzHEcx/Fvyqi70nHST10/VS7q+sUl97rq+n3dddZCQ5q0JSFl02jH
kI2Uyma66Y+sHCnNIlp2jWoNs5I0Zc3vflqYVdYV1vvzh77bZ589Ps/P+/N1
ST+kyVjCcVz83/VvX/gmZTbJTS2NB1xBBxBXozgsgHk5hHOnu8xMma2Rc6S9
cUO3C1mIUyG1fVOVzLYoee49sT+N2RF7us78inNkFqEt+2Rh+3sR2RUWH9bl
jjxkdkfqWn7CnlJmTwzKgnb0JjN7ocTuWf+0L7MPXOueKPd9cCaL0VDut/Ft
DvMGZM92SJYtZfZDvq7esuz8WrI/CjIH7w+ImCU4OtSj6n3gRA6Aud9AREMy
cyBCxVxrsjlzEMb6q7fLyxzJwVBv4n/NlDKHQCNImz123YG8CU7hV9PyFcyb
UfWSb1XeY0+WovSMafPQLuZQ+BYp9fpnduQt0Oe/lVWWMIfh8O7CNvcE5q1Q
OaY1Bzoxy+Biu9f44p0tGTAp7ZkbOUXWAk4BRa+d01mXo1z0eVgtZ10ODBWm
CqJYD8fAvENLat4a6uH4eU6xXSEhcxF4YLCIrhqzoR6BGuNNZ08dmYuE1PNu
f10x65G4og2rFoSzrsCyNjedeHw1dQWuiZpWfPlK5qKwTVfhUODPehRiRt88
trogpB6NnT8Ggj2Mq6hH41OWt9RYROZi8FRtqNQ+Wkk9Bll50/dNUshcLLwT
3YSKgwLqsXCw/Th8ucyaehyOe3fOZKjI2jgoozraP4WxHo9Yff0tD90K6vGw
zJWEvjptST0BrZ3Sb14f+dQTIBgX2kzaWFFXIrHukiKjie5rlbjRVX2Ml8d6
4qL5RFT28WZqgnjUVXhhPzlaYW1BXYXJe93Gk6vNqav/N9SYEZedqM0ma9VI
uui/3uys2YINavBM7xSMlpvQfBKWiHx+827Pyhbmk5CyU1Kf6zq/YO0iGxaZ
0yCgeGJKbpih+UXWav5/36Ch/3+X/QEXoS4a
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd03tIU2EYx/G50lkLMy+zmjkdlWWibdZSS/eb9+mW05IolZphkkJlSZYj
mlazjCgrhK5aXqhmhkZ3pQuFglhEYeQlW3hJNFgEGWJZ4fP8UQcOh8/5vg8c
3pfjl7UzNVsoEAi0f+6/z6nLrpak3XnUmCcHvYAuvTv1bRjbGVGJo6MuYrYr
JEZbX26nH9kD949YHkdVsufC0todZzSxvVE3Q6RyMLB9cbzUsTZHypajdV/V
3pghX/JC7Eobske2sBfj+4eRUdUZ9hLs+xaR93ArOwC2tqParmB2IEqOoyfU
nR2EW+fWD9R3yMjLYYvcnxuSxlZgflrJxIpPPmQljLaPY5sq2CHYuO5z5vUE
9gr45YcN548tIK9Ea7XcsfAQW4X3z4ymKj17FaYHux+a9dqbHIqySVnt10x2
GJJN1x0je6TkcKi2P++6UMNejSKHuwPnDOw1mL7smsK5bz45Arc1otmnT7Ej
Ubz/S6GflK1GS1OST0LHPDJQYFe0uGnIZqC7Mif/mHUudQ0aG3aeDUonmzWQ
VZ8o8ddzj8KPe+IN3m1e1KPQPSl9lF5AFkTDUp4XbpJxj0Z5vFdQ0TsJ9Rhc
fLVI61RGNsdA6VVpzLBwj0X7+OcyS60n9VhsVkU49XaQBXFQjQ721ou4x6G6
/0hW9DYP6vE4cPlNs8TmTj0ePg/23C1tJwsS0J+7NPxnKfcEuIm9mgebuWsx
XLFbc1PNXYsrNW2eJzvdqCfCNVAhfTk5h3oipv4f7kn4kTTgXKwjm5OQfalO
aKqi9QId1ih1pS5beF6HDNHV89JY7vp/bdZjgXWiM2MV97X/za/FYLA8ZMdS
7skY6fE/HFziSj0ZGzYpG3bLZ1M3QParoz3UPnPKMKDtRURhwUNnWm+g8yc/
MdB5img+BUUHx5/m3XCi+RTa72k0nwKhb8C42DqhnppPof0R0nwq9lhXq5uu
Cmg+lb5vUv0bIl4fKg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HlIk3Ecx/EnW+nUmqXVcqVOI09MrTyrfTTnPHLuMMwyUGFIp0dEOQQf
jKDLoCyKoj9qkdXUMjPRQpa5/igK6SL/KIOillRaluGRHfj9Em4wxmvv3+dh
44FHWVxqMLkIgqD/+/73OfkaVM1f33q7eVsg6Ass9Mu5EhXPdsOhVYJ3l5Tt
hWrbxh+Zr5RkHzQUm97FWthyTKhT8zU72Ysgc4+TjUSyA3BbU6A9PxZADsSW
b/LGKjt7Cezu/i09R9lLoav4VV+Rzw6BdbjP97cfOwy/vkj2hIz6kyOgKqxs
O3WKHQmj8rK0PYkdhZhW5dZ4V3Y03Pod+8ou+pFjcP3+AptnEHs5ZkYN26sc
i8krEJRYd/rAXvZKzEgb+6gZX0SOxbIZPU8DDrHjEKvIKfFczY5HXsnFW9aH
CnIC1OUnP72uZCdCcqfsZdxsdhLMnvcsw3Zf8iqEjlepRkrZqyH3bQ7e92Yh
eQ2+WfJt/jFsFTwOx1U2dsrJgL+ltiY4mywCA1GJ2Te+L6CeDGO0m9BrJIvJ
aC0wF+Ztn089Bc9DthddaptHPQXjFonyQ48P9bVoWvw0MOwDWVyLpK0Vpwtv
ck+F/kh0uGQ/91Q8LtrwdajXm7oarn6S3O4nZFGNc+Jzs6yJexq6dbazYsdc
6k4WNKhtkYZ39nHXoM40WFdQzz0dZS+GuoqU3NNRWL557IFjDvUMFLheOKNQ
k8UMhGqDfNQ7uGdirsPWZTVwz8Qz07A0pJ17FrwiohWPf3PPgsf0RnN/Hfd1
Tvt1UCaXHNw94UU9e+p5MRsK+VvHsePctRia6MivcSWLWlxTNLQ9yZJRz4F9
SGbcWO5JPQfahqNqU+ss6rqpHTq4BISNelj5vJNtOiyv/fwz2SalvR6PfAf7
T3i5016P5qbSE5Gb3Givh7l69O62qzNpr6f7LaG9AbusSaobFwTaG+j/TqO9
AZPPIxfaO50XjPR7RlSTeyeLRrre10nbnCzkYiBhdCIl8j3t//sPvGlE2g==

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1GlI03Ecx/Eh2tRKS9s0ncdWluWK1NSps3285ubVtkrbXAVGT5IKlU6v
v1KoadJFUliJB8YsSzNCpdSyJ0VWVFo+qFh2aJdSeeFR4ff3wP7w48/r//59
nv7Fqft0uyx4PJ767/n3nn2GFMItt9oa0ySgD/goPd7zRM5sDS+Riv+bz7wI
AbY+16x7xeQlSLmUHcerYnZG6/bcMuMBZhHWZqbeUUUye8J8svzdDydmCcbX
7HyrM3uSl6PmrNUeYRPzCtx/uVv9KpfZG3byoxHzDMyrkbf0hYu9hFkK/8If
TgWPPMhrsXmbSF+eybwOwsbAitMCZl9ITe/lh6+7k/2wNU45UZzJ7I/kVQ2h
aSuZ1+PNmFWOqduNHIDhoo97DUnMgdixbuWo8IWIHITG9A9fruqZZci46Fcl
feNKDoawz1QQl88cgkFX2etqd+ZQhC6YGcyudCHLUbnTP/5ePnMYyszpzW4C
5g1I3JrlO9yzlKwAKgb7GlqYge/8rjOXlWQOqG16UF303Jl6OOw7NtVaOJO5
cEx1eZQ09zlRj4BeIqt8lUTmIlBx+3uJmw3rkWgrPVmX1SikHon8AXG7WU3m
RcFDlRAsNAmoR2Gy2lL86ekS6tFQxZb2NenJXDT6d68KmSp0pK6EMdX8XvqZ
zCmxvUg5ENbFegyiw/qzn0w4UI9BSky77cQNMk+F8+11B7dIWVfhq6N+10gx
6+q59zk1xmr4uf3hrMfirtGr030+67Fwq5/sMQYtph4Hh88d9+p1ZO4/8+Kh
SP5lTHRlPR5rFnsPX3i2iHoCfk636gv4ZC4B+9s0ctmYHfVEjCxsyZ8MWEA9
EQafU6ruQ/Opb4TH9ONHsiFb6huxLPZcj+EKmaeZ2/GfOQ2O5E10ppnmzbpD
g6Gbz6ZyBDa0187t0KKurVf4UGRFey1m/ycWtNdCW+rrY3nMkvY6JBv8GjIk
M4rZvQ7+J76NhneMK/4A9+0o/Q==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0XtQjHscx/Enu2hOodptSbnU5FJ29lSrKLGfrZQu2os6zoozLGZchmQa
Ta7PkHFJMhJDo5Qy0zmz634ZBy0x5HSYEZ1TGJKhGtmVcSkUpu/3n31mnnnm
9byfz/z+ePzNmcalAwRBMP64fz77L4dGkX7+79MrA0AvoMvLzjVEsF3RG1kf
VzmA7YEJTa5Ntn/8yXL4bDm8MreYPQK1f5rnhpjYfgiLOtYXHcQeizLVycyv
H8eSA9Djeykhq44diN3Nx8peF7DH46HouGHIYE9ExbPoI3uV7GD8Ur3930su
bCWql/jUuOSNIaswUbLYftiXHYJ9hirZ5oejyaFoz47Ka1nODsPio74Ov85R
ZDVWTbh7ddQG9mSY3NX364exw/EWXZ0dZ/zIEfgwo0ZmjWdPQSlum35r8iVP
xZiQU+VZS9mRKLbs+L22biQ5CsnTNibKzexpuH624qYkmB2NQ17Ta6ytPuTp
aFYMrL6nY8/AGe2urd19I8gaXPjv/WSv22xAtib5+upNZBGwyf8avKhjOHUt
9ly2N/+RTxa1KGzwyK9P4h6DqictDY8+K6jHwHzteVfvObIQi+qyV6cmLeAe
i/Smgbt2bvCmHofgjKm3runIYhz8pU+fv/8qpz4TXpZHyx2byeJM9HyOrchR
co/HfPOLVmWbjHo8lI691ouFZCEBr4O6ckP13BPwckVQ1Lcd3GeheNw3k1DG
fRZSpmy52KrinojBo6VpNx9wT0RgjktRhJ17ktM+yen8ZLQfXKu1aLgno7zy
jndhoxf1FMzfpp73fxtZTIE1wW7Mcef9bLwoiQh/XMR9NvILqsZZJNxTMSjd
5ayjlnsqFmYt+HK3zZO6Dg80+6XDn5JFHV79GqBeHcRdD3fZjZw17cP6DT1M
Ryzl3koP+l6Pyrrj69yyh/bbpofnG7nCoSALBjQO2bmsO3UI7Q0oaXTrPhHu
RnsDTlszD6gyXGlvgD2ypzdGNYj2RmwqbbiiaJHQ3smiEYY9oZOk26W0N9L/
oS7Mwdx5Yda1AX2a/r2TRSfbnCykOe3ToC7o/KS1ddM+DW4Sy/qOonea77Sw
Uz8=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzQ0s1HEcx/E/KuZYhDt5yN0pQxhX5+lwH4fzLGOyrKeZMKyGNVtrEpW2
s9ipthI23Yopm2uZRY2Zh2XlaUUpN9V6YIWSYVwP8/2t6bf99tvr9/5uX1H6
qaQThhzHKf7cv+/GmZfzUx52tOaKQR9Y+HKxSuPPbIJPb9Z8L21jtkDZXCpv
pU9Etkap5YxLUw2zLexE66GzmcwOGD3sV9HpxyxEUWuv6pkJsxjOA0O3dK+F
5N2QPDF2GtEwuyD76nwMl8fsCtWeySFRMLM7TMP7llWmzB4wuL6uq9M6kb0w
3aYvzAtn9oZj6mLI9NAusg/m+pcjNd7MEjQlH1R66BzJ+9A9O/AipZh5P9QD
Uz61JsxSBNX+PJtc50D2xVRcvbYSzH5YM9I/GGy1J/ujTVaQMS5nDoBA1q4Z
+GpHDkRY24xaqmKWQVz0WTMuYQ6CPoXvqJrYSQ7GmsH3rPY05hA0FsefjLJn
lsPz/KujvEVbMlBmIzx34zK5BEjNbFxeNWI9FJPOOQ39LqyHwqpH5CmoF1BX
oLf79kRXOrlEgYlrx9PuDfOph4E3tpivLyaXhCEr92NYlznr4agQDKuX8m2o
h2NvpfK5YtCaegQsyvMzdA3kkgjYHuscvaJkXYkPOW6B6+VW1JVoiZxLKjIj
c5F4V+MrnazeQT0So3L1FsFbS+pROO12tVqttaAeBU9L14WbI2QuGj/0jw6V
GrMejeYgcbZrz3bqMXjcH/jN9b0Z9RiYF0hkY6Xm1GNR85K3ckfKox6LqgtG
7bojptTjcLdjnP/UYSv1OPCM7p+ZqTagHg9Dofsqr3lNvtHjUdgsk2sbOOoJ
mAtY1Su8lqgnbJ7nDiA1TdJSIP5F/T9ziZuNRNq/QPP//BsGcBE1
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd02tIU2Ecx/FjWioGTdOpa14mIpWycrOWdtlvXuaWWjtbmkrSUBaWQdlt
UbkWWflCLUwpMgt8kxoFWVKpmSZJShIWKeQbzZIs8lJ0XWnF/k+wc+Bw+Jzv
+T/n4cCR5e8xWuZxHGf4e/67Oo9ptTizpe1WUQToBnbrh6Wr45i9sPDkRUmJ
Q0YWQfc9xJzQy+yPqmONjmeXmYNwKau1VZrHLIXj9NFzbSuYwzFqvVcZ48Ec
gUM7lWXmgXByJAYkOV3jtcxRkB+6VDVZyLwU3bO8zGs583KcDf3ulT0ZRo6B
4sFPdzQzy/HqaEFSt5F5JXpsL/cGzISSY+FtPXYxuJRZgSx5VKxExazE1WGl
2HcihByHrg9PXmbamFehbsRPVCpiXo0fxfrC5BYpWQXbWG+C9TjzGjQ1Oep3
TC0hx6N8cOv02wrmBDz2Kyr1SWNeC1mkYkD/VEJeh8OK7hHrNub1aNBqapp/
BZM34HaVTX6ullkNN/+yz7O/g8jATd++8Yl6sh3Q1nrPXItmXYMDyp71B/sD
qWtwUBVlabGQuUSMRlse+cSwnoicksmU8i9i6knoaPXzmq4m25OQ3zHyafYO
68k4MSF7+FrPejIahrtr6gYDqKegcW//QGEl2Z6CNbvUiopA1rUYWnBmKOST
P3Utgra3P6/UkrlUFGV78gUXFlNPxbJIzzffUsmcDubiPEffO1/qOrRJquvu
T4mo6zHH8XPmA4uo6/H48yJTbvFC6hsxFf9zNlG+gPpGpKuO3x2Tu1NPc7U9
Dfuvr1U313PU01Fy5UW7eJT1dFxrGxL3SedTz4Dzf5xHXWBuk2D9TYL1N7va
vlmwP4OrYRDsxwC+PDba45SH050GhOky4sVNbH+8YJ4XvI+Hj/uNI+/Pu9E8
j625ipv7IubUznmj6/Mw0vMzzm430vcdd7pTYM4EZcXHb5rOH07DRP0rzZsE
84LObfn/vj9Cg0yb
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1A1MzHEcx/G/SxxnoocrPbg6RZTSpVLJfTrS9XC5hy7rMIbMGPLQskLH
hHRUlGiypKGarMhDms6seVgsIjFjjTHPh9LDrLD7/mx3t/13e/3f/+//7vvf
7bxWblKn8TiO0/09/r2bXyapUNt4o369GHQC8+YM56RLmPkQaJOamoa8yBPw
MT9hpWsbsyNK317JmraP2QUR7/l1G1TM7pDUTWrxFjF7YkDpw3P/6kkWI2N6
8dEjDczeyJFJNb37mKei3Lv6nH0Ssy+q1gwHr3JgnoEtOaueN9wSkf0RO6X4
27oU5gC0Lc4rOsBnnoVGW4czpbmTyUGY+NlRaBIyS7C+p7+6p9KDHAy+Kd/H
4MU8GyG1zjNT693JIXgvvtlZoWAORWFBu8Kx140cBkWN28n2y8xzsKywateS
1czhUEQevtTY70qOQMHu5bdVO5gjEdO6MfuID/NcDGmFHvldk8hRqLA1qu9k
Mc9DVERckHgFsxQtby+2dIcwAz/OpBpFErIe8PxwqbHrtQv1aBy/dcpmfwpZ
H41nT3fePziXdRnySmJtRe3O1GWYfGBddY8TmZuPUSa7zqK1Qurzce/J3tyM
e07UF8Ck6igoCSXrF6Ap3b9Pw2M9Bn53XHqruh2px0BlCPIbmUvmFuJwekbN
Eg3rCyGPN7xoSGU9FvYC5+Z3zQ7UY1HabRjx6rs9dTk0nXmGxx6sy3Gi5Vym
1p/1OKSVn+VlV0ykHocnab/G+F4nc/GW1sdDYHMh6+NR1hOwdHRlmVsM6wn4
9HLa3sA9E6gnIrXswmknf7I+kX5/46kr0PrTTqPbPI66AldMhYGuD1hPwmKd
pG6L2I56Eh5de9rT1S+gvghT4o916s6Ppb4IOr8i+cPtrCtxtzUqc1sT32wo
UfRma7asbzRdr6TnPdJsoxJbayOlDZUczato3xE0rwLPc8agoPa31DyvQvCh
L33RxgGzjVbm1PT9h82GlfVqfAsfHJIF/KJ5teX9OY1lh8Zq3spGK3PJlvsg
GSK5IlxYY0v7JyMxLOfqmwAb2t/KnBY7T3U0C7vJ0ML8/8mjea3l/Y1ael7f
6fNTLPeBlfUp/6//A5q7bsY=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd039MzHEcx/FvJ6ecFP1wpV8unNXd6Uq/rh/3Kv0uXXfkR/rhV5uVObS2
FrkzZBpRYmIoWbbiqMgoU2Q2W8yasJlzxDCTpbFOCrv354+77/bdd4/v8/P+
fj9/fL8LNmk1RTyO4zL+nf+vluO70iPnZnd7iQh0A/HqO3xFBLMD3IvE1XYz
mV2Q/05Yc+XlArIbhlf/2nrpArMQ1QVlodHFzN7Y3L/DaX8csz9ahxJNUh9m
EQr35LhMmvzJCzFaI+7Lucq8GDp9Xu0XHfMS1A9HZCkUzIG4bvZ5KuWYJdg2
a62yu9OPLMOh3Yeb9RuYg6Hq/CAs+uZLluOnzLGhuok5BIajAa9UEuZQOMnv
q3SPfcjLIGz883DjQeYwCMsVi66FMoejS7ByqfGRNzkCQ6Z1J3u2MEei68b2
07GezFGIGZ04FWCcT1bAbuTExFQhczQ8PuVy/iLmGLg29za093uRY/F1Y0tj
fxhzHIRe7eL9bz3JStQ1Gs3GYmZAuu9VgWBMaLEeyD8maXijJXPxODD1WsN3
ZD0eI8GKFR1j86gnoLTeUOnYS9YnoEp+y/dFNuvL8aMqaW1SCOvLEYkAHkY9
qCdCMDi2c3IvWZ+IkSjzZIKM9SSI36ibyqazngSt3e+q1mh36snIc/DSn45y
o56Mc/rnFc4GV+opkCefuZ0+MJd6CpLvfi7GsznUU7HuzNUmd4kL9VR0fT++
1GtgNvU0tMWIti554Ew9DdJY2ap7H52op+PskGC8JUxAPR25QbWpT8rJXAbG
JXV7Lm9zpJ6BdoO2XrbegXomJJ32/PCaGdQzYfn/eNRXoLQtWtlxkaNuYy4L
a3JDDLtEU0pLz7LpKmRG6G69l02jeRWqaksUu/3ofVw2Ks8P9niYqCMb6iPy
IPuD9rTepvdmWz+PU6NCZ+4raeXTvNp6/3q1zbzaer+cxnq/0NjMa8DzDzQL
2iYs63s19H18VP4FO2wn4g==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0mtIk1Ecx/Ens7KmqdPMlpkt6aJm3lJT537Tbepsc6tmIJWgWaKSldUK
Sx9mkZZZdiEwFqOLRUoXzaDpi0GuKwhdULsg2CKNQFtKpmRW7H/eeOBw+Jzv
OXBenGV5pRsLXDiOU/yb/1fn+C7107e13y8WgzZQmK+ynI5hdoPjtdnYM7mM
7AXhDluyqYvZFz5dsWtKbzP7o9sRscNewRyAoRlDJcd0zEG4/bXVESdiFqP5
+nrzwGAQORj1Dy594ZqYV+CcdSLQXsS8Cr2OxG818cwheHGqr7l+PnMYRGtH
/R0dS8nh+Ng0aj6pY47A5srcfM1UIDkS/a3D1q5s5igIsoay1T+XkKNxz8sk
iL/IHANh4JqIRG/mddBbZ0r4GwHkWDy9+/DVrhDmOEQ/V5wt6V5MjkdwkVEf
nse8HgYuV9o3IiIn4KB77oedPHMiAsvk4reOReQkpA6rVhqrmCUQFm9+P3vI
n5yM5eoD2fw2Zik6fQ2Hg34sJANTRfnVzwbIPFCb8GdnqoF1GdoaGmV1nqzL
UHew0pjU50c9BYI3o3v/VJD5FIhb3BpsatZToX83q6a6fAH1VMSe7yzMEJI5
OSx7wsY2ubAuR+gZZVfKS1/qCmzN+2QPG/ShrkBmq0OliyNzSmytis7pHRRS
V8L5f8lcGjq11su8hfU02Dsm+dA41tMh5w9NRp7wpp6OAlOjS7mZzGVM6xmY
d+3XdqWNdRW+rBVH717NugrtogumR8Ne1DOhVj6xfZaQ+UxomusUBW0e1DfA
NuK5KWevO/UN6PaoLhzXsK6GS1DIhKCJdTVuyR7bnixiXTOtazAedu7IzZK5
1LPwzCYx7Le4Uc9Cvb2sPGVsDnUtbrb3+L0ImOU0tDh65U2HX/9MOq+FrjYy
1PW4q9NWLbbkRN3ZJ56SOu/rUNaUKG25ytF9Hb3nt/QvOPQUzA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HtIk1EYx/G3ZeW9LJ2my8u0MLXhJTWv+7nSdPOyTbdIu5ikBVGBCkFq
vRUaWFZqRRlY2D3LMpMgtQbdJQktKrCSMII0c4klmmbFnvPH+w7G+OzLec95
zmA+eTv1+RKO49b+e///tLzMSqmhta15mxz0BWpRNPggnNkap9rP3PGb8iHP
w6MdRrthE7MzJPtuKdoPMbshfzsMy43MMjwbX3P1VSCzN2zcdMPmEW+yHPk9
Se7a+8x+qN5krXlSxbwEle29quYMZn+sO8e9PiZjDoCqr6BmbqcXOQhbAxp8
1WBWwKfBcEH20ZMcDEn8oNFjP3MItBeHimsmF5FDsX9xzob3dcxhmO+5LDjG
iXk5fk5srltaKiOHY6T+UmC4hDkCRx0GTnsbPciROPvS3rG2x528As29VR+6
y5mjcHTfxoe6UuZoTNuW59V7Mcfgnfnc+Y6iheRYvIj/nKTvciPHoetHxR6/
QuZ4uKQXRH6560pWoi5jvC93WkoGglrPGybbyDxQPHFVHhLNegIiRrL9NX0u
1BMgOXX2dzJP5lS4fbPC0+29M3UVgtcfuNxxhcytxJYTkmKHMNZX4uvJwoQb
ygXUV0HT8kOtiyTzq1DVYhN4v28+9UT8qmxyXT/qRD0RPcoaK9cPZC4JsaGp
Bx1zWU/C8zd+o7/tWV8tNL8ajbHyrf4P51JPxprs0KZCOZlPhtM3Z6lZ6kg9
BenXjyTmtzpQT0HH0+jv/v321NXwVZ98k33FlroazU07jytyrKlrUN1fVKIa
m0Ndg6AWq9kRR8hcKryS06Kk12ZRF5lLQ1n9q3bpp5nU01DUGKO83cBRTxea
T6d5ppWWnoHhqIk/KsUvi/kMUdfCbuaN3QO1MyzroUVF9bboEi92Xi3MLd1T
ZS42Fpu0ePY4blfxPTafTjgfdKL1Otp/Nq3XCefh9AirGhpLMI1bzgM9LP8/
Elqvh+5wSKBVuRWt1+Ny21tpp4zdTyZSI/fe7VfQ8yAynymc15Qpur8s4fOR
Jfo9soTnNYnMGUT7G4T78aJuMgjvmzOK7t8IiXfAhF3jpPIvMVlilw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0HtMU3cUB/CLIFOUpwWpdAiI8hBBqKLgsF/KG0qhD0QRnS/MVGQyHJkY
Q1cfQKKGhSxbloW5LGNEUMcMICpSq4hIiCBJnQrZosQwUMFoNikvXXrOH+Um
Nzef+z3fc3+5vrs+V+fNEQQh68P9/9Nyjck8shqvNRzwA73Ar9UYqI9mz8P9
mu4NCVO+ZBd0igpHndvZIlwc1h+ermJ74ti02GZmE1sCw+PbX54Ss32wd3ee
ZvKpD9kPT3oCqr+/wvaHyGje56hnr0Duw2LtWg07EPtqGzybg9jBeHDz0D8O
o0vJIdhSkFHYuJsdCvNRYccKO/bqD/M7XjV2eZPDsRrK0W+K2RFojPKt97Jh
S5FqknSdrP2YvAaShpx+YSN7LZYXXF1pqpOQI2Gscwq4pWCvw0RZ6V/1IvZ6
SDsTKvNNXuQouF8qul9cxI7G1xOtNcPjS8gbEPOHfKjyAvsTDH57+/hQGDsG
keaDba2XxOSNmGjpcbY/wpbhxnVvre0LTzIQMbNH3HaOrAMqJvtMDXGcx8KY
Vhvcm7uY8lg0GxySfhrxoFxubZ0cffn9LXf3cB6HTyNj7Ae63SmPQ/yPf7u1
VJCFeGQ9mltRfpTzeJzq/k68OYTzBOg7sreZFSLKE+DdUtRU1rWI8kTkHpfm
/DnkRnkitia1OZh/JwtJ2H/4XZNNNudJOGR6Y9zpy3ky9IO7zgzWu1KejJpl
qY/XGF0oT8HzMD9pQRDnKeg0+b+dWEgWUpGeeKd9MIbmdakY6Q84Eabnfpr1
Pl0a4nVfTYWXcV8Bh1/ebU9s5/0K6/MI6ZBlv81VenGePmu/EqtcA1//0Mv7
lXDMdxspL+Q8w/q8ugwcCeoYz8vgPBNNY5VhS7qdLEYm5vgEmxfULaT5TLR2
RL8KfEY2ZCJfXtnq9DPNCyqYHMs/G1c6Ul+F9jfOmpxC7qsgPfPyv1jDfOqr
MHa5d+qYO1lQI+SynX3k2Y+or4ZiXWnzs1Bb6qvx27WHHvckc6mvRkmp+eaB
8/bU10B1Onyl3Uk76muQnRNx8Qu/GZmlP8sGDZYmp0d5nKd9gtZ6P7Szvq+l
/zFJfS0W2F4oGa56bbGQhdEo87Q89F+LwX4uew938WNv
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0H8s1HEcx/FvpCyF0PmRHFZqtIs7cufX94XocOKMcpVCsXSto5SQXCX6
pU2/t0akWcSF3WmrbNVqaSWtyB/RJqsWiVUjWlTz/vyR7/bdd4/v8/vaPvu6
pGri0ow4jov8e/97Tl8jvCDBcLdJ7Qp6AXunmFpPKbMpHHUvFZUcsyXau7d4
Z7e5kG1QH9clGC1jtkP3tZYWVQqzIx7pDfLaFczOKPlgslX/yZnsipM3jY53
GZiXomLMb97AUWY3VO7rScqIYl6B6+lTkm3WzO7Q9+64cUAvJK8En/7qglU4
swhVdW6LJb1OZE+4ZTeet89n9sJU9bsgdxtmMeqWZ936WrKELIFqvqTjuQWz
N+L7daLP1Y5kHwikWuNiGfNqfKuo8fAxYvbFicTWzeUvFpOlEHo2VmWlMctw
+FdrzcC4A9kPoe7tSb06Zn/80HREb8xiDoDaUeN92Z85EK3NUU7ydntyEIq2
r3oyUczMo2tIazrYb0cG6jsTc98mkrVA7c5yu5UGW+rBSFatH7+kJmuDMczv
jugzYT0El2V3Lw49FFAPAVJbus/mkLnQ/60NxfuqzgRLB9bXQFOaa299bhH1
NSjYxAfo48lcGKQ7eXGpLethsGroyhg5ZEM9HAY+/efBXWRtOPJyPT69Wcb6
WlxY9lvFXbWmvha3M2tUokVkTo7MN98fprhYUZcjQKwoMU9eSD0Cgz3Li1Yd
saQegVPitJ4ryWQuEhs2inV7XC2oR2LhFxvBiMCcehTW1Z8JSzMsoB6F60+r
95tls66AcLL9mXRkHnUFmnSa86JNptSj0fY4MCf7DlkbDaE8WiaoM6G+DmX9
e/NDxuZSn2EuBsVlar98IesxyCuceKCum0M9FsOyickQERmxUJ728ph9bDZ9
HwuFb+HtfpHxtO/HQlI6NBZ8f5yf3iux96Y/33yNo70SZsYNeQPnZtFeiYKK
1/cEfWyvpP81Rfu4Gfs4Os/H6a5lHuX/APeWKlw=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzA1MzHEcx/G/XA+6ZiSKolJI0lQqndN96rqurq67/xUj1VJrxs2aeZoS
Nw95GKZOIs+XkFISzVOriGrU0jjMs+axybVZepCn3fc347/999/r//59fu5p
mZoMC47jYn6/f77mxyQZN//y9SrtZNAPlBzD83IRsw0aD67shy3zKJwrvcW3
NbuTHfBwQ26H/xFmJzwy1NQsWsLsAv2DqNB7nsxueKjr3aQddCNPxu08deb1
OmZPNAbnXIrcwTwVVcvnrP+mYPZCcELdm82TmL1RPKLh3ceXrmQfSMXLZG9T
mH1xYqLeatfQJPIsmKa0WeMRsx/it7zq79Iy+0Oo6l6g7J1IDsCdwGinI4eY
Z+PpkyxOGccciJSNxvOlr13IQTgrTRu7R84cDFV2qWXoM2fyHFy7YeqcuYk5
BEabjekqF2YRaitbSlpPTiDPRZ+/VZMsglmM9fG7fJp/jifPQ6H9vLqKTuZQ
+ImL3QaUzBK8au4avcKRGWi4axCn5jqZrQN2FsgtXdsdqYeh4VaJhXERWReG
loJyvsuL9XBUJggEPd3jqIfjcUFqYnk7mZOi9Pi7CzOSWZdi2gv+5BpL1iPw
vVjg/r7dgXoEBvqkhnU+ZE4G7UJrPr1wDHUZ9BkmfdIZe+qRKBEFNJ85StZF
okL+RbPOjs5zchS+3j3sRQ/rcvhFFl1VtLJ9FN4cDgp8qmc9Ch2SfIHj89HU
o5FkbShylpF10Zge5+EgW8G64t/zOgXcw5buXPNjFPUYiP1jt49MZT0GLUbP
r4N2bB/73/2xsP9Qf7NMw7oSzk6dH/Ly6T6dEqdaitcKV4+kHofaJlG3V6cd
9ThYuHkPCMvInOq/rsJho7D/dKCQuhpVFZn7fRfbmA01voQM/Aj3taLzavhU
C6yC9lqbXa+Gh+KAMfGsLe157Ns6/MrLZDJ4mKrvD+WMHUF7Hrl5WlG2K9vz
4Hf7zRBsE9Beg1VlcyUXDRztNRAOP5/1Sd8jMe81CNjz+VtYfb/Z9X/7L6zg
Ml4=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0H9MzHEcx/GvytD1U9eJfrqafu76xeU63OsuXV11v8oN8QcSGxIKaZrv
JFtWfqRmQ4zQEtIvIT8K+TE/tpDN5ses7dDQxYauEnbvzx/12b777PF9vt//
fGauyk3PtuM4Tvfv+3/bjkUhMrW2N64Xg36g8nv7SA+YJ8Np20DIsIDZDUca
PhctezmTLMSf+5lOkrPMXhAGdW7vLWT2wfK6Rc4FScwBWFJc4zHHm1kMf/5N
woP3AeQguDzO6/JtZJ4Ffe5qy70S5hCsUFtjTmmYw7BnmndwbTBzBJ53bvrs
2O9PlqBJaq0YKGGOwuw7r8vlaczREJ0rjhoa8SPHYOvty1kFB5ljYbrYUlWm
Zp6NwWO/6gLrfMlz0JKxQB6pZpYip9qj+Pp1H3IcnF/1fHXMYp6LCH3Nj7VO
zDK4ul2tyPvmTY5Hrd2mR0UnmeVYqVWZXGXM8/Awqj2/7OkM8nykyndqhKuY
F+CJ9KOj6e10sgInlN37dCnMQJOydPfgqJfNPHC3tuV43FEyp4Ts2q73nhLW
lfDUrYkzt02jroLfvXe/n2vJvAoRrTWm4XYR9QTkW+vE0fFkPgH17t+8ZjV7
Ul+IsGVzu27pyfxC5E4Y2nteznoiLMYXB6qkrCdC+sX89sIk1tUwlkWHO5QI
qatRzfcUul7yoJ6Ej6Hfd0QbyHwSvngszf5ZOpV6Mtbl/74yYTGZT0a4r2j6
2pWsaxCqCxQm5rhT18AcKY7dGErmUpDX2FBqKGQ9Bd5evZ8OVbhRT4Xuwv7E
7FZn6qnYoDp40+WUC/U0nHlUs02QT+bT0PXDNSNzsxN17biuRcKiYelENdvX
jZ3ndXg6w9JX6eZIXY/M8EPJzwoE1PWwNHePFHlOoW6g93OwGQbk1csVTac5
mjfAP1krE52faHPHuHnOiKITL26IPtjTvnFs541YnBlzaYt4VGHbNyItbldb
r4TmuXT0y6x/VJKfto502AWEWQX1wzbz43pHOgT2Fwv7Dg/YzGUgtvzrL2XH
IO1njJ3nmc2Kv/4BOB8=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0HlIk3Ecx/FpeU5y6janea4WTU1M0w7LfeacebvNQvKotIYLCyGlKLWe
REoJy9IOLSgPUimPYYfUghlFF2URKhQihUqI1aLCI9IKv78/9IGHh9fz5sPv
4fHPLdDprXk8XuK/+/9z/rIoxNvvPDDmS0Ev8HgVLy1tHbM9JsqdbMKXMAvQ
GZjTf7DPnyyEpGd/nWM7swQC5XW9poLZC+0Ww85hLbMfJiv3paulzFL41Fgl
d/3wI6/EgOl3gamXeRW69A+vNlQzr0ZGVflF+R7mAOxrNUruyZmD0JO+pjH3
sy85GL6BkhPjh5lD8F3U61+nYl6LWZd8V8VLH3IonHdqoo6nModhg6QuW+nJ
vA5ZFUNCN5M3ORxNDpe68kqYIxD23uPrIxnzehR98wyTm73IG3D79cfeN6XM
G1F27PUF6c/l5E14F1JzyXCVORI5tdvuxq1g3oy+gLQPjg89yVvwqWJqUODM
HAWl3ekhQbcHWQGZlyGzUcsM7DpgvHa5XzJvDrCxnjPJysk8JQyN7rJTItaV
KKztKHUwu1OPxt7RwtuVkWQuGvVtvapf7WLqKkS06bITismcCkeqhf3xVqzH
IDdF3jrrJKIeg5RCQfHFJ0Lqarjy3U1jJjfqajQ0PxOdHXClHgv1lpGSvhky
F4upxFH7E0msb0WN3lKT1cL6VgR6iz3ycliPQ9lIbtXILRfqcSg0dlZqjpJ5
8ciya6xfrmY9HkfkT6f1qQLqCfgxe39HmR2ZS8AcTzu3u8iZeiLSM0I7DkrJ
XCKanzcd4hcto54Elwmh2CImc0mw9guY4d90op6MKwP86RvhfOrJMHYU1AZn
2lNPwclz+ZuKfe2op2A66HxJy34H6qkIq/oyqTSTuVRUly/pGc52pK5ZaGjw
ytMyXisgcxpYut/+KRXR3qxZeB5Pu9DQIqh7qW3EGfY9i2zW4tvGmdnoYFva
6xbtdWh5MCh+4WVDex39vznF/F5H+zHFX5/TIgM=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdznlIk3Ecx/Ens5yZZYemqanz6LJI5zGdax9tTm1zmw+VmRnZacgKXMNS
hEftsBRDOykDE+nAvJEiCa2s7FInGRUlRlRWFmZmJk0q/P7+6YGH8Xrez+e3
x2vLHn67Fcdx6r/3v9+Ja1DhtLapuT5dDHqAkexil72hzCIYI4Zc3tkwO+B0
7cec5Kde5LkQVz7v76lgdkYqX6l9lMHsBl++SfcjmNkTFqnSkj+FWQxbmWRS
8WtPsg++JCqG919n9sPdp5EFdZnMi3Dga/7puhDmJch+wj0OnsbsD157Uura
7EFejuy2pXJnHfMKDHme+q2bzxyA6oepfUdfLCAHYnhG1zpRCrMEy+TL17S8
dycHwfezw2DSRuZgDDgl1VtZ3MghWOmqNUtqmENRVi286YhmliLjfGCFf68r
OQz5Iy3vk/KYw5GctSO4fyGzDO1SU6FD13xyBGTmFqNyB7McjTbd98ZEzCtx
xulLe+olF7ICD3pUhluhzEDntljN1ivOExYA73jTOiGFzEXCrdzwYc3NedQj
YajcYnNoN5mLgiXDK94kZT0KUnhbYciJ+io8Wry7zu03WViFi5bLHn5lrCth
O37CVhbCuhIl7rsGzr51pB4N89XO7z4GshCN3vXFh4t+zqWuQt79xJQxDVlQ
4auh7YdkZA71GGwqUH2Ut5GFGPxKNVpym1iPxYP9yohtfqzH4kJlu+OxZ7Op
x2FU/U6UqyELcehWlFrPez2L+moohX2WgMNk4T9zaoR1NJff63OgrkZh4PZX
5zaTOQ2qIsRpi+7MpK6BafGJ46UNrMdjdn/r7SqenR8PY33tEX0WO1+Li96r
XwbdZudr4RW584hpnO11MFbJFA0VrOtQ63r1Wrea/o/TI3FDYE2GmAw9ntkX
pP3S2tP7elh5Lhmzq5o+4VY9zNd7hp+P2tE+AYONZkuOoy3tE9B+V56594aI
9v/11gQcKkkPz/awoT0P/0brqSHFZPBIKApYan3QmvY8fT9Hex52k6uzPh3/
pvgDJ0Mvtg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzWtI01EYx/Fh0/JSecl5TWtdNF3qtKZtU3/ObbaZulkRmlBIC03JMEtz
SX8Dg9Iuli9EXZpGQpK07ibdL5ChprCMXihlRYqVhpmO7vicF+3A4fA5Xx6e
pdkF6QY7Ho+n+Xv/vbNnPF6w+XqnOU8I+kCF5qzKS8I8D6E9baMr+MyuaA0p
nH+tfyl5EUy1U8XKWmZvHBhsiXtvYPbHuk96t+xI5iW4rTyeo53HLITcubE3
4MUS8nIclH5urjQxr8Rb7bZw5U7mYPRvdi8xRTOHoDfNpfLKVCBZhABudeAb
M3MYdhuzjIMpzBHICDpsfe/CLIbs3r1BWX0AORKXn3rdd1nGHIWoxlXbA82L
yWugulQb0ixnXovHqQHcyzF/sgRVjZnVHQ3M0bDM6X7uxmeOgST38ev6837k
dfDM6DsgljJLYXh4U9d4w5csg9+TjQV8LbMcM5nXEsbsmWPhZfwSU77PhxyH
T70T+bERzPHw2JP8YHeZNxkwtxfUhG0lc8CApazrmJz1BFz3+TA0OeRFPQHz
JxtGkhvIPAUeVp10axGyrkAMltnhq4B6Ihx/1TjKJGQuERJfx5aJJk/qSuTu
+FYSHkTmlLBOJzYXixZRVyEr++2w6KMHdRXqUsutw06sq2HiLKUL21lXQ6yu
69B2u1NP+t9cEsY8MgxTR1lfD1eR2K/ntxv19SjKab2bJmBdA/WdkV3oY10D
g+mCnbGJzNMiRf30ybtYV+paJG76IbFXL6CejPPPWvY7F5G5ZLTJhTnBjxZS
34B8xak7C86xbmNeCvpuWSZfTTtTT0G37/hojasT9VSMX+37WebpSD0VrZ0D
gi5/e+ppKD1kfZB30YG6jXk6HKnOkxoD584aOoiu8h0kJ8icTb+vQ/XwXqPi
O5mnx4zo9MHWfNoPG3N6m3k99FXiUH4Fn+bTsSUzsr1Q+Dt+dj4dznMulY6e
mYj/A/QXH+8=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzH8s1HEcx/EvSWR+xHXO70PkMHJ+Xn7cy/l5HOekmakmsoTIz1Z/5DJi
oglZtvqv9eMq0fKrlmbLj/6wVtbYihaythQjdV1FP7w///TZ3vvs8Xnu/XHO
Lk7N1ec4TvZn/t6bZ1nK39/zqLvABfSAtOlnpUERzEbQraeqrpowW2A+1/vB
tRlnMg95/SLlSDezACUlr9fyzzPbY7druDjiALMQHTze9WYPZhfE5HdJzBaF
5F1wLNMrsxpkdkfvu3AnRTuzBwLupaWH5jF74tjNbkGfiNkbrvOXyke0TmQf
ZBQpS3pymPeguqt9qXDFkewHo9XPXnWNzGIMVQrsqz2Y/ZHeljzcMOlADsCK
dFq1kMccCM9btVzTD3tyEPSdVgMT1MzBcBYuBjT6MYegKUcq+DVrR5bA3zrb
/U4l817YFMj1mxdtyaGI8hw/ON3JHIbZeu2khTlzOC7zP40dvmFDjkDNEd9R
3TlmKdY1DsGZNszA1NG24s67gk2rgZqNN6mGxmQuEv6tDt1nOqypR2LAPuP4
mBuZk+HKcze5YQOfugzrpd/cjId3Uo9C2NrQTOMhsjoKIflScZM169G4cKJC
k7mPRz0a2xwN0p6+tKIeA5lPVltpFlkdg8y4J9t1XZbUY/F4tO6ttoqsjkV+
ubZXL531OGgT3xudVbAehzCxos4sawf1eJgWWn6sL7GgHg87wdyHiy1kTo4K
UVtry33W5VjwdfEvErH9BJwSjX7PVbKegA1OtZFVbk49Eb3Lzb6242bUE2Fa
Kg6dqDalrkDBWP/gxIAJdQVe9L/6MqUlc0kYGw4/Wf7QiHoSTlfphgo0htST
sSTRrct8yOpkOMUnSfiardSVUDX6eRnUGlBXQhFc1Tfns4V6CvSFnjqT2z+l
/4j/rE6h/79KfwPqVwFG
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd03lI02Ecx/Ef3lmapZutvF2RZmvOdJrHPs5rm06dWaFBSmRQEpYnFOKi
Q0yXRRkhWChapmjYMCk7FhUpLvAgOywhyw7CVExNqezY9/kjf/Dw8Pq9n+/v
jwd+nrtzUrLMOI5T/ll/d9MzIeNva+9sy/YCvUCaz7zXz3BmGzQs7KvJsmZ2
gIBLU5b2eZKd0G9vdW17C/MqFIqrj9cfZnZBfcHd1l1yZg84RPmNFtsxe6Ev
dPrktmEPshC6TvUTiybmdWjaky4syGNeD0ebj40jCmZfpFW31PL8mP2gcDXq
+J/dySLwRlxmuGJmMYQ9lWP3XJn98WnyldmmdjeyBIKH4lD7COYA1D4TSM2/
uZI34033qPp5GXMgYlou+taFMQfhSsDWc3q9C1kKaf6h1zkS5mCMT12vF0+t
IYfAoDd+yalh3gKlNXd5FsyhKOIyZMNTq8lhKFyWMbRXyxyOyrM7Vx7rFZAj
YBCX7T14ilmG/q4Xkub1zIAx4n1sytNVJmuB3qnvht4MMhcJz+7J0mAf1iNR
VhVn6d7rTF2OygGHcqOKrJXD2JFqKxSwHoXOijNXj7TxqUdBeKjv5RyPzEWj
cehhVc0gj3o03BXqEH4TmYtB8H6ZROfMegw0Ff4bLE44UY/F1wOPpgNmHKnH
wu1W3s3SHjIXB7ko83xuJutxiNdPqjRS1hUo1zWsbTFnXQGfRG+nmAMrqCux
wGkWMvOXU1diY7go9f4HO+oqzNjdOvojcBl1FbxVFwbTG22px2NC3/ezmLeE
+iJzCeh6HF6Uf9uGegL89BZWQaetqauRIC3peCcyp65GXnOo7EYdRz0Rpv/V
jHoiii8N3OG/pfNcEg6XzD/IbrKinkT3a0k9+f95LLI2GWYevvNLm3/I/tmQ
jPGQ+V9y0YzJnAY70iWtuV4LJmORtZpF8xoE6MZmIw1zNJ/y//fA/EH2G+Jj
JiY=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1H9MzHEcx/HvTl3XD5zqopR+XfqhTkVUpFe/dF2d7q5utkMN+RnzIz+S
XyeRGRtpMqJlODTWndAJnfxYMT/y4zCbn1NjKJmoIaz3Z+Z723e3x/f5eX2/
2/1xvrOWaOYIOI6b+uf6+93/6Yx3055tMOb7gW7A/p5xw5skZhFM36+uyhMx
i2GIdNpYZfUlu6JmoF168UnmYVgVvr/kSBGzJypanmfYpDD7IDn2Q627L7Mf
GjzKD5o7fMhStJlts4R1zCPxsi/Yer6YOQguovbjr+XMIegINB2VujOH4pCt
IW/+ZW+yDE9miFqU85jDEa10KJr5dgQ5AsIbWm9JKXMkNPeFxvVRzGOgPRd4
Lea+F3ksKmShhrdy5iiIWi6OfChgHofpF/yLK897ksfjypfqAi8pczQGi+vL
Cj4NJ8fglc32itsm5liMSPhVp+j2IE+Arj0j1Wsz80TskIRLl8qY4xBWqjxx
4pY7eRJy5lZvEuqZ45G72Fi179EwMhBiPeUs2kfWA8VvGpdvymQ9AX0LZ29r
bh9KPQGWQeMvNTmTuUREw1+ALjfqiai8G5Am3E7mkiBd1vq0R8J6ElaYm3yu
KiTUk7Eg72vh6ECyPhmlRdcKv1e6Uk9B7uOzOQ8KyfoU6LqejQv46UJ9MtqD
u9ZEqMj6yZiW2ujQW+tMPRXi0Ijhd/qGUE/Fwznd9kFmMidH8BR/15TFrMsR
NiTo8/5WMfU0rAwu31NmIut55hRwcmlavfTdYOoKTNVFnl7uR+bSERYny25s
G0g9HQKfkF7HGifqGdhVMqD+xQwH6hkwnl5SLpsmoq6EbtRu+Z1CR+pK3Pbo
fF8upvPcFPgr9lp1x9meZy4TnWdaf66X2FPPRPP1uNUrLrDnqzBm58dvCRbq
UCG/uf7yAzN7nwo9oWXrDIuoW1Q4YHXsORZFnVP/36H+//l6Nbbuzo9d621H
ezX6/18EtNfA0PDY7aanLe01UO+IGGWzxYb2vG7R8PZZKKiZEG86zNE+i37f
H/H9e54tPHPZ6Ijp/ZUo6+43suE44FTR+z2fac+zhZ1vo72Wt9fy9jxb/p3/
DdY0Yck=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd03ss1WEcx/Ffx0gxl1xyOYeDGDKTa+h0Pg6O+3W1uTsss1YSmUspl5Uy
Q3JbagpN00kt69RGbVKi/qH4w9BKKjJSaxSJauf7tNWzPXv2et7P9vz1tUjN
jE7jcRzn93v/OZXrs9hwv6LnziFL0AU2mUQ2yn2Y1fH6eurykhqzDu7q6+eL
hizI+rB6L483v8ZshO6kU1UJucx85AkMBvL9mYWYTw30qtBjtoTCc1wSPSEk
74DTiXD+KzmzDTj3g2P8DGZbGL9tqE7aw2yP8oLM+QOazA4QSVJO1ynMyY5A
WPlovITZCckjUnHRghl5F1Km3nyLa2B2Rs1Qi4OIx+yCkK6yCn6FgOyK7w9K
53TcmN0QxwtuLenhk90xcPvei3R7Zg9E68rWcptNybuRLqjMHk5k9kRvpcJJ
d9yE7IWR4ZVm70Zmb1SXJD+OKmTegyrvOruSrcwiXL3oaXM2wZi8Fyc76j3i
RcxiVBf4tNs+MyID5kH9ZrXN5GLg5mhMwUQM6z7oaTW7XGjCug+mJ6OzStRY
lyBnvG1Qd2w7dQkWyrbcOHOOzPliUXwkaEqVdV80dTzyXeo0pO6HJqFC+8OM
AXU/CKcN6ttiyZw/bglGLO1n9Kn7w/VlZZ51N5mT4lPGkyWXZT3qUtRb/4zl
rpC5AEgcZXXZMtYDsFNgaJyeso16IGRZiT+ez+pSD0S7VfC4a58O9SB8Xe+O
Ld1MLg6CqdH0bM0F1oNRYDewkhbBejAqnNMmL8lYD0GY9Gn/OxHrIdDU68s7
+lGbeig2uKgNWQ65OPTf/7gwHJacf6jVokU9DL771txVpWQuHIP9orycbnXq
4Vj0XF2XOKpRj0CoR9H9aUcV6hFQzjePeiSOyb3FXa2c0ogET2i/qiFfEyvf
R0JDpfP4XO0XpXv/Mxf1178AKTcM6A==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1A1MzHEcx/Gf85Se1ElyhboZSspJD+j0uetBLnRXXTZURJQsD9NUHvqb
SWNmJMvjTWaZFBqOGJenNdFqaTJWubaizZQsKXnafX+z+/+323+ve/++v///
bv/9vVK3xqVJGGOr/37+nS1HT5ir/vb9m5ly0BfI1eVuu7CQ2wZlOTG18RJu
J7T7sfO59V5kF9w9WPBIbeB2Q3bGG5vOVG4PJPctzv+k4vaE8HZ4q0zCLUeD
pv3w0yZP8nTISivqjhm4Z+BWX8ABrzzuWWi0X7u3XMPtgyDF8KN7Um5fnH5d
qa0zTiP7QVI1LmFfMvdcaG4MsZb2qWQFbMbIZEcPc89D5pGSwvGjuQOwPiqz
t6ZtCnk+Xkhrsq4UcAei6LnROHssdxDMHSFe8ioPcjA8nHXTi9O4Q9B4t/lb
y4A7eQFSUpB06hL3QiR1bzF/kXIvQtpjo9ZwR0YORdO1rpf2GdxKLKpmFcpf
k8mLUeL6uXZdGXcYWt1Htdn2u5GBhr4BU0MKWQBeJF//+jCYdxVMLuVj13VP
oq7CRfk5j21VZKZGgcI49Y2WdzV6HfVPvP15D8fl9x+amgdcqYcjfXfrxlIJ
7xEoFpSXnNW8R2BzcJajoCezSEhKDEPRwkTqkRhy3BRWE0lmUXA6tH1DW6kL
9Sjsbs51YGvJbAnmdLkLtqN4X4I1qeYO348TqEcjuTDqk/IpWYiG1G7Sg84H
vC/Fza8yQ14670thPhsU+K5ISl0DRbX7THM2WdAgQsgZVhxyph6DTn95QJY3
WYgR9WWY4zyr90yjE/VlyL6vDQ0ZcKS+HBJPn0G7cnvqy3FF9eTZ88kO1Fdg
1ezj0fU5dtRXoN/h3v6fgbSexdLzxXssap8pd+2stqGuxStZT/dJJ1uLocUP
3xN7yraMo/Va6/UmkZkOefmDNZlXx9C8Dl8WDP5S+5EFHSzvEwnN62A3siKv
u2gEzcdh5ap5lTvkv8Ms83E032+xIOqmOAQc/fxdZfphMYu3Xo946y6IbIq3
3o8lWN8fEuj//knzCdb7m0RmetH19fT7emleZJPILNH6/pAomk+k/Ttp/r//
ACBMiJ4=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdyw8s1GEcx/Era0noCufP+XdH/0xXOnW5q+5zjnA4V62dobVUo8ipu0NW
+qkNlVibNZvZCvlb1lnK2EqHpsJkOUtbqWNFZjQaiVXzPGt5tmfPXt/38+XF
aw6dWsliseR/7t936UxKOUcaWwxJfJABFpOTUj8IqS0RV/Wwz2qeR8xGW/eD
sYIOanvIay167+dSO0HtP26qiaZ2Rc4bfVu2N7UnAjlicfWUJzEfZvcwfVMH
tTd86gUujrnUm6C7ejox4yj1FqieDsce51P7oEm9rSz+qwexL67PaBN1V6gF
SN4uKHKZcSfegRtTP+eLM6n9kDLBKf1mTb0TJwaH27OfuxELMZQ/6AsFtT88
ewdE7966Eu9CCPKmWCnUu9E19Oi91JZahIX0oSxtP5d4D/JN6smRm9QBUJ/Z
WOnNpRajx+4Oe87sQixBYfaxtoMXqfciyVXjXyyh3oeZ1WOVCQZn4v1YrHUT
xTpTSxFsafFr2uBEDPSHG2M+8YgZQFtUf2lNqyPpMmTqvDR1MmJGhhf5xvS0
ZxzSAxHHOsxR3SJmAtEtj3YemXUgXY4s38ySlEliRo7xgp4GaR/tQegyly/A
h+4HwSM0MoBTS3swNCvmc2oldD8Y7NxzJz+W2ZN+AIbZglEnEDPLzArBxNn2
GeEPO9JDEN/JbxYyxKxQfNn6/YKfivZQvH7cWHM+lfYwtKtaS5jmDaSHwa+Z
u/mznpilwD2xsLOqlHYF7lZ0OhSaaA//30w4gpiMBb/c9aRHgCdLuKZfZJMe
Aal6Ok7JpT0SlV6KQX8j7ZHLuhLaOom0oYx2JaztjOmpo+tIj0LFy/K0tTpb
0qNgsslLnFPakK6Cl+K2KabaaslQoaplgPPKdRX5r0KE6PITs8Biya3//BuN
8hG6
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0nlIFGEYx/FJLU3zqnUz3fLE+1rNI6/9ebvuem1mYBJZGZFEYlimWZtK
EaUiSdcqUZKmlSUpKitoRpCGppkpIYUHeZRo4ZWUVvi8f6wDw/CZ7/O+Lwxj
cfiULFWN4zjJv/v/c+2aFfH3NSjr0ixBL+Dm9TC5PIhZCyE+82XLPGYD5Nhs
tLk7bEHmQeGSUThaxWyM2kLpmYkTzAL4zVg2FYcym8Ouq2EkcROzJfTuHFU4
D5qTreEzr5tfVMlsgxHX2BMPMpjtUDrmHePry+yA3x8a/d9qMDtB95CjSFZp
RnZBYktPT7KY2Q2eLW8WViZ2kYU4fX+x/3kNszsUA/mfrRyYPXCtSPmuoX0n
eTfOGd/r2+LE7InAT8emUiYEZC/Udw+/7Mll9kb7Yz3bV1JmHwiOjAb2KU3J
eyAwaNYsDWf2xbD4wsL0qgnZD+N157Pmspn9obY53+eqHXMACgJTnPWrd5AD
IfSvMF+OZhaB1zXUsTJpTAZ02sxFrjlkOdAvaU8atmA9CJneNqkNqdupByEs
dfTF9dt86sG4NGnROiImy4NRnd7Ve7zIiHoIvnyrytxfRpaHIPeAyL8+gfVQ
FGh0dGrd4lEPRVF6Zs2BvWQuDGeNFFxx5TbqYRi3/3lOGEfmwmFvrTm2GMF6
ONb+363UI2DgJDTtXjWkHgHtiqWD4a/JXCRC5Vl/hFdYj4R9jBUv7CTrYihN
SsubZwyoi/FtyLbANY/MRUE3w92vL0+XehSemT5pfC/Rpy6B4Xcef5avR10C
5wCXhNavNM9J0dvUPze4pENdCquomx+THmlTj0aSY0lkdxbr0arzXAwUH3V+
VXqyHoMq5QC/U7CReix9DzXqsdBRf5o9dWMD9TjVjjhcLknzzTHTpPk41f3a
1pmLx/4k99oMy1XR2vr4defFQ+p9sXHURZ3Wx687X6ZqyFTn5TJ4FE4vBrX9
Wtu/jc3/EP0F3/8wPQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdy38s1HEcx/Fvkt+X8/t3zk0lzJyLTkf3uvNbkR+LpTRZNhWj226V1XyX
kZ+1xmaYJlsq1s8lldX8GDHDGsNWGRbZtUaZioxq9/78wWd777PH5/n+uKXn
JGTocRwX+W/+37qzqLA91tr+9LwY9ADp8of9IjmzEXy+9Af3GDILUfSyhUsc
cSNbw/hPhbS0itkeAef6hZfSmZ0xPJhQssOdWQSB5c4ufkNEFiPRv3BlbpTZ
HbZJcrm6kXkP5soGxmpzmD0w+2jeXyVh9gRe6VWsf3Mle0ORdrmtuprZB7vP
1QectWL2RZZBCSd7s4ssgSbyasZyNrMfCprFd4ccmaUwO5Gf2/nAhbwfVXm3
SlT7mP0R0Fh55/mAMzkAn43r90hvMB+ArYzfXhTILIPvrKCJH3EiB8JwdK/m
jJr5IFK1WTMLlsxyyM02tFcaHMlB0LxxzXssYw7G26OWk+3NDuRDGONrf7YW
MytwW/m+NDaaGZjq+2qRbUfmgXfKJyYzXfbUlfAVrazL75F5JVJvetdM5rCu
Qod1i+FprR11FX63mSY795G5EBwXyxomklgPwbRXRpepN+uhSBkWnK2ZtqUe
CvEzo9qeGDIXhqDlzsnyUzbUwzBucH3c5Yc19XC46X+aWloj8+G4aFPH3Wyy
oh6BgRetD9S5ZD4CJwukKRPzltQjUT1dvm3yO5mPhOS1094ZDetREHpLnIY2
LKhHIXCovaF3Skg9Gi1B4kyPbnPq0Sjzy/hYl8b6YWja44Jkv3dSP4wxQXHm
SqyA+hEI1H7ykWtk/gjuK7t7eh1Yj0HPknliygUz6jEYdFzUVglNqMdCWvHt
l7LDmHos8vJXO883G1A/utn8FnNxiC+XeOkX6uuMLebjNu93bOlcPJJT/B6p
xRsK3f946Ik8V01b1nTmt/SOeJhuf5inrfyuM5eAhcDVdZXPnOIv9nYgGQ==

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdz39MzHEcx/HvQlcROXWV4uqkck6pE0W513X9uFLpfoROlF8zC4n8GMVX
CKlMwjTMj41kbn5ULKy7fhhak7WSZvMzTFjWTT9shfX+/KHv9t13j+9zr+8P
z9UZ2nVWHMdp/p7/rsNHt0KUVPngdroEdAOyARfvjBBmG9h37TDV2DE7IK8/
4GJnmyfZESVvjoRrLjG7IO5VrcqSxeyOoy/U/E4VswcEb+oqdK7MEjyf52fz
sNOD7IXTs26W9ZmZvZGkcvh5PI/ZF0G11h2qJcxS3EJItq+YWYZ7qXvlrT/F
ZD/oV7gnn9nGPBtmc1qLwJ05AAXhu195Vk0lB+LHoTOlvIRZDmte39V+agp5
Doo0b79dkzIH4aPteW95kTt5Ln6PmTn5rJh5Hho31efWG93IwfDhJRuWRDCH
wOrKqh2FryeT50NV9bU46BjzAiSFdqz16nAlh8I2M96h08wchqzugEdCJfNC
CKRVBaIKF7ICzT19puZUZuBla86z/FAyDxT1pqk3tTpTV8LJOWhmUy6ZV4K3
ke/t+SiiHo7SZ8Lqi0Yn6uH4sF/ou2UNmVOheousV2fFugrGKS0S6WdH6hFI
fVm5smUXmY9Ayur3H2RfJlGPRHJqrdqwjMxHIuWA3ND+RUg9Csuja+wGbpH5
KPzKNzqvsEykHo1P/hL55hlkPhqKpZaUBDfW1QgNjDs8Po11NZ62eVl+j2M9
Bl2vfQ765zpQj4Gncv3R7YNkLhbbZ5ScLL7Deuz/7+MWIUVwudQtkj1/Ea5O
i+2YU8v2cUguvXnJScb2cbDfKOw6ksl6PGKuG8unn5tAPR5DnGYoLYvMJWDi
N0dRt2g89QTMCvPT13yyp74Y02JPtxnK7KgvRr+sOPvaRlvqiZDdHW09t0gw
bCRCXvi9V2mizo+wKRFWHtKBsTfG0V6DMmVdw2NXeh80aOiZoDNkUuc1eHG/
1dLeN5b2mhF7LcSDTY3B3fR90OK2MaPEb7kN7bV40hC2M6uabNJi974Bc3q5
Ne11/xs65J1In79HTP/D65BzoeWh6N0o2o8wp8dSQ6Bxq2RIMbzX0//2K/4A
99lEbw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzg0s1HEcx/H/ULgooqu4OpSIXOXhQuRzdzich3tg1SnryVSXLGU9jrO1
WjZ6UlvLmsqsEENCzUOtlZR0WttZa9qUIkqxkqSH3fe3pv/233+v//v/+e3v
uiVDnWrGcZzqz/33abqGw/hJdXeqdW6gFxgrscx+I2G2Qp68+APPjtkOh3Ol
/ItGV7IjFr0tTxaWMM+Dzs5+0GMDswDidn2mgxuzC158T5gMGHAhu2Hbrgvv
i28yL8bpzVaKB/nMS6CTlY+9UjJ7IsanJyRNwOyFlNeXG/b2CsnLYFZjnZid
wizCPkHQkScDC8krMGOpsO1nBvNKHBpd0Z3szOwLs5LuZJ5hAdkP/U4D1qKD
zP7QHjsiL7VlDoCCZygqahaQxVAG2rxLC2Zehf3NfrLOFmdyIHanGVMs0pmD
4JNRmt0hYg5G3OqC2roxJ/JqdHppXvKamEOQlGNcu1XCHIqiq07r2h/MJ6/B
JYkhLz6GOQzyiH07zCfmkQFLwba3oSfJemDWaKVmyJd1CbLGPaoetc+lLsE9
xTUvwwYyJ0WjYH16mzvrUhjPbdJWPONTl+FKrk1NiYqsl2HxHkP39zmsh+PH
nuKcuO1zqIfD1eLV65EJR+oR8O/K3+9+m6yPQKu3dKgik/VIaL+8FLv/dKAe
CeldzUJvIetyPN287vNIN+ty9J/PlNwII3NRuK9svai/PZt6FPJrrb2be8hc
NCKb+nfCYE89GiG+scdnbiJzMXCVpJ3ImrSjHoOspYVnz9SQOQWqnCvquxSz
qCtgP+jIH+bPpB4Ln1BRYkufLfVYyBInxNMiWY9DfEVBRGod6/+Zi596nj5+
6nlcAm4Nn1ru1MF6AqKvV5a5F9H/cMqpeyiha2toft44g75X4qttY+5EgI3J
rUoYGl6MGseocyqcOmre0LORR3sVhJMdjwOHyXoVmh4Gf/TsZXsVtN6no54e
YHs1/PKHvklarWmvRnVlRqEo2Yr2ahzKGb+rK5tOezWW1VpMFxdY0l4DYVRc
EL9sGu01iF2VU98rMqe9Bmu1vpWZbr/CTHsNPgWNT0pFX03mEsl9JuOffwPH
HEey
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HsslXEcx/EHK+kguZzckoOiszq5H5LOxzXX45wjd1mrGTFLyR/d1tGs
QsKssbQxE6vISuY2Ra1a1B9aO5qscrQWuUVjJKqd7+8Pnu3Zs9fz/n5/e/56
BMdOKlK1OY6L+Hf/f2quGQk/prXrYaYd6AWedTXVF3kyb4I8TyyM0WE2QkbD
hQqDfgHZFNVDvZ01pczmmPDNX6iLZbbGWMWpyXQHZlvkKbLDRuZtyXYYMcwS
2vcxO6B37qjDrjLmXWhuy/X+lsLsBK2RoaRQS2YhdjTkLKuf7yDvwYCUX9mY
xCzCW58C19lJG7Iz7m6ptLl9idkFfP031YNT28mukI9XL54tZHbDmeA+flM0
szumv+o6t/Zakz2Qohiv609h9kRcbM6t9FUrshj17grV7xJmL8jahAJxALM3
9Et8M7vVluT9SOY9ia8yYfbBstZsWnuiBfkAVu5tFydZMPtCqGoy3lRpTj6I
R1ytssiIWYITqp0iXtk2MpBg51XzIZasBGS/Hr9uD2TdD3NLL18MD/Gp+yFv
TPBUHUrm/NG/9L3wyh0z6v4YzTN2yj5O5gIQePuLcUcB6wFo6Brk91mzHohP
8TeuXl8wpR4IrwyJa/E21oOQdlP7jIEb60EIb/kZJhebUA+GusrT42O5MfVg
TJgkpM4XkLlDcOm0clTnsr7OXAjep87rOXVspR6CZN3aW1ZBZC4Uu6X2pkFZ
rIdC4JdWkLtiRD0MP4Yd8/ddJivD0GzV2PYufAv1cOz1FR1++s2AejiqVLzF
eg8e9Qh0v9o/5TSqTz0CKoNr6YtSmuciEXB42XNDsCH1SJTm67R/PrKZunSt
ldJ150dhpmXgz0UzPepRcCueXPDrIXMylI3mnPdf0NUYMkx7L634izbSvAw5
930kj2o5jXtktL8o0ezL13bIwdNpOjderkX7csQluj44bbeqme9ZZ04Bzf9G
m/YVa7tSsfa8HgUixJfaRkU69P3R0LYVLvHuL0v+AlOoNDU=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0HlIk3Ecx/EnLa80t3LzmNfMDmxaTdPM2T4zNY/lnFqWGR0kGRVpM+xu
kJHVJO0+/qhMwjIMu+wUsQwhLVd0kxoSRRlOo7LLVez7/ccHfjy8njcf+PHI
l63NyLMTBEH77/x/2x6LWjr36q26VUGgD6guduvKVbGdsFcbkTrPgS3CclVN
kqJVTvaAondbq+QQ2wu7A/1+fVnK9sX7J/p3yUp2IEKLNIYT1kByEOZfTar8
1M4OhrLBMcBcxR4Pp32+ulsG9kSUaG5PitGwQ+AaO97d3ZWtwCnZQK24KoAc
hmv+pvfNyewpyJzb2X3PjT0Vz7cUlLjU+pOVqC0b+1KnYIcjxnzRnG/1I0cg
c7lqj6yFPQ090gV1dn98yZE4N5DdPukGOwobciq29cazp+NSlNjvtQM7GqZn
2ZZ3ZTLyDGSVNrUWqdgxWHP/0Yyd9mwVNijvdhXn+pBjsTFzj6LF6k2eiReW
U2fuGNhqVJ+/WeoiZwO656FLnAe8bDYC0Te2d0rCyIIG+ZWe43ZJuGtQUHq8
r7DQk3ocWuuzXIK9ycY45DxyW3nsrZT6LCxr6OofvEI2zkJCXvdl01Hu8ZjQ
oT+9fgT3eCyOjHV40yahngCTZ/v+b4VkYwK2LlSrrmRxT0SaQbT5cLMH9URs
frrRTVhCFmbD0X941r3HY6jPRnDxsAORvWQhCXX9Pic35XNPwpG3pmEdfaOp
JyN3R3jOiw9kYzIKnn1pWirnngKRYqrsoVVMPQWh4ol9x80i6qkw1MSoL1WS
jamQa1bsXj/IXQuZV/eHiv3ctTg7NuVVRBP3OUhfHfLgqzf3OUN6Gq5Zyif7
tI2inoaLsgv1j1Pdqesg7vGQWqTcdbALDPk5ssaVejoCBtseTLe42IwhNqaj
vMT+eucicmM6Wppji4tuOtFejzYfy8eDIt7rYbls/rNV4kx7PbRR2+u7w+xp
r6f/IdA+A9k5ytp1QVa1bT/Exgy672+bGzPQG/1zMC7sm81CJsLLPn/XNP5Q
/wViczCD
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJw1y38s1HEcx/EvFkbmR+fy2/lRoboldX7k3Mudw51fm6tMMmqLPyxG1oYt
3zSrjaVJtWV0pSg3FhvFrU5tmmldYqLEapak5udSLlk1789n++yzx/v5efuc
LEg9Zc5xXNS/+//dPIsy4ZEufUeeL2iAwtcXngbKmK1RmfmjYk7I7AD3gerc
vg8+ZAGExruNgnZmF1xvzpz0Lmb2QPoJyaqrglkERUJkfo0tsy8WxPFrziMi
sj9cioe65xuZd6Lodp6uPJ85AO8XAj7fCGEOwrfeSos0K+Y9mFgfWrv42Jss
RrdX9Zd+FfM+XPHKWh6b9yIHQ9NTu1F/jnk/fu5asjzrwRwCxx23jr4Z9iQf
QIlmSq3MYT6IiQyhVe2wB1kC7Z+wqrBK5lCsjgyklGy4k8Mg7TLaNTczh8PE
G7URacwR8J+3+RXc40Y+hK8GVf3NNVdyJMYXtU1PzjBLcb+195KND3MUxnPr
CtrbXMgyVEwbis6nMAOd3B2+yoHMA87JOaEzj7ZTj4Ym2Jp7pyHz0QiDnzmW
hdTlkDxIzVSXkXk5siRSy8lXztQV+H7Z2CkbJvMKiKadrzWlsx6D3TWxRvlL
AfUYlI2W2HHZZE6JBn601L59G3UlbnyqNptacqIei4w4g43pIZmPxb2IkIGW
BtbjkF2Y+Xtw1pF6HPRudQ09Cw7U4xFu1GtffCTz8XCa7XuuS6X/nAqByX4C
5Wm2r4Knbv3t8VDW1VjZ6E2vsGL7auyVig8bZuyoJ6B/xV5zrHAr9QR0tBfU
iTOsqSeitNz0LK/VknoiWvRjwkGPLdSTYGvRVjp31Yx6EsxFQSZb3bpssydT
X9o0n4yFcNOGXLxKPYU8I/sLZRQACw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1AlMk3ccxvF3LcWjUvGqaFGOjQWVkXEjgn2obaUILT1okcM0myzLxkQG
GeBC9mImCCIRZW7DrBlsEw0Tw4QhsqPMIVMCCRhwIZvMkIwrxiYUGQzHXPj9
l9AmTfPp9336f9M09Xst15At4Dgu+/nzv9flh0MuTW3rbHnbH/QGivXFx20x
zKsx/ttiZJk7syem78oEjiE/8mYMStyvmq8xe2Hmcsafk6eYvRH6hrWk2sjs
C7cZhaAokNkf49Gf6r+d9SW/BB/Pyp6QH5hfRmnUwlsjFcyB+CzZJpk1Me8G
ipwxu7yYg/DRUMdIa7cPORhTk977Tx5lfhXp9sEMlZA5BPWvPylta91JDn1+
/mxjO5jDkFFRaI8TM4fDeDS2UvbLDnIEpnPPhwcomSMR2XChvrXXmxyFGM1A
D+/LHA3nzvu1I1Uy8l5cF/VpJkTMMSi1qts/PradvA97+ifWaLXMsThVYYvz
9mOOw+SPmkt189vI+yH9XX6r4CKzHCNS0dV+HTNwMufxmcYHXsvmga7ehlhr
GZmLxyddNmG5mfV4iHLFYe90b6WuwBP5Mc0jEZlXoE43P2pdklI/AGWAJGh0
A5k/gN6Ficqyr7ZQVyJ2tuth1REyr8TDtOryqrnN1FUIHzxbGHCLzKvwyriM
X+vGuhpHTqsn437eRF2NpKgP2seCydxBhKjrOhL7NlI/CGte1t/3JjZQT8DT
yuatWU4yn4D8lusVKSdY1yBzVUOdTMW6Bkq+6FlIOeuJkFucmVoZ64nY0bQ4
nBnF+iHIvMYmas57Uj+E/KZ98m8ayFwS9vZ3fn7nD9aTULyrZz5bx3qyyz4Z
Hjkbp0/nsa7Fuk0/FR6fXE9dixzFue8l9RLqOnx594v3xAVkXgdLemjzu/50
PZeyco8UNMX6vxl4m32ei+0u13N6LHH6JWsB2+uh/bpald3mQXs9fP7p6412
rKW9Hk89OkoXI9bR3gCB7+4FcRMZBlyJv919ZxvbG9A9s96YnkfdbsDAzSHn
r3+JaW9c2WFceR5vxLkPhTdHs9j5RryYeHE4/QqZM8FxY+BZyZY1tDe57E0r
789ucrn/VLQ059YGZ6ymfSrS99Qk9BfR/fEutqe67M24NCyevxxBHWb0bXdM
1Xqy880IuuHmHlm9ivZm1Izlv6+YI3MWhJ19PBdvZ/dvQWPnA+k9bxHtLSix
3f9O+khIewuW/98FtE+j3yNH+zT6fSzJl/cutqfR97G4bO4wxMJrJ6YuvED7
w/9f/y+IeJ9o
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0H8s1HEcx/Gvs3LX6QediyI/ii6ESKIfXo47P/LjuKNfTFmtH6oTakbq
1Gqafokt1FhhFmlrafrdtdZGP5h+kmqVatQqdqF0nWr3/vzhvtt33z2+z8/7
++PjnKZO2MDjOC7p3/n/ajz6g8WJl69fTHcB3YA2wJannsfMR4HC2iPS4Eye
giaRKGdpO7MITV29uSHFzLZ4neHzVryR2R5lZmmzCoOYnSCz/ChbI2R2webx
td1tz5zIsyHxSy1LLmd2Q+zPqpSS9cwSvDr+iQvyZnbHl0mHm6oNjmRPuFmN
tp+/yeyFK2WDlfEKZh8k1d7dlNo9kzwfH5tLQh+fZPaFRjd0Q+rL7AfD09Lj
XVUO5AXomZuqehLG7A950gOH0q/25IU4wOfrG9XMAcgrkBR/dmVehDpeRmt+
1QxyIHZr97i22TIHQZ35oX1bzXTyYvAE+xcdkjAvwbhtmu2GPjvyUrxS7hK/
LmdeBjNRoc7wx5YcDBnfXP/jIjOQcsyz/I2arAHkpwQDdR6shyD7ZXWLVec0
6iGwmebv8WgfmZPiYbNqwmw71qU43fytyEHAeigqzt0JHWwUUw/FrWvW/P5S
MheGgj7n2+8jWQ+DIXPYVXDPhroMm9cP5njPIWtkOJqxs36NUkRdjrZ1Kwd0
XVOpy3EpI0u3OofMhaPoSK1roznr4Zgvr7ga9ciaegTO1LTYHHtO1kTg5LvD
Zm8GWI/E2h0pv+/3WlGPhPxm3xZ0kLkoODTonycHsB6FZIuzFTNkrC+HznBt
1T6LKdSXo2GJyybJ3cnUo6HY6v5g0I71aNS0Vu8SZk+iHoOhiVcL9P6W1GPQ
ceXZj86fQuqx8DvydThEK6AeC8eImEBx/TjqccjdO3InvX489Tj0X+r4k29D
6zkFfnme2F23lQwFDhanB+U5WtB6BYp7svKkw2StAkLzxtzPJWY0H4/ogL3N
PV7mNG9iTTzyK5/cEL8ja03MJeB74IhB6kXfhwST+QTUXX8hvm9P/6M16Zxy
7POgNJlXgufkPiJs0Acb55W0X7+M5lRYsdr3QqbLqNFQjX2fRjX2eVoVfe8n
mk8cazAPGa1JpP0aCP4LE/VpRw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HtMk1cYx/Ej1MsAHYKrCEVo1QXBEAQpYNX+uAiVApa20MuGioaEDCPe
NXjhTbzEeGHLJGxTphFDqlYYuCy4oabDy4yEeEWW6T/gNkMTFTfnKhJR0+fE
nJekIZ9+z3Pe9rxvql5Zba4IYIxVvXu9/+//G9IrS37qbK/SgN6AovOXm4M6
7gmod3zvLhnPHYqJdeWWr+6pyVPw9fbTr282ckcgLnq5akk1twqrun42NOu4
Y9HtbY1+HsatwaOEp0e1A7HkmZj9223bQRf3p+hPazmr28odh6IV6kbHIu54
BOVc8x0I4p6D0S+dvjXXYsiJ2L97We/GNdxJmKX4bjQhinsu1I9dcddvTCcn
o0l/ZcReyZ2CeSGpe3u80eR5qLSyW8ZN3KlYF9jmm/mHiqxFeEVFsSWFOw0n
2vqSau5FkdORbWqa4TjCnYEy7+qBZ2Hc8/Hviqv6i82RZB0ub23YeVzJvQDf
Kp9cL3dNIy/Enzn7ap+Wcy/CkbzkzRE2bj1Wnm/L6HoQQQZ6jV3OfjVZAk5o
GlVrz02lnonmh/13e31K6pnQnjaX5W8jsyz8NbbhZcc3n1DPQvoX+uRDU8ks
GyMnFerHt6ZQz0ZS2S7XxVNklgODt+/SpAO85yBi+YU7dbm8L0b7P5HHayrD
qS/GYMP6zBY9meVi4Kg29cHhMOq5iHaP3P88bTL1PJhWx3f/Ny2Ueh5Cwru2
rB38mLoB7gWayrjLZMmAH6LOdtwx8r4EAbHxw8HuEOoys3zcPt/74ndfMPV8
xLzp6U4fCqJuRE/kkLc+lCwZMSO/4b7zFO8FSDn05P9Mz0fUCzDnR8U4bd14
6oWoqR3+terMOOqFKD44N0GxR0G9CAVptR2PEgOpF2HHsbsXlP1ktlTWl4r7
MZO4HiZxf8mEGENhhvLMWL89JgQHttR4D4+h+WJxPWSWiuH/PQmgeZmZWTTM
2ODW6c81MZo30/We6/3zZjqvV34zC2zO5Nb1mlG/YRG7ZJHNW/AsY/hNVuJL
mreKHVa6vyM0bxX391hl1y8R10NmqURc75F1Vip+X5SK15NKZedXCldnn/KG
iu4Hs8nun032vNjE9R4b2lur6xM/m0DzdvH5g118/iS7uL/HLn4+5hDPEw7x
PCWZPTIzp2ye+2+al9nzYf1bBHnHVA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd02tIk1Ecx/GlLp0mzUvT6axpXqboNF1eU3/bnPfLMMUmgWL5QkQkLZTC
tey6dBLNIGSEZaFkWs5CSjOLirRXZVJmSNGSkBITRI1FF/Y/hB54ePg8X/6H
87w4/hW1hZV2HA5H+ff597atxVRB8b3hgeoA0Ad08KVddQpmJ9jz9d6nvZj5
6OMt1hV99Sd7Ym5hoj9lkNkbVmnjuEbPLAJ3/87CTg2zGCUD46UnQpgDcEkb
5Tq+KiYHYipYFqV7zByMO5UPTVcvMEtgclsJdC5nDkOOMbJYGcQcDiczWqZn
d5Cl6ElUVF/QMkfhbJdRphYz78K8yKgY/bCdHA3fXo2ea2COgbLIGstNZ5bB
X7LFw2HVj7wb9/da7vqcYo7FZE9H7XNn5jioxLefdr0QkeNxubVmbeYMcwJ4
PsKy5lDmRPxq+Kitn/IlJ+FG7/m2pUjmPTAdelMk++JDToYd72S8XsKcgtEC
99nhm0JyKoRb2xM7E5iBd25LwqrD3jbrAG6tS0zNMy/qcoQPOmyObSPr5DAN
LbT48VhXQNO0oGpdFlBXYOilF9daTuYoUTzN1Z87to26ElUHlxsjQ8icNByY
GRnp/uZJPQ2y14aGoAdkjgqZ2a3vzRrWVdCUPcks3edBPR2hgY6WlQyyLh2r
1x21Frk79Qw0WyoMlltu1DMQ4Sb50fGKTz0TR0LbjRfNZF0mIpKlRY/mXKln
wbUuOmmymazLQozh+4p8jEc9G93DbwUTIi71bNiJw3669FpTbT1nvXU5sN0v
O5rPXW9dLpquTI4IPtlTz9vQ8+Bi33d03riJej7qe5NSzdc41PM39IIN8wXI
jTs+9FnK9levn4caJaXR/XUBv+m8avrfNZvH/vsPp24EZA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0wtMjXEYx/FXSrajhDoV3VcS3S+616/7/XS66Lg0s6bVyuhuSjphtqba
krTG0ArrVMh2WgolhQhNI6S5NGkSsVNx6ISd52+rd3v37vN+n+fdu3d7TZP2
xSarcBwX9vf8d1UeU778LdKOlnQz0A0UbdKYlXkwL4dFp3GqD49ZCzXS86p5
b03J2qgcnvwikzDrIe/ghLuikNkAx5xHB9+ImE0wPDfXds2S2QzxE817w6ZN
yObI3JoyUi1lXo9iV3naqxLmDbDZtudFq4h5IxqPTFs0ODJbQ60iqjtu3phs
i+p7lWesDzHbY77fePKcM7MDXG7cn1GMG5EdkXO1zmN3GrMTap/puy6VGZKd
kVpzUt2xntkF21Y4PelfybwZGuMus2rZBmRXjPVaP9Z6t47shtLnoqkPZczu
qIoa9DL+tZbsgZtX+i48qmX2xEVDtfLBBGYvXN0V6doaxOyNUh178wxbZh94
tnPN3gp9si8KW4aqBCnMgE3xy508mZ7SYsDsOBKGqsicHypGswv8Z3Wp+8Gt
t6jgbDuZ88c3zS13rOxY90ciF8cXVvCpB+Buaff+vE6yOGBRD0SJfECiP6dD
PRClugMnZjLJXBA2fx4baVJnPQiCbK2CU73a1INRnpEr2RFHFgcjMen9qPX4
GuohUDdSje95ShaH4GGrtCErg/VQfLT6fsBByHooeoRdp8Xtq6mHwVckSxSs
W0V9kblwTLy2PGp3WIt6OHI7hF5uPzSpR0DQVB6ULNWgHoH6vro8Xg7rkbDx
to3vHGM9Eun3224NXudRj6Lvr049Cl/d5Qp/22XUBbjUMcR/YKBGXQDe0ub8
T5VLqEdD+T+rUI9eOM8JF3YIkV8kv50uoeeLhQvnuxbNczEQbXe8nGU276vc
j6H3m1FaHAMVk41yXuNvpbti4FQ2OevX9VNpLnbRfuz//T/x7DFn
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HlI02Ecx/FfaeXRMdPWdDM3O8gDK6eu1NxnNu9tTkPEKyUa0WGSHZSl
rchspHZJdDgDsyyyQsaa5pElRQoGKRVluA47MMuCWlqUFfs+f9QDXx5ez5vv
v49kdUGqbiLHcTF/5u9tP5/k/DRzS+MGX9AD3icapAORzE6IfDl1znZHZh42
Pc0Pze6RkD1glQXIt1cxC3Cl+p25Yh2zCPnPGxzbIpjFmJ/VvqTZk9kXPSP7
bLIXYvI8DF9UCgvPMS/AGrcJntmFzAvRkHOCvzWU2R8uyrujh1yYA9Gz0634
bbUPOQgP+1QZdSrmxZDUptWJBuaQl8B4wadt1TrmYBS1J5WfkzFL0R5tnGy6
6U0OQf+TIk6tYQ6F/6VSruKHiByGk+X5Y/0HmGUoEHSV1DozL8UtUXtN3w0h
eRlWJAyIPiYwh0MdUWkyj3qRIxA2PnR9sII5EvmppyxiAfNyOG9W817f8iRH
4ZH+tM18kFmOZFFeU4g3M9B/du1mw2WB3XpA0vW5bKkfmVPA7PnG+sU6m7oC
TiWHhd25ZC4an6endfotYv2PLakr50bxqa/AV0tps+3pLOr/mVNia/NtcWci
60potvB2nbjjQT0GgtzW3spYsj4GpzV7v79yYT0Wg+v9wn+WuVOPxflw6b16
40zqcRh2z9DZDGR9HEbrppQMKliP/9f6eLg6XCkaOu5GPQFbGq8ZtEVkfQLk
6V+yNULWEyFRrDVs+8WjnogWrypj8wiZS8KhYN2zM3msJ+GasMHSmzSDugqa
hsoYnXkadRWO7Hdosua4UFcjM+Bo/P0drtTVaLxaUBWU5URdg0+mBz+LZzlT
12As8Nju+o1kLhmBJsfJYZVTqCejvuUxv1s0iboWKtkey6sgB7uhRXFNXyv/
BVmvhf0/mGh3hxbpmcFXC33H5fb9FIws+/4rOshmN1IgrfjwTdExJv8NFPEZ
/g==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1H9MzHEcx/Fv96OQckfqCNWNMlrTJemXe3VdV/px3Q+/lvyc+COh/Jhh
6ytaE1IMRYz8aCtlmcSi3WbVsIhUzHHsLNy068cWWSvs3p8/6rN9993j+9z7
/f3v47d1tyFDwHGc9t/z/+04fUrP1fWNdZly0AfcDHexDC5lnoQ3/ZnlzUJm
Cao4bc6nTj+yByois2ouVDLL0Pn2p/3KfuY56Cy/La/UMPuiFyKffk9mObw/
Xhrbbvclz8eH9oCrpQ+Z/fHJZvdXFjIvRHr3gVWhRuZF0Mmbeh4EMgeiq/nb
OyeOOQhlb2t1Lxp8yEvQmmlsF6iZg1E1EOBlt8wjKyAZym3I3cMcgrS1pTvS
pzIvhVuOIrIjby45FL8f59kkoczLsHumSNb1ZA45DLzAbJumZl6OkrEPxc+G
vcnhaNw2JGqsZo7AGTdbme8a5khktbyKyBcyR+HIVPFqQ9NscjQkYmvhtPXM
KyDO4neN/phFVuKa2GRoPcQMOEUsfvRqMpkHaqXPe35UyKjH4MRIR1ddLJmP
wfONdweawlhXoVyqdH497EVdBavZkH3UmfVY5MzK6u7NZT0Wt8xfOjp/e1JX
Y2vT54HR+2RejfN89A2pivU4qBe4B1qkrMfh2PGn5oummdQ1OOXVfnYom8xr
ICnI3map8KAej03d9Rs7DpL5eOw4L9jnFsJ6Al5uWdc/+H4G9QQE9hXVNpwh
cysRrLn0KLFtOvWViFIkF7hvllJPhLfM+r3krIR6IlI0Lc1fo8lcEk4qMsyX
N7OehNhVI8vEGnfqydipKn7ifp3MJ0N7pyguo96Negp8RtteLO+bQj0FxceF
Dy0byJwWJda9h1W/XKhroT8VvFiUL6KeOt58KvZWRyrvVXDUdfBJSAn3rBI7
DN34zuuQHJbbYA0SOmyaYE4/fj/0cBXWHLKdc6J5/fh9Jv2EeQMc942A5g0T
/m/A2jRFbY58TOmYn2DOCIHvoj+u1SMOw4iQ072/YkzDDvNG2MP/jKqCepR/
ARisPlM=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0WlIFHEcxvGpbFPX1EzLo3Iz7TCPTF3La5/1PnMvLY+iy5AMRNSulZrK
IsM0jwo0CBLUMg1XpLQXbqnVEkaSmkREZZQZ4YqKrNla4e//IgeG4TPfeWZe
zPqDOYrMxRzHJf09/13nD71kVXLb45ZsF9ANaMZVk9FSZlNI3a+MKcyYrfH6
6afu32/Xk22hq+m7bVfHbI9WjVxTkMe8BhUZ2dCEMosgmBSrWk2ZXXCj/3Cb
26CI7AqD/f0iVDNvhN8D1e6gLObN4B8pL/OhzO44MGXMsbBl9sDXe56Tm587
k72gcrs51y5j3obj5zVNJVPryD4oS68pLitg3o7gtAOz+hXMvjj07kv3uSdr
yX5oau/yFh9l9sebhuqcZ+bMYvwYqt0jrVhDDsDulLzqrDkn8g4ENacOeV5n
3omMIy/2juxjDkSh9ozbK3vmINzNtjM23HUkB6Orr2NaYMEcAqHdQH5nlQM5
FLGW4Y8U5cwS+ATXimYSmQHjvbUB6Q5kHrDtfa8zfrenLoVQK5J4q8m8FMPv
FbnnBKyHwfKke8qHytXUw/C45Fq9umUV9XC4aEyrexLJfDjGds4Yw7xYj4Cu
v+higc6OegQibn20aS8mc5EQV3ZnxdqwHok9MWXWnzttqUfB85sTb25C5qOg
Hji1nNvPejQ89KXND8tWUo9GQsDZh8NeZC4GguRFrfouG+oxyLjgmzY0QuZi
4dPhtOlzAeux0A26Tv6yWEE9Dqe2PDdkJllTj8OEsSP1/DIyF49d90sjM9uW
U4/HHCef259vRT0B4apZ8dIoS+oJ6JmwUqblWlBPRM2g0FDnL6SeiJbmnCqv
dFPqu2DwqCisP2ZGfYG5pAX7JPQ66kerrM2py7Ah7sZgWgMZMjgbe1/u0JN5
GV70hJzI76DvaWXwaDURiEuX0V6OS+XZgWpnMuT0fwW0l6N8OE8dNk1dK4e8
xGeryUUT2isgXNJ0erRyEe0XmFfA9+rPaanWIJnfK5DXGCTR3OFor/zfUGKx
yH1G2Dg7/zyvXLBX0vvHJX8AqYFEKg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HtMjXEcx/HHWaU6y6Xr6X5HSqpT6JDzOVGHLqdTyaGLMG1tRSihFs/c
ipi1WlFa0Q1t5bKEhtMsY81EnCHWHyh/1CrpuhJ2vr8/Os/222+v5/39Pn8+
znszYlIEHMcp/53/t/YZllrGtbTdTXMBvYB4rMffaT2zIe5NPs/eZ8i8BNKo
xp1hr53J5pBY9PjHlzOL0Nmr8ohIYbaDdLlN1IyY2QlBs/m/TcecyC7QL7Vq
XvyO2Q15hxyrVVeYl6G59Uhg3y7mFbjx7Wpd1yrmlUiOk536yjF74WN+UfW2
c45kb/QaPzk2uoDZB95d8uALhQ5kX5hYZex5b8Hshyut8qRItT1ZDD03g47m
BGZ/hG7vtC8ZtCMHoCVjNGmggnkNbBpiy8ZSmddCtT2zPHXOlrwO3T7FZanX
mAPhPldYNGXNLMH1oeTFP4tsyOuRfMBUMuHFvAGKHbm+IxprchDK5X7ZIhXz
Rgy+GUkP8mGWYqHdvh9Bl0VkoEZQVeouIfNAZklTnpHairoMPXO2bQlZZF6G
0ekXHV8+W1IPhldLTdxMG5kPxq2qvjueSaxvwjPHClGlEeubcPrM8y9lagvq
m/FhRfqe+lYyvxlxn/TPF+SyHoLHB70mYgWshyDnuGe/xt2ceiiUq6tdskRk
XsecHG5HFxSvGTKjLofDo8wH+Z1kbgv6PX4d91WyvgV1EvHLhkpT6ltRnDJc
nNhA5nXMhWHAbGfK+HnWwzBZu/DEdxnr4fPNh+Nponu7g5D1CIxfaLJK+r2U
egSMayZ3hXaQuUjYN85oEteyHokNfhH5i3azroCHwtU8ZD/rCtS+qskWZi2i
HjXffBQ0JgWpUwoT6kpUaIRT9QFCraGEa1ipJv6mMc0rkfby4dPuR9TVSgzf
fzubZ2FE+9HIOTndnnbbgPajMRQ4/SfYm8xHz59X63QuBtr/jYD2YxB90ddT
76we7etYHQOB08ppYeOMVLsfC1W8X9NhlzmtETv/e7yO1Trz3DaILw1OyNRT
0r8v70H5
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxV0nlIFGEYx/FZ3bzTvLU186pcNfG+svytZ7oeu5tW2IEJm5GRbWCHKY1F
GKibpf1hSaZEWVkiXpF4pJl0/JFSEhaWSVlRuWqRmtnBPm/gwDB85vs+78vA
OGfmKJQ6HMdJ/97/ntpLE2GT1tLemO0CeoECy/POZyTMBpgWtx99ZMG8DOPp
R3StnzmTrRDy9Hqn3wVmOwwNHzTfn8XsgDXDPqHKQGYn8NKxHdW/nMguqOqq
9EzvZ3bDfO7oO3Ex82qUCDpELjJmd+z6vpBjYsXsgV44nlz1eCXZC4lzzaNT
cmZvONemXXEYcST7QNBXVJxzjtkXeVmvWl86Mfsh40S+OL5hBdkfx6pcalMz
mAOQfbih4PqIAzkQfdNmm9JVzEFw09fZPCNiDsaLLW8e9o+LyCGwGb5xQlrI
HAqhZ52vwevl5DAoe9pk1a3M6/D7revdcxXM4aicMsm2s2BeD+7ZflX2B3vy
BtgemwgpzGWOQJePYOVNM2ZAUDa48LHQTmseyAuv2ZDmRuYkOHD6wqRKZUtd
gidtqUZu9mQuEpmdb6YWmm2oR0JPYzZ0dg+Zi4L+Pdcqr8/W1KNQqb60t+cQ
mYvGT9Xl40l7WI/GyFZ1UckPK+oxaInYPZO/j8zHYO24iDcSsh6LnadjP66/
b0k9FtKmyQR5MJmLQ2mToWfnawvqcShXasq3XyNzGxHul1hkmmFOfSOuuiYM
B/Qsox6Po+L+WWUKmY9Hg6i+bVBqRj0ByfXqGGXLUuoJ0HHymDO+aUJdiotD
xrNXA42pS+n/YD0RHf1hX93HyHwiolLng5bEmlJPwr7Isg7TGjKfhDpJb98D
ezqPS8bAneffXsyw/ZOhaRr4VWBtSD0F/qVffki6yXwKvJqEekFqfeqyxR0y
NN7OqfDeZkDrZZCX+HoKTwm17pZhInRuIdJbj+blMNa9lfepXEDzcvr++Qjt
POuTWnfL6bxZrTnF4vVQLO68gs57T/OK//v9AfTrMXw=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1GtMU2ccBvAjYASKoQjWDlEKglxtQRhQcJ6HInfRtoBRiRVJvK1uipVk
8TKPbirxjoIf0KCCQYGIskmiAbQaiNBsRsSA4mXZUDe8pRi0gEzU9P9+4Jzk
5OR3nvd53//5cvwKNupXO3Act+zL/fVpv6y8LLexqcHoD3qBqPePohUJzM6o
MDzTvnBilmKWlL9y9J4f2QshHZaxiWeY5egZ2FGs+oHZB+eKWuoNGmYFjk9u
j5zvyeyPmZbWwdPPFeQAHHm+sq+0iXk2gqwO8l6BORguhsiOwGTmUPiY+Hse
7szh8FYNygeafclKNIfWlPPJzBH43etfw5NPM8mRCJjspnxYzTwXlXzr6NJ1
zFHwK1T3F9pmkKNR5tx+9v4G5m9hHmjdlCdnjoH8YvbP4RYfcixkcYLjXjVz
HCJexSn+s00nqxGzvrX35DnmeEjUa56+jmVOQHtc0QHpXW/yPFyf9yi2y8j8
Hf4pHuqRujPPx4MTD/iQtm/IPEYnvFt7dTkz4Br2ywoXq9xuAfCtOrQ7KIvM
JWKX6YrqjwyWJ6JoJOhSh2Ua5Rqs7w5USkrIggaN5dWJh91ZnoStO0duGmtl
lCehouhCb4Q/mVuAgMLOh8NTWb4AnzbbAl3aplKeDKuu60hZDFlIRtWzPQVJ
a7woT0HD0OF+OchCCoZXmf7f1ehJeSo0yvzSzflkIRV5qTdcRy5PoTwNLbf3
/TW0kyyk4cP++mkrBj0oT0dKS//36CQL6XCtGjKktLE8A3M8ggfKO6WUZ6Cj
O2DwoxvLM5FeU18beMqd8ky8ehz0q2o3recWonpWRm/0LdZfKOpn4YXKP+rH
EHZ+FsY43Vj+FtqPW/Rl/vi3wX1ulC+Csf3q9a5rEsoXY3lYSdqdn8jCYlGu
xXD4se3nN7jYDS32lhjjt/lOovVanG/qkVl8Jtpt1kLieHHry+MTqK+D/X/h
QH0dTHUJ/G+VHPV12FHR1Sz725H6ovWcHr5pWWpZLe0Pveh8PXQHI8Oc9jhR
X4+SPtM2jY1yLht/eltflkpdqZ89fl4he/z+ZpG5HDTUbyxV5jlTP0fUzxHN
nzN+Hi53vCGyILI5V/T9SxB16I0t0TzM2/tL4KAIHZHUjfKfAVDAZls=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HtMjXEcx/GnOl2Ukkq66nSQdJpU5HTR+RzV6XrqZKKli7WiKTvKWIo6
oxsrdPmDGLGFQuuidSxLSRObFsdCU6FoixL+0IW57Hx/Mz3bb7+9nvf3+8/z
x+OYrNiaqs1xnPTP+XtrnmmxZUxre1O6APQCHkm1a8QiZgPU9bfxRrWYTVEo
TeGHPHYkW+D8MO/E9XPMVrAunCtavZfZDiUZecndImY+onbtelerxyyAwlcq
1+/mk1dheOKzk/gksxMGJ7lvilhmZ5wxHuqb4jO7oE1o8rr5kQPZFd4Sw+GX
sczrcLneydZzaAV5PVKmngl0s5jdUbWiZvf7V/ZkD4x4iRWNO5g94WZb3Zul
x7wBPDfz44uf2pE3YuyqVk9MLrMX5KLF43t8mDfhp/C0Q/28LVmEJaaqigNT
zN5o9Ff5qOKZfZDmv62Dr8Xsi4w35VFO923Ifng+IOvPCmfejNm425JPusz+
OFSsnWygsiaLsT8xr2tVBDOgfminM6hPVgIev1Ks79VYUZegqUFRtW4nWSmB
rsLIc1/PcupbYJLtsn24kqzcgqLydJ9cB9YDEJQ62lJ61pJ6AOoufWgUJpC5
QAiaDap7ZKwHYj6zJl+Wtox6ELpWFjhzArIyCA32aoHLuAV1KYpzHmTPXCAr
pUh60ZqozmY9GEcvqu9avjWnHozxtV8Pu8vJXAgqU6cr46+ZUQ/BsbHksrGb
S6mH/m9lKOL1r1TbBrEeBvsbPwbiN7EeBuMMs48lmabUw3GwXe4nmjGhHo44
YXlIX7YR9QicKdBRjSQYUo9Aeq+qQ32HddmCLsOsa8WRaxmLqEfCs2zyu6ST
rIzEE5vpiSpTmueiFuxHwbWFp+d1Sp+6HNGl7kJeIU9jyJGTP9eVXq9H83L6
fjoady6Y56Kh+V9o0340jHRu5UxUfhFr9v/5N+ijEac=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HtMTnEcx/GjnpQyXdQJpZ6KR8oekqLI8+ki9ZR6LiWS/qiZVki5NLmd
XJPLamQjNQxNkdUmSc0pIo9botk0d2LRKtdpCHu+v1nnbGdnr/M+399+v3+O
W0qmbpkJx3Hxf+9/T+PVp+LjL16pznAHvcDqgprivEBmC9xpMIvcYcFsg8YV
bS5nnriR7fGmRJ5WXME8Bml51rsVuczOeJit7udCmOXwrl3YZjma2R0XZOK6
R11y8gS8tW3UZl5nVqDMwVFx4ACzJ/yahz8JXcjshRHJXrpjcuYp4GQ5nU33
XMlKiKnJWYvWM0/DfbV9qbMdsw/c3pV7thpcyNMRdvzV++1JzL7IK2zcVGvN
PANf79yq3nB4PNkP7XtjCiZPYvaHIW2cR/M2Z/JMdGsmtrcpmGfhV86LLWs6
nMgBeMBnPavdwxyI1YtbOkQF82zUbRfKxnePI8+BIe/pDasg5iBcrY7aZ2kY
S56Ln8M+La9LZFaho0ew+PB6DBloCOhFdhFZAKxEuWrqRtaD0emRfvKmgvVg
KI/U9C796Ug9BIPpqfmt78hCCFaeSjHftYr1ULjkp5/94sB6KJI4Pa8p4qmH
YdIz7Yl1ZmQhDEcNdvXHqxyoz4P/x66n58zJwjyYu8jirrePph6O04G+reWl
dtTD4RN+9LL6Lpmbj1cl/n6dB1mfD5spPk73Bm2pR0CV8CUpxoksRKByjnua
5zVr6pGw/WjP9/GjqEei5bO1PjFrJHW1pKthIvcasKpkPQquv+/entVnST0K
hTtM654vJXPRaG0Jyllbb0E9Gq4RCwL4CjPqC6Dd5+Mt2ymjLjEXg81lDxv4
l6bUY5C7daApo2I49Vj0Bgz8DlGShViUX3nMG5zZ+hrsKsoI3OhqbjQ0qK7K
PKRcwvYjsaiRrK+VzGuHdkGL6JlbL71W0v5EreR8uqH7gU4yr5PM62D8P5nQ
vB4JidOrst0HVcZ5PZ23y2hBYlEPK9Pzud0H+43m4uC7v+d7sPiD5uPo+280
L7Eo+Z6LH9rx338AnrNdUA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdy3ss1WEcx/GTS0qU+yXEOWKncHLLLZzPOW7HwXFYcijaXGYmSfFHqP2W
/mnrogybaRG55DZaJZeKRjbTSjKa1DBdh3ShWlbN9/kjz/bs2ev7fr78pKzo
VDUejyf9e/+9a2dRbBJzu6stQwAaIHa+Iv+GiHkTol2e39P/wifroTHOzq6j
l9kIb8U9IcoiZjO8UKjqDaKYLWH12KS8lc9sg/nmU8WmyzZkAWpt5S/d+5h3
YtaTS3cpY7bHZMtCtlYSsxDt/mMjoULm3QgpEzkKJ6zJjijMkGcH5jGLMNGh
OTBtzewMjZan48mdO8gukA1f3zijYnaFVF3pxRu1IrthVqVTMShldkdUTmnl
6B1L8l5UPXpl5uDL7IHxvCE9rWkLsicSimpOH0xh9kKjT9vkzLvtZG9IMu18
0mOYfXD/wNis/S9z8j50DEzw3Y8x+6JgoGVKe8mM7IeA+YaSzBRmf9Q1jo4v
fzIli/Expf3MUhMz0N9bPf4wicwBOg2eUd3XTKhLoF+k4ElcyZwEWRdOmhsW
G1OXwvdb79T5RDInhXNCYV1PvRH1AKSVqOXoupG5AGSotKKSywypByJpUNDp
xpG5QLwvPS5pFrMehLjDfbJ4FetBqKoZNL40ZkA9GDPdvzkHTzIXDO3qlcTg
fn3qIUi9WquWX0nmQjC3R+B2dBfrMvAlaedyV/WoyyCO/XpIYcF6KJz0hZ/L
n7EeCu8nXZUDb8g8OVotmu6OhG2jLkdul9LXa2Ur9bD/zYXByU+0/8GcLvVw
FJ1V73idoE09HNarw0Nei2ReBH44XimoO7KZegRs5aVj8fWsK9btK9btR8Lx
lsZGj4ta1CNxeeZEvnSZzFPCWhbhbXJTc81QYot6c96H4g30X4kF75+rUtF3
8R9KGgbn
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd03ss1WEcx/Gf43ZGlnI7IWKpdHRyieOSzue4HPd7silqNTEajVVD9Kut
MrYU1ZTR3OpgGEuM/tAfp1oWlSVZpiE2Mwkzl5Vq5/v84fy2Z7+9fu/n2e95
/njszmbFpgg4jov4N/6/1c+CzDy+s7c9wx70AaaTTU1fpcxCHFfOpil0mY2x
sZTePNVvRzbFlQdiq8xKZhEalHOdTheYrdG4ontP4M+8B/vd86sNLJjt4Vkg
Ta2Y2UPei+K4hETVS+Z9iJsv1XIoYj6ADyXzibrnmA9C3mDiPO7E7IQRyxN2
imlbsgSnVtfy8ZjZGRMeqm3DAcwucI3Ml/Z8tCG7YuSzYaLoJrMbkkpblKNO
zEcwEM+b9KztJrsjY3m1cbmW2QPlr7u6xPrMUnRmLSXNVVqTPVHWJpKn2TF7
ISG1/kVzvxXZG1XP726eqWT2QUNz8Z3Fw8xHoSNWugjHLcm++DXk0zfxiPkY
unsFgzn6zDIkn6+5rsfvIgOLVRJFtxGZBxo6VHVFQyLqcphcDHuVWUDm5ejg
avkSY9b98EPQdblswoK6HxZWUgq/15A5f/BCt8KlKXPq/qi+pBx1tidzATjt
4as39t6MegAEFU82gnkyF4iOtls2om+m1AMRmWOc/1BF5hQQlyoG/PpZV+DQ
jBVvoMN6EPJyxTPDDqwHYSrd0fv3bRPqwaipf2tWOryTejACfaeuDq6TuRCo
7wPrIfgkK9OxGNtBPRQGdavJChWZD0Wu45u1lChj6mFISHRtzbbfTj0MRtmu
PkM3jKiHbzUfjsphw7Wn7obUI9DemnVfclJIXcNcJGyDI7zMm3SpR+JZ7xfz
d9ZkLgqG2i15s+Va1KMQLr3WNSnRph6NnGYfWUctpzaiNeZH0/kFavdpdC6G
zrcpU6+P0Viv0fs0zMVu3Q9it+6H13Cfxnwubuv/EIefXut//CTTsr8fkTNx

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1H9MzHEcx/HvkroclerqdLhKiAqVTj+ce91VV91d191VuxVJOEOMGUth
XY2NpSJlreaP/shQl9EipM6qYXamM8koMw2zRRTSyI/d+/MH3+277x7f5/f1
+fMbuHmPweTEcVzan/vv03GNyXyz2m9dKQgCvcC+vWpbn4SZh67jRv/zc5g9
4Zv/6uXOgUCyD+652VUD55mFyEz6uSXAxDwfTcl92qFo5gC8Tat13ejKHASt
Mau4cjiAHIznZeOtEY3MS3Ama/2q7duYQ3BU3hkaL2dejpmH44zNfsxhuO/z
2DvvqZi8AiYtb33oMeZV+NjRqz4gZo5ASV3z3omHC8mR4PO4bTcymaNQcO3Y
cO3EAvJqFHRPzk4wM0fDNFK6W+DBLIH0iGYo/cR88ho8ax+3HOIzxyC+NXsw
vFZEjoUgu78oIo45DtKrinenLP7keFSV5vXoDzOvRWnRaGGgiFmKmtHiarF9
HnkdRhKPl3zIZ5bBLWVt9KiCGeCXrymydAkdNgN1mmADr4LMyeFhzWhyErIu
R69PYVHAZz/qCnxyz+pZtpJsVmCwdlNOyyNf6gmQXDTkqg6RzQnoFjcIz7mx
nog8idRlyCagngjJmd7tqV5kLgk7tn45uHIp60kIrVI+VDzwoa5E2V1j7pSG
bFbCi+/X+abTm3oyyiuaFltmkM3JyBg4cdK+gPUU9OqsDeabXtRTEKGsv6Gy
kblU2GXVzn5Dc6mnomxkc8VIC5lT/ddVkBknNmhFrKsRPjfkU32/J3U1yiNN
Lxo2kTkNdilO3XZvdKeuQXa9pVEQxnoaRMLX705Xs30aLotartvVHtS1SMj8
IZmpZHsttC2VSab2OdTTsUh1diDnwizq6bD5j72v8SRzOvR3PJkYnOQ7DB3E
07YHMWPsex3G2vp/HhG4OWzVIazN2UVS6Up7/b8detzrkxbuv8mjvR4fY6em
FStcaK9HccnUnYJLZM4Ax//GifYGRFWMfpNbv8scewOMOZGt+4J+OWz9r3MZ
dP5Xh8H8RvYbfko0+w==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd02tIU3EYx/HjrbJhqZnadLqZ1kpZ3s0s99u83+bmpaArWlFhYN5K1HRp
oYLBLAuytMxikalliZapkwos6oVdLAp7oSUiiQrLy5Ks2PN/kQcOh8/5/p9z
gyNKz0w6bMpxXPzf/d/RuE1J7VPbux5kuIFOoP/S9uqdW5hXIN/V57TBICJb
Qz9m8ivvCbMdCkpDJePlzI647tEkiIhldsbGgML6lQ7MQsTlzHx2GhKS3RDQ
oI7e08nsjm7PU196y5k3IE1jtXAghVmM+wguErsyb8ZC5imLomlXshemWlWC
/ovMEgij5po7Apm9UX1Fc9Kuw4XsA//9aQe9Y5h9oS9S9OrbBGQ/5JX6i/SH
mP2ReLl99LUdcwBCnRQDfi3O5EDk764ungxnDoLQ0P566LsTeSs8n1Za1B1h
DsbkT4V+Rsi8DW2iMvHnOj45BClnFgfey5m34+GFYonm6jryDuRO+XTbyphD
8Uz76FpQrSNZitX6luQJX2ZgtS75tqkjWQ1sfVFSWP/EgboMJypqp7OyyGoZ
XJ5/nXubwLocyqQZp9ZSe+py2GgUnMyXzIVhuOF9qjWf9TBUC479qB1ZSz0c
gXzLxukbZHU4+tafFXNurEfAe1+ZtvuOHfUI6DzlE/eyyVwk9qYPj3iNraEe
iU3uy7/NRpG5KCQPVla9FbAehZ69Hn0uPFvq0eCZNReMX7ShHo0ufk3d40lr
6jEIS1kItIhcRT0Gt142nuTlkrlYDFpVHJ1XWFGPRUZ/Z8+7xzzqcRjo/KD/
NEdWx2He60KR9rgl9Xi84U+N11ivpB4Pv/MTszId6wmYDDb8lkuWUU9AQYmh
L+MumVNA2/XR/pWzBXUFVFU+nubnzKknLplPhPH/NqWu/H89lNi127cl221R
alyvRHxQSceIxMzYdUrkNIVI225yNK/6fz1U9D1N6H5Luk5F7zdvNJdEzzdK
80usXmJdEl1/muaTqc9I/wAF+zrq
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1A1MzHEcx/G/K5JDXc5Fpbo0o5KUosR97lRylequu+s0bCxGVpOHJYu/
55kMeZjFGE2kXcRYFDvykIedhxbGPCTlYSimuix52H1/tv//ttvtde//737f
/+9up1yQp8uWcByX/ff579Xx6FApDBdqq3MCQG8gWNbnXRTFPBAnSpKOvpMw
uyMryH38wSYlWY7nigbX+nLmEdhkVu61rWP2wYczXUVtWmZ/bPXwL5f6MQfg
SekQr2et/uRApMrfVMqqmMfAtl9XeauAeSw0pWNci+OYgxA5Wj9lh5w5BN+S
XkXjhh85FObc1OUXFjKHoS9mQ2PrR1/yRFS4HfQ9vJ45HFtOP7h63Y85Ap33
71SvOTCKPAm2e289T41mjsSa2PPL3K74kKNw2MI32+KZJyPQRWK0ezNPwXd7
7q47Z73J0QhcutEQuoA5BkfaQyrknV7kqTivdnEr2c0ci/pHl7sHDGaehvpk
+XzD8ZHk6cg5Uei1OoRZhV+LCguyH4wgA296fA0bw8g80B4Wk3Luhyd1NV78
9q7NWknm1djV6L7jvpZ1DaIqdHO1axXUNdjPTyuTacjcDMR2XntVPG849Rk4
WftUcdeHzMWht8xZ+f6hnHocPCxNSzrWkbl4eEg969rqhlGPx8cD+WqLiswl
4Mrtba/t6z2oJ2DpSvvFfiYyNxOPVSXOni9l1GdiUJl9XsJNMpeItgkBEbnj
WE+EUr14+6o+d+qzYC61HBseQuZnQfZZruhQDKWuRdeQSxt6IwdT12L3Zqea
13MHUU9CTkPN1cZLUupJeFTT9OOZncwl/50/5uvYFrY+WdRTMCd4T6KtgK1P
waEn0p7ySNZnY0/LirWabhfqs0X7p6K6Km9faNZA6qnwS0yJVpzuTz0NRUca
6xTNTg4jDRL/oJ/Syl6V4/o0rKicqjp3nHN0axoidn7pVlt7HJ1LF14Pkfl0
SJ0shZ/29qP16TDNCa/KD/hN63XCz4dO2HmdcD+rDu3RP/s0oV20Xi/aXy/s
vF74eVa9cB4ug36PdB7IQHrxxGDnLc50Xhlw/B9KaP4M4bycQbgfDMJ5eYPo
/Ayi/Y2i+zeK1htF8xuF98uZRPdvEp2fSXR+JtH8mcLrkSnsvMjWTNH3bxYa
5v/n8Qc3Ya1O
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdynss1XEYx/FTCttJRTrIJRQzHeROLufjuF/iJCcptpOy1US1k0SlX+ti
hZWwQmqxYimG3MOpqVyaDSV/tFmOTKVFKyeiVfN8/8h3e/bs9by/ZvFHIhOW
83g837/zby++KZFAWt9ak2gOOkCqrFP38mDWxKSsdWzHMua1kEU1nTHtMyPr
IlKam6STz6yPa+5aMYekzEYIctpdskLIbIp8vWjdCypTsjn224+tLmpj3oxM
i/aS3lxmS0wKXFtSY5mt0KESXn9uymyNTjtR8VznRrIQhRk1uuH7mG3heOm2
/MQq5q0YfsPfo3/RhGwPtSCX03x9ZgfUZ41+bLhrTHZEX++oXsUmZid8G/DO
k74wIjtDYTGYNpLH7IJsEy1Ff5sh2RUvH3d1pxkzuyHhWaPkTsMGsjvGCjrP
T9gxb0NFgE9B7bwB2QMnk666pexk9kTHWHXHe2dmLxwtTI7oUuiTvXF5fnCo
xpdZhPLK18OqST0yIIvZNXsjkcwB/gnKuuybAuo+KOC8yrTFZM4Hr5RlC7Bm
XYwMYXpx8tR66mKMfC5Pib5F5vniXoFcuxms+8JpICfVokWXuh9Kmjz35lWR
OT/Exo8qhRPrqPvDpFnekNlL5vwR32Xe4sixHoDuND/PA5asB+D4wfL2CIEO
9UAonyxwW1zJXCBmrlTpxX3Xph6En6EfNM+FsR4E2bG4Xz0TrAcjVqO0yNCf
zAXDRttquqh/LfUQSA5b9/4wIHMhyHJIeFcsYz0U1YYPGwdC11APhY2XbVTH
uBb1MBQP8WfvO/OpLzFvO3KV8lNilQb1JeaFI/3s3NPEB+rUw1He+lbQY7SS
egTklR6i2lIe9Qh8dZ/7LbYdFy12CRxzvqh8FLOLhoT6zKI5yf//FRLw1R6l
f8qbFv0BE1EZAw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd02lIFHEYx/FRMy2PNrXNK3dbLFTUyvtsfx7pes+uiihCJQnpGuERmJZO
xqovKrIwOrCCwqy028oSEcJuNTIPfJGVkqZWJmVtmFbs83+xOzAMn/ny8H/m
xazN2a3KNeY4jv93/3/qrhm5OL314U21DPQCX25ULdaEMZtDVDxV8NiUWQR5
yRKVT89ash2Gy5c4Xz7CbA/NuNOHjAJmZ4xlHp0+F8IsxUTmBb7UjFkGr968
3jfPpWRXzL2dmg44zrwe8331/Zb5zG54nW5T2hDI7IHxXe1GdVbMnhjhdzQe
uSohe2NgVB3U7M68EZ55GT+ePXIhb4JVaaOmMIvZB36W/tXdk2vIvtjUdPGc
Rs3sh+V8ysuttsz+0BbG7YxudSYHIM1V4hiezRyIqoqeetl3J3IQXPOr0r1z
mINhHTokPbWOOQRepQ4tZQ8cyaEoHJ4XxW5lDsPk6KtfEhfmcMRZR91X1TmQ
N2Msurbyy3ZmOaSfbrcOjdiTgZOJrirzw2QBaFEMfywyYj0Cn6uXXdHUrqYe
gWf1zcopNzIXiZyOd7MLd8TUIyG7ZX66K4nMRSFgNsstYWQV9ShEefb3mmjI
XDRykt2bFixZj8bg0prBNbN21LcguVhUfqKLLGyBTUt/3kwF6zFQxB8avpXJ
egxc2orv1rywpR6LsXz3kD81ZCEW2Qd9s4YmbKgrkNvQaFx+fiV1Bfa6P9Hm
poiox+lbiMMip1zcVrKCejyuOzXfe51AFuKx5yEfFvTLmnoC7s4c3eDYTRYS
sHLaTjwjZj0R6qf3O/raLKgnYs6q7cC8vyX1JJwZsNA2+rOeBK3nsX2XCpZR
T0Z1nTqkXGJGPRkSRVKw+Iop9RTo/mdj6inIyPK5ViRblOs6r9/Bw1jq8dvi
6ryuCzx8D3/+GdGp1bmTx9fg3wuR3nM0r4SFSUvZ5HEjmjewoERiYOW9UW8T
nTuV+udxKv19YGBBZTBvYC4V+8/2tYvfk5FqMJ+qv29nqv73cGm07zf5X+IR
SMs=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1H8s1HEcx/GvX40d+XHuEOUQy48uQkjc63Dn1znn5I/rB+uHfswaWxrZ
rJOENn+0oqWtn8uPUX5shqmcij9qa35Fo6ymaYro14WMavf+/MF3++67x/f5
+fXP9+t2OFudacxxXNK/+//TcM1LhGltXS1Z7qAXGDl7fE4TzGyO+cfXB81M
mW3g9OXo++E+N7I9eCYPCj5fYXbEsnf6xc5MZhcUyz555gQwi1CxkjonWBWR
3WFW5dBkPci8FZ6hq/zJamYvqF+OpPaeZN6G3JC60nEvZh/cvxS+Wv7HlewH
/sLr7oA6ZjGKbg2YTuxj9se0Df98ztIWcgBONL/tETUy70RxR66iVsIcCG1r
Vem14c3kIFj4j0c3pTEHIyuvqbB+woW8C9nlJSWnjjGHoD8orkxuxByK8Iea
N9srnclhGHrXrTe3Yt6N20cCFU+LNpHDUXR2Ns/NmXkPLkQe2m5d70SOgF3W
3rENXx3Jkej/saDrz2CW4FVsOu+XCzNQXhlr5trvYLAWKMj1yG6QkjkpQuFh
jO9C6lLU35pq9j1I5qLwq72kUz8moB4F0aSg8p6GzEXjsNK7bsWS9WhkjLal
D+XbU4+Basdt91xHsjYG6WXy6YjnfOoytOfUaMQCslaGGb4mU19uR12OJwc8
e7bwyFo5vJUe9rJTttRjkSTv6/0YYUM9FprqB3cEfmQuDme6VHtCFzZSX2cu
Hk3Oje2DidbU4zFiVXZiUWlFPQG2M/bCeSGbn4B9vpfjXuXzqCeiTvqst8+J
xmsTYSzyWeI1WFJXQG/VWbQcTNYqMNDx+uebBTY/CTdGeIs1wWRtEgIrZn9L
dRbUlWh5mH1VvN+cuhK1XaPCFy5m1JOhCDnXPik2oZ6MwptDj4QfyJyKvlcj
g6Gi8y1LDONVtN+iwToV5sKWVqLEeoO5lLUdKevmp+B0Q7ik9S5nWF+XAsP/
xZj2V6811OvOq167nk69bv9UOv832j+V+pTkLyikPHI=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdznlIk3Ecx/EHNScu88iW12xqRYeaR4f3PvOY53RuZWAaWkhRgmEoJlaP
WkZ0WVmQWoEY3jMlM7FIMg0zIYucpl0kJB00a4SJaMa+vz/cAw8Pr+f9fH48
bvtyVFkmHMclLt7/n4ZLJxXt6uhuO+wOeoFWa8mjZ2C2gNW3/J7Hlsw2+G5S
l5E17ka2x7S2fn+zhtkBAZ1FP64dZ3ZB6xe+KiWBWQKPiAxVkCOzO8pkW2Pf
jUnIazGodz/zsZN5PWyOLUyOlTBvwPIJlSAuhnkTQgs8TgXZMXtCMpwkThlY
Q/bGjRNt9omZzD74tFyvyJ53JfuiMHDiz7daZj9Ul1UXe/sy+6PJqrVSMSAm
b8U9dVjwFjnzNigFXTW65y7k7ThtYTHXksO8A59T8yN3OjAHwH8gqjx7xJkc
iAPiC7kv05mDoA01z1fPOZGDYZKWMjbVyRyCvg7B95YM5lD0Flw/cVvEHIaG
vLfSqkuOZCn+el4pqstmBtplZ0v+LjgYzANexWN7hXoyJ8OLsEm5aoh1GcY9
DtU8W896OJq14o91tauph6Ph0E0Hzw4yF4GL+SdLQt6LqEfAXGc9cvkgmYvE
nWtHbbuwinoktOZntOJf9tSj4JNeWveonsxHQeBqtvPpq5XU5fDUXdR0XiLz
cqSV+qeOTtlRj8ae6MeWs3fJfDSOjPx+kunGegzspnqeNKlsqccgTVBT6RxF
5mLR7VRxs+unDfVYnPPLmqjKIHNx8LLdMF05zHoc8jZWXL3Szno8FPL+vslQ
1uMR26BpXFdtTT0BVrl+wa9LrKgnoF7W29fvSOYURl1h1BOxO9VPk+tO5/GJ
yOtWhgTMrKCehPu68i1OQ2Q+CcMP3uhHZ4TUlVgzPzQYoLM0GEqUnzJ98CGd
zCvRpsmp8N5jYXDP4vcxikBR4zLaJyP5vO9ms9NmtE/G8VuvH4o+mdI+mf5v
QWrYG5lT4WhTsLS9hqO9amnnVTCRbJoVNs3R3qhz6qUdaqO9GkLTlsKvV6el
/wBm+zwh
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxV03lQjHEcx/Fnsq7aTrXpUq1qwk6jUrKVPltI9+42Sa4xxo5jB9tqNTTY
Dsa4so4SRWgqwoyICK2jKO04otwxmDBomSalS6bv7w/PzDPPvH7v5/v7/fHM
475snVxhwnFc3ND97zl8GcMESVU1F5RC0AKu1GXPNZ3GPAY/nxRntfa7k63g
8LEjYF49sy0k2aJGdS7zeLy8y09+tpTZGccqknTFvsxueJGh8r/e60YWwsa2
821uE7MHytrKK/oOMHvhVn7h/vwUZm88frg61dGTeTIeJvB3VXa5kkUYLMnh
TFXMPvDSzU/+ack8FStqI3jqqxPIvvD5NdFyyXxmP4i/8rzzul3I/lB2dp/u
PMk8DWn99gZFKnMABv9kejR1OJMDYXguVsfkMU/H5UtrD4c6MAehZnkXr6bC
iTwDr+721q1JYRbDIvi5W4EnczDSizwHZY8dySHY/eC9xTs9cyiaz7Y38Vcx
z0TwNe5c6IADOQyvEzcI3hQwA2+deG2mXeOHrQUcnJQr89eQOQlan21u3BnC
ugRp/vWhGoM99XCcEBY6qyrJ2nBopnspqhSsR6Dwyo9dLmNZj4Au0t5nU6uA
+iyMTHOZsrWarJ2Fhqc52zQNdtRnIzvnzut8PVk7G0ZZc+6hQNbnoO8Uz739
kS31Odir0pxZmEjmInHIsz+FOz6OeiTaJ/3a6Cslc3PRHfNpTGasDfUhl4ze
8lFC5qJQUFuWniRiPQrD/wfr0Viauri38bM19WgoikpNMorJXAzCkjsXxTux
HoOUI+dO2ImsqMeCP+52uuqLJfVYJC/wO68Wkrk4lDSc2mCWZkE9DtbfbAVG
AZmLh7naL7g5y5x6PFwHDA+CjKbUE9BivmNlTzzrCbhxT/zD+wOfuhRHW8x6
SgPMhg0pNDXSkKBudp70//31UijvV99svkrvczJMjM5rWVBO50GG7TqlOMN1
NM3LoPuwPiP8N1kvQ8eMPwPhPqNoXg6Do/HrQSs2L8e+nBHVbYvJWjlEF3mj
Aveyefn/+3OJ9D1MaD4R/nu+/5boe8L+ArP7PFY=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxV03tMjXEcx/GHpDoq3Ryn0+VULktaOZIcyvmU7jfnIlELs9niRMWZ3KZH
KdaI1IxcoszQyrKVI5ednViJbLllTNjZIqGT4SRbYef7++M827Nnr+f9+/6e
5/nj8d+Yr9o0meM45b/z/9VymOTCjNbbLZoA0A309JfliGTM9jD4S3udOWYX
dFfczXjf5U/2QHRpcPf2Y8wiFFXnPfJZzeyNVpnRXD+X2Q+/FXMme3/zIwdg
jXaoNlLHPBsPfU93lhYzz4Xt29yWM+HMgRhqL7PJtGMOgs5+56nysxJyMC4U
V54VBTGHoG9fwUFBsy95AZx2XS4rzGKWIvRxb1PQgA95IdZrXKVuJ5jD0La7
HghgXgRRk3p/cLc3ORyaJ8EO26uYF8NB7Lm+ZB5zBC4vUr38c8yLvARJdlyd
GcwyuFdfbL/6UUxeChdbY8X0bOZlOH8hfO0GKXMkbLfy28YHPclRsHl+sW95
GfNyxEYMh2eFMMvR7zXlneCXiAwcyRAkPr1O5gGfsEMvJBtZj4b2dUOX66uZ
1KPxZsLrdraWzMWgXHrTt0/BegxGnDM65oWyvgKOVyOUd+qE1Fegymfzl1rj
DOqxOF15fothJ5mPhfaWwa8jmfU4zO8U/bz0wYN6HPrXVB46YiZz8Tini8yu
bmY9HiWdmTljqawnoDb9wJhRwHoC1h2OH4y67049ES3fxXV7csl8IpoThlVF
jqwn4b5Cf4Zvd6OeBMv/QeaSsUU72jYpk/VkCBpG18U/cKWeArdPekOjisyn
oDEyIDewYzr1VDjluQ0dLnShngpHd0NRwSDradbm0zDBKSc2aFlPh+sXD6FJ
6Ew9HW2m46HiHjK3Er26Fz9ejU6jvhKaLt29Z7fInAJdD6KKtO32FkOBYdnY
eEzIVFqvQNjRr+ZovYPFegV6xKbPNS4CmldaG0q0NOfXhGTTfrwSksQ0mfCa
Lc0rUWXcsTfGbEfzKkjGex4tMbF5FWYln3yZdYXMq6z316us34dTo7xKs3Sv
hPaD2vp5vNr6e/Rq7GhcJr9Rz9H8KkyzadrzuXpEbplfResH5H8BRQ5G4A==

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdznsslXEcx/EnKnKEIqTcztJMTSFxTup8XA4H4VyccumixlQ007RKTc9M
mpbFarRWjcrK7YhNkySXZGujdUNpqUhXKUocjTTf3x+nZ3v27PW8n89vj+Pu
FGWCHsdx8pn733P2+i6xVNfeqU4Sgl6g4/WJ7dYiZkOUTO+9lGDAbIa5Ffnx
Ua8cyRYQKyI8xzXM1lhb3mbnmca8HFd/DRYPSJgdsKumPuaggFmIl5U5qO92
IK/AQOKbHSOVzCuRW9T9cewYszPyJwTXeryZXXATomPO9syrkdZ8P7vrkT3Z
FW83HdnnoWZei8ybBcPJI3ZkNxj/ejvUWcPsjsz9sXsWKZg90KnmzesnbMnr
UDswd6dNIbMnXrTsOloUxrwe98Pt+K6vy8leqE59/6Uimtkb3epevciFzCJs
fH2+tez6MrIYD+9N5XfYM2/Ap2RL75RBG7IPSpOWTN0oZd6IRp9er6dJzJvQ
uKVrYOXkUrIEWfFr2rXZzMAc8arbjxaQeeC02kj2pMqaui/QlxG7KJDM+8K0
SVWiZ826H3aGNqChxYq6H8Rf+vmqAjLnj9FsaZTUnXV/XDYuvGXxzJJ6AOTK
sWVVmWQ+ALXb0uO2JrMuxamMHVYVP5dQl+Jd8TO1mQ3rgZg0SZQ0S1kPhPc+
iXuuFZkLgsb2qdDlgwX1IETJzpi9u0fmZNCO+185tJp1GT4VHPCtlJhTD4Zb
4IXbIR2LqQfjq3l0wlgOmQvB3faTfePHWQ9B4zanZjsB66G65kMh6rxT9OCN
GfXNGJ2qj840IPObEVyqKXO6aEo9TNd8GMp9hHucW1kPxzSnmI5LYz0cyX55
d02KTahHzPyf+JtzvzH1CMSsypd1HhZQl+t2yHU7L0fbqKkqJpV603/mFHhc
9/xnzzh9DwU8cod++zYtoL0C1ZqUc66xhrRXIC9Lv65vuxHtlUg/rm1OKptP
eyXsZWEiy7J5tFdia4y75oBwWjK7V9L5E7PmVNBzcNEKyv/MGirdzqswLNJO
+bmO0V4FgX5l+uezP2gfSX1Q8heUPFI2
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdyXtI02EUxvGfZTac1py6tEznDKu55jWd2tzjZZtubstKDFcWhhk5sqYR
aIWGhpNITBOSIFFRypguMcrKmabiyDBIiQy7GNGyQkVkidAF3/cfDxwOn/MN
zC08kLeOYZiEf/v/rs6cjJfZ88RSIAB5wJCvb7kTQ83CZG1oTuV6ag7GB8d1
ttFAYi9c9/jk/6yd2gcOeYGi9DK1H1qjPF++UVLzEXWicHrem1qAz33NbkV2
PvEO2AXG/P4u6mDU+ItWDpqod8HqF25jpVELcXNKYltyphaB1fprhukNIBbD
RdKxcDSSOgwDqtG7vlZ/4nB4BnwYnzNQR0BvutAvZVNHolrLzatr2U4cBY/F
YdGEmHov5rWW4MFXfsTRcBTbG6KDqGPA2byS2zy2jViCY45bQp8z1LHgfctm
+ALqOLTZlyp0U1uJ4/G95rEifoR6HxwRLiPyFGop+sNMJ89W+xIn4OKwedp1
wYdYBnnnx6u1T6kBdXv1YfYm4jKAF8c3ul3aQnoiApvKvRLHeKQnoudIyfEs
AzGThI3Pg26LfniTnoRGG7e3yUzMJEOolwz16WhPhraIU9ow5EV6Chq15csz
rsRlKegPSfp530i7HDlVCrv0hSfpcqi751UZMcSMAi6ZTt1zg1zSFdArra7L
XcSMEqeLHQ+dsmhXosjSadpf4kF6KtqCVO+iBjikp2L2/c6K0CvETNqanobz
u+vrbjygXQV3A3e26hztKmgUw0NfpLSrsUcqPmT96k66GpPuVad+a4mZdLx+
NLH41sEmPR0Wc2G9WM8iXYOAVE0s794G0jXIuBYe4lzpTLoWWdkRZqPgj2y1
rzGjwzq+cJndsSL7C6Fg8mg=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzglI02EYx/G/B2gN85xmrpymHR4j0w413W/TaW46XRLi8FiFYJlNUUw0
YwVpiRYWhBgZMTsslERGdBArNDOhFMugoiDxqKxU5sR5dex5CXzh5eXzft8H
Xr+D2n15thzHJf7Zf0/rmhR77jc86ijwB11gRLhvwrKH2RGisd6YbgdmF8id
XXvG+v3IHig3mp0TWpjXor0+uWz8CLMAb+Oich+HMguRnphwSGsSkv2hqa1R
mwzMAXj+5ovmUwnzJlSpz8cYFMxbYJxR24duZg6CusNWr/jgSw5B4I0uSVI2
swi5IZGLNVMbyNuQ/uDi0pWTzGFo9l7m5/sxb4fwVrLQZmQ9ORyCgJ6ejBzm
CDwOPtf66auAvAN6ra9Hy0nmnYic7t2WJmXehdaJzIrYaR/ybvQVdp3uameO
hPZEap4shTkKtvoDZfUf15GjsXXhhHhOy7wHBQJtRGM0cwxenzfXS696k2PR
LBmoVcqZxRjsEdi9d2AGZI52C6aOtVbrAPcixdNjVWROAoP36GfTZy/qEhwe
ChTxGsicFM/qLrjq/VmXQpY33FnX6Ek9Dq3XRu8FZ5N1ceizjNdW3+BTj4fW
Zr76TjRZF48Fvb3fWL8HdRly3xlyBsvJOhmalKcsw6tZT8DPwq6ZcLM79QTc
L7qZKeKTuUQ8yQp8uoHnRj0RmuLs+ZfjrtT3wiUkzOfVMlm3F+badq9sE+tJ
EGeYspQ+rCfB6ajb97PFLtTlyGxqu84PIevkWOZUy5pSZ+oKtPTqy3ila6gr
MOR0Nn9O6UQ9GRvll4fUt1dTX2EuBeH1P2YlxlXUU/CiO+Z46UNH6ko0DJdU
SmcdqCsx2TmwWMWn91wqqhsKoip9WU+Fqi4s2P6MPfU02AqDLLy7C+J/RBp4
dm0V3y5NWa1bYWMa/WfOak6FX5GWJalolOZVK+ZX2PjfvwF3aSRO
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzntMzWEcx/GjkqaLpCvpJibsyBFJ5Xy6X1Tnd84R7SRzJ9VCUTLOj8If
oibMZRSiQp3FTOvmnKSlccyMpqKklZhbVKTJpe/zx+nZnj17Pe/t+T7O65Nl
m/QEAoHk7/53jq4vYuvoO1XlCS6gC8RcuT9cEcBsBEVDYOIFS2ZzXLRQ+x7t
ciZbgjObXdJaymwLrbJX25TCbI8NjzP8epYyO6Euva1R8duJ7IIekaMb18Ls
ClHtBMenhcyzkF8w49yzVObZ6O+MvR8dyTwH9o71IpU18zwUruzg8jscyUJs
VPfUnMhhdkfMJ9FgjZB5AUaS4nYV33Egi9CqWN2wL4h5ITYEJ3zVtE8ne0Dz
ofF59H7mRRhf2WUXEsG8GFrBo1duHfZkTyijtvm+TGdeggfD2y3ODU8je2Go
cknsyF7mpbjWO5AlaZ1K9sbVTuX3iUpmH3Sdqs98N5/ZFweOn27dctOOvAwt
1uNLtBJmMcKqkm2+jWMGUte906vcbDtqHmhao+qr9SQL/FBvmbbHqc+Guh/i
zX6sSCoiC/wRpeXqi7ay7g/FE9P4s2+sqQegIbsubfc9Mh8ATjYwTXWQ9UC4
7nj68qcV64Hw6de8zl5jRT0Iemfyf4XyZD4IzYZHmqf3WVIPhntcZlFNMZkP
xi3VYQfbNtZDcKHCJzavjPUQcPMLXFJtWQ+FhbFNdXf1FOqhuFTYaJXzwoJ6
GGpXz9Q4GJP5MFybEd7iUWdOPRxe2qqChg4yH46HL1y//zKZTH05joo2tZ1f
y/pyJPrn1phdMqMeAdOdIu9nB02pR+DBt0lyxQ4T6pHIzdKvaI+bSD0S5WXJ
J4WxRtSjxvQozLttYLj4+ATqEmQohzQJ1w2pSxDhqbz7VqhPnUPKDW/xrcuC
UYPT7TwHPac5Q8Y3hsX/reaw8NjHQT/1z1ELpLodY8xLdd9XSyHNXjDX4JAB
zZfpzoMMxvqlGe/zxtH8MV0twyqFqGynywjNl+sact3/8XJ67yv9X47PXkO/
/YXd4j+MIUt6
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdk3tMU2cYhw8iirICOqwiMArOBQsjCnIRQX7lJndKaQVKgVaHshTjUPAC
To7oLmbq5DK2hblJvBSFYBwxIEytIl6niRJxWaZugbhl2bTARKpYtqXv98c5
TZrm6fP93u97v/Mev7WbVCXTOI777L/v/7/2jyVWqjnbe8boD/oDQz+85gMj
GDsjufCRZIRj7I6b142JT2/4EXvg/ER9v+kw4wWIXvRYllLJ2Bs+bZODugjG
MrRXFNd/4cDYH1cS5Pdv/igjfhu/tFxd7/U143ew4/0mZXMB4wCEKyT6qqWM
5SjvGc9475kvcRD2GFPLE6oYB8OWfmrfNifGS9Fgm76pu/kt4mVYXhvcFpDD
OAQXd5ZqbM98iEPROGvv3eMHGC/H7nVHj42uZByGS8nVX53gGIfjlVW+y73B
mzgCLX0PFwRGM45Eq/fikpIHXsQrMKqbcEtcxzgKpavUF2QOjFfipHGerfXk
QuJoTM3+aO23voxj0Le9add3UsarIH0Y21PR5Ekci0mH0Q3dWsbAwDVvx59n
EvOAVDFU1r51AXkFkppnjZgCiXkF9kfZ1sdvm08+Drxz6K6xYSn5OChV416n
a4m5eNwPKDOc6JpHPh6vyo/UZJQScwno8Bnwl//uQT4BTzdeeR46/ib5RARZ
DnZ0fU7MJyKtcyQ1O4L5JMzQOHRa+uaST8LxqNDrpsPE3Gp8+dt+h0cjzK9G
Q4mlQWdiPlnkkxHoI/XcYGA+RViPT8EHg2OXDX7Mp2LLmdP7lFVzyKfiXmz9
9PkPibk01A6vPTDcznwa3IOWed2ZYj4d0SHpn7jqmU/HksxFHokbmc/A3D/M
l9tUzGegckljQ/337uQzURZ36Lxriyt5EXNZOHbj6FaXCuazMOcvD6lFyrwS
Y7ae/NqZVA9K7FhyzVqSRcwrUdmrjI6coPVmJU57tXfdS3OjfDYykq72D8ew
fDZSTnacWvwNeT4bme0HE0vOSiifjeZBF+uJMBfKq2C83n1h4BwxVLAG1e80
lc2ivAqH9jp2Py6cTXmVKJ+DRalNg9pW8siBr+32rUgLMZ+D2wstfza6s7zI
c2phfaihDaxLvrOd6vNqtCr6+q96svOrRfenEfYHDXK1IR2b/Vn/GuF9mUXM
rcGg5NNSaybLr0G8ejLcKYk9rzWQbA5ZOVDL9hcxl4t3Y4LVF5+wfK6wHp8r
uv9cKMvkt557svnJwxSXPaWvoPMgD23R/qUBfez8eaL+83C3+/4/P02w+88X
euQLz8fnY1xybvdk2BuUFzGnFfYLLfrH3HK05eR5rXA/s1b4fLgC4XoUCNfz
BcL7MBcI3wdOJ3p+OmE/vIjNOmE9rlA4ryiEpfPu6w/nsfktRN3Qluq4FzMp
X4jQA3+/UJjJc0Woqnl5yXhqBuWL8HGdMaral9bzRaL5LcKZjk2NwQXOlC8W
7V8smt9iUb4YQZ3TZ4QfpPqcHs9WvLTFBdP+Mj1MvQ+kN72dqJ4e6RE1XUPB
jnbW62m+p2Lt9fXUj9XOR1i9cTubRf5XkecMmCaTv3Rpm7SzzCCsD4MwrzdQ
/knsv+irUAg=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0X8s1HEcx/FvoohEOBH51S/HLD86Lo7X3eH8POeoFqKxVkPrhzal1r79
YaOYWmnrh6ZhWpZo1Zof24VrqBYTNW39kynXDxLyM9Xu/Vm7+27ffff4Pt+f
z2f7fj2yj6oPmnAcp/57/3vqr4kIwe7Hrc15nqAXCMiq2xYRwmwOra4uq241
sw205auVXX0eZHvk7lnydrvFvAGjRfWaznxmF9hkuKqcY5jdkSuv1zmYM3tC
9iavonTYnbwZB0IVijVVzFtR2zAqvpbDvB1i06YCiTezELZt2bUfXriRfTF8
JkfeqWb2Q/j7qwJueBN5B9K9krzsSpj9kTminenyYQ5A1d4mRc8jV3IghtaW
HJ5TMgfhOya/6R66kHfiVNrlc+ORzCL4OPa/NJvZSA7GfEtI+vIZ5hCYth17
F2zNLEao1bLubLUzeRcavkgPKYOYQ3E65YJv97ITOQzXbxTtnLrNLIHto1an
y0LmcLQV7FsQPdlAjkDfz1lNXxYzkCmcnspzI/OAS/WRT6ntjtSl6Ii/K+zP
IPNSVAzYXHwZx7oMHtXn7aWvBNRlGBfP/5b5kTk5RM4WNT+qHajLIfcdfL2y
mMxFwv2jQ2XNPtYjETb97ENZJutRmEgeqKgUsR6F5DJ/H9Nie+rRSJt8L9qy
ZEc9GlGSkbOv59dTV6BLpbnJt5B5BQ4c37/Q+9mWegwKmh+UqorIfAyi28dy
0c96LHqGNk8tWLEeC9eGxaGMYNbjkBj9XDsisaEeByu7jsJjY+uoxyNfdqnd
+o419XjYfrUXTAjIXAL6nw5OvZu1pJ6AwPJvv6QaC+qJ6NZKCk+2mFNPRHPj
0at+6WROaTjPK1Hf+lbQ62JGPclwnk+CW0yiWHCPdRX9r1V6Q0Xf15TmVbBc
eb9Id2WF3hoV9qYFNJ7wXI7Qr0+m8+f0hpH5ZNp/Rm8N8yitV9P+P2i92rDz
RtYYzXMpRuenGJ7HG3VNCkzchfOWDYu0PtVwHqmG+/P//QdbfV/v
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd03lIFGEYx/HJ9SrTtrzPVQkzNfM+MvW367HeupopgmCC5ZGKoq2Yx0Ja
EkaxWibUX9puRhoh5ZpkElTaocmWYAQSlkVgq2RbJnaxz0vsDgzDZ77v887M
H+NRXJ1dYsRxXMbf899Vd6zE2uXeGbtd4Qm6ASvXxqrXAczmGN8rWDM2Z+aj
6+zcQPK8B9kG3Yve7WFKZgfcPcnv75UyuyDGg5dXn8zsDu+6Ss0pJ2ZPWFcO
16iW3Mm7MTNQ4vjkFrMXmgo/HVJLmb2xkpRv+UDC7IM3Yl50hCezH0QLR+U7
ngrI/ihwn5FG1jAHoLW4qGeGzxyIvjJNwbFrbuQgNHyLiNAWMAdj//PZQZ8l
V3IIsjTa2I8y5lC42m+ol5yZwzCzZ7zvndKFHI4NE1+nXgFzBKzOtCr4cmdy
JPZVK1pe+DMfQMeXMpVa7USOQs7FhJ6hZuaDqHCpDrkcxRwNxcP7j8snHckx
mPaIFopzmWOR6VKkCnFlBhpkO3uksw46y4A807W3h0PJnBCV/cVmp6vsqQvh
1lE+sGZL5kRQbF4XeF2xoy7C1Ku29vopW+px+GBySTvSQ5bFodP+pVxbw3o8
fM8nToue2VCPx4SvaPlmLZlLwPSR/NWv89bUEzAk1mRLt5O5RPzoN2t5L9xF
PRF1pcrxTDsyJ8aYU/fVUQ2fuhj9U30nLOqsqCdhzrKjdD3DkrqBuWRUTKrG
1aMW1JNxoY2nWijcRj0F637yJuXxrdRTsDI8u9lsS+ZSDXqqwXwaJh9FS+vu
mVNPgyby5y+Rvyn1dEg6A32N242pp0P3fxpRz9C3LAOCpPRIuxsm1DMN5jNh
wRts/Ny1hXqWvpGFtPDWkUV/Hq3P0t9/wmA9J9FfD4nB+0iQVxA0VOv5O1Y3
L6Hv0+rMZSP43PJ34cS6zjCwzMAT2fT8VZrP0TdyaP8lmv/vP/TcQPw=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0nlMkwccxvFXRCdiERWwKmc12JQNoaCWyz5UQKjYg4ImRDemQdBivGqI
9ysqHkGoGjUZMSpmQGBqvEAkuKpBSxc0cQMW4xmi8T5iqFKNm6a/3x9tk6b5
vN8+7/umfaMWr8wr9hEEofDb+/un+/VOHVJwsf2sWQY6ANmdGoVMxR4BZVn3
nroh7EA0Cbo1D3qiyEGIGer/ueR3thTr6ipbbWZ2KAo/JF5FMjsSj+/rW/2D
2TL0RJm6Sp5EkqcgaMCRoT3Djsa+433PnJvYckSvsC5V6dgKxCyfctMlZf+I
nOLXT+yOCHIsDiiqq88uY8ehPLvm9mFfdjwefmyxan4LJyvRFTbTcNrETkDF
6sRh5rdh5ETEX/p3009W9nQscRhVqmz2DHweVGwJPBhKnon+Y3b7f75sFRYs
1tp/SZhEToI9rt1S1T2RnAzTocwjpzezU5ByWTiV9nUCORWvavuXtF1gp0Ef
WnQpMYw9CzXr0+vlXVKyGn09mx17U9nAywtHH8Y1jXdbBCrjW8P7DGQhHR9c
Nzrv3Q2hng7l+GO/LqwkCxocqT/RKAvnrsFA6842591g6rPxZ0St9Kgf99lo
HvNGGn2eewYa2vtCHKFkMQNxi7Y3dDQGUc9EySEfiySBLGaiPLhWqKkfRz0L
pt49VXfCyGIW3M/vWOpzsNzyqWXIArI4ByNPfvo5q3MM9WxYShuu6EO4Z+Of
YqefvI17DlKVubsCishiDl7em7pjWkUgdS0mSfuf7T9AFrVY25yiPlfHfS6S
brUfv/GI+1wYyhR/DUzgnovmVFmp/Ppo6rko01g7Ak4EUJ+HUeOula96zn0e
eiW7Swd1Euo6T4s6tLyzTpvYzXs9dH9UZxZf5K73Or/Bs8OAjpvJb+T9o+j7
BkjWKFP+rqBu8+qCET6RCpd/MxlGOCVt275M570Rk7WHewsbR9LeiMr95uSN
ET/QPs/TyEPCvtcf021+tPfqtjy8TXJ91cQOp73J0zBhw1bXVXMTWTTB3plW
brk8gvYmr+vne10/H8aq+Bjfnb60z6fncxjt8z3PLxTQ/y3QvoDuf1Dt3hfQ
7/PFbZuXhfl0/0/dBttJ+/nwH3pqw4uD79X/A1L3cEw=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HlIk3Ecx/FHzcyWV+nmcnPTNCqPssM828d5zWPmZmFKwRRCSypKKZuJ
C0I7R1oIaf9UpKVpp1nqHzMwTNMOakWX4pFRRoaVOVMr9v39s8HDeD3v32cP
bDCv7D3q7dYcx6n+Xf/fza8xGX9zU+vNPG/QDdwtTfdc7M88D3bHj9wbtmF2
hl1Iv3ao14vsivaB6t19lczuyM9e0hamYRZBFL1/mzyAWQqDY1bL6E8p2Rti
90XCBgOzD9ba7JiSVDEvRan1V3VBNvMyiOvHj2eFMa+AsWPktRXH7I9zLxpT
u5sl5EDsiyv8NLCTeRWcPFMvb3BhDkLujXft0mue5NUofts3mpPBvAYn9K1P
mh6IyWsx9euKbWUO8zqk699oR2dF5GAMDIZ4ed9iXo/28Qv5Yh/mEDiWldQ4
V3iQQ/FY25V1UcAchoBCYYO2ZTE5HEnhhxJcs5kj8Gam58twr5AciaCIS1KT
knkDYq/3l5a3uZNlOJx/Z+XjRGZAP6FR7HopMFsH3Bdl7Or0JXNRaKqqidI7
sR6F1pOna4tu8qnL0dwtsP2jIevksJ85ax8ezHo0jpme1gmn3ahHoyd6i3D4
N5mLwYct+rKTE67UY6A96Ddi9CVzsVjIE7R9bFtEPRbLfeyGJuLJXBz8xHxh
TtZC6nF4LquYI3jvQj0ePJsG7eczZF08YnSF00FlrCsQsTq5zFHDugKy9B9b
UzxYT8Ajo8+PqQWsJ0AZ97BjKNKZeiISrjbW+Z53op6IWU41qykgc0lwGXXl
j/EdqSfB6HA0dzLFgXoyOsad0jL3LqCeDMlMT3fI2HzqSmT6lSt6C3nUlRY9
BdbSFSZePdunoNrIm6xZR+e5jRi7/Wy62M2e+kb4354zN1hvRz0VpeV5YUUS
MlKhLTG159XNpfMWNlic51To7Ig8UNAyj/Yqi+ep8C3UNCMPZHsValtf8btE
trRX0+9jRXs1JAplKL+Ouk4N8/+RNe3VSF5f0jwYaEP7NIt9Gj3vl8y8T8Oa
U18nogyTZhssOreJvr8/ZmMTfd532V8h70nb
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdlQlQU1cUhp8rsikKgixqgtQKIhQXFAT5ZausBghLQgKPkOCC44qlLtUH
VVvb6gAynU6tgtpRFMRiVUBUIg4qOipqRbQuUCijVpERStkktcO9nbkvM5nM
l//+5z/n5CaRatZE64ZzHFfx4fnf69Cjw8869mxVWbojyBuQF1gcN3hRHoPE
wWv+UhPKFgg3Gdhyp1FK2Ap8/9jz54ooT4J12SXVmTWUHfDMV7PtkQ9lCX54
19hgNJqyIzYZBewaVi8h7ISQ8OrdJ3IpT0fQSc9wNxXlGfjOaFn/KW/KLggc
fLXHfQxlVzyXaY/uLZ5K2A2j7g00R+oof4JDJ6bbz3k6hbAHHKuflPeupjwb
hiPPFrlYUZ6Dl1k5PiWlkwnPRe/BgsDEBMrz8OtIw6PMQQfCnsh22D4+5xfK
83FR+2yf51zKC3DgTI6B329P2AvNIdu63xjsCHvDqd2kx6OS8kKU/b7n6d2d
lH2QtelNptSesi+M10VY/HnZlvAiHG9za3yRQNkPK6pyVpx9NIkwYDLzS7Vx
B2EBmJAufzy6neqLUd/Zo69PpvpiPAirUTZLqe4PyyvSWTYFNkT3xy6P8ikP
ZYS5APxU3v7tZGOqByDrQH2y7Vprogci66W0+o8QwkIg6n7bsXNj3USiB0ET
6Vw0aEZYCEJfT8DhTFcrogfDKXPYPs+3lkQPxhcH71+wbibMfYrWlc7e77+i
uoi5JSh7Z1eweTnVRcyF4LWlQte9ewLRQ7Ayo+fcsHjCXCguqT66PMWU6qHI
btXsaS0ZT/QwmBzpSQquJSyEYaNz/r680xZED0ebu+Oc1c5UD0ddg1NXvxn1
R6DKLv9A5VtyXoiA1+2qwqtN1B+JDWWndss2U38k/OK7VJH21L8UFq4e9rcN
VF/KzsPJsLahsyZFShgytFx4L8ycT+eRgV+n7r/xgvj1Iuai2PqIQvc3pTbq
LpoXxdbTRyHIt3XrnT6aH417fnkjbZ5Sf7Ro3mjIVrnc/NuWsD4am5yv9eqW
0vlj2H0iBvaTWl7k5lF/DAxclIHPGEf8H85XyXwW9IwlfjlbD3KYWdZkrn1J
zgtyKH48eWiiK82XI145u3S9I9G5WHQOnldkG1F/LHteiMWG4oV+pw9TfyyO
Tgt9PLeG9h/HMuLw15OPd7hnU38cm6ePQ7GP4/IZV2h+PE7Zl5TfCyOMeHZe
QaTr49Fg/vXy3khz4k9A0eIrtVdtCSMBs3zd5NVthIUERARfrW31pf0n4Oe6
I5+ZZtD9Kdh6ULD9Cgq2vl6B2s5xMcp1ZsSvZBlK9rygxCr/nItjD5E8vZLt
j0vE+NdW1h3WREcihktc+kyLST0hUZSfiMiSvUG6s9SvYvuFSrQ/FQLkA56j
gmm+SpSvFvnVov2pYb5+9sL72TRfLcpPYhlJ7D4FEeuTcPGad/uMFrq/ZNyt
eNDV2GNK/Mmi+ZNF/SeLPj+evR8Snr2/4Fk/z7P5As/ut5Bn59HzyNkxouK5
2mSIm3h0m1dmDcyj/adAOTN3ye3PSf+SFNE8KUi/XnHpfiVhPgVTB2/dXNBB
6gkiLhSxPgXTQr9vUBbR/BS2X07DzifRsPuBht0nr2H7F0RcqBHla0Tza9h+
uFT2vCQVva55W4+tMib5qWx9XnReSGW/P4Wpov2n4lxHjrvdLTJPU6ro+69l
9y3R4nqtb2bG+TEkX0v+T0eQfC3eevUN+ruNJvla7MpN994y1Yjka9l59Vrc
sut4lW9B59dif4Np79F5JI/TifJ17H6gY+fldaxf0LH1C3XsfdHrUFa6Jt8t
kczTJKrPpbH9StLY+ZCG3JYNW/z/IfPxaThW9dD6hsMokp+G8Pnby1vcyH4K
08h9GfAbyk8jvw+GIW6i9duGmFv2P/8LsAAeGQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd03ss1XEYx/Gf+6njnoNzyG3unU5uh1zqfM7BcReNmTRrIo0aCyVGZ/7o
OpPKH442tVxWblnDXBLTWKXssLFlrVbKosQWykyXeb5/1Hd79uz1vP/+Ombk
Hc7S5jgOf+bv3n7LMsvkrv7OXCfQAQ32en4SKTMPgx7233V5zKa41l5WVjvr
SLZA8dCaibKB2RoN9y+LtnKYbeE1P6MIlzM7wHi0tDGTx+yE2cWxEd60A9kZ
6nKL/F+1zK6Iq9ZWz2Yyu0NW9/nLYxdmT0hbhMuLH+3JYphC2jF/glmCU5uj
PgZ6zF5Il9eIm1rsyN5o5VYDa9KZfWBpOF4/s7Sb7ItkicVY8R1mP4R46ojS
jjBLoSVUp0xobMn+mB/orT+ezBwAkW62erjNhrwfglTNee8g5kAsVPUqg8dE
5CA815oIcktkDsaIpm9d35A5BCen7R4+ahSSD0DRv3k1opz5IMxzk17rL1mT
ZQjveHexeoAZqP5QUKpYt9q2CigKcM3qyiJzcoz3JO10FrIuR8mFjeHcB5bU
FXi72FyUcltAXYHlxKmqGn8yF4o9VcpXihcW1EORXaNdaORL5sKwdPrpqu/a
Luph8HA2mFuPIHPh6MlvSpUIWA9H7ZPmc8lic+pKePfZuL0vIquUyCn80a2V
wnoEBo+6DNvxWY/ApOyGrtUbM+qRqJjLqJxrJasiEeITe8n4GOtRKOjsuJJQ
wnoU9pq5r6g1ptSjkapuuysQk1XR6LBp7ZmMMaEeg+7l6/tEL42px6Dh2b2z
/EIyFwujMz7BUxVG1GNRN83/2STlU4/716o4+FZ+XZcP7aAej872vFuSNB71
eGz/X23qh/AtcGNLIfkk2+7/mUsAX6etZOHmiuw3uOv8sA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0nsslXEcx/FnHXe5poPcT5FKZyTJLZ9zXA/hnENNTcta92whckkcmz9K
SWFlXVSUXDKrqVUkLGIuJXOm25puo1KpzC2p5vtb49mePXs9799ne/54bLbt
l++Yx3Gc7O/97zlzffPmb7hVe2OfAPQCDoWHgja6M2tA/8CnmBZVZn2UB03a
jSptyEZ4z1O5UlzNbAKhx+XPBSeYzVG3tGA8LZLZGvE1LyIzhMwCFH7vU6qr
MS9Bq8pIdHaPNdkO5b83fekuYbbHTl3HM12pzMtxXH3XZLU7swPUNHJFwzxm
IWoMD94tzrMiO2K6w2ro4mpmJ3w0zxfXv7Qkr4JmUlqhaRazM24LnCBzZ14N
veqSsv4OC7ILEqaMO3fEMa9BV/sb47LFzK4o1jp9KqLHnLwWIxPbzy5LY3aD
pX57nMsrM7I7JE/5zxKzmD2gUhfb56rL7InrBv2P1NoXkb1wMot35/UW5nWo
36h8ZzdpSvZGadP9lr2tzIC49ld2QDpZAQw9Ho7xcmRdhNwUUal9mwl1EQYj
O5O/JJM5MR4aJaVYfzemLkZTcNny7igy54OrL/t7esf41H1gcynTSNRJ5nyR
mjHRuK+CdV+cf2wrUctm3Q+ZF55sNY1l3Q9FiWXPHQWs+yNz0ObBGwnr/jg6
8aTCdGoh9QCUx3Z27z5BVgSgcXGWPSdgPRAee+MLo2uMqAfCsKp3z7d0MieB
uDHccoUV6xIkLTzH5ZYuoB6Eba2Ce84KsiIIx3Ku2lbxWA9GfZRto6W2IfVg
WFT+Uka5GlBfD8OBhqZKOVmxfk4PgZnJ24FTefrUQzDNyaajE/SohyKxVuq5
dkyXeihWegkjHnzQoR6GK20lB7UTWA9D8w+98M1x86lLodQ5sns8lM5Diu47
vT/7xrTpvBTOOUOjogbNGTdI0drslZRwT4P2stmGjP4/LdrLMO6Ql3Ythu1l
sAoMceNXqNJejsNFPXX8fh7t5ThQ6eF9s5ijvRzavKrUj/nD3jN7OX3P+Iy5
8Nkdc6wIx1e3id9i4QfazzEXMdv47z9ak1bi
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxV021IE0Acx/GxkbqWuonpaj4uKV1r+ZBPqdtPnU7nnGAoSBgZ+Wqi0RzU
jLbEknoR+YCUSEXRg80SF+rUUhQNE1pUKKaElSBYkVpSuYY94P9eeHAcn/ve
3bsLP1ZVWM7lcDjKf/P/ujGWVQFF3QNdBiloAzn55SFIZfbCgil4ptubWYhz
QZqh9slwsj9aJx5rtLeZxZgu5NS+MzEHYcSWZozVMIdBJpbHp4qZpRB4PRXN
rYSRI9B9qsx5s595N7Su52bZBeZILNpV81MFzDIMjEunIiKY5VD3D5covoWS
FdjW7G4bsDBHo/7Oh8pnP0PIMeAqPxdLapljcT6yZu2RjDkOcTeijoZ2BZMP
gB89m9lZxByP1vsqn3Y/5gQYnHL+yYYgciJEFR59bZHMSVhsGT2tn5GQkzEx
tN7wIpT5IHRD/J67JTvJKfB8+/L4LJc5FXXKsn2+7TvIafjqOdp0I5tZiSfG
kt8JPWKyCllePPdqFzNwdfg6r76YbAUU1+xLpe5A6ukwV++qsqWTrenYUh28
1+IIoJ6BS2ePBHasbqeeAXXbe7++i2ROJmSHk8YGC1jPhN4orGkZ86euxiFO
krNLRLaqEdMv2fPR5Ec9Cyemvo+UhZOtWRDKYyTOPyLq2VjYL42rjCJbs2GK
am5qtAupa9Ap6eh9nedLXQPRF/+A5QAf6jnQd1zOKu/2pp6DV47J1elfAuq5
WJM3nrlXwaeeC8O4Y/BNH+taXKnjOeZKt1LXwmxxDRseeFDPgy7R0juv4FHP
AzdM5hLY3KqNroPRlqKy3+JQ12Hj/3Hpfv5mW/M3n+foN79n1UPAe2j+1LRC
7xdgKdm1nqH4ofoLGpjzwg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0X9MzHEcx/HPSkSa9Et+9ONCpFuTSB3nXnfXqairu+r8KMuajJWFq4XL
+spvCYmtJaFZRUTIj4xdIzVWfmwy//gxMWO4+VV36RvW+/PH9d2+++7xfX7f
n332+Uoyc/VZDoyx1H/3/+fQZVF4pzbfbsoOBL3AxgNXju+QcTvDWql8uVWU
kN1g7cxtldzh9kSx0q1efpzbB786fIM3reGeAqlzuYNWyh0Ap8SwZ4O2AHIg
qqXTb+3s4J6GVRXuHi713EFw/+hqVG3inonHPRfv75NxzwLrX2h44sQtRVVR
WoSm1J8civ6GOz9Eqx95NhpKLZsLD3OH4dQxSfML0Zc8B9YTveemnuMOh1uA
ISM8insuWmNNFbWMex7U1zK6HlyaQo6ALO5puxDAPR+/vYsd1+2cTI7E5eoc
Q3oIdxSiX5lEj+eTyDKor386Oq+EewHuGrp7gvonkhfiXrxnRmoNtxxyWVxY
4GruRSjO+VJS98KHrIBlRruf03puoKK12nGvgSwAy9bW99kceVcisq3IVN0y
gboSB2XiWnUBmakwsFmSkB/JuwpVN76W+I7mXY3Mu2++i9e8qash5Ct+yoLI
LBqd6uUT3/d5UY9G5UP3ltONZKbB6891+cuqeNcgUxtcL47lfbG9hcWY+6y0
YHqLJ/UYhLT7/Dr7lizEQHcwLGTEbt5j4XfLeH3vIw/qsWiM+aYvGEtmcdDI
ewof29ypx6E8y1KeXkdmS5B1stbBdHo89SUwNl3an7SNzJbCt+FPd/p83pci
WDvVU7OB93gYGxYortS4UY/HisqLZ7ykZJaAQaYbXJ03jnoCtBcOabKaXalr
7S1osTKkLLZriwv1RPiLnY8iLWOoJ6LsndGk6h1FPcneGGYhCeGlX3qV5tFD
NifBcvXpwHYvMtOho01ekNfiTPM67CnLlpn8+bzO/nuzjs5/BM3r0dSYeyw0
jc/rsa3I1pp9fiTN6+33Yx5mlmy/PpJhlR4trMshC8n2+zEP6ywFR3Y53ny9
is4HKfbrCSnD5lPofzGaT8W3KJuoCv2tGJrn/qD4C2EDYPs=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJw1yXlI03EYx/EfWjCdOsuzaelGpaksb9s8fh+3ec2JZYeYSEOR/lBRKxEd
zXWhEaJk/eNRHhmFKGhFmFnSgaEglGiyMiUrMrMSTfJcxZ7vAw8Pr+ctyS5M
y7XiOE7xb/9fy/ziXY8+6OvOk4IemHKsKhXGMAsQ+H5iNd8sITti7lRH3fIw
szNcCmovopnZHU0VGSNDRcye4H3EqeshzN54Kg012a17k6WYG7nyYryfeTf8
umRit0rmvWhYVG/apDH7ol2yYZvpyuyHW8emD96c9iIH4EKeplhdziyDio/c
c17EHIiF3s+y+au7yEHISZnHKzlzMEx99W/1pp3kEOgbpa1HdMyheOx/+e6H
WU9yGGqabHvjTjKHI3GsYSNrwoMcAa/sc2vXo5kP4He6hkufE5Pl6H5XPfn6
ErMCK8fvx37fyhwJc1jB2crnO8hRGH4jN/fmMEejvedlW9WoOzkGwgFvfr+e
mYdo4HC7lTszYL/UOJvc6GaxERAYajyGTpC5WBgFIYbFT67UYyEcXSreNJA5
JW6U3DEFSllXIlxs07bQ7EJdBcmWyenFdWfqKujHyuw5HZlTY/WPqrU0gHU1
moxj5aIuJ+pxqL5n4/9kajv1OAQ98vD5WELm4qErzlob+rqNejyigrWVDjoy
l4DTHZF8T6sj9QSU7RtcyU0lc4nIqO9scQlgPRF2Ts9Ki2ZF1JNg5g6ZdWfI
xiTkK2v7HVocqGvQP6j44TtjR12DhnHhyu0wIfVkdHcVXpNlCqgnQxtR8XBG
Zk1di5/y1U2lbJm3dC2E1p3l3+oWLOZSqH/h/wJr8uzj
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdlQlQlGUYxz9F5ZIAxZVTFlACRSwR4pQ/IIcgyH0tLN/usuiIpSKYaeLG
iNeEI8doadkmDXiQio5xmX6ioGRYHoFXugnhkRnkBYhQDe/bzPvtzDc7v+//
/J/neZ/nnV0H5Yp49ViO4+r/ff77Hv30BkqSTjbV5jqCvMDqYvOq+kDKBtju
z01uNqRshlNHbUL4TgfCFiiUJ+UvrqJsieQzz5LkBZRtYaounWPrTVmKqbsM
uja+kBJ2xFfWqkV3LlOeDtm0iYuydlJ2xp4fW0MEnrILikw3Ojf7UZ6JGQvX
Bt2UUHbDPb3ba3tv2RN2x+4L5V+4FVJ+B35nwp3HSCi/i7fvVt6UaKcRngt7
sxfVdaDsgZSKmJbtnXaE52G2pK9y9xrKnjjqcGel6QzKXti3/ac9EadsCb+H
qI6/K608KXvjs4thsdY6G8I+KG73PfblFsq+6DAoVC22peyHkftOjWUV1oT9
sd8twSJ+DOUAGI14LHty14rwfOhd/7pzfjHlQBzscb/xMJUywA88GCiZTFgD
tPdtLpyeZ0n0IHiU29UWfj6V6EG4PWLTJMsnzAXjaebZOkWrhOjB8DoYnxm5
njAXgvaQVKvf+6cQPQRt1zcVF7QR5hbg9SrtxuilVF+A/IZm6blIqofC60nP
rzX6VA/FUOU4hwc/WxA9DLX9Ox5ZgrAmDPKtYY8Czk8mejj0p41LPH+VsCYc
G/ZdOyX5jeoR6F7m6vtmC9UjEOzOV+TxVF+I87HCXk3jJKIvRG6qfpxqN9Uj
UbeyKs19CvVHou2jBf7ZzlSPQkLHtk+v2lE9CrPsJFZLFCQftwglJwxnnb5H
84uYi4Ys/IzR4DGqR+P+Xi/P2+VUj0G5urc8o5rqMTCq7JeHtZgTfTGuq18a
ujQQ1oiYi0VRt7Kku4YwYuFzuUnbqjMj8bFwCFqyrWCYsBCLnjmOHh+4Un8c
qpwib81rJjriEB3W2tIdQP0iXYiDyfJJf2xdRZiLZxnxeDbcmFakT/3xbD4h
HjaWXQ9Ly6g/AQWuFeVlx6k/Ad/17pxj3f4W8ScgJHHIa3wYYSEBh/0dl7qc
MyX+RBy1qam7GkUYiYhdPvPSCytaPxEFTbH+3v3UL4rnkmD+xELSKyE6kkT9
J2G2uUvfniu0/yR2vlwyex4kwzXGySL0fbqvZKw+7Bd4fD/1J6OtY/rz1xPp
/FPY/BCxJkU0vxR801a5xjif9MulIqZmR6j6pAnxp2Jvh/FAlacx8aci92L9
6WsNhIVU2A+3X/LuNSL+NFZHGq7U//L8Rj/1p7H5hTR8f8H3qUvXROJPR8sz
04T0VYSRjvRZpRGX11J/OnpPXHmzYYoh8adj3cbBs7mHJhC/DPYR0T6SQ+OJ
X8bGa2RsvCDDzk169fcyaf8ZuNgS8GF+owHxZ6DduvdxhRnRNRkYcCv7uHo5
rZ+BlyYNnwx50v4z2XlBxJpMkT8THiV/vgoSCHNylHatXh/8Sp/45dhcmuu7
3p6wRs72I8jZ+XJZovllsfvQiFjIEvXPs34pD5O8uX7Xiuh94Nl6vIg1PLsv
Lc+eT+BxIOhcS6sVyacT1eMUbH9Sheg8Cvb8vEK0X1G8VsHuV1Cw/ekUcIrc
1ZF+gO5fyc5DqmR1KFF7ZEWFu4zcD14JtxPjJnjtoPtRsvdPq2T3KSjZfeqU
7H3jVOz9lKrwl8/gcLA7YahQ3dQp+cGW5OdV5P9Lj9QXxWtFLKjY/nUqtj8u
m9WlIkY2O28+m+1fI4rXZrPzEbLZfnQinVOT3zeO1FfDWO/bdY/Lx5D6aqSk
zz2S5zgSOFpfFK+h8X2julZN6r0cZUGk60Q6l0O4Z5SlIoaI+Rw2nyaHzafN
wVjpzEHjw0OkvkjXiZhb8n++fwCYCCVZ
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0n9MzHEcx/HvLuXHietc336qnNhF+p1U1OtOSaXr7sqYMdWw1i9JWKr1
1WhRaBY2NvqjdUs/Nn+wcscOQyIb52e1YZLyI20S11ph9/7Muu/23XeP7/P7
2uef75KsvbrdIo7j0v7e/57WazSW33zNcDVXDnqBsMBfki0RzHOgTZR0iaeX
kCU4vtyzKeceswzDS/NF3heYXeF2bKJqWQ6zJ6arV3UEhzD7oLygfipMxCxH
a03EC3OPD9kXkwfef/SrYV6OwlNljz5uZ1bgx+vOR18imVfAFBzV12jP7I+S
ssV2zxq9yQHYWxiX+SmDOQgxffU81+tFDsZdmbtkTwpzCM42+ykUlsXkUOwv
OZFhLmEOQ0zvns+ZQ57kcCi6s6r69jOvxptrP9pKxcwR0IsKH5Zf9iCvwfef
6rFxH+ZIdAUZimt73MlRqHUO8i0MYI4G97xgX+6QG3ktBuKqK0YymddBmpve
6zDiSo4Br/yQ13qQORZHp/t1DnOZgZ3JRhjvuFgtAPmNWbOrCsicEqfNkprH
Sawr4VWd0zzmzLoKhto6felVnroK5rz+zq5dZG49LnRLbzS0O1Nfj6qe825b
/clcHLS1wStnHZNRj4PqdprXSm8yF49VnzyEebNYj0f5JbORf7+I+gZoAhvk
xa6sb4BU7GIcNLKeAFVARn1RBllIwCHni9zpJtY3zvxe2Ijhc0XKtljWE1Gc
rb+VykupJ2L8RLvLjjEn6kkYDJSHFviRhSRIh0x3WnSsJ6NyIOvkQCvryfBT
L5XF57O+aaaFTYh8Ymi4/05CPQVbtoW0F8kXUk/B9dG6QPeeBdTVeOlYnW1R
O1JX4+JLsaUpXEw9FXVH7Tre7phHPdWmayDyWTEhbplvNTR42vFi7PVv6oIG
Tl9l/ChP55k0cCwKiTZX0nmcFjcfRI0oPrC9FuOOnUcmw8mCduZ5JpvO6WDx
P1Omz5tLex0OV0zczr3iQHsduu6tO1R8Yw7tddAbXvHdnva0T5v5PdLo/7Cj
vY1NNubS8T1yYkoVMB5r3dtYSEfoyW+/lCaL1ab//Q8di1PZ
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1H9MzHEcx/GvE50r9PP0W5dSXYR+6fTjXl2q6/p9sSn5MZb1w7BKUeS7
bGhLrYX5UW2qJR0SExPrOjWZzciWsaUpbCilmNzSsHt/Zt13++67x/d57/fn
/vpKdu1XZwo4jkv6e/97Gq4JuXjznc72XDfQC7xrK+KeBzMLsfhLobZLxGyB
QY11zOgrCdkGAd+z60Zqme3w6UGltySb2QnlBXfvDYYxu0KuCnCwMmF2w8R0
2cOjL1zJ7sjLWHpWd5F5JY5cqc9bo2b2gib/q9VZD2YpJLPjwx39y8mrYH5m
prbzGLMverbNC9R7Mq9FhaL4taTDhbwOuxPG0Cdj9sOCmSveihFnsj9KfkmU
afnMAZja2VQXZM4cCK3Hy8NDNU7kIEzWN/sECpjXw6S8Kqf1lCM5GJ8dg183
ujDLMGmvXXCw3YG8Ad23G3rmS5lDEDmu8iw7bk8ORUtpwj6lI3MYpAPXrYTn
7cjheCAbR141sxzFoZfDN7szAzu6eXuRNZkH/Guc20svLKMeAV1FlWWjG5mP
QFbJ2z0NAtYV6Pxwy2moWUxdgaDJdK+4IVvqkbhQWZ+jKyTzkdiirLIY7rKh
vhEZQgf+vIzMb0SR7SWuqtmaehS2xnSJ9DetqEdhusm09H0EmYuGqHF6e3Sv
JfVohPrFn1yyk8zFoHmF6k2AzoJ6DA57P/6VmUTmlNCEumV5PVpKXQlza13R
gU9kLtaoxxp1FSxHbcQT4iXUVWhzvHa3P471OORrQuS3Gtj5cUjeK336w56d
H4/YqzdaPWrZ/nhMzd5PKzNlPQFNTxoLzQrY/oS553GJWB3mu6nr42LqiUj3
qVY+O2RGPQkrVOcG0ltE1I3MJc81ktHXG1ZUcF9Iv0+G/+mxnxHaRQZrjTqX
guJj+u7c1oU0n4JxmX5W4UvmU3CiOndDyXJTmk/BxO0Xv4/a0j5OjeqR/BLF
T+pQz93Hq43m1TB8nwQ0nwqBq1RvppmRG+ZTYTb/evHnmm8G86n0fz4arP3f
/wAeJjuz
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1AlMFGcUB/DhkCqgUAorrFy7IPEglEsOEffPvdywB8sSDaaKGBFJQI3F
VEZRo9QSjQe2CVUaIhtWJWDaVbHtqpF4QFSItFFbbQWvxIhHrAVcarPvM5lv
ksnkN/9537zvZTKKL2o0FY6CIKz5cP5/tR9jKpn+x97uKiXoBiyXG9WusczT
UdPjMtkgMHti1ejcit5+BdkbKoW7e99BZl9YEhrbv61k9sfX8hafgHDmYNzJ
srR8PhpMVmJbz85dTaeZQ5EXFj7oVscchhUb2p9EZDPPQ1zU+1/PejEvQFNr
elf0zSByOG5tMs24v445ArbF24ZGnwaSI7Fl7uaQumrmKHSE3TX/MR5Ajobv
0op9U3XMMWh7f3HLuUDmWCiqjh1YvcOfvAi60CB58jLmOBROfPelcWwOOR7X
zB79v/QxJ2DT3o1H1UeYE9FTKQvrdGVejJrakRvV7XJyEvZvflze5se8BPsf
/Jnm97cfORkNAVMx69czL4X2zGSkQyyzCt4D967anvqSgam1K3dfeTzbbhHw
KVgd/8hCFlJgVCYc+72E5SkQp8dsfT0iozwVLcfbTMpAspgK091Lh1qHfShP
w+i0w28tLWQxDROzKlUXMliejsjljR0/m7wpT0f3u+YP3ZGFDPiWnx9szmR5
BlrF2/Uepz6jPBPdr+RH69eQxUys3fDuJweDF+VZmF8Q4p1R/SnlWbg6HPpm
wp0sqBFgnhxeFs9yNY6H5NyJvehJeTYUKZV7NtrIYjbyM/sujySzPAddc05Y
BnM9KOcs5GJmbXTS0PaZlOfCMXjBuJvZnfI8xHzz/J8U6wzK87Bvh9OZ+8td
Kc/HgHzs2UFPspiPINvA9YQxlhcgJOfwcJmJ5QVcfSGC1PmJss5plBeieG/U
QuedzpQXIS++wfIwwsluFMHN6WT9swMO9HwR6sxJqp4fBLutnIVirr4YhrLo
U7XKKZW9vpjWe2m3lbOgof3/azc0NJ9Jqtdw79dI1xe00n6hle5P1KKj9zfZ
NX/av1WLr74fOi/7i/oVdNLnoePmpUP4aWeXuOZPqF6HF4njttQIF6rXS/uB
Hvb/pyPV66XrWfXc/EukOTiLJdz+OQsGbv4Gbn4GaT9WA9d/Keobxi9UdZJR
Kp2PWCqdr7VUup5g5OZv5ObP2WqU9iuUffwe/gPbGJ51
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd02tI01EYx/F/m+bMUCtbXmZTu1jOLHPeq/1S52WbumlS2o0aSTLNblpU
y2kZSBcUQ8Ks1G7mRG1lgkuwRKHbVhlZGdH1VRbW3piZVvicF3rgcPic73le
Ht/t+Wk7eBzHJfzb/8+JNSQTZrSZb+r8QBfI/27taAhjFsB67Um0/I8v2RUa
f11h8CNmN+zcktNtV8XsjvxAwZHPOcwi3JG2T7sdwuyDA9B799kz+8G0SCJz
f+BDXohWqTZDUsW8GHvrdMaiXcxLwD+n15vimAPQOuJtXcYxByKt6enPdxVi
chDGH4u/XZIyr0Bhbp679sF8cjDGRozKCC3zSjTXXgktG/Qmh+DkGbO17T6z
FO9PvQmEgjkUH8t2d57mM4fh96+Ao66VInI4HD09tpYsZY5ArLp+QWa1FzkS
47NLapaomKPgoUvilQ96kqNRqw1R3S9mXoWCTvGhlgjm1eC/qOtfU+pBXoM3
QvsbllRmGWZIjm12HHInAxf0ouyrlWQDsD67YXiEz/pa7A/pXV3wZB71tei5
d/lV13YyF4POwfSU1MtC6jHwMwmqe5LJXCyeNVltC/PmUo+FaGADXCvcqMdB
cypYYldKNsShTZY9fCSXdTks2zb8sL2eQ12O6RnTbg11z6Yej4/nw0IHKsmG
eAwrvwiKVawnYJNDfbWXfBb1BERazLW9712pJ+LrW//jy0vIhkQk3WhuXFTj
Qj0JLV5N7c+VZEMSbGMdmSUObF6BArN6VcSwM3UFYteNhtnHkzklcmPKO53r
WFeix+aSnrVnJnUVsiQViZaDTtRVWKCoepnVMIN6Mm42558N2iigPsVcCk5U
6KIOix2op2Di//Kop062IRX7jNEyUz1HXT25Q43r5n7hQ5E9vVdDf7HvrvAD
f8JdaqjCi9o/BZE5DcSJyZHCRnqPKTZopsxrwPMJGHEyjsr+AtUuFdI=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1GtIU2Ecx/Enb80KtNLlfTVNI81MzWu1X/M2L5tzVppaoilqK4b6phR1
pRgF3lp3RTQsbdGkoiyzsJAkTaWMIrpRRpBgaVGCll3Y/3nhDozDZ9/zOw/s
xVZla1S5Zowxxb/P/7vxmpQIt9+4c1UtBn2B/D1x3TWB3AJIh/RezrOryLZg
/eseufdx20G778DBe8e5HaBvLmzYreF2wW1PwZEaKfdKTIiO/vAQcovh8S2n
7sLYSrIHClPz3py+we2JurK8+vha7jVYP23fm7Odey3kj6MCszy5faD+oLAq
HxeRfdFwbvz63mZuP+xP6Az4nMi9AcKLlX6zv93I/vjpa332WCt3AFoLDrk2
xnAHQmquDGHPXMkbkb1xPGWmnDsIuoddXd4LuYOR0e1+uKnLhRyCjohs+5oY
7lCcLDlUO2HJHYaUvLablwedyeF4Iix8e/Mo9yZ4acUFOyK5N0NT9HFkf5sT
eQvubXoVPKrmluB0wQrW6sINVOWs75+pdjRaC8zpXYPTHclsK0ZyZAl7LjlQ
34roRuupdm8yk6L4hKHMuncFdSkE5XXOA5lkFoHObRYWU1+E1CPQYmPm9CuK
zCJxbmBZd4vBnnokZgtbKuT5ZBaFa53Vbg6v7ahHwW9XZfvdDjKLRobASXsm
lPdoOGT2PK2N5j0Gw1mpU99fLqceg52ZD2RpqWQmQ5+yt1HbvYy6DLrcSV1G
O5nFYqznt9Y7mPdY2PpscB7+s5R6HIovh0uunbelHofYSwb96iYb6vG42x/2
Zc3YEurxEM0NDYZMLqKeAPe4U8/TOsjaBNRXmd96t4t3ORrGikul0wupy1FS
MXNfrbeirkB1gzqsVMS7Yv7zLNFknwif6xZWQbW8K9F+54VwwMXSaChR1jza
I3xvTs+b9F4lRDJ5qFBPZklISfM3FIn/SIz7JJN9Eq4aNCd80wW0T5r/PqYy
OV+FxeZXSsZ1C2ivgvH/yIz2Kvq9Ge2TTc5Ppv2U0dpkfA2dmZP6fpL8BZlk
ObM=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJw103lI02Ecx/EfTvMuXXOaV2pioqbO+1r7bN7zgpFEkSVmoFYoTNIQY0Xg
kUmS0B+pYGoHRqWmSxslhW5apmmeXZglUZpKHlQaGX6fBx4eXs8bHnh4eJwz
chUn9DiOk2zO/+vWWJQIU9sft5x0AW3gu7zM/0MEsxGkHuULCmNmCzQtPX+n
GXEmC5B4MySTV89sA1nv/GBfPrM9vqjLvEPEzE7Itmo7WmfA7ILw/uW56lEn
siuOdKd5Hm5ndkPGg5xEXimzO9zXqm5/Tmf2gMH7rJbrgcxe6FnpePXk026y
N7TrdgV+SmZfTC4fk14zZRZB/97QxPEuR7If5O52xj1yZn/8PG2oVS85kAPA
TzM96HOBOXDzPrpsoYA5CCbnenMcGuzJwXB2mguoEDGHYLDvTdNAtx05FGNX
ea1DCuYw1Bqlnx2esCWHoylXtMctljkC/pfn16Tdu8hizA8unRL7Mu+Hrkdc
kN9lQ5ZgfLS4vzyCGcifatBZTlhvWQXUu9TY57WSOSlq1D8uORizLsVb7cOp
caWQugwvZxo24EFWyXAnb+B1VqUV9UikThqUlRaRVZHIzlwp9NnLehQ8tTYr
jdMC6lGIk1dMtR4ic9Hgm1prZjU7qUfDsVPZUfKCzMWgKcxfd6uWTz0GM5oN
lWcwmYtFlKpwQ1RiST0WfWOuy3/MyFwc+F+7nzUrWI/Dfbu76uGEHdTjsU/s
feDprDn1eDT2NZwxzd9OXQ7LOYFwUUhWybFq3nl+PdCMegIGbBe/VVuYUE/A
lYu8Rx/TyFwivZ8x9URUzSiLZGuG1JPg1aa/LaiSrEpCcd2IRjjNo56Mrf+q
Rz0ZyuZwSesNjnoKnf9LstVTsBD6+6/Me1XyD3/MBMU=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd03lIFGEcxvFZjzRF82q980hEVDS19bZ9XI9ddXfV1QosyTJT0AhNMDay
hcpSVBRF0yTTLFKzSDFBLfcfKwJR8iDoQsyCUjxITPPI2N9LuAPD8Jnvy7zv
vMy4nLmgyNLhOE62c/67ao5FIf9o78CzXFfQDYRmdxgFC5kNYZwqs20zZDbD
aEZPTvlHF7IVuPzUrtYuZhv0TiZcn7jC7ICeyg2IRczOSJSsDLzlMbuioYXv
nf3OmeyGOOlQaUc1szsGbZajfE8xe+Daiqq72Y3ZE/JswdCfLSeyN0Jna9v6
Sph9MNzEuzTjwHwIJRbn6nj5B8h+uCn/sjW0h9kfn/hz50/cdiQHIFA5625q
xHwYvvpj485lDmQBEqaW79sKmAMhmbyzmf7enhyEab2y+pFu5mBkO1YUjKUz
h8CypqW//bsdORQvwz8Ejecyh2E1M3ik6qctORwNjUrBr7vMEbinr1a8VjIf
gWhgo0xczCzEXkm4YF7EDBQ7Wj9YnrXRWAWMnpVIM9vJXCRCjsU2lxqzvmPx
BLqfWlMXoaQ6N/SyE1klwkLI+pbIh089CpMeeacf9u2nHoWUplp7pR+Zi8b6
76jWIm8r6tFwK+LVBC5YUo9B/XQ57/OSBfUYzAxuqryCyFwsjHW7lD9qzKnH
4qRBa6N9DJkT42JnmLC71Yy6GLLYV8NfI8icBNtc8nZG4T7qEuSJql6YtphS
j8PzxSpfuxGyKg7mc1b8RT7r8ZgyuZWzJjehHg/548qYrF4yl4CD8XVTaY+M
qCfgzXBEUWG/IXUp7Z8BdSmSy/289G7oUZdBGnS1b8ZHl7oMOs6e68adG0JN
l9P786hrmUuE5n/WoZ6o1ZN2Pw9JCKiYX41Ur2msSqL94zTj1VrmkncbyVrr
1bJaazynwPE0/ycFrts0v4K+n280v4LWu6SxWstcyu7x+O+/T8M2Pw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1H9MzHEcx/Fv1zVZrVWukyRXM6tY+qGSK/e6U9eVS9f5UX6sHxqzykRs
DekyhDHrhzStiCaEEiep1Y3rhwxLSyalMT8yXBa5Tvm1e39s3Pbdd4/v8/P6
/vH949w3bFVv5HEcp/x9/bmbfyMS4Spt07V0D9ADWFYG2x4QM1tj5PW2HXUc
sz36FzR07mlzJwuwT2p/IewEszNCDzfPK0lkdgV/VMbL9mQWIeje465MjtkD
dUP7o7b0iMhzcLHx04BtBfNcrPAcuNubweyJEtFEQKaC2RtBfpOtjY7M86Ff
ICkz6WeTfWCPwNq3m5h9IU8xtkQb3Mh+UCjet1gfZfaHocMYWeXLHIBBo1XO
pYezyAsxXnE6fF0CcyD4pfn+kXzmIESIavXnOl3JwXj5qK21Ko15Eb7n5764
LGAOQWmnXOUyNJO8GBaGoomfScxiuEl/3IgecyGHwutywcvb25nDMNwaVXZq
fAZ5CdIm9mn1ecwSFH7c7LlXzAy4O6dMPhhwNlsD3OwbXejYQeakGDLd4q7k
si5FX29O15FQ1mXIKr6aM1U3nboMdtneqweLyNxSjJra254/E1JfitqVfP7n
T2QuHNr1u5LjM1gPxwlN2DkHGesReG1VMtZw0ol6BKqb+oRdrmROjtT+5ubq
DwLqciT1aRN7sslcJMZTsibztNOoRyI9YUpc6kkyp0DiIflwmJ51xb/nuSis
SbqjWJvAehQqqzqdjj9xpB6NtB3GmxbxZE00Npaf5+0+40B92b/WLIPjO92d
GjXrSjS5FJc3GuypK7HTq7iosJ7MxSDkYdOZ9iHWYxDqr8y3S2b75VBleN//
OoP15XD4IBCOCO2ox6L7Vu+Xp0Yb6rEYud49meM0lboKBwvSF++ePcVsqKAM
zm145WNJ51X0va3M1qlg/n/g0T4O8Wv9r273+Ckx7+OQVSOW1J/laB8HQ4jp
h8xnzNx1/53n1OCJvE02NRO0VyPg2MdvUt242Ro1bCyv7Hpf9Jn2anrfG9qv
+OtfFlNGSw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0H8sFGAcx/ErEi6FLoTyu4QplPzsPufH4XAOoenQSCy18qMIu26WqNVm
XWilZkqn0Q+WWmyN6sofmpnl2lpUM1NNERW66Ifvs9Y927Nnr+f9fP957NIP
xWUu5XA4ot/7z7m4JvhmCe2drTn2oAsYnrfZ7RDArI/SC2W+VYbMxoh816bK
VduReUj0y9V5e4XZAqeay7PbDzNb4+Bw3quBzcy2qJi1qObO2JLt8bXStv5G
H7MjThbtUhs3Mm/A2fd59QoZszMclEPOtxOYXSB9nvpCz4zZDf1GtebTvTZk
dzg1PhFEpDBvQVHVnY0Ro+vJHpifa470yWD2RIYwZ7J7eB3ZC1cNau9klTJv
xSela62My7wN0g6Hsrr71mRv8HqOJcrEzNuh0hw2vaixIvvg8t2qhT2XmH0h
3deTMpbK7Ad1oN7ReI0l2R8NoT96C08wByDh+MukDAFzIBrc4nlxS5h34HEU
Ly2hYS2Zj6BOzekwGTNwTz211fSZxaLlwKrpW/HjnmSOAD6q4yVXOsypC/Bx
b1vZlxYyJwgri1wShxSsB+H6zyabDXVm1IORlTMa3GVElgejv6VvyvHgGuoh
8LY0uDpZT5aHoLE63+QBWA9FunhT0/wK1kNhp/v6zZSGR10Icb5xSY2KLBci
Td2eOlDEehhG9m/y+1mxmnoYZq4tl40ITKmH/295OB5KnbrXc1mPgCJzQiFV
sh6Bgmzlwxgz1kXg6tws/qAwoS6C6VjXo+Y4MicS+a23T0mKWY8EP2laKrZi
PQrRwqeqkUBj6lE40ikJ8JlZST0awTs13suEZHk0Bo0qs2fFRtTFcBDVDCY3
GVIXY9btXKnygAH1GPSoAgsLOvSpx2h1CWLPeLjqlusuGhLkN/vz2xo49F4C
r7Pj3wVds/y/7tIyJxZJyZ638uwXFg0ty2O15mPpvyZpPg6ffefmg9y/0byW
5f/8C3duNIQ=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1H9Qy3Ecx/FvCfMjlySVRL9ITRRblOy11oZZWWuz6pxf59ep82tzSX4M
R+kkRCRU5Mf5eZbGohTqovPraId/cDg6XJEfjX7g9v780Xa32z32/Ly+u9v3
7uu7aJVqiSPHcUn/3v8/ba9Wkbum4saVVD/QF/j2XD+2MYKZh9vGoLAXA5ld
oFb55nS+8iW7ofDUnqauK8weKFc/Wzx/G7M3fExFmQUa5lFIEpxI1foz++GG
14Fj5pZR5ABkB28Rfq9jHo2clyXFH3KZg/Cqo7JtfBxzMIzra5dVejPz0Z2X
0r6yfiQ5FGWDrjlkzmWeAP3R3OWHPJjDsKa0IkBj9CGHQ3Px6sHdMuaJuFRS
Jtj1eQR5EvrvHMnrWsAsQPu7isSiJm+yEG4NGXM2xzNHoKQ7rzCndDh5MlbL
YjOyljJPgbW580/say9yJIwbTh2LzmeOwrZz713yVcxTcfe5/IjkvSc5Gorr
kI49zDwN+tawKlcxswgOkSHmR/2YgcOKABUv18NmA3DSsbggMJLMibHu95jL
9+4Poy5G205pkjSczMXgQlRZvfyjO/UYLKp+/a3rKpmToLrSldd6gHUJzI3J
Jm0y67HoW+t/lP95KPVYSPhNj3rtIHNSPL5QtWu7xY26FBsyQj5YAsmcDAHp
DvnCliHUZZiXLWuOvkvmpsPHrDNlNbI+HeWrdW0p61mfgYcLk762vWB9BqwL
dZ1bK1ifCUXElmtvQ1mfidKyhqF5FlfqchTeOpOu4ZMNcqzQt5sctKzPgqyq
eQWeDKY+CyLt97nxw8mcAs5prp+y17hQV2Dc4KCvR56QuTjozkeJjCdYj8Np
f/nLSbdZj4cyLbjxhyfr8ZCoO4S9ZYOoz4apde94rwdkw2ycFd+pq/d0pq5E
kWWA9bRggM1Q4qezeWuHYCCdVyK14Xr1UzP1GiX2vdVlxvzqS/sE8Mud+gj3
kJEAK3//xjNp/WifgIa66HR9JY/2dp1TwV9eYEk525/2djao7PYqtEz53RUT
2of2iT2NRPq/ONonwvY8c6S93XlOTfe3F+3VPc8b1D2vV6PGpuNPb7q/ofOc
Bgm7w0KcdjjRXmP3+3au0UCbEn5prV+3yLafg4m5X36Ja6yivxcMcJs=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd02lIE2Acx/E50Aw8Sm1q3gc1c1le826/zfvaTDPDEKZh6hS1pSlmuC6h
QN9kHgllUq0yJDUlDW0emZgauIIMIQjUfCGZwnJ2WLH/E9QDDw+f5/s8L/9u
OSWpuVwOhyP5vf+chrUq4qX3PusqdAdd4Ib3iXe3w5hNMamN4yuNmHeguzkz
TjfjRraB27pPn98dZju0ty1Uz1QxO+LtEcGYUTyzK4o8v7Q1ujG7QxhgoS7T
uZI9Mdi2IA+aYt6D0OnGOWUTMx+XNfYT5wqY98HhkZU+Yz+zAPNLDnmtP1zI
Pqh9L8u2VTAfxPLLho5yR2ZfFAtWjONbnMl+KNd6TV/lMPsjo5ufc6zbiRyA
qcfXpfUFzIG4Lx59MW7PLER3vnJwa9qRHIQaqSJirpI5GNa5uYfT/JlDUDjx
dEjb70AORewVdYKtL3MYbr02s7g2u5scjntOxvXao8wR6Nk2O75pynwIzbyV
iWy1PVkEuX5JX2fNDAy/ag+X19oZrAIsNWl3uXZkjhhVZR4lHWJb6mIEw4OL
NR51CYQPUrMSzpJVEuQVLkZqzFmPxMVLo/NNml3UIyFcy+QnfiBzotBSf1Mx
cob1KIQplM3yJzbUo9ErOrlRXURWRUMynObs7cJ6DHpKT69nVlpTj4FJulHP
6qgV9ViMpWhaVQNkVSx8Bxz2fixnPQ6Kso0+owzW41CWrx6S8ViPR8tzdUW6
gPV4yE9lfZv8tJN6At7k6rbz+8mqBCwecPcv9mI9EWbWIxWly5bUE2Gu9AvT
XjCnngSdef/574Fm1JPQ1VnS4HPclHoyqmo2hwsfmlBPhmE+udSlyMj061S6
b4kMXYrPIZs/JT46gzky8iJ12X895V8jBf51K1/FGj29T/n7/xdPmA3s
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HtMjXEcx/GnHJVL1vWkC6fbEs6iOkXC+VQ61bnUubid494WfzgJyawt
PXKNiikWpi2lSLWppeW2I7Nc1hAOQ4S00XDkErmEne9vVs/27NnreT+f/357
/FIztGm2HMdp/97/ntbLIhUuaLpwdq0/6AVSSl7ZKkKZHdDsYerpsGF2Qve0
N8d33PYju6GSX/wit5R5PK4qZwZtXc3sg44kt4H7EmZfpKxc+fKkHbM/nvS2
XXUw+5IDYZ7SeXOglDkI3Aber03FHAx9l6SrXcQ8Bcs1nc/6TSKyGK66grTX
MuYQDD6STDt2biJ5OlxFz+9YjMyhaIryq/W2YQ7D3mSXtOKKCeRw5OctOf10
ErMEPYW+X7JbfcgRUJj7KjwjmCNRel2m9uryJs/AujWPlgvSmWei4VRbap6Y
OQqmwqbpzo+9yLMQID9sNpxijsbg6J2pZSLm2Xiq2yzsPOJJnoO+Cr1JFMY8
F3nGd/uqH44nS1GqDNQ6FDJjqHkgQJW1kF/Gegzyf94zn41jPQYjM8aEp1/z
oB6LG4dqNb3BZH6YuTjoc97HF3wRUo/D5fMuDpYSMjcPfJb086wg1uchss8Q
rHjuTj0eD4KNq6qayXw8Mmx+7KqJZl2GO7WX8reb3ajLsOaQ7SbHcDKXgIkt
med233KlngD9itZEw2Iyl4jJgfbd/QmsJ0JsKapv3s96EhrXZ34ybGE9CcoZ
uc2vQliXI1R2tEXe7kJdjm+V9lu7Y8icAh3SgwKPTmfqCkgXfV6a7E3mlHA0
uvTu2eBEXYmsySXFBxvInApVAfLHklbWVcg8Ey1tOMF6MvRH68rdxawnwxh7
4NK48nHUU/DVsWXbz4ix1FNgabz7K8d9FHU1na/RVkONdi/L2xInMq+GuFFg
F1lkb7VJDev/wZb2GmgKQqcKdgpor0FO2b2LwhcjaK+BKFEVJawZSXsNsnMH
rqytsaO9FtUXHgpv+lCHFosMYfUb/Qel1r0W4YXv+mNM3602afEhauB3bMhX
qzkdxoyoy35b/NFq6IZ2XjdsP8zc/KHfg7mH9v/9BzGPVVM=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzwtMU2cYxvFTxAgWRJi0sKEtDSBaLCIyUXR9ikXuCKW0wGYCZFMMMlGq
w2aM4waSGImTzZGgEFECKBkGHetQ5moQLTpdugkxk+gcixJ2g12K5ea29P2W
tE2a5tf/eb5zTnDRXs1bbhzHvfnv979fx2dCKcrpudpdIgP9gYc2PjJFzuwB
7fEQwTl7MHkp9KLkUclN5mXwfnardrqeOQAl3XW+gl3MQTA/Km7JUDBLMcTb
qkpmpGQZpm9ExZpuM4fA1P/JyjXNzGEIi2wvuFfKHI5LleMzL2KZV+P7IG/x
j4uZI7BDbGpoaZSQFaj3G3E/G8G8FoGGHRaDZQU5CpK03VMnK5jXYb1XzJG7
48vJ0Qg4MzdQWMO8HheDR8p8QpljoCv8sDa1LYj8Kj4wHi5X6pg3QC62fr3Q
9go5FhrfgtmDzcwbIRrL56Qy5k1o8ig49O2Dl8lx0F8fU3m1M29GnPWrcvVO
5i1YUa6W3Z8MJL+G+KuzRxPfY1ZCsEne+40nM7BWap+Paw9wmAcMhWNuV3aS
ORVKW4sWHXlbTF2F3qC8UksomYtH21yHJOy0iHo8iq798Mf8Z2RuK3reMBbo
97C+FSeW7/6lcdSfuhqD96trDgySeTVm9p2pSi9mPcGlJ6DjYf/JpmHWt2Fm
yS7l9QTWt6HaffC2R8My6okwHpI/Gw4l84n4rfTG39G2l6gnoYkfMvp0kfkk
+AnFfU/7WE9G2oYq06iC9WSsCln001Qi6yloeHJM8GjSj3oKTGVteQp/1lNx
5/Oe8/vL2D4VdZc95dce0/VcGlpaLf7Hh9k+DV/eqn38vIr1dKj5irmoWl/q
6fh5ZGV15PtLqWegvDNOeeksmc/AGt/wyUYr69vRuVlWHN7vQ307WgfPHRQa
llDPRPL5rguhp6kjEzbv3sOzMV50fSasXwz99eC50GFzJjpU/QM3A71pn4V8
+YmkexXU4WI+CwN/+mTn76PzzFnO53EauElXTws7qcPFvAb2iPp32/d40l6D
6Lpfp1RmMpcNy8CWdwxXPGifjYnL1rlKf+q8i83ZkMzfvRM7sZj2WmdDi1PD
QntbDHt+Lbq79n6seJ3ON2uRdSxK7l7jTvscCBd8ahz/SED7HPy+cXo+XmFT
OvY59D6zDptdzOloP+kwdPR+dtrrXPY66PPXde2XvaC93tnQo7L5uz7RkwX0
/C42u1zP5TrfD7nOz8Pn0vs8pfu7mMv73/8ANDGrgQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzwlMk2ccx/FXQDk8JqzUCihtnYtHQ2xRLKXaX8thwSKlpYpoGi8SIypR
MaIIvtGEsnkQUJZNZWbCBkowETynSLUBlB2BLcErwah4IJrV6KQQqZvp/zHx
fZM3bz7v9/k/z/vK1uRbcv04jsv5//749F1undh2/srZPDnoBWaHeiOL45iD
4G754a/RAcwTsa5QeenIPRlZBJWuMrnsJLME+trulwN5zFG4OCfTP3w+sxT8
3ZH8CD9mORovDsjdPVLyV0gM0Tfbypm/RlZ/wtu8XOYZuPM6YeAbNfMsdJVJ
TFwgswLdRftaD38bTY6Bprer2hTHPAf2I5G6ca+mkpWwXq70HithVkG2Jb5/
y+AUciw6w65vri9lnoucyrWSVgXzPDx6rJbJm6LIceg1nWgqB/N8aFK7O3gp
sxr73rU+Xb43khyPKYbvV21PZtagqtGR7boVQU6A1S7aX2Vk1mKd64LywHjm
BTheE5Hd2T6ZvBC/t9gfBdQy61C4qVy93coMjBKVvfGOSHzmgfaCisJ8I5nT
Y3rwn9kxTyZR10OskW4dV0zmDDC/PXfrUhLrBvBBsSVv+sTUE6GadGL1ylIy
n4iC4VNypYb1JNTfd1VV94RTT4L23+u9B+xkLhnFK3Tac1msJwt6Ct7XBMie
dYmop+Cs51C/BGRuEfo2zNSMOL6kvggHm4NnX3sQRt2InzWxN+uqybwRLR2O
B549rKfCUxtY0qdnPRUbCjwXRi1jPQ1JfOGI0hFKPQ1hz503GixkbjG0KpNj
wirWFyOkxmNPaWPdhF+mpd2be2MidRN2zuwYys0gc+lYfrTxp3AF6+lo0MrX
z3B9QX0JUk+dOT39OJlfgtCXIrFbPIF6Bur1rrb2yeOpZyDa+8dvancIdTOm
pX3Xk1NPhhlDisrddRuDab0Z/8QPew0xY3x2mlF35ba4M2o0zWdC0RwwJu5Q
IM1norQiT1MUTeYzUfF4W5FhkOwUrOcsiDamx4tP036wCOYtuNm2YEfBr0E0
L+icFcU//n1V/NCf5q1YlqM6s1X+Qeebt8JPOmt4bMN7n51W+p93PnNZGOvf
uOvF4dc+I+vzzgu6U9A5G2IPvhrUO4doXmDeJjjfhm0NCbqmkxx9/9LPOwTm
l37a7z/pPnOB
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdy3ss1WEcx/HfpBEa5XKQEw5ZuZw4co3Oh+N+PUJF1k5nUZQQEaqd1Yio
ZTWWNKSwcm1dLCI2IaMV2br+44zVzDStCzmq+T5/5NmePXs97+/XUp62O1GN
4zi/v/ffu3LmxEaxDzvbjwpAHxC2zDtWujJrIqGh7bXWoiVZD+4queR2N7MB
Yi82jB8qYjaGKEl25nI0sxlklroD9/jMFshO7fR5r7QgCzDhMXW/qJXZGmn7
2rrbC5lt8PtF05hyP/NWpCUjrdGB2Rb8Y17Tgx/NyfawfrMcIyliFsLEarRf
w5zZERW8X8dT2zaTnWBbU1SfJ2QWoXshv4X7xCc7QzV+7crbauYdcH5nMtu3
hdkFOufLy5tzzciu0ODbjBQvbSK7wZknt2nKZnbHwIPBoVw+sweetg7dGak1
JXui1NDROl3IvBMVyTyu1ozZC9kX1OSaHSZkbwSbjr967se8C12ZcYuuj4zJ
YkjbLYL3dDADvcO3vGSFZMUqcz4w5LnYjZzjUfdB1ePZEv46MucL7bFvGaqz
RtR9IeJVH0woJHMSaPRaVdnPGFKXwD1FLLrEI3N+aOGPCWynDaj7Qbq9RpBl
TOb8/7fCH3XKArkkifWAVT0AypRtnksX9KkHwt9befrlwkbqgZjRj0v8Xkzm
gnC9pyEn1p71ICTerFfLr9lAPRhadT8PBPSTFcGY7FpS2Lmx/RBkHWnojjRi
+yGw9DlcfFKlRz0UOvp9OemfdamHokSU+OGGjPUwxFU21xrakxVhWOailmVZ
NM+Fw8FbGNMztZ56OPrndaPjM3SoR8BcNTLsPqdFPQLxdmVBo6e0qUfCKqR8
Ir6R9UgM9nvnZD3RpC5F2WRmvu8PjRVDCvOgcA+ju2tpXoqoUic79QL1FT+T
Ym+8qOWEYFm8sh8F7TXNeV+ufhX/AfuACUo=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0GlIVFEYh/GDtmhamktp5Taa1DCJSzqZmX/3NG3UaTREhZZp0RYsUzOq
2+aXzBCTQiJsKhCnLBWxLHM006xIgjYJVIxWyEYKTdM2fA8x58Jw+c1z33vO
PR6b9qRozRhjWX9//+5TlzFsnqbxTl2ODPQHNgdsUw4Hc1tAX3kuu9ua2xYf
0gvNHZ97kB2QfSz4o+9Fbifks97qgVzuRXDRT7zMUHK7w1Mvvzdkxi2DPtP1
rGuXO9kLO8/tjik8z+0Nr9Ivb2t2cS9B+FV7334Ftxwl5Zfiq967kRXoXlqT
sXATtw+mj1b4+Rpdyb6Q3Wh5PVzG7YfE0MrqW37c/nBIyrw/f9CFHADrxeUN
V1Xcy9HT2tm6o38RORCDNjafbuZxB6FvwKlYJeNW4mSJuvtx20LyCqx+VZdV
H8sdjB65+s2slgXkldBF/3xScII7BG0Nug5zOfcqlA30RToPOpNDYZmbaPuu
jXs1jl9rt9dkcYdh2dHeLKvvTmQg+sZAcdldsgRMbi0q1PbwHg7/31ucW6t4
D8cbz2xdlzfvEdiv9NY2audTj8CFpqFTLpZkFonOkvaC/NZ51CNRIYVenhtB
ZlGofGTXXFXrSD0KQeUd2+PsyCwadtdf7DAedqAejfEfkboCBZnF4OnGDcPf
eu2px0BhLK1tOkNmsUhQHml668N7LGJaPmXj2Vzqa2Blfr3oczlZWoMDS7vG
tCpb6nG40n053ypvDvU4jMy+fXQi0Jp6PIwNzyYPOVpSj0fA6S+j4QYyW4vi
spyVB91mUl+Lhw9CC/KaLagnmFpKgKJh2oygUnqeJaLoyHhbTs0M6oLZOpi5
y8et9BNhU10wUwldRd87TD3JtEOwlIR9+pCweh2bWs8gmCXja/D4rwifEZpP
Nn2/JNiQLOwvBWnp/rV7Zb9pPoXe957mBRtSTNdjajrvMZpXC/tXmz5vEDpb
b7o/CJbWC+sLZhphXrCkEdbXCPOpwvmnmn6PlGp6PgahszTh/NOE8/vvP4p7
nTk=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1GtIU3EYx/GTmqar1LxPS7OMUrPU1LzUfk6nbl5ycyPRFGqGxpIog6AZ
HSmjyCi7aJgUKWpmWVaCFtSMzBmMvNQqwgQDX0iRhaYzu7LnT2yDMT77Ps/5
n50XW7lrn2K3Dcdxqr/vf5/m16TIU9X5qEMTCPoCl415Tq5RzIugrXrZO23L
7IKRNrfUT29Wkt2hVgs3dDYxe2OoJGJceIjZD4ZxZy+DiDkAfUXS2P32zIG4
dTrm9bAhgLwaS1Nbbp2pYV6DF7kD+v0a5rX4Fld/dXQdczD6+uMcmz77k0PR
WuTzZMFx5jDkjm0ylgYxb0Rh4qXQ5rYV5HCUPx/4GKlkjoA6RfO1Z3Q5ORIS
536TtpR5EyQBd5416v3IURC25NROlzBHo/r3+3P9Jl9yDG5cbyw+Vsm8GQ/a
j530EjPHYswgUPMzQnIc0uPLpe67mOMx7TDRXNzhQ05AkF9JfoOceQvWV7wr
FEx5k7fCUayfyNIwi1DvKrIfNHmRgT1LZ5WlLWQeeFp11rUxkPVERLcqCmRa
T+qJaL02fjekgMyJMXb9lcpFyLoYqncLT53UelBPQsJ0z4eqQjKfBHlVeIhd
pTv1ZGhyHeTqWjfqyQhPqeuWGZZRlyBkuadP8U4yL8GQ6Lyd14gr9RTscGio
85WQ+RT0G1dP/VjMeiqkre03g+qdqadie15E+4FAMpdmaT4N35d0V8xHLaYu
xbnjtl2jBU7UpTh8dK5Hc9OeugwnqjVxWn8H6jLoe7ccOvhwEfV0y3k+HV9i
536Jw9h+Bqo/lmnFM2w/A6tkNca8G3Qel2l5PT4TkWc+zyTqHKlnwSCcnLjo
wu4vC6bQ8+Ute1nfho72fRfD8tn+Nqv9bGj0XY+HuwVmIxuDXa+n3s6S+Wxc
MQpMzVFkXTYm7w/+POLB9uUw/1/Y0L4cNgHBc4K2eZF536rr5PS8f5s7p0BZ
W7zoXgNH+wrLzivoeX03W6eAwPb24YkLX2k/x9LIsTo/h36vifat5jklXX+c
9pWW87zScl5nNc+prM7/7z+LfGaR
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0AtIU1Ecx/G7tOdWWtnSymaaYdMsN03nZv5cOufU3EutlWGSVlpUCmVq
NKSCzCwV7SHUKHpYGtg7FrSiB1KTSjJ6oMUsqIgUqXC9Y/9DbBcul8/93v89
hzOrYKO+cATHccv/3v+ermsgUZh92dpREgx6AdPclu/ieOYxUNYMSXg8Zl8I
NKKK53dmkf3gyMr9sr+Z2R8Lizt9ywuYZ0CRUBTKlzIHoXpZwKG33szBaNsb
+7TbHkSeDemaYGjPM8+BtspS07eFOQzNQT+km9TMYlxsPRFmncgcAfHKuIkP
bovIkWgQ19V1rGNegC3VF9prv8wkR8Fa1lGIVmYJKkPLQ8o2MEvhM/zREfIz
kBwNLnq7wLGVOQaBU793v5vOvBArBEUxlrYZ5Fj4r+wfc3AKcxysq796W89N
J8ugsJ3ML/Jhjodc8PtDlWUaWY50eVWaXwGzAscjDH56HnMCGix9zr7iAPIi
jFUrYj4pmRMh22p0jHL6k4GHi/pVejvZDOTtjzjcu5H1JNQ7yiqV36ZST8Ke
ptSRokdkTokJ5eKc3kbWlehsatN9DGN9MV7ev/TiWZmQ+mK0brI/Xls3hXoy
5MWlh/Iv+VFPRvX93DxnBplLQdeqpYNDzydTT0FT6M9l3DEyp8LBN7W83sFJ
1FV431ya1J7IeioMPXtqnwSy+VR0bktWrJ7DuhpRqiPXNXY2r0Z4oDBgzSoy
l4ZTIZoX0bd9qadB1mW13HtN5jTIVN2725/AugZ7JYWvWvJZT8eVgQPzp9kn
UE/HvIRI481346lnYHypRN5dTTZ7mMvE3SEfg2mzgHompPs+fUuyjaW+BMMR
DVWn15PNS9DSwx8+FcOnnoUQTXOP6cw46lk4sNPrWl8emdPCFF6v7iqn76GF
6Jf9QdwA+16Lih3OWyVnR7ls0+KzzPlLGUnmdO6GDiJ1pkx4diTN67D9aPcN
4RsvmtchI3bHVUckmdN7zOvd1zPrsbu+JL5SNJrm9R7zBvf/w4Bck+R8afDv
RNe8gc5r2GWbASOCxE7+uR8uc0bwvdorPjTyaN4IXW1UuPcub1rfwzaj+/64
bHfDw2YP27I99p/jsT7zIO0/h87nK+3/v/8ANC5ybg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0n8s1HEcx/HvGIujjMuvTtxlMskcLr/d63Ac7pCYhZrIVmmr/Cp3ymlr
+aNbyqKl/NEPCTW186sf1DW/5o/aKhXpD5TKjP7AXJZq9/601Wf77LPH5/n5
bJ8/PsK8I2kFZhzH4ff8s5rGgtQxo+PR/UIRaAPdq0FhaaHM6yCs3x71YwOz
HbIVwojIt0IyH6l9KX0BemZnxOq35Ys0zAIYxvft6Y1j9sDpFy3dYgGzCAUl
ri7lRg+yJzS6vIG9/cxeOLh1cuHVRWZvWI/tbI7PZPaB2vmD/7I7sy8krS4L
s5/cyX6oH6y96nuK2R+eI+fnet2YxagY+noi99JmcgBUkVeau8XMgXh/bWV6
14wbOQg51RN8h8fMEhxI514mlTLvwPT+6bkGAXMwFmv4Ou8JATkECTn612ez
mENxYW28ZnhlEzkMkR8vP2+5zRwOeX6M3DKDOQIVNhYZab2u5Ego+6w6m3Yz
R6HJ8GTg0JALWQonzXxIVSkzUHhL7VrmS9YCg7J260mDM3UZZrraxOJ0slaG
kP5KTeNDJ+rRGDhnOF7W50g9GmFe7e/adGQuBo2lzWP+ItZjsNh1pmdpbCP1
WJzMlkbo08naWCQX22nq+vnU5dC8KbflcslaOXLyJqd8vzhQj8NIZ8edoqNk
bRxM/9eeejxsD9vPVh+zox6Pm8M3yngl66krsGTbU7UqsaGuQMMob6VJwqOe
gC2JdaNZzdbUExCom1uWPbWinvhfT4S60vissMWSehKUwZVdU37m1JPgrlCF
OrZYUFfSe82oK1HcGi59cJ2jroKZh4+R17oqNXUV5kONP6P9lkzmkpGZFXCv
SLRGPfnf81wKeOZ31d9qv1NPofufqaf+9S9muQYa
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzHlI02Ecx/GfVyaKdx5pTqdY2LA8Uue1z3TOYx6zFNEicimCB+YR2UIc
Ih7ogorAKCFQK2YH2kErsyUdZqHYHxlmImVilrYUtcS0Yt8nqAceHl7P+/k+
XorSvfnGHMfF/d5/TsPSi5wyb9/vLuKDLnBwZVdvaTTzZvTrXi9ZWjHbolVf
PH1kwovsiDptaEldO7MLagr1tybymN3RLWpZlYUxeyK3oP3NwJonmQ+Nz5e8
hUFmH1SX8S5mtTL7QvNB+tG7mHkHFv3qKh3FzH5INAN/yp5ZgP6MUJVEyyP7
w2I043i8L/NuKIXjy587PMgBUPbJWtpDmQNxuM1N7z63jRwEWU99s3szczD2
q4f1xgvu5D3I1JlEqTqZQxB2wt560p85FINdNi/7nrqRw1D1Nn2ysZJZiJ4r
zxS1AuZwOEfc7RiY20qOQL+0t2doiDkSO4dmLFJTmaMwll/pkWfKHI3hk8vq
mDZXsgiJ90udF42YgUpheKNDp4vBKoDXrq7dnkLmxNA5dpnnzjpTF6PctWR0
robMxSC7ej6uZcmJegy0L7LvZGWTuVh02c27+N7cQj0WnWcr7LQgcxL03Kj3
cBl3pC5Bg/Jx1fcLZC4OBxTvPwhmHKjHQTHAvxekInNSPD8uiczzZV2Kx3Ld
edU9e+rxOPfw8rFMAVkVD+mDT4UYsaOegNophXrqKlmVAFtBgNvQBuuJeCU6
ber8jvVEVHTfaJIrWU+Cl7ig6ei6LfX/zMkQGZjcYH2IzctwyTtpLLif9WTE
ZqyFmEmtqSfjyaLNvpwyK+op0N8c+Vm9xYJ6CpQ1q4+KNJuop6L+VFH4CZ45
9VTwElKEThoz6mmwNLmmnD1jRD0NWTmB18v5GyJDlyNIPbci1v0wGHJ8Fa6u
x/gvG6xinjZYJ6f/vtF8+r/vkf73/S8QChtK
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd02lIE2Acx/FpymRzoaZTl7cxr7Dc8prZfk6dt/NICsuDQjSXR2lBF6yQ
8CAiNSGtDFNfuBK8SBNEwbNypoYvPIjQJCVIMRTNtML/Q9QDDw+f5/vA8+rv
eC4vIUOfw+Eofu8/595akQuTOrpb1E6gC8gym3h+cmYjNOxeeJLBZTZBw9o0
b+q9I9kcO4PJxp4NzFbwlonHJ7KZbVCX1X7vtIzZAWlnLOqK9JmdUCs6Hz2r
cyAfQjAvqC3pPrMYn/hSw5OpzK7QJd/yKD3C7I6JlSphoQHzYVhbXWywvGZP
9oSkwzHbj8t8FALTdsOqu3ZkL5xyaw5QuzBLMN3Z1r7dZEuW4ser3dt6aczH
8GXEPn9hw4bsjamUd67uOcw+SE1Yrn+byuwLrq14tOTnQbIfHotz13RlzP4Y
MFMX8aOYZWhcWi9SzYjIAXijNyZziWc+jnnnPunTHmtyICJEH8YHQ5hPIP9R
rmq414osx0xt5qUSLTMw45xdNyQmawDDPL40Z8CSehCePTQyGpoga4JQrdr8
mL4rpK5A9+dWm4+NZI0CmerF4F4B68Hw+bo494JrQT0Yir5EOw97c+ohSC1W
LgX2H6AegkSOn67FlPVQRLWtRsb7sh6K0MCFm2NbZtSV6I/rrdG8JmuU8FJW
d0WOsh6G9dJmy5TvptTDMCEvN7CcI3PCYavdnjrry3o4rrhVVpS3mlCPQJkk
Y7YmnayJQP3I86v8wv3UIzElKM7ajBVQj4S+g/sWX2tMPQqCy5KAyTusR0E9
3Nkz2cWnHo1R0cpypQmPejQezBfcUGxwqcfAPjzGX9hkSD0Ge/OpTz0WBdoA
eWsdh3os/b8t3+sq8Pe9vL5csbpnzX/mxP1rxOGb/9aOwnOR3v/1L0k6Bxg=

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd038s1HEcx/HrEqalU37/KE5umMmv/DzudedHOPlxHEXLplVyolWqnZZv
tbVF5MdlWZolreX6qaWWDGetRaZUVH9IKVSM1kbMqOb9+cN9t88+e3ye+7w/
f32dsvIVe/g8Hk/+b/3fl74piaXyYct9lRB0gBHN4nCJF7MxWsXTgpTfTmQB
0saelb5rYTYHd+nDkOoMszXcui36JhXM9mhb0ehSLmR2RHHoZfWOaUeyEAVv
wutqupg3QSxaHMmtZhbh04YTz7X7mF0RX5ggCglkdkfwaoE8byWzB0JUbWb3
mjeSPXG/+oPcKZrZCyaumhDjtxvI3uCH/Uy1O83sg07NQpXIhtkX012ZC9/u
OpD9gF268IlY5i0w//hLffylPdkf7sO6zlNq5gAMxtU1XQBzIAKUvbdf6OzI
QRjffjOqKZs5GL3fv0w2GzCHIHeoIkGksyWLoSx6n7ZbyhyKzjjzTGW9DTkM
qutq26MezBIIS5A6cNGaDIw+uuXtnULmgFozieHrWSvqUhxoyDI6m0fmpFAf
cc7XSlmXIbtwcG89n3UZ0nvX7K/5bEk9HDkBeaacksyFw6jDudZj3IJ6BLrn
xorPXidzEQjMkfiUWrEeCb++0mMuT8ypR+LKY3FG1R0yLwrz1wycRl+xHoWy
gwWNGcmsb4V15tO+sijW9cyLRnL/ufN9DuupR+NPg9HJr9J11GPgoJ3v3xlg
Rj0GBW6aqsomAfVYaMXCbNfOtdRjYWc9PFZRyboczVPlm217TKnLkSsrbzW9
SubFocd26odGYEI9Dh4PDAz9y4yob0PF8OFC2QyZ2wZ10VyHqtGQejxutAxY
dtmvoh6Ppf+XTz0BfEf3udXaeclS1zMvEZNBcwsyz+klQ8+cntsT9eYnwbd0
YkbaPkv3k5CW7nPnkHCR7ictf689afk8nkLvfT1ziuXz21kfkfwFn4063w==

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0g1ME3cYx/GDgiC1CIgVKyjWTY1WVJggCvZXXgpCUQrXEjvcEo0xvsX5
ghBf8CAxGlEGIchmwnyJb4GVhenWqRjOKIpzLza+xqiJUev7hEVBkfiWPo/J
9ZLL5XPfe/53/+RGL1hZsMhfEITij+enq/foMmptv51sXaYH3cBVXUpjZRI7
GHvruiuCNewwWEL6N/x7YzQ5EoFud4u+iR2Fi5rk08fL2dHQHf3rVkMeOxbm
/ytzr4xi61H/py1pzPNY8hcIvbimI6aVPRYPbwx+6JLY43GhXBXhZ2FPQPFe
4UpNNNuAb6y37/TKo8hxcC47tnWhyJ4Cz3ZTiU3DnoraH2vWRbpGkuOhKTu0
ZZWDnYBvx8Y0jxvM/gp/FO5XtVfFkKchPbreXpHJToSfXHJn8a1ochJqtw1s
elHBno57jnUZYhQ7GRvnBww6s30EeQbGSfol9gz2THROL6kKu6Qjp6Cy6UFY
XQE7FfrSRweux7Nn4W3Tk0tbNw4nG9F+/5f2u9PYQJkU3lDqjvJaAjo7UkvX
niALJuirYL9ez90EZ/ZNz2o/7mlYEvpaXHF4GPU0uOSQrD1PtdTTob78ctW7
crKUjgeBu3pcDUOpZyDxmef2z0FkKQObvjamHBO5Z+LEd4beQn/umbDumDox
YEskdTMqzxfN77OQJTNaX1c/jgL3LBQH66Qfkrln4b8VZ18l9Ayhno0I9bA2
TxtZyoahq7rF9T332ajaefBLp4q7j4UcHJyR0Hm4MYJ6DsynHi+FO5x6LiaF
j+/e7Q6jnot5u537hhrIggV55nMd91O5W3x6HsKfRWq7tKHU8zApNU5s92io
z8HvXTWTdX9zn4PlaTWnQveRhbnK56W5SBf7EwPN3PNxxHSm49xw6siHY2Jt
9j9lano+H2Nydl1zHAnxWs5Hws7nvSZ5IM1bYTgaMCCxOojmrfT/BNO8FS+S
+96lxQ2geSs2/XS5TXtXRfMFsCRtdt2LI8PHko/lAhQ54ltW698bvfOFtH6P
1yiEWuVc/6Su22vJp8vc/ej9onI9iLS/NzQvwj92Qp+6uZ/mRaxpnmn8db9A
8zZlh03ZJZ8u25TrC3alYVd+n2RXfp9sV+5HKPq83w+w4Xob
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxV02tI01EYx/E1SzRdauqal5nXEo3hbZqp8zfv12mKpauWGpZhNqNIQ1/8
RZDIC1hGLyQo1Fmp1byiFWjYxUKLCKfiC4OIUErNS22aZvicFx44HD7ne56X
xyVXnZbH5/F48s39/9xa8+HCjO5n2gJX0AUCla/P5Psym2AtIOVY2S8XsiVK
y2TTzYPMNpCdL666UMssQmj7fPzKcWZHnLL6qShyY3aGUazab3DJmeyKXfr1
2ZheZnfoqltW75YyH4CpynfYI5rZE0KpRqE1YfbCsqDH2KFuP/kQQpMvRix4
MUvQ/i5n+saEE9kH6RXT+tkCZl+k33s6od8Qk/0wUiBZM8pg9kfnzo2J4nVH
cgBUaTNN71XMUvCOnl3qMziQAyHTaVUdscxBKF99oZnR25MPY6Cm28dqkjkY
XX/+LogbmY+gJUPXJS1kDoHIXnuwYtqOHIqH3yTj3zOZwyATerQZhkRkGSwG
0pv5IuZwVPfPTaqq9pGBPseswrceZA4Yv52tbPsopC4Hcnt0N4vJnBx3NPcf
uDqxHgF1zTU761u21De9Y7XyUQiZFwnvN6Llpi821CPR8aTSSTRF5kVBdPr5
p9oY1qMwmpO5sDhhTT0anUWXF5UlZC4a0WFfyz4Y9lKPwVDqQAPXT+Zi0Fuk
yZLYsvlYeIuFdudyWI/F57wVU88+K+pxELeujZ0MInNx0LglTAa8tKQej+Ex
96VVc9bjUeWXN9WQzXoCmoYbr5pd2UM9Aa8WLdKVl8ypJ4Lv7GUwayVziRgT
XM/XKwTUk7a/55KwIugrX5Oy+WQoveviRkvMqCejYcxMr5GSeQqM2M/P1Fvu
pq6A9rG6XnLChHoK5oIN6xESY+op2PrffOqp241U+Nf8+C0f0If/A2AVC5k=

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HlQjAEcxvFVER2sbIvdzVZMl3W0iN2wj87t2K3ddWRUGsRSOWKGQaws
MY6RnJFyjSNXrpU1TeQa46ZCTAxjKjOuITRyTb/fH3pn3nnn837f5533r9dn
yhxjuoNAIDD8Pf9d246PGvG4c/ayDF/QDTx1OuM/X83ujCP3bU6vO7CF2H6y
MWfSYx+yCE6qvG0bD7J7wUvkm5Q9my1DyaA9J9QqtjduTItRzevE9sUBW7mu
4bY3uR8u760a4Lyb7Qflym8Vt8zsAHSy9/RYG8IOQsqM2pdZ3+VkBU5fyE3S
FrEHQhSo+moNYg/G+INV5sl1fcjB+NVSGjdiKlsJ14T343XNXuQhSKpfHlth
ZQ/FTM+bM8Ui9jD0ji5eYiiUkUOQWaq1+UnYw+HvJzdZS6TkEUiefjOlIZWt
Qk3nZVMTZGw1TvusDHhWJCGHIkM2Z+iOUPZIyK+trq5925s8CuIXmosLtrFH
44di89JDmWwNnIPOrxef7UUG7Pv67F4qIVuAjd/StFnVPamPwZACr7JlO8mW
MRCrvbPdcriHYXV+hnqJnHsYbJUu0cXvxNTDofY79eTYBrIlHIfrqrYW1XhS
j0C4ovqe4yqyJQIhBVfNMR7cI6Ftqq3ouk5EPRKyuiQI88mCKOTseXRJ/KoH
9SikrolqHHWVLIhu16PxZlagujWPuxZlnyXFi83ctdhwpkv/inoP6jEQKoKl
d393px4Dl/3fU6OukQWxeJze3CWgnHssXl9qtfQfzvs4RFgWtQbncY+DXbKl
qPyDkHo8Rirj87qmcY/HgO4BnwofcNfBo6HySqmRuw6qu/aS6y+56/Huub91
UC7Zosc6ZfrzXWncExCo7yuKzOJ9ApKd9xVKI/n7E6GZ8CVZLyUjsd37EjGx
8PheTwW5MhE17mvMP/TutDfAPVsZ+iiXDAPcelxZOLexG+3b9UoDTkqP2R7G
URcY/38exv/fbzGi2b18xc9hbrQ3YpPV8UJ9igvtTbgj+di0RUiGCXKtTiU+
2pH2JrT9zxxob4Kr4/HFTQUdaD8WDt5BLa6lPzVt+7H4oGr5FTbwreYPwmQ8
mg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdz38s1HEcx/FvyUVGOvLrzo9D+jFTXBKu7oXjcEc0ZdmlaVrsKros2/XD
NRPZspVVWzvN0rI42dUwFTm1NSsV1bRSKX+IJapLnRnV7v1p47N99tnj89zn
89lHtLdg+77FHMfF/J3/VuuYlLrtaLlrVPuDNlDkLbnIkzDbIcFrIiuIx+yM
ZcWGpJ4BEdkV1W/Hv5obmD2w3vhktr+UWQjRy9b2viRmP9RIeM9fBDD7I6/M
O/zOdz9yIBRjOXk5D5iDsD+9w9xYw7wGWlW+Z90h5nWoPSEc/BjKHAxVb/Yr
nhtzCITut6X2T33JG5CxW7jr0hHmUKQbZEaBxYccBnVF986MemYxMkSVn1zk
zBvR6Nh8OaXHmxyO9w18Q6WceRNu5Wk65nqF5AiU2dnNNBUwb8YF7amqcVvm
SBR3iuOe3ReQo9AarckdkDJHY49z3wg34UWWQK6S+lXombfgS8712ofhzFsx
HGASX+n0JEtRmH3SFKhkBgbvlUdZRjys1gGTqx/52OaTuRg4mvWjCr079Rh0
OUV0dPPJXCy0JdMmdYMb9Vj8bCtrn3qzknocZPohfvsZsi4OoiXvhn7MuFKX
wbn8cO6Hq2SdDMbfVaMeYD0ej1tbbmgKXajHQ1Uqznr9mU89AZ2qVSYfB7Iu
AWtTA1zjD66gLoc006xKFZB1cjQLDG39iuXUE3Gtp+6oQ5ET9USIz47/iumy
p54037okWILPH68/wHoy/Z9HPRmnz6mjjvkupa6AMqKkbTjEhroCDjZN2rHq
RdSVyMwKu6nxn5NauxITkdOzsSFTVnMp9L6F+gJzqXTfN+oLzG1bcH6BubT5
7yHt//k/++QQIw==
       "]]}}, {}}, {{{}, {}, 
     {Hue[0.67, 0.6, 0.6], Thickness[0.005], LineBox[CompressedData["
1:eJxd1nlQU1cYBfCHQkVwYZFFWQwICkKtuOACwglIWGSTECQQQpYyAlZFsUPF
SmNnOihSLSKIWCiIC5RR6wKu4EMLbhWlhYylVcEiqLVuCKJUbTu93x8JMwzz
4+S8+3Jv3r1xUq2OSRnBcdx3//7+9/f/n2f+1pK6s0dXOIP9A72eedobvmRj
dPanPW5478RsBr7cpP7hVfIEfGn+aGrNHrIt8tefuhacSrZH4JDI6NVMsgBW
f00WFxuSnTGcm1ndcEvA7IIyP4cnBZXkqdBO2vBOmkZ2Q4SopblnEXk6LDf2
iraMJnsiJrJovt3ZycwzIJcm5VyLJc+EidtOH+N2R2Yv1HuP428XkWdBdVRZ
NziNPBtGW3cUB9xwYJ6Dyl35tuczyHNR2HLypMcosjdMclrSHarsmedBrQ4+
m25Dno9uw7xd14/ZMS9AtkH9/d3R5IVINmvr455OYvZBsMxfsPlbsi+Cmldt
2OFKXoR3EmuHrbcmMvvB1Kpj3fmdZH+UC9vyIsPIQPX3ZzabODFrgIzdq6Iu
87YsF+LZtEuORmnMGiHG8+L9I2wpD8C6zqrL5rdsWB4Afty8hgsWzFwgnI8Z
lzZHWLM8EOWfVnfOdGbmFuOnP6reYjrli7H+mwkdoQaUB6HD7RPlgZNWLA+C
x3ZRa8C1CSwXwSd9bYniBLNGBPvf4mFWQHkwNpb/cs6625Llwehzf7HeK5qZ
C0HlvstW27UWLA/B0L5ROT1CZi4UDZdy7w59QXkoPBysJy5XUh6Gx5bSlMEt
lIchpezAiA0V5ixfgsyjR7ZEZzNrlsB3VnjuOAXl4fBf9lIWaUd5uF4egUaZ
a5OjKV0/AqKGh+loozwSFg/4C7Ux1I/U60fBPXLKhKCVlEfBzNPLrvU95dHI
0PZfUDqx6yNa7/XRkI3aW2oXxMzr5dxSmFQNyUXNzFiKK1qXl8NjqK9nfqnu
fHAxujli4FD7t1Y2j/ox+Nl/h6HNberHoD1lcLTbaeqLsfv8wSyJJ92/GB9I
DI4/u0jzJdZdP16Mr4+P9mi8S+sXi6BFPZ/feEP9WBwOfhqTNYY+L7G6683H
6q43J8G61IONUdbUl+jen0aiux68RHc+uTgo1iQNX31A7z8OpiMPZT8qpH6c
Xj9Ob/2XYTDvsE3SS+rrWbNM9354vZyLx9CS+8abwun+45EYfN7kzQ80f/G6
88XH684XJ9Wdb0hxrb6uZm0GzZ9Ury9FT7r7wre59Pwl4MM+O42JIXtekQAx
N7/1qDk9zwl4svLHgdmD7PV8AlyyDAq9n1I/UXc8JOJh8VrhIX8aPxEWpjbn
es9RPxGvlZlvN9VRXwaZ8SRNyQIaX4aQsPzOY1IaXwaPS7YD+7qZeRl8B5ru
5MvZfsQlIe3jgc8+msaMJNRkXG9L3Ub7VRJKBXXje/uY+SRsKruZPDGD9jc5
SmuaAgcOMUOOI7GGhs+f0H4ox2l76crLrmw/5eUocyxq3ONH+2systdNWV0r
ZEYy0rSuM0wLaD9OhtjLmPtVTP1kNF3cP0Irpb4C+Weedsq3MgsUqEkvs/Ws
o+spkLnz8MbRPLNCgW2vFCErO+j6CjhdeZ47352dBxUKZPtW+klcmHkFUvfa
uOZaMXcpUNJUPjI3js4PJW72D/E3k5kFSkwObXYsLGeGEucypcPe9cwKJd4X
n1bf66bzSAkv3yrBmwh2flUo4bq9XfR6DTOvRPgpBLmXMHcp0d/9VWVcB51/
KnDtq9aseMAsUMGr1eXU2CFmqFDQdSdw4j1mhQoy08b4PZbsvNWocDzHqHmj
B3OFCq8TTggfGzHzKtT+KVweOYe5S4Wa5tvKRfF0XqvR8vvUlL4iZoEaU8KK
tQnVzFBj7qxazvQEs0INR+G7E2GDNL4aWuMcdZQ9+75QoUbWC2G42IeZV2P8
4JmQZyuYu9TIdxzLtzXY4R9FBI71
       "]]}, 
     {Hue[0.9060679774997897, 0.6, 0.6], Thickness[0.005], 
      LineBox[CompressedData["
1:eJxdmHtcz9cfxz/MJXKpWCTxFZlWIxpi/Hopcs833ZRv+XS/63stcnl82CXG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       "]]}, 
     {Hue[0.1421359549995791, 0.6, 0.6], Thickness[0.005], 
      LineBox[CompressedData["
1:eJxdmXtczGn7x6fWsRbpIUVSybGe5NTmtH2qTTll6HzSdD7XNE3NTJNM7BYW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       "]]}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  Epilog->InsetBox[
    FormBox[
     StyleBox[
     "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
     TraditionalForm], 
    Scaled[{0.05, 0.95}]],
  Frame->{True, True, False, False},
  FrameLabel->{{
     FormBox["\"Number of individuals\"", TraditionalForm], None}, {
     FormBox["\"\"", TraditionalForm], None}},
  FrameTicks->{{{{0., 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  FrameTicksStyle->{
   FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
  GridLines->{None, None},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->NCache[{{0, 500}, {
      Log[2], 
      Log[10000]}}, {{0, 500}, {0.6931471805599453, 9.210340371976184}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, {{0., 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.751642113412551*^9, 3.751642123404204*^9}, {
   3.751642199102998*^9, 3.7516422056460257`*^9}, 3.751642322268405*^9, 
   3.7516423972292767`*^9, {3.751642566840013*^9, 3.751642621167348*^9}, {
   3.751642651679969*^9, 3.751642672587596*^9}, {3.7516427608778276`*^9, 
   3.751642826712287*^9}, {3.751642873310339*^9, 3.751642919848667*^9}, 
   3.751642983238916*^9, 3.751643233799735*^9, 3.751644936043626*^9, {
   3.751645053983769*^9, 3.751645121408024*^9}, 3.756492274407484*^9, 
   3.764200838242322*^9, {3.764200878878666*^9, 3.7642009544560957`*^9}, 
   3.769256431395636*^9, 3.769340781647572*^9, {3.77154303346632*^9, 
   3.771543056624549*^9}, {3.771543210581745*^9, 3.771543223863455*^9}, {
   3.782251388651505*^9, 3.782251402487276*^9}, 3.7848556299360323`*^9, {
   3.7848996565854797`*^9, 3.784899686175066*^9}, 3.784903102567292*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mutation dynamics (panel B)", "Subsubsection",
 CellChangeTimes->{{3.751643310350029*^9, 3.751643318982791*^9}, 
   3.7516460922572393`*^9, {3.7849031091821547`*^9, 3.784903111325245*^9}}],

Cell["\<\
example of allele dynamics for one rescued replicate\
\>", "Text",
 CellChangeTimes->{{3.743878510025237*^9, 3.7438785108459053`*^9}, {
  3.771274256272873*^9, 3.771274278356511*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"n0", "=", "\"\<10000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "\"\<4\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", "\"\<0.000100\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "\"\<0.01000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "\"\<0.50\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", "\"\<-0.10\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mutmax", "=", "\"\<2\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rep", "=", "\"\<83\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"genmax", "=", "500"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nmax", "=", "1000"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{
   "datadir", "<>", "\"\<alleles_N\>\"", "<>", "n0", "<>", "\"\<_n\>\"", "<>",
     "n", "<>", "\"\<_U\>\"", "<>", "U", "<>", "\"\<_Es\>\"", "<>", "Es", 
    "<>", "\"\<_mmax\>\"", "<>", "mmax", "<>", "\"\<_mwt\>\"", "<>", "mwt", 
    "<>", "\"\<_mutmax\>\"", "<>", "mutmax", "<>", "\"\<_rep\>\"", "<>", 
    "rep", "<>", "\"\<.csv\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alleles", "=", 
    RowBox[{"Transpose", "[", 
     RowBox[{"PadRight", "[", "%", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{
   "datadir", "<>", "\"\<kmuts_N\>\"", "<>", "n0", "<>", "\"\<_n\>\"", "<>", 
    "n", "<>", "\"\<_U\>\"", "<>", "U", "<>", "\"\<_Es\>\"", "<>", "Es", 
    "<>", "\"\<_mmax\>\"", "<>", "mmax", "<>", "\"\<_mwt\>\"", "<>", "mwt", 
    "<>", "\"\<_mutmax\>\"", "<>", "mutmax", "<>", "\"\<_rep\>\"", "<>", 
    "rep", "<>", "\"\<.csv\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"allmuts", "=", 
    RowBox[{"Transpose", "[", 
     RowBox[{"PadRight", "[", "%", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rescuemut", "=", 
    RowBox[{"Ordering", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"alleles", "[", 
        RowBox[{"[", 
         RowBox[{"2", ";;"}], "]"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"-", "1"}]}], "]"}], "]"}], ",", 
      RowBox[{"-", "1"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fig1b", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"alleles", "[", 
         RowBox[{"[", 
          RowBox[{"2", ";;"}], "]"}], "]"}], "[", 
        RowBox[{"[", "rescuemut", "]"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "genmax"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            SuperscriptBox["10", "4"]}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Generation\>\"", ",", "\"\<Number of copies of allele\>\""}], 
         "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<B\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
          RowBox[{"defaultcolors", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]",
       "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"alleles", "[", 
          RowBox[{"[", 
           RowBox[{"2", ";;"}], "]"}], "]"}], ",", "rescuemut"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"Thickness", "[", "0.002", "]"}], ",", "Black"}], "]"}]}]}],
       "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"allmuts", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}]}]}], 
      "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "n0", ",", "n", ",", "U", ",", "Es", ",", "mmax", ",", "mwt", ",", "r", ",",
    "mutmax", ",", "rep", ",", "genmax", ",", "nmax"}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.74267566307705*^9, 3.742675738028081*^9}, {
   3.742675793382869*^9, 3.7426757941699123`*^9}, {3.7426758242657747`*^9, 
   3.7426758650463943`*^9}, {3.7426786610125723`*^9, 3.742678707278528*^9}, {
   3.742678865359585*^9, 3.7426788708994293`*^9}, {3.7431786248700647`*^9, 
   3.74317867251116*^9}, {3.743178774984033*^9, 3.743178793853217*^9}, {
   3.7431788660578403`*^9, 3.743178966613968*^9}, {3.743179006583357*^9, 
   3.743179036592964*^9}, {3.743179072719985*^9, 3.743179135126026*^9}, {
   3.743179179293623*^9, 3.743179217109619*^9}, {3.7431792852033854`*^9, 
   3.7431793547671432`*^9}, {3.7431795886138687`*^9, 3.743179665943205*^9}, {
   3.7431796963860826`*^9, 3.743179703976123*^9}, {3.743180184364689*^9, 
   3.743180184726823*^9}, {3.7432776211771593`*^9, 3.743277700536654*^9}, {
   3.7432777376714373`*^9, 3.743277919986001*^9}, 3.743278353152574*^9, {
   3.743278802125987*^9, 3.743278805400436*^9}, {3.743279048593625*^9, 
   3.743279076393252*^9}, {3.743279166224839*^9, 3.743279168335823*^9}, {
   3.7432792160679407`*^9, 3.743279240129554*^9}, {3.7432795039697323`*^9, 
   3.743279517934054*^9}, {3.743279693387833*^9, 3.7432797386881723`*^9}, {
   3.7438764370845757`*^9, 3.7438764425864573`*^9}, {3.743876481903409*^9, 
   3.743876520919177*^9}, 3.743876570192697*^9, {3.74387660075054*^9, 
   3.7438766008485327`*^9}, {3.743876634210388*^9, 3.7438767564934883`*^9}, {
   3.743876792932558*^9, 3.743876860830018*^9}, {3.743876897126893*^9, 
   3.743876900159235*^9}, {3.743876940413685*^9, 3.743877121718658*^9}, {
   3.7438771591939993`*^9, 3.743877232237978*^9}, 3.7438773082588673`*^9, {
   3.751031975453422*^9, 3.751031989099609*^9}, {3.751558403041318*^9, 
   3.7515584494855337`*^9}, {3.751642449459279*^9, 3.7516425125797043`*^9}, {
   3.75164335178233*^9, 3.751643369348876*^9}, {3.751643401264991*^9, 
   3.751643406323514*^9}, {3.751643530379558*^9, 3.751643540229603*^9}, {
   3.751643591892383*^9, 3.751643707318774*^9}, {3.751644505387813*^9, 
   3.751644543010627*^9}, {3.751645140882887*^9, 3.751645148736663*^9}, {
   3.7516453799768343`*^9, 3.7516453842799387`*^9}, {3.764201222496896*^9, 
   3.7642012950427647`*^9}, {3.764201398625935*^9, 3.764201423319559*^9}, {
   3.764201490559248*^9, 3.7642015647529078`*^9}, {3.7642016992643223`*^9, 
   3.7642017651284857`*^9}, {3.764201969130981*^9, 3.7642019893440323`*^9}, {
   3.7642021719681387`*^9, 3.7642021916445847`*^9}, 3.764202232151041*^9, 
   3.769183483697809*^9, {3.769256445554963*^9, 3.7692565842080107`*^9}, {
   3.7692588346918173`*^9, 3.7692588407531424`*^9}, {3.7692589522988367`*^9, 
   3.7692590792970448`*^9}, {3.7692591206494083`*^9, 3.769259147346993*^9}, {
   3.769259182550456*^9, 3.769259204000216*^9}, {3.7692592370556192`*^9, 
   3.769259325593935*^9}, {3.771543255266448*^9, 3.771543266077338*^9}, 
   3.7822514134692163`*^9, {3.7848996927191067`*^9, 3.784899704161696*^9}, 
   3.7849032082516108`*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[0.005], 
      LineBox[CompressedData["
1:eJxdmHtYjdnbxx9Njk2JH9EBlbP6Jafk0PiWKWFkU1GJdudz7Xb7vJPNzOQw
UYRhhrFpCJPIYZzZIofx1oSpvIaRcWaYrTKS5PVes+4/1tM/rs91r3t91/de
d/d65BKTOTfeQhCEsx0E4f///ffHCQL34wyrT/bpnhW9mvIvu+LvCa3tfh7/
MB4kig/BmNUv3via3jIehvkRo8vkrh8Yj4Bd6JGT5akWTMcdi3+4ccru3ieM
PURxT1F8FNPrwHg0LJxHtFr91Mb2H4M5+aPcLL+2ZPGxGBA4a4Ld3o6Mx0G3
pPVc6t5OjL1wudJHrTjRhfF4lJdlrvdYQOwtWj8B7ocsO3mt6cx4IqsHxScx
/10ZT0aVg/nZettujH1E8c+w9n623u8N7TcFA2dsrIvYTeuBf6yPL20b9+m/
bACuHattvtlixeK+qGzqHhyRRXFfnL408eWw+4wFP1jLR0+6scyaxf3ws7lw
pEOVDYtPxayAi5UPfGxZXMTC5/jxSrHKSsHWGz4X5fsjza/wtM12ivtDkjbi
6mt7yg/AB2HOB6miO4sHoMdfvezMdpQ/jfUHxaeJ8gNF+oHYNXDGrbEVFJ+O
57eHfjVyGZ1/Ov7bY9ir765RfAYiO+/4ztG/B4vPEOXPxEmH9VuP/035M9Hv
p7a6yPFsvfAFv97whWj/WZg8+ovlNlLaf5YoPwguvokrle2UH4QJ1SeNFxso
f7Zo/9ki/xJ8Mzr+9vdSxpCI6inh62eSYLfv+cqL9uy+hTk8Yw4i3NYGVmtY
/xjm8P1mEq0X5vL9g7kY0F511dvM1hvm8v1tErEQzO+PYKRePnbmxnHSD+b7
2RTM95MQgqkhbV4dAxgjBHXWK5LeBlE/h/DrTSGi+oWK6hcK67Sez1dkUb1D
oRy+vmjdQcamUIR/t297b3fKn8cz5vHrDfP4/jOJWJjP9x/m8/1hmI/rU9ZZ
9rnD2DSfzTfqnzDYuo9yrP5A+WGI37rLQm+kfFHcFIZ/VpX1WdhM+eEYdcJx
6J/Kniw/HLK6popoF8aGcAScfpqCa5Qfjs1nS9Sh7iwuRKDlx865D3wpPwKK
pJIzs+0oP0KUH8H7FRbgp8muScPOs/7EAv5+DAugPCmZ7N1C97dAVP9IaIdf
ehs/m+ofid/i/+k67Dj5jxTpR+LRSNcxGcNJfyFfLyzEsgcxqx+UUv5CUf0X
iuq3iN8fi/i4YRHun3pvcBvP6mFahG7FLYsCKik/Ctnl+1dKdJQfxccNUaL7
i+LrLUj5+3IWMaQ4Ezn4XH8rxlIpLkhM3xtO0P2I2CiFn4d0vVz6H6YnxfBB
nR+8mca4QQp385qyowWMhWiER1UERoQxdo7m8xHN3mfG0mhUR4e9avpfxoZo
dO5vGXLhOmNjNDYMfh8ubCP9aJQ3OmzTJZF+NJ5ulPvum0L6MSiKNxdFlpD/
GHQK7XDIfJ78x8Df50HOr63kPwZu/ezsE6PJfwweD2/UjpKQfgxiLrueGGMg
/RhExvx53/0J6YtYiIVkpNFV0bcX04/F1mOTFxSVMUYsakpPr/yyjrE0Fm3F
li6PaxgbYhH7+6lTJX8xNsYis8O7vL2TejP9WJwb+NUwwZVxQywWL5gy+XAI
YyEOU91rf/3ka8bOcdi85oeUChVjxLHvG8bSOPY9Ysf04xApBNtJ1jI2xqGT
uXvd2iTGpjhMHHLgZulqxg1x2PV+94AhWxgL8aiaGmb/sIX04xHl5dPpThXp
xyNztdb+P0WkH48/wtYsz39D/uPhVXQhaXpPFjfG8/5MonhDPN7ZJE4550/+
EzBigXflmdmkn8DnIwFXW5+syttJ+glwsbzT0NRG+gmICRq+u/1T0k/A2Our
1YNPsLgpgb+/hgQEb1nvqBtF+olIjnutGTmU9BNxQub+JtiC9BN5PWkiwgIL
bP88S/qJ8Prr0Z3SzqSfKNJPxMH9ef373ib9RL4eQhJ/HuckeC78suT0buq/
JF5PmoT6Tsvr+zWSfhLfr8Yk/vymJL4fG5J4v0Iy3AoCqv2uUv8no2/Uqetr
Akg/GcGCd3V5D9JPhsnN70WpnPSTMUjdocjrb/r9E603JaPnvtpkcy75F7GQ
gqBsW/3GStJPgdPvH9+8taSfgsAZ+bcOhpN+Cv772NHQzZL0U6Cv1VoLUvKf
gtaWqTvU7qSfwp+3IYXvByGVr6+ziJHK95dUxIZUUf+n8vPAlIrAZ/VnbL4h
/VT+PEIabJdnxd3dQfpp/HxBGtwu9X394z3yL4ob0pBX9a19mDvpp8E850bB
Bi+6/zRcK/21aVA63X8afz4hnffjnM7fB9JF+un8fgYRG9P5eWVKx8rWmr32
70k/HUu31kTZy2j+ZGDpU5ezf05n7JyBV0fnBg/8jDEycPqv4KDZxYylGWhq
vVh5+xbNvwz0X5Gyp7l3H6afgby1qRP1AxibMnDPLb7Cyp1xQwaOmrpN2/ac
9DPRlOcf5j+axZ0zUXmu+KYphjEykb2+bHFXE2NpJo7YP7rbfJexIRPbXbc4
yQ6SfiYGd60O83hI+pk4uaP/lhyHvkw/EwsL3Df/kclYkMHO935aqYqxrQye
zm/bJ5UwdpYhP7Rb4PX9jD1leORa/Dp+C2PIsHWxU8LOIsYSGUbU7evZZRNj
qYhlMnT1u/wsKJWxQYaVbTfqyqcyLpShdmZFxD0XxkYZ5ifsbmn9hPEBGZyM
6Y9DTpM/GV+PGhl6ByWMf3SU6i1Dy1Gr+U6XGZtluNBLrXVuZCxk8fm2WWjc
ZNWe/zfdRxa/3jMLUTNP4VQF3U8W9qRs7et+hLEkC/kT2xOmqum+stj/vxnL
ROsNWbCb6Cz/dDHjwiy+H4xZvN8DWVjzRhqYXkv+ReepycLKDdM6Dqgh/1ns
7wnkX6QvyGGjGTHvjyLyL8fzuIPLGkvJv5zfz1PO1wtyJNu0hKSXkH85jBu6
dLl0nfx/3O/w1ruee8m/HGOK+pXnbib/cpw7v9OiLpz8yxG++KV//mv6npBj
f4il5auXjA/I4WJc2su3ir4v5Aje/OG+xIn8y5E36mj/egn5F7FZtF7I5n8/
bbMRVC25UJJE/rPRJbfA8Zco8p+NtdP6eOjqaT5k48yJnl3M6xlLsoGYn+vX
qWleZPPzRZaN0X22RUfm0fwQcaGIjdnwj79/KH8T+c/G0at9OrZJyX82rG40
Z7XnMq7JFn1vZeMH5e5bnq6MzaLzCAp47Zm7cIaesa0C2sJetdM70DxU8N9n
ngqkjM+wMYSSfwX7+xX5V/Dnlyr470OZgp+/BgUifrVO3nyP/CtwMr+wRF9O
/hWi+1cg5kxDY/th8q+AocuY3KYH5F/B90/Dx/0eHnS6u4v8K3B1eMYBpzby
r+T7wVbJz2dnJd7LXWYpven+lTB0f/PVonHU/0pUzNw94lok9b8oLlXy/SNT
8v1mUOLId7t813Sn/leio6Kf25Jj5F/J1+uAkn+PTKL1NUpsmnBy44sK8i/a
3yzyJ6jgjYEWaKT7V0HSfPjKsc+p/1WQ26fXv1hC/lWwbt7ydOYW8q9CaX2/
hpIfyb+Kf4+kKvTuM86tahn5V/HzxqBCx0yrMemV5F+FDymxKy4/pvmngmLM
RR9lFc0/Fbb0mNLp2luafyqoyvuvC71Dv/8qdDcF77ToS+/dx/xbxZd73CT/
Kn5+CWr+fLZqSMPnvf02lfyrEe7qbbw5j/yr+fkF0XqJGgU3bL/5nxnkX42K
/IIexa7kX83PL4MaNzdII0prqP/V2Hn73o3aFrp/Nf89cUCNKxtK5zwfRv7V
ULYO3X/lF/Kvxr7AW4/kHci/GjNLVoVZ2TA2f9S/8mq593B6/zVYNOJ1c+oA
ev816N5cFvxiNL3/GjwNq9K81ND7r4F56KX+HZPp/dfgomKtJjOQ3n8NSn8L
0/4eRu+/BlYm5ykj9fT+a6CbvP2z0EH0/msw4fiSu7096P3X8N8jRg02fTFo
bpfV9P5rUNPUYqqJYmzSoKzHL4+e7mBcI9Jr0KBD4fX2p0vJvwadneIe+hSQ
fy36jVleOyCG/GvR0eLDqcFfkX8tFNFPLE4kkH8tdh6sLF5xg/xr0bjVI+CY
tT3zr4Xjyon7bw9iLNVizyOPm0/CGMu0MG6eMGR5JGODFg8+X7HkZTTjwo96
5lGne/oyNmqhSS/wVgYzPqBFW4fGxGMRjE1a+J1sWzUtl3GNFu/2PqtZnsO4
QYtD63I9Cr9nbNZiS7FD2C8XGQs6HD309cTonxnb6hCV0XPiG3cH5l+HM/Pq
Hgx5x+KeOrSH2vX75iZj6PBtch9huxNbL9Fh5LyxAxubyb8OfR3Kh37ZQP51
GFCZV1v/iPyL9i8UsfHj/j19zpbdJ/86POv/fooshemZdCgJrT88Lp1xjQ4F
S6POz8lh3KDDzsxRA4dMY2zWYU/lnWifMMaCHqFLbs6P9WVsq8dPz30Tg8aS
fz0uSXZfz/2MsaceFl2/9F45jDH0EIqWr9rsSv71OK/ZmLvNjrFUz9dDJso3
6Pl6F+oRsvTDtd/8GBv1cKt+0jUoiPEBPXQz+rQ7KMi/HsEb/L8tW0z+9eiW
+XDZksvkX4+l707vevaW/Otxv8H90KTRjsx/DlZUpdtlDWJsm4PEfqvlNQsZ
O+egMbKlu38sY88c7C8fNKT7YsbIQbe887scihhLcuBzpNp61y5H/B/BWp3x

       "]]}}, {}}, {{{}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{6., 0.}, {7., 0.6931471805599453}, {8., 0.6931471805599453}, {
       9., 0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEqDgwoQM3hveWvf056z+whfA0Hbua1Va8mf4Ty
tdD4Og5MClq/uFf/gfL1HMRCt+7emM0ENdfAITzKaF2R0n+ovKGDce/b744H
fkL5RmjqjR2KV1vbb1rEAOWbOCzffV3slAwrlG/qENhjqM3SygLlm6HJmzv4
mNdvf6zHDOVboPEt0dxjBfUPI1TeGs19Nmj+tYWHFwBulEpq
       "]]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{24., 0.}, {25., 0.}, {26., 0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{224., 0.}, {225., 1.0986122886681098`}, {226., 0.}, {227., 
       0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{239., 0.}, {240., 1.0986122886681098`}, {241., 
       1.6094379124341003`}, {242., 1.791759469228055}, {243., 
       1.9459101490553132`}, {244., 1.6094379124341003`}, {245., 
       1.0986122886681098`}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{312., 0.}, {313., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{362., 0.}, {363., 0.}, {364., 0.}, {365., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQYbyhwYkMGBMof3lr/+Oek9swfzL5Q5GPe+/e54
4CeE/wBN/gOM/w3CZyhHlRcoRzVfAY1vgKbeAY0fgMZPQNNfgCbfUO7Azby2
6tXkjxD+BDT+AjT1G8pR/XcAjX8BTf0DNP4HNPMZKlDDQ6AC1TwFNHmDClT9
DhVw/wEAJGOA6w==
       "]]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{392., 0.}, {393., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{397., 0.}, {398., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{428., 0.}, {429., 1.0986122886681098`}, {430., 
       1.0986122886681098`}, {431., 1.6094379124341003`}, {432., 
       1.6094379124341003`}, {433., 1.791759469228055}, {434., 
       2.0794415416798357`}, {435., 1.3862943611198906`}, {436., 
       1.0986122886681098`}, {437., 1.6094379124341003`}, {438., 
       1.3862943611198906`}, {439., 0.6931471805599453}, {440., 
       1.3862943611198906`}, {441., 1.6094379124341003`}, {442., 
       1.3862943611198906`}, {443., 1.0986122886681098`}}]}}, {}}, {{{}, {}, 
     {GrayLevel[0.5], Thickness[0.005], LineBox[CompressedData["
1:eJxd0n9MzHEcx/GPU6jDiu4biuqGpdqhXPqBexWl0uXqru5qjBnDRAuNJfOd
H2l+DjM/wsgUmfNr5Ed/fDGGJfohbGiGjPyItbj8tnt/bN/Pd7vdHvf8fL7f
z/u7C5lTkDVPwxhb8Pfz79t9dZik7AtXzy7Sg37AO8fiSQviufsgpSJ12MVe
3D7Y335iretBCNkPaD/+3Psg9yAsDB9c2iOfOxBhZZWvy6O4g/G0NC70ys9g
sh77jkgR8xu5h6Mk7mPF5oPcI/HmxeEhtgLuUFS3tZhOJ3CHYUT0Za8ab+4I
xOhWfDReCCIbsK5+9n2tiXsMSm6/XTl79zDyWCQF9H4YEcMdiSMBZa0ZT4aS
o3DUa8+Z+SXc4+BtmV43ayC3EbaXTsPbo4HkaBwwoLnBwT0ezmMzQz74cseg
0XnYXlMdQI6Frex63fIJ3HHoLLhvziscQo7Hvv3Fxs5Dg8kT0HG+4edqHfdE
1C7L/R59cRB5Ejw1v2tHrOc24cte7a8tn/zJgM7fGH5vLVkGrt04pmnJ5T0B
25t8Ntel8Z6AnMrySHtf3hMxg1klyw6JeiKGFzY8cenIbDLeb6s/Z2rUUZ+M
O83rNxTdIbMpaG2vKrIf4H0KnEOb9GFv/KgnwWdj4dzWCrKcBCuLqT/ry3sy
VujK2fbKgdSTkT5+Tc1LA5lNhfv/PID6VHRtcvrP7PSlnoJG004P/2dkOQXN
87q8Qi/znoq20fqoJaN4T0W//AHtZYU+1NNgTr5189VEspwG3/d+UofUn/o0
teVpaLj0sPPxNy31dJS3aF2VRrKcjqitH74mKF7Uzer1shmuiJ0lVfm8Z6gt
Z9C8GurTYc+LdC7V/za5u2BmgbbnqeJ3u3q418MCTXBYt/bkD1pvwafY7l+J
hi63FYuwPxPLTsabzlUw2p+JzC1jwz02eNB5BCuZKN2xKG5VUG86XxaCUsyx
UrUn7c/C6kNNtdKLnrRf6EoWqq4+ku4GkplVPS+s6nlkq/q8ipXer4vOb6P1
n92GjeZto/mFrtjoufzKVhuCZcFKtvr+LEd4fo76fcs56vWK0JldPR/swn67
el5FMHMIz3cI8zuE8wtmucL8guVc4fxCZ3n//QeB/Zjc
       "]]}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  Epilog->InsetBox[
    FormBox[
     StyleBox[
     "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
     TraditionalForm], 
    Scaled[{0.05, 0.95}]],
  Frame->{True, True, False, False},
  FrameLabel->{{
     FormBox["\"Number of copies of allele\"", TraditionalForm], None}, {
     FormBox["\"Generation\"", TraditionalForm], None}},
  FrameTicks->{{{{0., 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{0, 500}, {0., 9.210340371976184}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, {{0., 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.769256505177463*^9, 3.769256558548091*^9}, {
   3.769258959451062*^9, 3.76925898231723*^9}, {3.769259023590016*^9, 
   3.7692590446339607`*^9}, {3.769259129845583*^9, 3.769259148524482*^9}, {
   3.76925918297082*^9, 3.769259205393708*^9}, {3.769259239355654*^9, 
   3.7692592959528513`*^9}, 3.76925933486633*^9, 3.7715433019097958`*^9, 
   3.782251414007621*^9, 3.784899664346669*^9, 3.7848997050439167`*^9, 
   3.784903210067854*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure 1", "Subsubsection",
 CellChangeTimes->{{3.784899716602643*^9, 3.784899717538375*^9}, 
   3.784900539169342*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GraphicsColumn", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"fig1a", ",", "fig1b"}], "}"}], ",", 
   RowBox[{"Spacings", "\[Rule]", 
    RowBox[{"-", "30"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{"figdir", "<>", "\"\<Figure1.eps\>\""}], ",", "%"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.784899724298213*^9, 3.784899776005975*^9}, {
   3.784899821904286*^9, 3.784899842912471*^9}, {3.784900259563116*^9, 
   3.784900306720999*^9}, {3.7849003384131107`*^9, 3.78490033967591*^9}, 
   3.784900539169818*^9, 3.784903294213354*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{{}, {}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzX9MzHEcx/Fvyqi70nHST10/VS7q+sUl97rq+n3dddZCQ5q0JSFl02jH
kI2Uyma66Y+sHCnNIlp2jWoNs5I0Zc3vflqYVdYV1vvzh77bZ589Ps/P+/N1
ST+kyVjCcVz83/VvX/gmZTbJTS2NB1xBBxBXozgsgHk5hHOnu8xMma2Rc6S9
cUO3C1mIUyG1fVOVzLYoee49sT+N2RF7us78inNkFqEt+2Rh+3sR2RUWH9bl
jjxkdkfqWn7CnlJmTwzKgnb0JjN7ocTuWf+0L7MPXOueKPd9cCaL0VDut/Ft
DvMGZM92SJYtZfZDvq7esuz8WrI/CjIH7w+ImCU4OtSj6n3gRA6Aud9AREMy
cyBCxVxrsjlzEMb6q7fLyxzJwVBv4n/NlDKHQCNImz123YG8CU7hV9PyFcyb
UfWSb1XeY0+WovSMafPQLuZQ+BYp9fpnduQt0Oe/lVWWMIfh8O7CNvcE5q1Q
OaY1Bzoxy+Biu9f44p0tGTAp7ZkbOUXWAk4BRa+d01mXo1z0eVgtZ10ODBWm
CqJYD8fAvENLat4a6uH4eU6xXSEhcxF4YLCIrhqzoR6BGuNNZ08dmYuE1PNu
f10x65G4og2rFoSzrsCyNjedeHw1dQWuiZpWfPlK5qKwTVfhUODPehRiRt88
trogpB6NnT8Ggj2Mq6hH41OWt9RYROZi8FRtqNQ+Wkk9Bll50/dNUshcLLwT
3YSKgwLqsXCw/Th8ucyaehyOe3fOZKjI2jgoozraP4WxHo9Yff0tD90K6vGw
zJWEvjptST0BrZ3Sb14f+dQTIBgX2kzaWFFXIrHukiKjie5rlbjRVX2Ml8d6
4qL5RFT28WZqgnjUVXhhPzlaYW1BXYXJe93Gk6vNqav/N9SYEZedqM0ma9VI
uui/3uys2YINavBM7xSMlpvQfBKWiHx+827Pyhbmk5CyU1Kf6zq/YO0iGxaZ
0yCgeGJKbpih+UXWav5/36Ch/3+X/QEXoS4a
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd03tIU2EYx/G50lkLMy+zmjkdlWWibdZSS/eb9+mW05IolZphkkJlSZYj
mlazjCgrhK5aXqhmhkZ3pQuFglhEYeQlW3hJNFgEGWJZ4fP8UQcOh8/5vg8c
3pfjl7UzNVsoEAi0f+6/z6nLrpak3XnUmCcHvYAuvTv1bRjbGVGJo6MuYrYr
JEZbX26nH9kD949YHkdVsufC0todZzSxvVE3Q6RyMLB9cbzUsTZHypajdV/V
3pghX/JC7Eobske2sBfj+4eRUdUZ9hLs+xaR93ArOwC2tqParmB2IEqOoyfU
nR2EW+fWD9R3yMjLYYvcnxuSxlZgflrJxIpPPmQljLaPY5sq2CHYuO5z5vUE
9gr45YcN548tIK9Ea7XcsfAQW4X3z4ymKj17FaYHux+a9dqbHIqySVnt10x2
GJJN1x0je6TkcKi2P++6UMNejSKHuwPnDOw1mL7smsK5bz45Arc1otmnT7Ej
Ubz/S6GflK1GS1OST0LHPDJQYFe0uGnIZqC7Mif/mHUudQ0aG3aeDUonmzWQ
VZ8o8ddzj8KPe+IN3m1e1KPQPSl9lF5AFkTDUp4XbpJxj0Z5vFdQ0TsJ9Rhc
fLVI61RGNsdA6VVpzLBwj0X7+OcyS60n9VhsVkU49XaQBXFQjQ721ou4x6G6
/0hW9DYP6vE4cPlNs8TmTj0ePg/23C1tJwsS0J+7NPxnKfcEuIm9mgebuWsx
XLFbc1PNXYsrNW2eJzvdqCfCNVAhfTk5h3oipv4f7kn4kTTgXKwjm5OQfalO
aKqi9QId1ih1pS5beF6HDNHV89JY7vp/bdZjgXWiM2MV97X/za/FYLA8ZMdS
7skY6fE/HFziSj0ZGzYpG3bLZ1M3QParoz3UPnPKMKDtRURhwUNnWm+g8yc/
MdB5img+BUUHx5/m3XCi+RTa72k0nwKhb8C42DqhnppPof0R0nwq9lhXq5uu
Cmg+lb5vUv0bIl4fKg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HlIk3Ecx/EnW+nUmqXVcqVOI09MrTyrfTTnPHLuMMwyUGFIp0dEOQQf
jKDLoCyKoj9qkdXUMjPRQpa5/igK6SL/KIOillRaluGRHfj9Em4wxmvv3+dh
44FHWVxqMLkIgqD/+/73OfkaVM1f33q7eVsg6Ass9Mu5EhXPdsOhVYJ3l5Tt
hWrbxh+Zr5RkHzQUm97FWthyTKhT8zU72Ysgc4+TjUSyA3BbU6A9PxZADsSW
b/LGKjt7Cezu/i09R9lLoav4VV+Rzw6BdbjP97cfOwy/vkj2hIz6kyOgKqxs
O3WKHQmj8rK0PYkdhZhW5dZ4V3Y03Pod+8ou+pFjcP3+AptnEHs5ZkYN26sc
i8krEJRYd/rAXvZKzEgb+6gZX0SOxbIZPU8DDrHjEKvIKfFczY5HXsnFW9aH
CnIC1OUnP72uZCdCcqfsZdxsdhLMnvcsw3Zf8iqEjlepRkrZqyH3bQ7e92Yh
eQ2+WfJt/jFsFTwOx1U2dsrJgL+ltiY4mywCA1GJ2Te+L6CeDGO0m9BrJIvJ
aC0wF+Ztn089Bc9DthddaptHPQXjFonyQ48P9bVoWvw0MOwDWVyLpK0Vpwtv
ck+F/kh0uGQ/91Q8LtrwdajXm7oarn6S3O4nZFGNc+Jzs6yJexq6dbazYsdc
6k4WNKhtkYZ39nHXoM40WFdQzz0dZS+GuoqU3NNRWL557IFjDvUMFLheOKNQ
k8UMhGqDfNQ7uGdirsPWZTVwz8Qz07A0pJ17FrwiohWPf3PPgsf0RnN/Hfd1
Tvt1UCaXHNw94UU9e+p5MRsK+VvHsePctRia6MivcSWLWlxTNLQ9yZJRz4F9
SGbcWO5JPQfahqNqU+ss6rqpHTq4BISNelj5vJNtOiyv/fwz2SalvR6PfAf7
T3i5016P5qbSE5Gb3Givh7l69O62qzNpr6f7LaG9AbusSaobFwTaG+j/TqO9
AZPPIxfaO50XjPR7RlSTeyeLRrre10nbnCzkYiBhdCIl8j3t//sPvGlE2g==

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1GlI03Ecx/Eh2tRKS9s0ncdWluWK1NSps3285ubVtkrbXAVGT5IKlU6v
v1KoadJFUliJB8YsSzNCpdSyJ0VWVFo+qFh2aJdSeeFR4ff3wP7w48/r//59
nv7Fqft0uyx4PJ767/n3nn2GFMItt9oa0ySgD/goPd7zRM5sDS+Riv+bz7wI
AbY+16x7xeQlSLmUHcerYnZG6/bcMuMBZhHWZqbeUUUye8J8svzdDydmCcbX
7HyrM3uSl6PmrNUeYRPzCtx/uVv9KpfZG3byoxHzDMyrkbf0hYu9hFkK/8If
TgWPPMhrsXmbSF+eybwOwsbAitMCZl9ITe/lh6+7k/2wNU45UZzJ7I/kVQ2h
aSuZ1+PNmFWOqduNHIDhoo97DUnMgdixbuWo8IWIHITG9A9fruqZZci46Fcl
feNKDoawz1QQl88cgkFX2etqd+ZQhC6YGcyudCHLUbnTP/5ePnMYyszpzW4C
5g1I3JrlO9yzlKwAKgb7GlqYge/8rjOXlWQOqG16UF303Jl6OOw7NtVaOJO5
cEx1eZQ09zlRj4BeIqt8lUTmIlBx+3uJmw3rkWgrPVmX1SikHon8AXG7WU3m
RcFDlRAsNAmoR2Gy2lL86ekS6tFQxZb2NenJXDT6d68KmSp0pK6EMdX8XvqZ
zCmxvUg5ENbFegyiw/qzn0w4UI9BSky77cQNMk+F8+11B7dIWVfhq6N+10gx
6+q59zk1xmr4uf3hrMfirtGr030+67Fwq5/sMQYtph4Hh88d9+p1ZO4/8+Kh
SP5lTHRlPR5rFnsPX3i2iHoCfk636gv4ZC4B+9s0ctmYHfVEjCxsyZ8MWEA9
EQafU6ruQ/Opb4TH9ONHsiFb6huxLPZcj+EKmaeZ2/GfOQ2O5E10ppnmzbpD
g6Gbz6ZyBDa0187t0KKurVf4UGRFey1m/ycWtNdCW+rrY3nMkvY6JBv8GjIk
M4rZvQ7+J76NhneMK/4A9+0o/Q==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0XtQjHscx/Enu2hOodptSbnU5FJ29lSrKLGfrZQu2os6zoozLGZchmQa
Ta7PkHFJMhJDo5Qy0zmz634ZBy0x5HSYEZ1TGJKhGtmVcSkUpu/3n31mnnnm
9byfz/z+ePzNmcalAwRBMP64fz77L4dGkX7+79MrA0AvoMvLzjVEsF3RG1kf
VzmA7YEJTa5Ntn/8yXL4bDm8MreYPQK1f5rnhpjYfgiLOtYXHcQeizLVycyv
H8eSA9Djeykhq44diN3Nx8peF7DH46HouGHIYE9ExbPoI3uV7GD8Ur3930su
bCWql/jUuOSNIaswUbLYftiXHYJ9hirZ5oejyaFoz47Ka1nODsPio74Ov85R
ZDVWTbh7ddQG9mSY3NX364exw/EWXZ0dZ/zIEfgwo0ZmjWdPQSlum35r8iVP
xZiQU+VZS9mRKLbs+L22biQ5CsnTNibKzexpuH624qYkmB2NQ17Ta6ytPuTp
aFYMrL6nY8/AGe2urd19I8gaXPjv/WSv22xAtib5+upNZBGwyf8avKhjOHUt
9ly2N/+RTxa1KGzwyK9P4h6DqictDY8+K6jHwHzteVfvObIQi+qyV6cmLeAe
i/Smgbt2bvCmHofgjKm3runIYhz8pU+fv/8qpz4TXpZHyx2byeJM9HyOrchR
co/HfPOLVmWbjHo8lI691ouFZCEBr4O6ckP13BPwckVQ1Lcd3GeheNw3k1DG
fRZSpmy52KrinojBo6VpNx9wT0RgjktRhJ17ktM+yen8ZLQfXKu1aLgno7zy
jndhoxf1FMzfpp73fxtZTIE1wW7Mcef9bLwoiQh/XMR9NvILqsZZJNxTMSjd
5ayjlnsqFmYt+HK3zZO6Dg80+6XDn5JFHV79GqBeHcRdD3fZjZw17cP6DT1M
Ryzl3koP+l6Pyrrj69yyh/bbpofnG7nCoSALBjQO2bmsO3UI7Q0oaXTrPhHu
RnsDTlszD6gyXGlvgD2ypzdGNYj2RmwqbbiiaJHQ3smiEYY9oZOk26W0N9L/
oS7Mwdx5Yda1AX2a/r2TRSfbnCykOe3ToC7o/KS1ddM+DW4Sy/qOonea77Sw
Uz8=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzQ0s1HEcx/E/KuZYhDt5yN0pQxhX5+lwH4fzLGOyrKeZMKyGNVtrEpW2
s9ipthI23Yopm2uZRY2Zh2XlaUUpN9V6YIWSYVwP8/2t6bf99tvr9/5uX1H6
qaQThhzHKf7cv+/GmZfzUx52tOaKQR9Y+HKxSuPPbIJPb9Z8L21jtkDZXCpv
pU9Etkap5YxLUw2zLexE66GzmcwOGD3sV9HpxyxEUWuv6pkJsxjOA0O3dK+F
5N2QPDF2GtEwuyD76nwMl8fsCtWeySFRMLM7TMP7llWmzB4wuL6uq9M6kb0w
3aYvzAtn9oZj6mLI9NAusg/m+pcjNd7MEjQlH1R66BzJ+9A9O/AipZh5P9QD
Uz61JsxSBNX+PJtc50D2xVRcvbYSzH5YM9I/GGy1J/ujTVaQMS5nDoBA1q4Z
+GpHDkRY24xaqmKWQVz0WTMuYQ6CPoXvqJrYSQ7GmsH3rPY05hA0FsefjLJn
lsPz/KujvEVbMlBmIzx34zK5BEjNbFxeNWI9FJPOOQ39LqyHwqpH5CmoF1BX
oLf79kRXOrlEgYlrx9PuDfOph4E3tpivLyaXhCEr92NYlznr4agQDKuX8m2o
h2NvpfK5YtCaegQsyvMzdA3kkgjYHuscvaJkXYkPOW6B6+VW1JVoiZxLKjIj
c5F4V+MrnazeQT0So3L1FsFbS+pROO12tVqttaAeBU9L14WbI2QuGj/0jw6V
GrMejeYgcbZrz3bqMXjcH/jN9b0Z9RiYF0hkY6Xm1GNR85K3ckfKox6LqgtG
7bojptTjcLdjnP/UYSv1OPCM7p+ZqTagHg9Dofsqr3lNvtHjUdgsk2sbOOoJ
mAtY1Su8lqgnbJ7nDiA1TdJSIP5F/T9ziZuNRNq/QPP//BsGcBE1
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd02tIU2Ecx/FjWioGTdOpa14mIpWycrOWdtlvXuaWWjtbmkrSUBaWQdlt
UbkWWflCLUwpMgt8kxoFWVKpmSZJShIWKeQbzZIs8lJ0XWnF/k+wc+Bw+Jzv
+T/n4cCR5e8xWuZxHGf4e/67Oo9ptTizpe1WUQToBnbrh6Wr45i9sPDkRUmJ
Q0YWQfc9xJzQy+yPqmONjmeXmYNwKau1VZrHLIXj9NFzbSuYwzFqvVcZ48Ec
gUM7lWXmgXByJAYkOV3jtcxRkB+6VDVZyLwU3bO8zGs583KcDf3ulT0ZRo6B
4sFPdzQzy/HqaEFSt5F5JXpsL/cGzISSY+FtPXYxuJRZgSx5VKxExazE1WGl
2HcihByHrg9PXmbamFehbsRPVCpiXo0fxfrC5BYpWQXbWG+C9TjzGjQ1Oep3
TC0hx6N8cOv02wrmBDz2Kyr1SWNeC1mkYkD/VEJeh8OK7hHrNub1aNBqapp/
BZM34HaVTX6ullkNN/+yz7O/g8jATd++8Yl6sh3Q1nrPXItmXYMDyp71B/sD
qWtwUBVlabGQuUSMRlse+cSwnoicksmU8i9i6knoaPXzmq4m25OQ3zHyafYO
68k4MSF7+FrPejIahrtr6gYDqKegcW//QGEl2Z6CNbvUiopA1rUYWnBmKOST
P3Utgra3P6/UkrlUFGV78gUXFlNPxbJIzzffUsmcDubiPEffO1/qOrRJquvu
T4mo6zHH8XPmA4uo6/H48yJTbvFC6hsxFf9zNlG+gPpGpKuO3x2Tu1NPc7U9
Dfuvr1U313PU01Fy5UW7eJT1dFxrGxL3SedTz4Dzf5xHXWBuk2D9TYL1N7va
vlmwP4OrYRDsxwC+PDba45SH050GhOky4sVNbH+8YJ4XvI+Hj/uNI+/Pu9E8
j625ipv7IubUznmj6/Mw0vMzzm430vcdd7pTYM4EZcXHb5rOH07DRP0rzZsE
84LObfn/vj9Cg0yb
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1A1MzHEcx/G/SxxnoocrPbg6RZTSpVLJfTrS9XC5hy7rMIbMGPLQskLH
hHRUlGiypKGarMhDms6seVgsIjFjjTHPh9LDrLD7/mx3t/13e/3f/+//7vvf
7bxWblKn8TiO0/09/r2bXyapUNt4o369GHQC8+YM56RLmPkQaJOamoa8yBPw
MT9hpWsbsyNK317JmraP2QUR7/l1G1TM7pDUTWrxFjF7YkDpw3P/6kkWI2N6
8dEjDczeyJFJNb37mKei3Lv6nH0Ssy+q1gwHr3JgnoEtOaueN9wSkf0RO6X4
27oU5gC0Lc4rOsBnnoVGW4czpbmTyUGY+NlRaBIyS7C+p7+6p9KDHAy+Kd/H
4MU8GyG1zjNT693JIXgvvtlZoWAORWFBu8Kx140cBkWN28n2y8xzsKywateS
1czhUEQevtTY70qOQMHu5bdVO5gjEdO6MfuID/NcDGmFHvldk8hRqLA1qu9k
Mc9DVERckHgFsxQtby+2dIcwAz/OpBpFErIe8PxwqbHrtQv1aBy/dcpmfwpZ
H41nT3fePziXdRnySmJtRe3O1GWYfGBddY8TmZuPUSa7zqK1Qurzce/J3tyM
e07UF8Ck6igoCSXrF6Ap3b9Pw2M9Bn53XHqruh2px0BlCPIbmUvmFuJwekbN
Eg3rCyGPN7xoSGU9FvYC5+Z3zQ7UY1HabRjx6rs9dTk0nXmGxx6sy3Gi5Vym
1p/1OKSVn+VlV0ykHocnab/G+F4nc/GW1sdDYHMh6+NR1hOwdHRlmVsM6wn4
9HLa3sA9E6gnIrXswmknf7I+kX5/46kr0PrTTqPbPI66AldMhYGuD1hPwmKd
pG6L2I56Eh5de9rT1S+gvghT4o916s6Ppb4IOr8i+cPtrCtxtzUqc1sT32wo
UfRma7asbzRdr6TnPdJsoxJbayOlDZUczato3xE0rwLPc8agoPa31DyvQvCh
L33RxgGzjVbm1PT9h82GlfVqfAsfHJIF/KJ5teX9OY1lh8Zq3spGK3PJlvsg
GSK5IlxYY0v7JyMxLOfqmwAb2t/KnBY7T3U0C7vJ0ML8/8mjea3l/Y1ael7f
6fNTLPeBlfUp/6//A5q7bsY=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd039MzHEcx/FvJ6ecFP1wpV8unNXd6Uq/rh/3Kv0uXXfkR/rhV5uVObS2
FrkzZBpRYmIoWbbiqMgoU2Q2W8yasJlzxDCTpbFOCrv354+77/bdd4/v8/P+
fj9/fL8LNmk1RTyO4zL+nf+vluO70iPnZnd7iQh0A/HqO3xFBLMD3IvE1XYz
mV2Q/05Yc+XlArIbhlf/2nrpArMQ1QVlodHFzN7Y3L/DaX8csz9ahxJNUh9m
EQr35LhMmvzJCzFaI+7Lucq8GDp9Xu0XHfMS1A9HZCkUzIG4bvZ5KuWYJdg2
a62yu9OPLMOh3Yeb9RuYg6Hq/CAs+uZLluOnzLGhuok5BIajAa9UEuZQOMnv
q3SPfcjLIGz883DjQeYwCMsVi66FMoejS7ByqfGRNzkCQ6Z1J3u2MEei68b2
07GezFGIGZ04FWCcT1bAbuTExFQhczQ8PuVy/iLmGLg29za093uRY/F1Y0tj
fxhzHIRe7eL9bz3JStQ1Gs3GYmZAuu9VgWBMaLEeyD8maXijJXPxODD1WsN3
ZD0eI8GKFR1j86gnoLTeUOnYS9YnoEp+y/dFNuvL8aMqaW1SCOvLEYkAHkY9
qCdCMDi2c3IvWZ+IkSjzZIKM9SSI36ibyqazngSt3e+q1mh36snIc/DSn45y
o56Mc/rnFc4GV+opkCefuZ0+MJd6CpLvfi7GsznUU7HuzNUmd4kL9VR0fT++
1GtgNvU0tMWIti554Ew9DdJY2ap7H52op+PskGC8JUxAPR25QbWpT8rJXAbG
JXV7Lm9zpJ6BdoO2XrbegXomJJ32/PCaGdQzYfn/eNRXoLQtWtlxkaNuYy4L
a3JDDLtEU0pLz7LpKmRG6G69l02jeRWqaksUu/3ofVw2Ks8P9niYqCMb6iPy
IPuD9rTepvdmWz+PU6NCZ+4raeXTvNp6/3q1zbzaer+cxnq/0NjMa8DzDzQL
2iYs63s19H18VP4FO2wn4g==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0mtIk1Ecx/Ens7KmqdPMlpkt6aJm3lJT537Tbepsc6tmIJWgWaKSldUK
Sx9mkZZZdiEwFqOLRUoXzaDpi0GuKwhdULsg2CKNQFtKpmRW7H/eeOBw+Jzv
OXBenGV5pRsLXDiOU/yb/1fn+C7107e13y8WgzZQmK+ynI5hdoPjtdnYM7mM
7AXhDluyqYvZFz5dsWtKbzP7o9sRscNewRyAoRlDJcd0zEG4/bXVESdiFqP5
+nrzwGAQORj1Dy594ZqYV+CcdSLQXsS8Cr2OxG818cwheHGqr7l+PnMYRGtH
/R0dS8nh+Ng0aj6pY47A5srcfM1UIDkS/a3D1q5s5igIsoay1T+XkKNxz8sk
iL/IHANh4JqIRG/mddBbZ0r4GwHkWDy9+/DVrhDmOEQ/V5wt6V5MjkdwkVEf
nse8HgYuV9o3IiIn4KB77oedPHMiAsvk4reOReQkpA6rVhqrmCUQFm9+P3vI
n5yM5eoD2fw2Zik6fQ2Hg34sJANTRfnVzwbIPFCb8GdnqoF1GdoaGmV1nqzL
UHew0pjU50c9BYI3o3v/VJD5FIhb3BpsatZToX83q6a6fAH1VMSe7yzMEJI5
OSx7wsY2ubAuR+gZZVfKS1/qCmzN+2QPG/ShrkBmq0OliyNzSmytis7pHRRS
V8L5f8lcGjq11su8hfU02Dsm+dA41tMh5w9NRp7wpp6OAlOjS7mZzGVM6xmY
d+3XdqWNdRW+rBVH717NugrtogumR8Ne1DOhVj6xfZaQ+UxomusUBW0e1DfA
NuK5KWevO/UN6PaoLhzXsK6GS1DIhKCJdTVuyR7bnixiXTOtazAedu7IzZK5
1LPwzCYx7Le4Uc9Cvb2sPGVsDnUtbrb3+L0ImOU0tDh65U2HX/9MOq+FrjYy
1PW4q9NWLbbkRN3ZJ56SOu/rUNaUKG25ytF9Hb3nt/QvOPQUzA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HtIk1EYx/G3ZeW9LJ2my8u0MLXhJTWv+7nSdPOyTbdIu5ikBVGBCkFq
vRUaWFZqRRlY2D3LMpMgtQbdJQktKrCSMII0c4klmmbFnvPH+w7G+OzLec95
zmA+eTv1+RKO49b+e///tLzMSqmhta15mxz0BWpRNPggnNkap9rP3PGb8iHP
w6MdRrthE7MzJPtuKdoPMbshfzsMy43MMjwbX3P1VSCzN2zcdMPmEW+yHPk9
Se7a+8x+qN5krXlSxbwEle29quYMZn+sO8e9PiZjDoCqr6BmbqcXOQhbAxp8
1WBWwKfBcEH20ZMcDEn8oNFjP3MItBeHimsmF5FDsX9xzob3dcxhmO+5LDjG
iXk5fk5srltaKiOHY6T+UmC4hDkCRx0GTnsbPciROPvS3rG2x528As29VR+6
y5mjcHTfxoe6UuZoTNuW59V7Mcfgnfnc+Y6iheRYvIj/nKTvciPHoetHxR6/
QuZ4uKQXRH6560pWoi5jvC93WkoGglrPGybbyDxQPHFVHhLNegIiRrL9NX0u
1BMgOXX2dzJP5lS4fbPC0+29M3UVgtcfuNxxhcytxJYTkmKHMNZX4uvJwoQb
ygXUV0HT8kOtiyTzq1DVYhN4v28+9UT8qmxyXT/qRD0RPcoaK9cPZC4JsaGp
Bx1zWU/C8zd+o7/tWV8tNL8ajbHyrf4P51JPxprs0KZCOZlPhtM3Z6lZ6kg9
BenXjyTmtzpQT0HH0+jv/v321NXwVZ98k33FlroazU07jytyrKlrUN1fVKIa
m0Ndg6AWq9kRR8hcKryS06Kk12ZRF5lLQ1n9q3bpp5nU01DUGKO83cBRTxea
T6d5ppWWnoHhqIk/KsUvi/kMUdfCbuaN3QO1MyzroUVF9bboEi92Xi3MLd1T
ZS42Fpu0ePY4blfxPTafTjgfdKL1Otp/Nq3XCefh9AirGhpLMI1bzgM9LP8/
Elqvh+5wSKBVuRWt1+Ny21tpp4zdTyZSI/fe7VfQ8yAynymc15Qpur8s4fOR
Jfo9soTnNYnMGUT7G4T78aJuMgjvmzOK7t8IiXfAhF3jpPIvMVlilw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0HtMU3cUB/CLIFOUpwWpdAiI8hBBqKLgsF/KG0qhD0QRnS/MVGQyHJkY
Q1cfQKKGhSxbloW5LGNEUMcMICpSq4hIiCBJnQrZosQwUMFoNikvXXrOH+Um
Nzef+z3fc3+5vrs+V+fNEQQh68P9/9Nyjck8shqvNRzwA73Ar9UYqI9mz8P9
mu4NCVO+ZBd0igpHndvZIlwc1h+ermJ74ti02GZmE1sCw+PbX54Ss32wd3ee
ZvKpD9kPT3oCqr+/wvaHyGje56hnr0Duw2LtWg07EPtqGzybg9jBeHDz0D8O
o0vJIdhSkFHYuJsdCvNRYccKO/bqD/M7XjV2eZPDsRrK0W+K2RFojPKt97Jh
S5FqknSdrP2YvAaShpx+YSN7LZYXXF1pqpOQI2Gscwq4pWCvw0RZ6V/1IvZ6
SDsTKvNNXuQouF8qul9cxI7G1xOtNcPjS8gbEPOHfKjyAvsTDH57+/hQGDsG
keaDba2XxOSNmGjpcbY/wpbhxnVvre0LTzIQMbNH3HaOrAMqJvtMDXGcx8KY
Vhvcm7uY8lg0GxySfhrxoFxubZ0cffn9LXf3cB6HTyNj7Ae63SmPQ/yPf7u1
VJCFeGQ9mltRfpTzeJzq/k68OYTzBOg7sreZFSLKE+DdUtRU1rWI8kTkHpfm
/DnkRnkitia1OZh/JwtJ2H/4XZNNNudJOGR6Y9zpy3ky9IO7zgzWu1KejJpl
qY/XGF0oT8HzMD9pQRDnKeg0+b+dWEgWUpGeeKd9MIbmdakY6Q84Eabnfpr1
Pl0a4nVfTYWXcV8Bh1/ebU9s5/0K6/MI6ZBlv81VenGePmu/EqtcA1//0Mv7
lXDMdxspL+Q8w/q8ugwcCeoYz8vgPBNNY5VhS7qdLEYm5vgEmxfULaT5TLR2
RL8KfEY2ZCJfXtnq9DPNCyqYHMs/G1c6Ul+F9jfOmpxC7qsgPfPyv1jDfOqr
MHa5d+qYO1lQI+SynX3k2Y+or4ZiXWnzs1Bb6qvx27WHHvckc6mvRkmp+eaB
8/bU10B1Onyl3Uk76muQnRNx8Qu/GZmlP8sGDZYmp0d5nKd9gtZ6P7Szvq+l
/zFJfS0W2F4oGa56bbGQhdEo87Q89F+LwX4uew938WNv
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0H8s1HEcx/FvpCyF0PmRHFZqtIs7cufX94XocOKMcpVCsXSto5SQXCX6
pU2/t0akWcSF3WmrbNVqaSWtyB/RJqsWiVUjWlTz/vyR7/bdd4/v8/vaPvu6
pGri0ow4jov8e/97Tl8jvCDBcLdJ7Qp6AXunmFpPKbMpHHUvFZUcsyXau7d4
Z7e5kG1QH9clGC1jtkP3tZYWVQqzIx7pDfLaFczOKPlgslX/yZnsipM3jY53
GZiXomLMb97AUWY3VO7rScqIYl6B6+lTkm3WzO7Q9+64cUAvJK8En/7qglU4
swhVdW6LJb1OZE+4ZTeet89n9sJU9bsgdxtmMeqWZ936WrKELIFqvqTjuQWz
N+L7daLP1Y5kHwikWuNiGfNqfKuo8fAxYvbFicTWzeUvFpOlEHo2VmWlMctw
+FdrzcC4A9kPoe7tSb06Zn/80HREb8xiDoDaUeN92Z85EK3NUU7ydntyEIq2
r3oyUczMo2tIazrYb0cG6jsTc98mkrVA7c5yu5UGW+rBSFatH7+kJmuDMczv
jugzYT0El2V3Lw49FFAPAVJbus/mkLnQ/60NxfuqzgRLB9bXQFOaa299bhH1
NSjYxAfo48lcGKQ7eXGpLethsGroyhg5ZEM9HAY+/efBXWRtOPJyPT69Wcb6
WlxY9lvFXbWmvha3M2tUokVkTo7MN98fprhYUZcjQKwoMU9eSD0Cgz3Li1Yd
saQegVPitJ4ryWQuEhs2inV7XC2oR2LhFxvBiMCcehTW1Z8JSzMsoB6F60+r
95tls66AcLL9mXRkHnUFmnSa86JNptSj0fY4MCf7DlkbDaE8WiaoM6G+DmX9
e/NDxuZSn2EuBsVlar98IesxyCuceKCum0M9FsOyickQERmxUJ728ph9bDZ9
HwuFb+HtfpHxtO/HQlI6NBZ8f5yf3iux96Y/33yNo70SZsYNeQPnZtFeiYKK
1/cEfWyvpP81Rfu4Gfs4Os/H6a5lHuX/APeWKlw=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzA1MzHEcx/G/XA+6ZiSKolJI0lQqndN96rqurq67/xUj1VJrxs2aeZoS
Nw95GKZOIs+XkFISzVOriGrU0jjMs+axybVZepCn3fc347/999/r//59fu5p
mZoMC47jYn6/f77mxyQZN//y9SrtZNAPlBzD83IRsw0aD67shy3zKJwrvcW3
NbuTHfBwQ26H/xFmJzwy1NQsWsLsAv2DqNB7nsxueKjr3aQddCNPxu08deb1
OmZPNAbnXIrcwTwVVcvnrP+mYPZCcELdm82TmL1RPKLh3ceXrmQfSMXLZG9T
mH1xYqLeatfQJPIsmKa0WeMRsx/it7zq79Iy+0Oo6l6g7J1IDsCdwGinI4eY
Z+PpkyxOGccciJSNxvOlr13IQTgrTRu7R84cDFV2qWXoM2fyHFy7YeqcuYk5
BEabjekqF2YRaitbSlpPTiDPRZ+/VZMsglmM9fG7fJp/jifPQ6H9vLqKTuZQ
+ImL3QaUzBK8au4avcKRGWi4axCn5jqZrQN2FsgtXdsdqYeh4VaJhXERWReG
loJyvsuL9XBUJggEPd3jqIfjcUFqYnk7mZOi9Pi7CzOSWZdi2gv+5BpL1iPw
vVjg/r7dgXoEBvqkhnU+ZE4G7UJrPr1wDHUZ9BkmfdIZe+qRKBEFNJ85StZF
okL+RbPOjs5zchS+3j3sRQ/rcvhFFl1VtLJ9FN4cDgp8qmc9Ch2SfIHj89HU
o5FkbShylpF10Zge5+EgW8G64t/zOgXcw5buXPNjFPUYiP1jt49MZT0GLUbP
r4N2bB/73/2xsP9Qf7NMw7oSzk6dH/Ly6T6dEqdaitcKV4+kHofaJlG3V6cd
9ThYuHkPCMvInOq/rsJho7D/dKCQuhpVFZn7fRfbmA01voQM/Aj3taLzavhU
C6yC9lqbXa+Gh+KAMfGsLe157Ns6/MrLZDJ4mKrvD+WMHUF7Hrl5WlG2K9vz
4Hf7zRBsE9Beg1VlcyUXDRztNRAOP5/1Sd8jMe81CNjz+VtYfb/Z9X/7L6zg
Ml4=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0H9MzHEcx/GvytD1U9eJfrqafu76xeU63OsuXV11v8oN8QcSGxIKaZrv
JFtWfqRmQ4zQEtIvIT8K+TE/tpDN5ses7dDQxYauEnbvzx/12b777PF9vt//
fGauyk3PtuM4Tvfv+3/bjkUhMrW2N64Xg36g8nv7SA+YJ8Np20DIsIDZDUca
PhctezmTLMSf+5lOkrPMXhAGdW7vLWT2wfK6Rc4FScwBWFJc4zHHm1kMf/5N
woP3AeQguDzO6/JtZJ4Ffe5qy70S5hCsUFtjTmmYw7BnmndwbTBzBJ53bvrs
2O9PlqBJaq0YKGGOwuw7r8vlaczREJ0rjhoa8SPHYOvty1kFB5ljYbrYUlWm
Zp6NwWO/6gLrfMlz0JKxQB6pZpYip9qj+Pp1H3IcnF/1fHXMYp6LCH3Nj7VO
zDK4ul2tyPvmTY5Hrd2mR0UnmeVYqVWZXGXM8/Awqj2/7OkM8nykyndqhKuY
F+CJ9KOj6e10sgInlN37dCnMQJOydPfgqJfNPHC3tuV43FEyp4Ts2q73nhLW
lfDUrYkzt02jroLfvXe/n2vJvAoRrTWm4XYR9QTkW+vE0fFkPgH17t+8ZjV7
Ul+IsGVzu27pyfxC5E4Y2nteznoiLMYXB6qkrCdC+sX89sIk1tUwlkWHO5QI
qatRzfcUul7yoJ6Ej6Hfd0QbyHwSvngszf5ZOpV6Mtbl/74yYTGZT0a4r2j6
2pWsaxCqCxQm5rhT18AcKY7dGErmUpDX2FBqKGQ9Bd5evZ8OVbhRT4Xuwv7E
7FZn6qnYoDp40+WUC/U0nHlUs02QT+bT0PXDNSNzsxN17biuRcKiYelENdvX
jZ3ndXg6w9JX6eZIXY/M8EPJzwoE1PWwNHePFHlOoW6g93OwGQbk1csVTac5
mjfAP1krE52faHPHuHnOiKITL26IPtjTvnFs541YnBlzaYt4VGHbNyItbldb
r4TmuXT0y6x/VJKfto502AWEWQX1wzbz43pHOgT2Fwv7Dg/YzGUgtvzrL2XH
IO1njJ3nmc2Kv/4BOB8=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0HlIk3Ecx/FpeU5y6janea4WTU1M0w7LfeacebvNQvKotIYLCyGlKLWe
REoJy9IOLSgPUimPYYfUghlFF2URKhQihUqI1aLCI9IKv78/9IGHh9fz5sPv
4fHPLdDprXk8XuK/+/9z/rIoxNvvPDDmS0Ev8HgVLy1tHbM9JsqdbMKXMAvQ
GZjTf7DPnyyEpGd/nWM7swQC5XW9poLZC+0Ww85hLbMfJiv3paulzFL41Fgl
d/3wI6/EgOl3gamXeRW69A+vNlQzr0ZGVflF+R7mAOxrNUruyZmD0JO+pjH3
sy85GL6BkhPjh5lD8F3U61+nYl6LWZd8V8VLH3IonHdqoo6nModhg6QuW+nJ
vA5ZFUNCN5M3ORxNDpe68kqYIxD23uPrIxnzehR98wyTm73IG3D79cfeN6XM
G1F27PUF6c/l5E14F1JzyXCVORI5tdvuxq1g3oy+gLQPjg89yVvwqWJqUODM
HAWl3ekhQbcHWQGZlyGzUcsM7DpgvHa5XzJvDrCxnjPJysk8JQyN7rJTItaV
KKztKHUwu1OPxt7RwtuVkWQuGvVtvapf7WLqKkS06bITismcCkeqhf3xVqzH
IDdF3jrrJKIeg5RCQfHFJ0Lqarjy3U1jJjfqajQ0PxOdHXClHgv1lpGSvhky
F4upxFH7E0msb0WN3lKT1cL6VgR6iz3ycliPQ9lIbtXILRfqcSg0dlZqjpJ5
8ciya6xfrmY9HkfkT6f1qQLqCfgxe39HmR2ZS8AcTzu3u8iZeiLSM0I7DkrJ
XCKanzcd4hcto54Elwmh2CImc0mw9guY4d90op6MKwP86RvhfOrJMHYU1AZn
2lNPwclz+ZuKfe2op2A66HxJy34H6qkIq/oyqTSTuVRUly/pGc52pK5ZaGjw
ytMyXisgcxpYut/+KRXR3qxZeB5Pu9DQIqh7qW3EGfY9i2zW4tvGmdnoYFva
6xbtdWh5MCh+4WVDex39vznF/F5H+zHFX5/TIgM=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdznlIk3Ecx/Ens5yZZYemqanz6LJI5zGdax9tTm1zmw+VmRnZacgKXMNS
hEftsBRDOykDE+nAvJEiCa2s7FInGRUlRlRWFmZmJk0q/P7+6YGH8Xrez+e3
x2vLHn67Fcdx6r/3v9+Ja1DhtLapuT5dDHqAkexil72hzCIYI4Zc3tkwO+B0
7cec5Kde5LkQVz7v76lgdkYqX6l9lMHsBl++SfcjmNkTFqnSkj+FWQxbmWRS
8WtPsg++JCqG919n9sPdp5EFdZnMi3Dga/7puhDmJch+wj0OnsbsD157Uura
7EFejuy2pXJnHfMKDHme+q2bzxyA6oepfUdfLCAHYnhG1zpRCrMEy+TL17S8
dycHwfezw2DSRuZgDDgl1VtZ3MghWOmqNUtqmENRVi286YhmliLjfGCFf68r
OQz5Iy3vk/KYw5GctSO4fyGzDO1SU6FD13xyBGTmFqNyB7McjTbd98ZEzCtx
xulLe+olF7ICD3pUhluhzEDntljN1ivOExYA73jTOiGFzEXCrdzwYc3NedQj
YajcYnNoN5mLgiXDK94kZT0KUnhbYciJ+io8Wry7zu03WViFi5bLHn5lrCth
O37CVhbCuhIl7rsGzr51pB4N89XO7z4GshCN3vXFh4t+zqWuQt79xJQxDVlQ
4auh7YdkZA71GGwqUH2Ut5GFGPxKNVpym1iPxYP9yohtfqzH4kJlu+OxZ7Op
x2FU/U6UqyELcehWlFrPez2L+moohX2WgMNk4T9zaoR1NJff63OgrkZh4PZX
5zaTOQ2qIsRpi+7MpK6BafGJ46UNrMdjdn/r7SqenR8PY33tEX0WO1+Li96r
XwbdZudr4RW584hpnO11MFbJFA0VrOtQ63r1Wrea/o/TI3FDYE2GmAw9ntkX
pP3S2tP7elh5Lhmzq5o+4VY9zNd7hp+P2tE+AYONZkuOoy3tE9B+V56594aI
9v/11gQcKkkPz/awoT0P/0brqSHFZPBIKApYan3QmvY8fT9Hex52k6uzPh3/
pvgDJ0Mvtg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzWtI01EYx/Fh0/JSecl5TWtdNF3qtKZtU3/ObbaZulkRmlBIC03JMEtz
SX8Dg9Iuli9EXZpGQpK07ibdL5ChprCMXihlRYqVhpmO7vicF+3A4fA5Xx6e
pdkF6QY7Ho+n+Xv/vbNnPF6w+XqnOU8I+kCF5qzKS8I8D6E9baMr+MyuaA0p
nH+tfyl5EUy1U8XKWmZvHBhsiXtvYPbHuk96t+xI5iW4rTyeo53HLITcubE3
4MUS8nIclH5urjQxr8Rb7bZw5U7mYPRvdi8xRTOHoDfNpfLKVCBZhABudeAb
M3MYdhuzjIMpzBHICDpsfe/CLIbs3r1BWX0AORKXn3rdd1nGHIWoxlXbA82L
yWugulQb0ixnXovHqQHcyzF/sgRVjZnVHQ3M0bDM6X7uxmeOgST38ev6837k
dfDM6DsgljJLYXh4U9d4w5csg9+TjQV8LbMcM5nXEsbsmWPhZfwSU77PhxyH
T70T+bERzPHw2JP8YHeZNxkwtxfUhG0lc8CApazrmJz1BFz3+TA0OeRFPQHz
JxtGkhvIPAUeVp10axGyrkAMltnhq4B6Ihx/1TjKJGQuERJfx5aJJk/qSuTu
+FYSHkTmlLBOJzYXixZRVyEr++2w6KMHdRXqUsutw06sq2HiLKUL21lXQ6yu
69B2u1NP+t9cEsY8MgxTR1lfD1eR2K/ntxv19SjKab2bJmBdA/WdkV3oY10D
g+mCnbGJzNMiRf30ybtYV+paJG76IbFXL6CejPPPWvY7F5G5ZLTJhTnBjxZS
34B8xak7C86xbmNeCvpuWSZfTTtTT0G37/hojasT9VSMX+37WebpSD0VrZ0D
gi5/e+ppKD1kfZB30YG6jXk6HKnOkxoD584aOoiu8h0kJ8icTb+vQ/XwXqPi
O5mnx4zo9MHWfNoPG3N6m3k99FXiUH4Fn+bTsSUzsr1Q+Dt+dj4dznMulY6e
mYj/A/QXH+8=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzH8s1HEcx/EvSWR+xHXO70PkMHJ+Xn7cy/l5HOekmakmsoTIz1Z/5DJi
oglZtvqv9eMq0fKrlmbLj/6wVtbYihaythQjdV1FP7w///TZ3vvs8Xnu/XHO
Lk7N1ec4TvZn/t6bZ1nK39/zqLvABfSAtOlnpUERzEbQraeqrpowW2A+1/vB
tRlnMg95/SLlSDezACUlr9fyzzPbY7druDjiALMQHTze9WYPZhfE5HdJzBaF
5F1wLNMrsxpkdkfvu3AnRTuzBwLupaWH5jF74tjNbkGfiNkbrvOXyke0TmQf
ZBQpS3pymPeguqt9qXDFkewHo9XPXnWNzGIMVQrsqz2Y/ZHeljzcMOlADsCK
dFq1kMccCM9btVzTD3tyEPSdVgMT1MzBcBYuBjT6MYegKUcq+DVrR5bA3zrb
/U4l817YFMj1mxdtyaGI8hw/ON3JHIbZeu2khTlzOC7zP40dvmFDjkDNEd9R
3TlmKdY1DsGZNszA1NG24s67gk2rgZqNN6mGxmQuEv6tDt1nOqypR2LAPuP4
mBuZk+HKcze5YQOfugzrpd/cjId3Uo9C2NrQTOMhsjoKIflScZM169G4cKJC
k7mPRz0a2xwN0p6+tKIeA5lPVltpFlkdg8y4J9t1XZbUY/F4tO6ttoqsjkV+
ubZXL531OGgT3xudVbAehzCxos4sawf1eJgWWn6sL7GgHg87wdyHiy1kTo4K
UVtry33W5VjwdfEvErH9BJwSjX7PVbKegA1OtZFVbk49Eb3Lzb6242bUE2Fa
Kg6dqDalrkDBWP/gxIAJdQVe9L/6MqUlc0kYGw4/Wf7QiHoSTlfphgo0htST
sSTRrct8yOpkOMUnSfiardSVUDX6eRnUGlBXQhFc1Tfns4V6CvSFnjqT2z+l
/4j/rE6h/79KfwPqVwFG
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd03lI02Ecx/Ef3lmapZutvF2RZmvOdJrHPs5rm06dWaFBSmRQEpYnFOKi
Q0yXRRkhWChapmjYMCk7FhUpLvAgOywhyw7CVExNqezY9/kjf/Dw8Pq9n+/v
jwd+nrtzUrLMOI5T/ll/d9MzIeNva+9sy/YCvUCaz7zXz3BmGzQs7KvJsmZ2
gIBLU5b2eZKd0G9vdW17C/MqFIqrj9cfZnZBfcHd1l1yZg84RPmNFtsxe6Ev
dPrktmEPshC6TvUTiybmdWjaky4syGNeD0ebj40jCmZfpFW31PL8mP2gcDXq
+J/dySLwRlxmuGJmMYQ9lWP3XJn98WnyldmmdjeyBIKH4lD7COYA1D4TSM2/
uZI34033qPp5GXMgYlou+taFMQfhSsDWc3q9C1kKaf6h1zkS5mCMT12vF0+t
IYfAoDd+yalh3gKlNXd5FsyhKOIyZMNTq8lhKFyWMbRXyxyOyrM7Vx7rFZAj
YBCX7T14ilmG/q4Xkub1zIAx4n1sytNVJmuB3qnvht4MMhcJz+7J0mAf1iNR
VhVn6d7rTF2OygGHcqOKrJXD2JFqKxSwHoXOijNXj7TxqUdBeKjv5RyPzEWj
cehhVc0gj3o03BXqEH4TmYtB8H6ZROfMegw0Ff4bLE44UY/F1wOPpgNmHKnH
wu1W3s3SHjIXB7ko83xuJutxiNdPqjRS1hUo1zWsbTFnXQGfRG+nmAMrqCux
wGkWMvOXU1diY7go9f4HO+oqzNjdOvojcBl1FbxVFwbTG22px2NC3/ezmLeE
+iJzCeh6HF6Uf9uGegL89BZWQaetqauRIC3peCcyp65GXnOo7EYdRz0Rpv/V
jHoiii8N3OG/pfNcEg6XzD/IbrKinkT3a0k9+f95LLI2GWYevvNLm3/I/tmQ
jPGQ+V9y0YzJnAY70iWtuV4LJmORtZpF8xoE6MZmIw1zNJ/y//fA/EH2G+Jj
JiY=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1H9MzHEcx/HvTl3XD5zqopR+XfqhTkVUpFe/dF2d7q5utkMN+RnzIz+S
XyeRGRtpMqJlODTWndAJnfxYMT/y4zCbn1NjKJmoIaz3Z+Z723e3x/f5eX2/
2/1xvrOWaOYIOI6b+uf6+93/6Yx3055tMOb7gW7A/p5xw5skZhFM36+uyhMx
i2GIdNpYZfUlu6JmoF168UnmYVgVvr/kSBGzJypanmfYpDD7IDn2Q627L7Mf
GjzKD5o7fMhStJlts4R1zCPxsi/Yer6YOQguovbjr+XMIegINB2VujOH4pCt
IW/+ZW+yDE9miFqU85jDEa10KJr5dgQ5AsIbWm9JKXMkNPeFxvVRzGOgPRd4
Lea+F3ksKmShhrdy5iiIWi6OfChgHofpF/yLK897ksfjypfqAi8pczQGi+vL
Cj4NJ8fglc32itsm5liMSPhVp+j2IE+Arj0j1Wsz80TskIRLl8qY4xBWqjxx
4pY7eRJy5lZvEuqZ45G72Fi179EwMhBiPeUs2kfWA8VvGpdvymQ9AX0LZ29r
bh9KPQGWQeMvNTmTuUREw1+ALjfqiai8G5Am3E7mkiBd1vq0R8J6ElaYm3yu
KiTUk7Eg72vh6ECyPhmlRdcKv1e6Uk9B7uOzOQ8KyfoU6LqejQv46UJ9MtqD
u9ZEqMj6yZiW2ujQW+tMPRXi0Ijhd/qGUE/Fwznd9kFmMidH8BR/15TFrMsR
NiTo8/5WMfU0rAwu31NmIut55hRwcmlavfTdYOoKTNVFnl7uR+bSERYny25s
G0g9HQKfkF7HGifqGdhVMqD+xQwH6hkwnl5SLpsmoq6EbtRu+Z1CR+pK3Pbo
fF8upvPcFPgr9lp1x9meZy4TnWdaf66X2FPPRPP1uNUrLrDnqzBm58dvCRbq
UCG/uf7yAzN7nwo9oWXrDIuoW1Q4YHXsORZFnVP/36H+//l6Nbbuzo9d621H
ezX6/18EtNfA0PDY7aanLe01UO+IGGWzxYb2vG7R8PZZKKiZEG86zNE+i37f
H/H9e54tPHPZ6Ijp/ZUo6+43suE44FTR+z2fac+zhZ1vo72Wt9fy9jxb/p3/
DdY0Yck=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd03ss1WEcx/Ffx0gxl1xyOYeDGDKTa+h0Pg6O+3W1uTsss1YSmUspl5Uy
Q3JbagpN00kt69RGbVKi/qH4w9BKKjJSaxSJauf7tNWzPXv2et7P9vz1tUjN
jE7jcRzn93v/OZXrs9hwv6LnziFL0AU2mUQ2yn2Y1fH6eurykhqzDu7q6+eL
hizI+rB6L483v8ZshO6kU1UJucx85AkMBvL9mYWYTw30qtBjtoTCc1wSPSEk
74DTiXD+KzmzDTj3g2P8DGZbGL9tqE7aw2yP8oLM+QOazA4QSVJO1ynMyY5A
WPlovITZCckjUnHRghl5F1Km3nyLa2B2Rs1Qi4OIx+yCkK6yCn6FgOyK7w9K
53TcmN0QxwtuLenhk90xcPvei3R7Zg9E68rWcptNybuRLqjMHk5k9kRvpcJJ
d9yE7IWR4ZVm70Zmb1SXJD+OKmTegyrvOruSrcwiXL3oaXM2wZi8Fyc76j3i
RcxiVBf4tNs+MyID5kH9ZrXN5GLg5mhMwUQM6z7oaTW7XGjCug+mJ6OzStRY
lyBnvG1Qd2w7dQkWyrbcOHOOzPliUXwkaEqVdV80dTzyXeo0pO6HJqFC+8OM
AXU/CKcN6ttiyZw/bglGLO1n9Kn7w/VlZZ51N5mT4lPGkyWXZT3qUtRb/4zl
rpC5AEgcZXXZMtYDsFNgaJyeso16IGRZiT+ez+pSD0S7VfC4a58O9SB8Xe+O
Ld1MLg6CqdH0bM0F1oNRYDewkhbBejAqnNMmL8lYD0GY9Gn/OxHrIdDU68s7
+lGbeig2uKgNWQ65OPTf/7gwHJacf6jVokU9DL771txVpWQuHIP9orycbnXq
4Vj0XF2XOKpRj0CoR9H9aUcV6hFQzjePeiSOyb3FXa2c0ogET2i/qiFfEyvf
R0JDpfP4XO0XpXv/Mxf1178AKTcM6A==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1A1MzHEcx/Gf85Se1ElyhboZSspJD+j0uetBLnRXXTZURJQsD9NUHvqb
SWNmJMvjTWaZFBqOGJenNdFqaTJWubaizZQsKXnafX+z+/+323+ve/++v///
bv/9vVK3xqVJGGOr/37+nS1HT5ir/vb9m5ly0BfI1eVuu7CQ2wZlOTG18RJu
J7T7sfO59V5kF9w9WPBIbeB2Q3bGG5vOVG4PJPctzv+k4vaE8HZ4q0zCLUeD
pv3w0yZP8nTISivqjhm4Z+BWX8ABrzzuWWi0X7u3XMPtgyDF8KN7Um5fnH5d
qa0zTiP7QVI1LmFfMvdcaG4MsZb2qWQFbMbIZEcPc89D5pGSwvGjuQOwPiqz
t6ZtCnk+Xkhrsq4UcAei6LnROHssdxDMHSFe8ioPcjA8nHXTi9O4Q9B4t/lb
y4A7eQFSUpB06hL3QiR1bzF/kXIvQtpjo9ZwR0YORdO1rpf2GdxKLKpmFcpf
k8mLUeL6uXZdGXcYWt1Htdn2u5GBhr4BU0MKWQBeJF//+jCYdxVMLuVj13VP
oq7CRfk5j21VZKZGgcI49Y2WdzV6HfVPvP15D8fl9x+amgdcqYcjfXfrxlIJ
7xEoFpSXnNW8R2BzcJajoCezSEhKDEPRwkTqkRhy3BRWE0lmUXA6tH1DW6kL
9Sjsbs51YGvJbAnmdLkLtqN4X4I1qeYO348TqEcjuTDqk/IpWYiG1G7Sg84H
vC/Fza8yQ14670thPhsU+K5ISl0DRbX7THM2WdAgQsgZVhxyph6DTn95QJY3
WYgR9WWY4zyr90yjE/VlyL6vDQ0ZcKS+HBJPn0G7cnvqy3FF9eTZ88kO1Fdg
1ezj0fU5dtRXoN/h3v6fgbSexdLzxXssap8pd+2stqGuxStZT/dJJ1uLocUP
3xN7yraMo/Va6/UmkZkOefmDNZlXx9C8Dl8WDP5S+5EFHSzvEwnN62A3siKv
u2gEzcdh5ap5lTvkv8Ms83E032+xIOqmOAQc/fxdZfphMYu3Xo946y6IbIq3
3o8lWN8fEuj//knzCdb7m0RmetH19fT7emleZJPILNH6/pAomk+k/Ttp/r//
ACBMiJ4=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdyw8s1GEcx/Era0noCufP+XdH/0xXOnW5q+5zjnA4V62dobVUo8ipu0NW
+qkNlVibNZvZCvlb1lnK2EqHpsJkOUtbqWNFZjQaiVXzPGt5tmfPXt/38+XF
aw6dWsliseR/7t936UxKOUcaWwxJfJABFpOTUj8IqS0RV/Wwz2qeR8xGW/eD
sYIOanvIay167+dSO0HtP26qiaZ2Rc4bfVu2N7UnAjlicfWUJzEfZvcwfVMH
tTd86gUujrnUm6C7ejox4yj1FqieDsce51P7oEm9rSz+qwexL67PaBN1V6gF
SN4uKHKZcSfegRtTP+eLM6n9kDLBKf1mTb0TJwaH27OfuxELMZQ/6AsFtT88
ewdE7966Eu9CCPKmWCnUu9E19Oi91JZahIX0oSxtP5d4D/JN6smRm9QBUJ/Z
WOnNpRajx+4Oe87sQixBYfaxtoMXqfciyVXjXyyh3oeZ1WOVCQZn4v1YrHUT
xTpTSxFsafFr2uBEDPSHG2M+8YgZQFtUf2lNqyPpMmTqvDR1MmJGhhf5xvS0
ZxzSAxHHOsxR3SJmAtEtj3YemXUgXY4s38ySlEliRo7xgp4GaR/tQegyly/A
h+4HwSM0MoBTS3swNCvmc2oldD8Y7NxzJz+W2ZN+AIbZglEnEDPLzArBxNn2
GeEPO9JDEN/JbxYyxKxQfNn6/YKfivZQvH7cWHM+lfYwtKtaS5jmDaSHwa+Z
u/mznpilwD2xsLOqlHYF7lZ0OhSaaA//30w4gpiMBb/c9aRHgCdLuKZfZJMe
Aal6Ok7JpT0SlV6KQX8j7ZHLuhLaOom0oYx2JaztjOmpo+tIj0LFy/K0tTpb
0qNgsslLnFPakK6Cl+K2KabaaslQoaplgPPKdRX5r0KE6PITs8Biya3//BuN
8hG6
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0nlIFGEYx/FJLU3zqnUz3fLE+1rNI6/9ebvuem1mYBJZGZFEYlimWZtK
EaUiSdcqUZKmlSUpKitoRpCGppkpIYUHeZRo4ZWUVvi8f6wDw/CZ7/O+Lwxj
cfiULFWN4zjJv/v/c+2aFfH3NSjr0ixBL+Dm9TC5PIhZCyE+82XLPGYD5Nhs
tLk7bEHmQeGSUThaxWyM2kLpmYkTzAL4zVg2FYcym8Ouq2EkcROzJfTuHFU4
D5qTreEzr5tfVMlsgxHX2BMPMpjtUDrmHePry+yA3x8a/d9qMDtB95CjSFZp
RnZBYktPT7KY2Q2eLW8WViZ2kYU4fX+x/3kNszsUA/mfrRyYPXCtSPmuoX0n
eTfOGd/r2+LE7InAT8emUiYEZC/Udw+/7Mll9kb7Yz3bV1JmHwiOjAb2KU3J
eyAwaNYsDWf2xbD4wsL0qgnZD+N157Pmspn9obY53+eqHXMACgJTnPWrd5AD
IfSvMF+OZhaB1zXUsTJpTAZ02sxFrjlkOdAvaU8atmA9CJneNqkNqdupByEs
dfTF9dt86sG4NGnROiImy4NRnd7Ve7zIiHoIvnyrytxfRpaHIPeAyL8+gfVQ
FGh0dGrd4lEPRVF6Zs2BvWQuDGeNFFxx5TbqYRi3/3lOGEfmwmFvrTm2GMF6
ONb+363UI2DgJDTtXjWkHgHtiqWD4a/JXCRC5Vl/hFdYj4R9jBUv7CTrYihN
SsubZwyoi/FtyLbANY/MRUE3w92vL0+XehSemT5pfC/Rpy6B4Xcef5avR10C
5wCXhNavNM9J0dvUPze4pENdCquomx+THmlTj0aSY0lkdxbr0arzXAwUH3V+
VXqyHoMq5QC/U7CReix9DzXqsdBRf5o9dWMD9TjVjjhcLknzzTHTpPk41f3a
1pmLx/4k99oMy1XR2vr4defFQ+p9sXHURZ3Wx687X6ZqyFTn5TJ4FE4vBrX9
Wtu/jc3/EP0F3/8wPQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdy38s1HEcx/Fvkt+X8/t3zk0lzJyLTkf3uvNbkR+LpTRZNhWj226V1XyX
kZ+1xmaYJlsq1s8lldX8GDHDGsNWGRbZtUaZioxq9/78wWd777PH5/n+uKXn
JGTocRwX+W/+37qzqLA91tr+9LwY9ADp8of9IjmzEXy+9Af3GDILUfSyhUsc
cSNbw/hPhbS0itkeAef6hZfSmZ0xPJhQssOdWQSB5c4ufkNEFiPRv3BlbpTZ
HbZJcrm6kXkP5soGxmpzmD0w+2jeXyVh9gRe6VWsf3Mle0ORdrmtuprZB7vP
1QectWL2RZZBCSd7s4ssgSbyasZyNrMfCprFd4ccmaUwO5Gf2/nAhbwfVXm3
SlT7mP0R0Fh55/mAMzkAn43r90hvMB+ArYzfXhTILIPvrKCJH3EiB8JwdK/m
jJr5IFK1WTMLlsxyyM02tFcaHMlB0LxxzXssYw7G26OWk+3NDuRDGONrf7YW
MytwW/m+NDaaGZjq+2qRbUfmgXfKJyYzXfbUlfAVrazL75F5JVJvetdM5rCu
Qod1i+FprR11FX63mSY795G5EBwXyxomklgPwbRXRpepN+uhSBkWnK2ZtqUe
CvEzo9qeGDIXhqDlzsnyUzbUwzBucH3c5Yc19XC46X+aWloj8+G4aFPH3Wyy
oh6BgRetD9S5ZD4CJwukKRPzltQjUT1dvm3yO5mPhOS1094ZDetREHpLnIY2
LKhHIXCovaF3Skg9Gi1B4kyPbnPq0Sjzy/hYl8b6YWja44Jkv3dSP4wxQXHm
SqyA+hEI1H7ykWtk/gjuK7t7eh1Yj0HPknliygUz6jEYdFzUVglNqMdCWvHt
l7LDmHos8vJXO883G1A/utn8FnNxiC+XeOkX6uuMLebjNu93bOlcPJJT/B6p
xRsK3f946Ik8V01b1nTmt/SOeJhuf5inrfyuM5eAhcDVdZXPnOIv9nYgGQ==

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdz39MzHEcx/HvQlcROXWV4uqkck6pE0W513X9uFLpfoROlF8zC4n8GMVX
CKlMwjTMj41kbn5ULKy7fhhak7WSZvMzTFjWTT9shfX+/KHv9t13j+9zr+8P
z9UZ2nVWHMdp/p7/rsNHt0KUVPngdroEdAOyARfvjBBmG9h37TDV2DE7IK8/
4GJnmyfZESVvjoRrLjG7IO5VrcqSxeyOoy/U/E4VswcEb+oqdK7MEjyf52fz
sNOD7IXTs26W9ZmZvZGkcvh5PI/ZF0G11h2qJcxS3EJItq+YWYZ7qXvlrT/F
ZD/oV7gnn9nGPBtmc1qLwJ05AAXhu195Vk0lB+LHoTOlvIRZDmte39V+agp5
Doo0b79dkzIH4aPteW95kTt5Ln6PmTn5rJh5Hho31efWG93IwfDhJRuWRDCH
wOrKqh2FryeT50NV9bU46BjzAiSFdqz16nAlh8I2M96h08wchqzugEdCJfNC
CKRVBaIKF7ICzT19puZUZuBla86z/FAyDxT1pqk3tTpTV8LJOWhmUy6ZV4K3
ke/t+SiiHo7SZ8Lqi0Yn6uH4sF/ou2UNmVOheousV2fFugrGKS0S6WdH6hFI
fVm5smUXmY9Ayur3H2RfJlGPRHJqrdqwjMxHIuWA3ND+RUg9Csuja+wGbpH5
KPzKNzqvsEykHo1P/hL55hlkPhqKpZaUBDfW1QgNjDs8Po11NZ62eVl+j2M9
Bl2vfQ765zpQj4Gncv3R7YNkLhbbZ5ScLL7Deuz/7+MWIUVwudQtkj1/Ea5O
i+2YU8v2cUguvXnJScb2cbDfKOw6ksl6PGKuG8unn5tAPR5DnGYoLYvMJWDi
N0dRt2g89QTMCvPT13yyp74Y02JPtxnK7KgvRr+sOPvaRlvqiZDdHW09t0gw
bCRCXvi9V2mizo+wKRFWHtKBsTfG0V6DMmVdw2NXeh80aOiZoDNkUuc1eHG/
1dLeN5b2mhF7LcSDTY3B3fR90OK2MaPEb7kN7bV40hC2M6uabNJi974Bc3q5
Ne11/xs65J1In79HTP/D65BzoeWh6N0o2o8wp8dSQ6Bxq2RIMbzX0//2K/4A
99lEbw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzg0s1HEcx/H/ULgooqu4OpSIXOXhQuRzdzich3tg1SnryVSXLGU9jrO1
WjZ6UlvLmsqsEENCzUOtlZR0WttZa9qUIkqxkqSH3fe3pv/233+v//v/+e3v
uiVDnWrGcZzqz/33abqGw/hJdXeqdW6gFxgrscx+I2G2Qp68+APPjtkOh3Ol
/ItGV7IjFr0tTxaWMM+Dzs5+0GMDswDidn2mgxuzC158T5gMGHAhu2Hbrgvv
i28yL8bpzVaKB/nMS6CTlY+9UjJ7IsanJyRNwOyFlNeXG/b2CsnLYFZjnZid
wizCPkHQkScDC8krMGOpsO1nBvNKHBpd0Z3szOwLs5LuZJ5hAdkP/U4D1qKD
zP7QHjsiL7VlDoCCZygqahaQxVAG2rxLC2Zehf3NfrLOFmdyIHanGVMs0pmD
4JNRmt0hYg5G3OqC2roxJ/JqdHppXvKamEOQlGNcu1XCHIqiq07r2h/MJ6/B
JYkhLz6GOQzyiH07zCfmkQFLwba3oSfJemDWaKVmyJd1CbLGPaoetc+lLsE9
xTUvwwYyJ0WjYH16mzvrUhjPbdJWPONTl+FKrk1NiYqsl2HxHkP39zmsh+PH
nuKcuO1zqIfD1eLV65EJR+oR8O/K3+9+m6yPQKu3dKgik/VIaL+8FLv/dKAe
CeldzUJvIetyPN287vNIN+ty9J/PlNwII3NRuK9svai/PZt6FPJrrb2be8hc
NCKb+nfCYE89GiG+scdnbiJzMXCVpJ3ImrSjHoOspYVnz9SQOQWqnCvquxSz
qCtgP+jIH+bPpB4Ln1BRYkufLfVYyBInxNMiWY9DfEVBRGod6/+Zi596nj5+
6nlcAm4Nn1ru1MF6AqKvV5a5F9H/cMqpeyiha2toft44g75X4qttY+5EgI3J
rUoYGl6MGseocyqcOmre0LORR3sVhJMdjwOHyXoVmh4Gf/TsZXsVtN6no54e
YHs1/PKHvklarWmvRnVlRqEo2Yr2ahzKGb+rK5tOezWW1VpMFxdY0l4DYVRc
EL9sGu01iF2VU98rMqe9Bmu1vpWZbr/CTHsNPgWNT0pFX03mEsl9JuOffwPH
HEey
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HsslXEcx/EHK+kguZzckoOiszq5H5LOxzXX45wjd1mrGTFLyR/d1tGs
QsKssbQxE6vISuY2Ra1a1B9aO5qscrQWuUVjJKqd7+8Pnu3Zs9fz/n5/e/56
BMdOKlK1OY6L+Hf/f2quGQk/prXrYaYd6AWedTXVF3kyb4I8TyyM0WE2QkbD
hQqDfgHZFNVDvZ01pczmmPDNX6iLZbbGWMWpyXQHZlvkKbLDRuZtyXYYMcwS
2vcxO6B37qjDrjLmXWhuy/X+lsLsBK2RoaRQS2YhdjTkLKuf7yDvwYCUX9mY
xCzCW58C19lJG7Iz7m6ptLl9idkFfP031YNT28mukI9XL54tZHbDmeA+flM0
szumv+o6t/Zakz2Qohiv609h9kRcbM6t9FUrshj17grV7xJmL8jahAJxALM3
9Et8M7vVluT9SOY9ia8yYfbBstZsWnuiBfkAVu5tFydZMPtCqGoy3lRpTj6I
R1ytssiIWYITqp0iXtk2MpBg51XzIZasBGS/Hr9uD2TdD3NLL18MD/Gp+yFv
TPBUHUrm/NG/9L3wyh0z6v4YzTN2yj5O5gIQePuLcUcB6wFo6Brk91mzHohP
8TeuXl8wpR4IrwyJa/E21oOQdlP7jIEb60EIb/kZJhebUA+GusrT42O5MfVg
TJgkpM4XkLlDcOm0clTnsr7OXAjep87rOXVspR6CZN3aW1ZBZC4Uu6X2pkFZ
rIdC4JdWkLtiRD0MP4Yd8/ddJivD0GzV2PYufAv1cOz1FR1++s2AejiqVLzF
eg8e9Qh0v9o/5TSqTz0CKoNr6YtSmuciEXB42XNDsCH1SJTm67R/PrKZunSt
ldJ150dhpmXgz0UzPepRcCueXPDrIXMylI3mnPdf0NUYMkx7L634izbSvAw5
930kj2o5jXtktL8o0ezL13bIwdNpOjderkX7csQluj44bbeqme9ZZ04Bzf9G
m/YVa7tSsfa8HgUixJfaRkU69P3R0LYVLvHuL0v+AlOoNDU=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0HlIk3Ecx/EnLa80t3LzmNfMDmxaTdPM2T4zNY/lnFqWGR0kGRVpM+xu
kJHVJO0+/qhMwjIMu+wUsQwhLVd0kxoSRRlOo7LLVez7/ccHfjy8njcf+PHI
l63NyLMTBEH77/x/2x6LWjr36q26VUGgD6guduvKVbGdsFcbkTrPgS3CclVN
kqJVTvaAondbq+QQ2wu7A/1+fVnK9sX7J/p3yUp2IEKLNIYT1kByEOZfTar8
1M4OhrLBMcBcxR4Pp32+ulsG9kSUaG5PitGwQ+AaO97d3ZWtwCnZQK24KoAc
hmv+pvfNyewpyJzb2X3PjT0Vz7cUlLjU+pOVqC0b+1KnYIcjxnzRnG/1I0cg
c7lqj6yFPQ090gV1dn98yZE4N5DdPukGOwobciq29cazp+NSlNjvtQM7GqZn
2ZZ3ZTLyDGSVNrUWqdgxWHP/0Yyd9mwVNijvdhXn+pBjsTFzj6LF6k2eiReW
U2fuGNhqVJ+/WeoiZwO656FLnAe8bDYC0Te2d0rCyIIG+ZWe43ZJuGtQUHq8
r7DQk3ocWuuzXIK9ycY45DxyW3nsrZT6LCxr6OofvEI2zkJCXvdl01Hu8ZjQ
oT+9fgT3eCyOjHV40yahngCTZ/v+b4VkYwK2LlSrrmRxT0SaQbT5cLMH9URs
frrRTVhCFmbD0X941r3HY6jPRnDxsAORvWQhCXX9Pic35XNPwpG3pmEdfaOp
JyN3R3jOiw9kYzIKnn1pWirnngKRYqrsoVVMPQWh4ol9x80i6qkw1MSoL1WS
jamQa1bsXj/IXQuZV/eHiv3ctTg7NuVVRBP3OUhfHfLgqzf3OUN6Gq5Zyif7
tI2inoaLsgv1j1Pdqesg7vGQWqTcdbALDPk5ssaVejoCBtseTLe42IwhNqaj
vMT+eucicmM6Wppji4tuOtFejzYfy8eDIt7rYbls/rNV4kx7PbRR2+u7w+xp
r6f/IdA+A9k5ytp1QVa1bT/Exgy672+bGzPQG/1zMC7sm81CJsLLPn/XNP5Q
/wViczCD
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJw1y38s1HEcx/EvFkbmR+fy2/lRoboldX7k3Mudw51fm6tMMmqLPyxG1oYt
3zSrjaVJtWV0pSg3FhvFrU5tmmldYqLEapak5udSLlk1789n++yzx/v5efuc
LEg9Zc5xXNS/+//dPIsy4ZEufUeeL2iAwtcXngbKmK1RmfmjYk7I7AD3gerc
vg8+ZAGExruNgnZmF1xvzpz0Lmb2QPoJyaqrglkERUJkfo0tsy8WxPFrziMi
sj9cioe65xuZd6Lodp6uPJ85AO8XAj7fCGEOwrfeSos0K+Y9mFgfWrv42Jss
RrdX9Zd+FfM+XPHKWh6b9yIHQ9NTu1F/jnk/fu5asjzrwRwCxx23jr4Z9iQf
QIlmSq3MYT6IiQyhVe2wB1kC7Z+wqrBK5lCsjgyklGy4k8Mg7TLaNTczh8PE
G7URacwR8J+3+RXc40Y+hK8GVf3NNVdyJMYXtU1PzjBLcb+195KND3MUxnPr
CtrbXMgyVEwbis6nMAOd3B2+yoHMA87JOaEzj7ZTj4Ym2Jp7pyHz0QiDnzmW
hdTlkDxIzVSXkXk5siRSy8lXztQV+H7Z2CkbJvMKiKadrzWlsx6D3TWxRvlL
AfUYlI2W2HHZZE6JBn601L59G3UlbnyqNptacqIei4w4g43pIZmPxb2IkIGW
BtbjkF2Y+Xtw1pF6HPRudQ09Cw7U4xFu1GtffCTz8XCa7XuuS6X/nAqByX4C
5Wm2r4Knbv3t8VDW1VjZ6E2vsGL7auyVig8bZuyoJ6B/xV5zrHAr9QR0tBfU
iTOsqSeitNz0LK/VknoiWvRjwkGPLdSTYGvRVjp31Yx6EsxFQSZb3bpssydT
X9o0n4yFcNOGXLxKPYU8I/sLZRQACw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1AlMk3ccxvF3LcWjUvGqaFGOjQWVkXEjgn2obaUILT1okcM0myzLxkQG
GeBC9mImCCIRZW7DrBlsEw0Tw4QhsqPMIVMCCRhwIZvMkIwrxiYUGQzHXPj9
l9AmTfPp9336f9M09Xst15At4Dgu+/nzv9flh0MuTW3rbHnbH/QGivXFx20x
zKsx/ttiZJk7syem78oEjiE/8mYMStyvmq8xe2Hmcsafk6eYvRH6hrWk2sjs
C7cZhaAokNkf49Gf6r+d9SW/BB/Pyp6QH5hfRmnUwlsjFcyB+CzZJpk1Me8G
ipwxu7yYg/DRUMdIa7cPORhTk977Tx5lfhXp9sEMlZA5BPWvPylta91JDn1+
/mxjO5jDkFFRaI8TM4fDeDS2UvbLDnIEpnPPhwcomSMR2XChvrXXmxyFGM1A
D+/LHA3nzvu1I1Uy8l5cF/VpJkTMMSi1qts/PradvA97+ifWaLXMsThVYYvz
9mOOw+SPmkt189vI+yH9XX6r4CKzHCNS0dV+HTNwMufxmcYHXsvmga7ehlhr
GZmLxyddNmG5mfV4iHLFYe90b6WuwBP5Mc0jEZlXoE43P2pdklI/AGWAJGh0
A5k/gN6Ficqyr7ZQVyJ2tuth1REyr8TDtOryqrnN1FUIHzxbGHCLzKvwyriM
X+vGuhpHTqsn437eRF2NpKgP2seCydxBhKjrOhL7NlI/CGte1t/3JjZQT8DT
yuatWU4yn4D8lusVKSdY1yBzVUOdTMW6Bkq+6FlIOeuJkFucmVoZ64nY0bQ4
nBnF+iHIvMYmas57Uj+E/KZ98m8ayFwS9vZ3fn7nD9aTULyrZz5bx3qyyz4Z
Hjkbp0/nsa7Fuk0/FR6fXE9dixzFue8l9RLqOnx594v3xAVkXgdLemjzu/50
PZeyco8UNMX6vxl4m32ei+0u13N6LHH6JWsB2+uh/bpald3mQXs9fP7p6412
rKW9Hk89OkoXI9bR3gCB7+4FcRMZBlyJv919ZxvbG9A9s96YnkfdbsDAzSHn
r3+JaW9c2WFceR5vxLkPhTdHs9j5RryYeHE4/QqZM8FxY+BZyZY1tDe57E0r
789ucrn/VLQ059YGZ6ymfSrS99Qk9BfR/fEutqe67M24NCyevxxBHWb0bXdM
1Xqy880IuuHmHlm9ivZm1Izlv6+YI3MWhJ19PBdvZ/dvQWPnA+k9bxHtLSix
3f9O+khIewuW/98FtE+j3yNH+zT6fSzJl/cutqfR97G4bO4wxMJrJ6YuvED7
w/9f/y+IeJ9o
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0H8s1HEcx/Gvs3LX6QediyI/ii6ESKIfXo47P/LjuKNfTFmtH6oTakbq
1Gqafokt1FhhFmlrafrdtdZGP5h+kmqVatQqdqF0nWr3/vzhvtt33z2+z8/7
++PjnKZO2MDjOC7p3/n/ajz6g8WJl69fTHcB3YA2wJannsfMR4HC2iPS4Eye
giaRKGdpO7MITV29uSHFzLZ4neHzVryR2R5lZmmzCoOYnSCz/ChbI2R2webx
td1tz5zIsyHxSy1LLmd2Q+zPqpSS9cwSvDr+iQvyZnbHl0mHm6oNjmRPuFmN
tp+/yeyFK2WDlfEKZh8k1d7dlNo9kzwfH5tLQh+fZPaFRjd0Q+rL7AfD09Lj
XVUO5AXomZuqehLG7A950gOH0q/25IU4wOfrG9XMAcgrkBR/dmVehDpeRmt+
1QxyIHZr97i22TIHQZ35oX1bzXTyYvAE+xcdkjAvwbhtmu2GPjvyUrxS7hK/
LmdeBjNRoc7wx5YcDBnfXP/jIjOQcsyz/I2arAHkpwQDdR6shyD7ZXWLVec0
6iGwmebv8WgfmZPiYbNqwmw71qU43fytyEHAeigqzt0JHWwUUw/FrWvW/P5S
MheGgj7n2+8jWQ+DIXPYVXDPhroMm9cP5njPIWtkOJqxs36NUkRdjrZ1Kwd0
XVOpy3EpI0u3OofMhaPoSK1roznr4Zgvr7ga9ciaegTO1LTYHHtO1kTg5LvD
Zm8GWI/E2h0pv+/3WlGPhPxm3xZ0kLkoODTonycHsB6FZIuzFTNkrC+HznBt
1T6LKdSXo2GJyybJ3cnUo6HY6v5g0I71aNS0Vu8SZk+iHoOhiVcL9P6W1GPQ
ceXZj86fQuqx8DvydThEK6AeC8eImEBx/TjqccjdO3InvX489Tj0X+r4k29D
6zkFfnme2F23lQwFDhanB+U5WtB6BYp7svKkw2StAkLzxtzPJWY0H4/ogL3N
PV7mNG9iTTzyK5/cEL8ja03MJeB74IhB6kXfhwST+QTUXX8hvm9P/6M16Zxy
7POgNJlXgufkPiJs0Acb55W0X7+M5lRYsdr3QqbLqNFQjX2fRjX2eVoVfe8n
mk8cazAPGa1JpP0aCP4LE/VpRw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HtMk1cYx/Ej1MsAHYKrCEVo1QXBEAQpYNX+uAiVApa20MuGioaEDCPe
NXjhTbzEeGHLJGxTphFDqlYYuCy4oabDy4yEeEWW6T/gNkMTFTfnKhJR0+fE
nJekIZ9+z3Pe9rxvql5Zba4IYIxVvXu9/+//G9IrS37qbK/SgN6AovOXm4M6
7gmod3zvLhnPHYqJdeWWr+6pyVPw9fbTr282ckcgLnq5akk1twqrun42NOu4
Y9HtbY1+HsatwaOEp0e1A7HkmZj9223bQRf3p+hPazmr28odh6IV6kbHIu54
BOVc8x0I4p6D0S+dvjXXYsiJ2L97We/GNdxJmKX4bjQhinsu1I9dcddvTCcn
o0l/ZcReyZ2CeSGpe3u80eR5qLSyW8ZN3KlYF9jmm/mHiqxFeEVFsSWFOw0n
2vqSau5FkdORbWqa4TjCnYEy7+qBZ2Hc8/Hviqv6i82RZB0ub23YeVzJvQDf
Kp9cL3dNIy/Enzn7ap+Wcy/CkbzkzRE2bj1Wnm/L6HoQQQZ6jV3OfjVZAk5o
GlVrz02lnonmh/13e31K6pnQnjaX5W8jsyz8NbbhZcc3n1DPQvoX+uRDU8ks
GyMnFerHt6ZQz0ZS2S7XxVNklgODt+/SpAO85yBi+YU7dbm8L0b7P5HHayrD
qS/GYMP6zBY9meVi4Kg29cHhMOq5iHaP3P88bTL1PJhWx3f/Ny2Ueh5Cwru2
rB38mLoB7gWayrjLZMmAH6LOdtwx8r4EAbHxw8HuEOoys3zcPt/74ndfMPV8
xLzp6U4fCqJuRE/kkLc+lCwZMSO/4b7zFO8FSDn05P9Mz0fUCzDnR8U4bd14
6oWoqR3+terMOOqFKD44N0GxR0G9CAVptR2PEgOpF2HHsbsXlP1ktlTWl4r7
MZO4HiZxf8mEGENhhvLMWL89JgQHttR4D4+h+WJxPWSWiuH/PQmgeZmZWTTM
2ODW6c81MZo30/We6/3zZjqvV34zC2zO5Nb1mlG/YRG7ZJHNW/AsY/hNVuJL
mreKHVa6vyM0bxX391hl1y8R10NmqURc75F1Vip+X5SK15NKZedXCldnn/KG
iu4Hs8nun032vNjE9R4b2lur6xM/m0DzdvH5g118/iS7uL/HLn4+5hDPEw7x
PCWZPTIzp2ye+2+al9nzYf1bBHnHVA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd02tIk1Ecx/GlLp0mzUvT6axpXqboNF1eU3/bnPfLMMUmgWL5QkQkLZTC
tey6dBLNIGSEZaFkWs5CSjOLirRXZVJmSNGSkBITRI1FF/Y/hB54ePg8X/6H
87w4/hW1hZV2HA5H+ff597atxVRB8b3hgeoA0Ad08KVddQpmJ9jz9d6nvZj5
6OMt1hV99Sd7Ym5hoj9lkNkbVmnjuEbPLAJ3/87CTg2zGCUD46UnQpgDcEkb
5Tq+KiYHYipYFqV7zByMO5UPTVcvMEtgclsJdC5nDkOOMbJYGcQcDiczWqZn
d5Cl6ElUVF/QMkfhbJdRphYz78K8yKgY/bCdHA3fXo2ea2COgbLIGstNZ5bB
X7LFw2HVj7wb9/da7vqcYo7FZE9H7XNn5jioxLefdr0QkeNxubVmbeYMcwJ4
PsKy5lDmRPxq+Kitn/IlJ+FG7/m2pUjmPTAdelMk++JDToYd72S8XsKcgtEC
99nhm0JyKoRb2xM7E5iBd25LwqrD3jbrAG6tS0zNMy/qcoQPOmyObSPr5DAN
LbT48VhXQNO0oGpdFlBXYOilF9daTuYoUTzN1Z87to26ElUHlxsjQ8icNByY
GRnp/uZJPQ2y14aGoAdkjgqZ2a3vzRrWVdCUPcks3edBPR2hgY6WlQyyLh2r
1x21Frk79Qw0WyoMlltu1DMQ4Sb50fGKTz0TR0LbjRfNZF0mIpKlRY/mXKln
wbUuOmmymazLQozh+4p8jEc9G93DbwUTIi71bNiJw3669FpTbT1nvXU5sN0v
O5rPXW9dLpquTI4IPtlTz9vQ8+Bi33d03riJej7qe5NSzdc41PM39IIN8wXI
jTs+9FnK9levn4caJaXR/XUBv+m8avrfNZvH/vsPp24EZA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0wtMjXEYx/FXSrajhDoV3VcS3S+616/7/XS66Lg0s6bVyuhuSjphtqba
krTG0ArrVMh2WgolhQhNI6S5NGkSsVNx6ISd52+rd3v37vN+n+fdu3d7TZP2
xSarcBwX9vf8d1UeU778LdKOlnQz0A0UbdKYlXkwL4dFp3GqD49ZCzXS86p5
b03J2qgcnvwikzDrIe/ghLuikNkAx5xHB9+ImE0wPDfXds2S2QzxE817w6ZN
yObI3JoyUi1lXo9iV3naqxLmDbDZtudFq4h5IxqPTFs0ODJbQ60iqjtu3phs
i+p7lWesDzHbY77fePKcM7MDXG7cn1GMG5EdkXO1zmN3GrMTap/puy6VGZKd
kVpzUt2xntkF21Y4PelfybwZGuMus2rZBmRXjPVaP9Z6t47shtLnoqkPZczu
qIoa9DL+tZbsgZtX+i48qmX2xEVDtfLBBGYvXN0V6doaxOyNUh178wxbZh94
tnPN3gp9si8KW4aqBCnMgE3xy508mZ7SYsDsOBKGqsicHypGswv8Z3Wp+8Gt
t6jgbDuZ88c3zS13rOxY90ciF8cXVvCpB+Buaff+vE6yOGBRD0SJfECiP6dD
PRClugMnZjLJXBA2fx4baVJnPQiCbK2CU73a1INRnpEr2RFHFgcjMen9qPX4
GuohUDdSje95ShaH4GGrtCErg/VQfLT6fsBByHooeoRdp8Xtq6mHwVckSxSs
W0V9kblwTLy2PGp3WIt6OHI7hF5uPzSpR0DQVB6ULNWgHoH6vro8Xg7rkbDx
to3vHGM9Eun3224NXudRj6Lvr049Cl/d5Qp/22XUBbjUMcR/YKBGXQDe0ub8
T5VLqEdD+T+rUI9eOM8JF3YIkV8kv50uoeeLhQvnuxbNczEQbXe8nGU276vc
j6H3m1FaHAMVk41yXuNvpbti4FQ2OevX9VNpLnbRfuz//T/x7DFn
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HlI02Ecx/FfaeXRMdPWdDM3O8gDK6eu1NxnNu9tTkPEKyUa0WGSHZSl
rchspHZJdDgDsyyyQsaa5pElRQoGKRVluA47MMuCWlqUFfs+f9QDXx5ez5vv
v49kdUGqbiLHcTF/5u9tP5/k/DRzS+MGX9AD3icapAORzE6IfDl1znZHZh42
Pc0Pze6RkD1glQXIt1cxC3Cl+p25Yh2zCPnPGxzbIpjFmJ/VvqTZk9kXPSP7
bLIXYvI8DF9UCgvPMS/AGrcJntmFzAvRkHOCvzWU2R8uyrujh1yYA9Gz0634
bbUPOQgP+1QZdSrmxZDUptWJBuaQl8B4wadt1TrmYBS1J5WfkzFL0R5tnGy6
6U0OQf+TIk6tYQ6F/6VSruKHiByGk+X5Y/0HmGUoEHSV1DozL8UtUXtN3w0h
eRlWJAyIPiYwh0MdUWkyj3qRIxA2PnR9sII5EvmppyxiAfNyOG9W817f8iRH
4ZH+tM18kFmOZFFeU4g3M9B/du1mw2WB3XpA0vW5bKkfmVPA7PnG+sU6m7oC
TiWHhd25ZC4an6endfotYv2PLakr50bxqa/AV0tps+3pLOr/mVNia/NtcWci
60potvB2nbjjQT0GgtzW3spYsj4GpzV7v79yYT0Wg+v9wn+WuVOPxflw6b16
40zqcRh2z9DZDGR9HEbrppQMKliP/9f6eLg6XCkaOu5GPQFbGq8ZtEVkfQLk
6V+yNULWEyFRrDVs+8WjnogWrypj8wiZS8KhYN2zM3msJ+GasMHSmzSDugqa
hsoYnXkadRWO7Hdosua4UFcjM+Bo/P0drtTVaLxaUBWU5URdg0+mBz+LZzlT
12As8Nju+o1kLhmBJsfJYZVTqCejvuUxv1s0iboWKtkey6sgB7uhRXFNXyv/
BVmvhf0/mGh3hxbpmcFXC33H5fb9FIws+/4rOshmN1IgrfjwTdExJv8NFPEZ
/g==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1H9MzHEcx/Fv96OQckfqCNWNMlrTJemXe3VdV/px3Q+/lvyc+COh/Jhh
6ytaE1IMRYz8aCtlmcSi3WbVsIhUzHHsLNy068cWWSvs3p8/6rN9993j+9z7
/f3v47d1tyFDwHGc9t/z/+04fUrP1fWNdZly0AfcDHexDC5lnoQ3/ZnlzUJm
Cao4bc6nTj+yByois2ouVDLL0Pn2p/3KfuY56Cy/La/UMPuiFyKffk9mObw/
Xhrbbvclz8eH9oCrpQ+Z/fHJZvdXFjIvRHr3gVWhRuZF0Mmbeh4EMgeiq/nb
OyeOOQhlb2t1Lxp8yEvQmmlsF6iZg1E1EOBlt8wjKyAZym3I3cMcgrS1pTvS
pzIvhVuOIrIjby45FL8f59kkoczLsHumSNb1ZA45DLzAbJumZl6OkrEPxc+G
vcnhaNw2JGqsZo7AGTdbme8a5khktbyKyBcyR+HIVPFqQ9NscjQkYmvhtPXM
KyDO4neN/phFVuKa2GRoPcQMOEUsfvRqMpkHaqXPe35UyKjH4MRIR1ddLJmP
wfONdweawlhXoVyqdH497EVdBavZkH3UmfVY5MzK6u7NZT0Wt8xfOjp/e1JX
Y2vT54HR+2RejfN89A2pivU4qBe4B1qkrMfh2PGn5oummdQ1OOXVfnYom8xr
ICnI3map8KAej03d9Rs7DpL5eOw4L9jnFsJ6Al5uWdc/+H4G9QQE9hXVNpwh
cysRrLn0KLFtOvWViFIkF7hvllJPhLfM+r3krIR6IlI0Lc1fo8lcEk4qMsyX
N7OehNhVI8vEGnfqydipKn7ifp3MJ0N7pyguo96Negp8RtteLO+bQj0FxceF
Dy0byJwWJda9h1W/XKhroT8VvFiUL6KeOt58KvZWRyrvVXDUdfBJSAn3rBI7
DN34zuuQHJbbYA0SOmyaYE4/fj/0cBXWHLKdc6J5/fh9Jv2EeQMc942A5g0T
/m/A2jRFbY58TOmYn2DOCIHvoj+u1SMOw4iQ072/YkzDDvNG2MP/jKqCepR/
ARisPlM=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0WlIFHEcxvGpbFPX1EzLo3Iz7TCPTF3La5/1PnMvLY+iy5AMRNSulZrK
IsM0jwo0CBLUMg1XpLQXbqnVEkaSmkREZZQZ4YqKrNla4e//IgeG4TPfeWZe
zPqDOYrMxRzHJf09/13nD71kVXLb45ZsF9ANaMZVk9FSZlNI3a+MKcyYrfH6
6afu32/Xk22hq+m7bVfHbI9WjVxTkMe8BhUZ2dCEMosgmBSrWk2ZXXCj/3Cb
26CI7AqD/f0iVDNvhN8D1e6gLObN4B8pL/OhzO44MGXMsbBl9sDXe56Tm587
k72gcrs51y5j3obj5zVNJVPryD4oS68pLitg3o7gtAOz+hXMvjj07kv3uSdr
yX5oau/yFh9l9sebhuqcZ+bMYvwYqt0jrVhDDsDulLzqrDkn8g4ENacOeV5n
3omMIy/2juxjDkSh9ozbK3vmINzNtjM23HUkB6Orr2NaYMEcAqHdQH5nlQM5
FLGW4Y8U5cwS+ATXimYSmQHjvbUB6Q5kHrDtfa8zfrenLoVQK5J4q8m8FMPv
FbnnBKyHwfKke8qHytXUw/C45Fq9umUV9XC4aEyrexLJfDjGds4Yw7xYj4Cu
v+higc6OegQibn20aS8mc5EQV3ZnxdqwHok9MWXWnzttqUfB85sTb25C5qOg
Hji1nNvPejQ89KXND8tWUo9GQsDZh8NeZC4GguRFrfouG+oxyLjgmzY0QuZi
4dPhtOlzAeux0A26Tv6yWEE9Dqe2PDdkJllTj8OEsSP1/DIyF49d90sjM9uW
U4/HHCef259vRT0B4apZ8dIoS+oJ6JmwUqblWlBPRM2g0FDnL6SeiJbmnCqv
dFPqu2DwqCisP2ZGfYG5pAX7JPQ66kerrM2py7Ah7sZgWgMZMjgbe1/u0JN5
GV70hJzI76DvaWXwaDURiEuX0V6OS+XZgWpnMuT0fwW0l6N8OE8dNk1dK4e8
xGeryUUT2isgXNJ0erRyEe0XmFfA9+rPaanWIJnfK5DXGCTR3OFor/zfUGKx
yH1G2Dg7/zyvXLBX0vvHJX8AqYFEKg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HtMjXEcx/HHWaU6y6Xr6X5HSqpT6JDzOVGHLqdTyaGLMG1tRSihFs/c
ipi1WlFa0Q1t5bKEhtMsY81EnCHWHyh/1CrpuhJ2vr8/Os/222+v5/39Pn8+
znszYlIEHMcp/53/t/YZllrGtbTdTXMBvYB4rMffaT2zIe5NPs/eZ8i8BNKo
xp1hr53J5pBY9PjHlzOL0Nmr8ohIYbaDdLlN1IyY2QlBs/m/TcecyC7QL7Vq
XvyO2Q15hxyrVVeYl6G59Uhg3y7mFbjx7Wpd1yrmlUiOk536yjF74WN+UfW2
c45kb/QaPzk2uoDZB95d8uALhQ5kX5hYZex5b8Hshyut8qRItT1ZDD03g47m
BGZ/hG7vtC8ZtCMHoCVjNGmggnkNbBpiy8ZSmddCtT2zPHXOlrwO3T7FZanX
mAPhPldYNGXNLMH1oeTFP4tsyOuRfMBUMuHFvAGKHbm+IxprchDK5X7ZIhXz
Rgy+GUkP8mGWYqHdvh9Bl0VkoEZQVeouIfNAZklTnpHairoMPXO2bQlZZF6G
0ekXHV8+W1IPhldLTdxMG5kPxq2qvjueSaxvwjPHClGlEeubcPrM8y9lagvq
m/FhRfqe+lYyvxlxn/TPF+SyHoLHB70mYgWshyDnuGe/xt2ceiiUq6tdskRk
XsecHG5HFxSvGTKjLofDo8wH+Z1kbgv6PX4d91WyvgV1EvHLhkpT6ltRnDJc
nNhA5nXMhWHAbGfK+HnWwzBZu/DEdxnr4fPNh+Nponu7g5D1CIxfaLJK+r2U
egSMayZ3hXaQuUjYN85oEteyHokNfhH5i3azroCHwtU8ZD/rCtS+qskWZi2i
HjXffBQ0JgWpUwoT6kpUaIRT9QFCraGEa1ipJv6mMc0rkfby4dPuR9TVSgzf
fzubZ2FE+9HIOTndnnbbgPajMRQ4/SfYm8xHz59X63QuBtr/jYD2YxB90ddT
76we7etYHQOB08ppYeOMVLsfC1W8X9NhlzmtETv/e7yO1Trz3DaILw1OyNRT
0r8v70H5
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxV0nlIFGEYx/FZ3bzTvLU186pcNfG+svytZ7oeu5tW2IEJm5GRbWCHKY1F
GKibpf1hSaZEWVkiXpF4pJl0/JFSEhaWSVlRuWqRmtnBPm/gwDB85vs+78vA
OGfmKJQ6HMdJ/97/ntpLE2GT1tLemO0CeoECy/POZyTMBpgWtx99ZMG8DOPp
R3StnzmTrRDy9Hqn3wVmOwwNHzTfn8XsgDXDPqHKQGYn8NKxHdW/nMguqOqq
9EzvZ3bDfO7oO3Ex82qUCDpELjJmd+z6vpBjYsXsgV44nlz1eCXZC4lzzaNT
cmZvONemXXEYcST7QNBXVJxzjtkXeVmvWl86Mfsh40S+OL5hBdkfx6pcalMz
mAOQfbih4PqIAzkQfdNmm9JVzEFw09fZPCNiDsaLLW8e9o+LyCGwGb5xQlrI
HAqhZ52vwevl5DAoe9pk1a3M6/D7revdcxXM4aicMsm2s2BeD+7ZflX2B3vy
BtgemwgpzGWOQJePYOVNM2ZAUDa48LHQTmseyAuv2ZDmRuYkOHD6wqRKZUtd
gidtqUZu9mQuEpmdb6YWmm2oR0JPYzZ0dg+Zi4L+Pdcqr8/W1KNQqb60t+cQ
mYvGT9Xl40l7WI/GyFZ1UckPK+oxaInYPZO/j8zHYO24iDcSsh6LnadjP66/
b0k9FtKmyQR5MJmLQ2mToWfnawvqcShXasq3XyNzGxHul1hkmmFOfSOuuiYM
B/Qsox6Po+L+WWUKmY9Hg6i+bVBqRj0ByfXqGGXLUuoJ0HHymDO+aUJdiotD
xrNXA42pS+n/YD0RHf1hX93HyHwiolLng5bEmlJPwr7Isg7TGjKfhDpJb98D
ezqPS8bAneffXsyw/ZOhaRr4VWBtSD0F/qVffki6yXwKvJqEekFqfeqyxR0y
NN7OqfDeZkDrZZCX+HoKTwm17pZhInRuIdJbj+blMNa9lfepXEDzcvr++Qjt
POuTWnfL6bxZrTnF4vVQLO68gs57T/OK//v9AfTrMXw=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1GtMU2ccBvAjYASKoQjWDlEKglxtQRhQcJ6HInfRtoBRiRVJvK1uipVk
8TKPbirxjoIf0KCCQYGIskmiAbQaiNBsRsSA4mXZUDe8pRi0gEzU9P9+4Jzk
5OR3nvd53//5cvwKNupXO3Act+zL/fVpv6y8LLexqcHoD3qBqPePohUJzM6o
MDzTvnBilmKWlL9y9J4f2QshHZaxiWeY5egZ2FGs+oHZB+eKWuoNGmYFjk9u
j5zvyeyPmZbWwdPPFeQAHHm+sq+0iXk2gqwO8l6BORguhsiOwGTmUPiY+Hse
7szh8FYNygeafclKNIfWlPPJzBH43etfw5NPM8mRCJjspnxYzTwXlXzr6NJ1
zFHwK1T3F9pmkKNR5tx+9v4G5m9hHmjdlCdnjoH8YvbP4RYfcixkcYLjXjVz
HCJexSn+s00nqxGzvrX35DnmeEjUa56+jmVOQHtc0QHpXW/yPFyf9yi2y8j8
Hf4pHuqRujPPx4MTD/iQtm/IPEYnvFt7dTkz4Br2ywoXq9xuAfCtOrQ7KIvM
JWKX6YrqjwyWJ6JoJOhSh2Ua5Rqs7w5USkrIggaN5dWJh91ZnoStO0duGmtl
lCehouhCb4Q/mVuAgMLOh8NTWb4AnzbbAl3aplKeDKuu60hZDFlIRtWzPQVJ
a7woT0HD0OF+OchCCoZXmf7f1ehJeSo0yvzSzflkIRV5qTdcRy5PoTwNLbf3
/TW0kyyk4cP++mkrBj0oT0dKS//36CQL6XCtGjKktLE8A3M8ggfKO6WUZ6Cj
O2DwoxvLM5FeU18beMqd8ky8ehz0q2o3recWonpWRm/0LdZfKOpn4YXKP+rH
EHZ+FsY43Vj+FtqPW/Rl/vi3wX1ulC+Csf3q9a5rEsoXY3lYSdqdn8jCYlGu
xXD4se3nN7jYDS32lhjjt/lOovVanG/qkVl8Jtpt1kLieHHry+MTqK+D/X/h
QH0dTHUJ/G+VHPV12FHR1Sz725H6ovWcHr5pWWpZLe0Pveh8PXQHI8Oc9jhR
X4+SPtM2jY1yLht/eltflkpdqZ89fl4he/z+ZpG5HDTUbyxV5jlTP0fUzxHN
nzN+Hi53vCGyILI5V/T9SxB16I0t0TzM2/tL4KAIHZHUjfKfAVDAZls=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HtMjXEcx/GnOl2Ukkq66nSQdJpU5HTR+RzV6XrqZKKli7WiKTvKWIo6
oxsrdPmDGLGFQuuidSxLSRObFsdCU6FoixL+0IW57Hx/Mz3bb7+9nvf3+8/z
x+OYrNiaqs1xnPTP+XtrnmmxZUxre1O6APQCHkm1a8QiZgPU9bfxRrWYTVEo
TeGHPHYkW+D8MO/E9XPMVrAunCtavZfZDiUZecndImY+onbtelerxyyAwlcq
1+/mk1dheOKzk/gksxMGJ7lvilhmZ5wxHuqb4jO7oE1o8rr5kQPZFd4Sw+GX
sczrcLneydZzaAV5PVKmngl0s5jdUbWiZvf7V/ZkD4x4iRWNO5g94WZb3Zul
x7wBPDfz44uf2pE3YuyqVk9MLrMX5KLF43t8mDfhp/C0Q/28LVmEJaaqigNT
zN5o9Ff5qOKZfZDmv62Dr8Xsi4w35VFO923Ifng+IOvPCmfejNm425JPusz+
OFSsnWygsiaLsT8xr2tVBDOgfminM6hPVgIev1Ks79VYUZegqUFRtW4nWSmB
rsLIc1/PcupbYJLtsn24kqzcgqLydJ9cB9YDEJQ62lJ61pJ6AOoufWgUJpC5
QAiaDap7ZKwHYj6zJl+Wtox6ELpWFjhzArIyCA32aoHLuAV1KYpzHmTPXCAr
pUh60ZqozmY9GEcvqu9avjWnHozxtV8Pu8vJXAgqU6cr46+ZUQ/BsbHksrGb
S6mH/m9lKOL1r1TbBrEeBvsbPwbiN7EeBuMMs48lmabUw3GwXe4nmjGhHo44
YXlIX7YR9QicKdBRjSQYUo9Aeq+qQ32HddmCLsOsa8WRaxmLqEfCs2zyu6ST
rIzEE5vpiSpTmueiFuxHwbWFp+d1Sp+6HNGl7kJeIU9jyJGTP9eVXq9H83L6
fjoady6Y56Kh+V9o0340jHRu5UxUfhFr9v/5N+ijEac=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HtMTnEcx/GjnpQyXdQJpZ6KR8oekqLI8+ki9ZR6LiWS/qiZVki5NLmd
XJPLamQjNQxNkdUmSc0pIo9botk0d2LRKtdpCHu+v1nnbGdnr/M+399+v3+O
W0qmbpkJx3Hxf+9/T+PVp+LjL16pznAHvcDqgprivEBmC9xpMIvcYcFsg8YV
bS5nnriR7fGmRJ5WXME8Bml51rsVuczOeJit7udCmOXwrl3YZjma2R0XZOK6
R11y8gS8tW3UZl5nVqDMwVFx4ACzJ/yahz8JXcjshRHJXrpjcuYp4GQ5nU33
XMlKiKnJWYvWM0/DfbV9qbMdsw/c3pV7thpcyNMRdvzV++1JzL7IK2zcVGvN
PANf79yq3nB4PNkP7XtjCiZPYvaHIW2cR/M2Z/JMdGsmtrcpmGfhV86LLWs6
nMgBeMBnPavdwxyI1YtbOkQF82zUbRfKxnePI8+BIe/pDasg5iBcrY7aZ2kY
S56Ln8M+La9LZFaho0ew+PB6DBloCOhFdhFZAKxEuWrqRtaD0emRfvKmgvVg
KI/U9C796Ug9BIPpqfmt78hCCFaeSjHftYr1ULjkp5/94sB6KJI4Pa8p4qmH
YdIz7Yl1ZmQhDEcNdvXHqxyoz4P/x66n58zJwjyYu8jirrePph6O04G+reWl
dtTD4RN+9LL6Lpmbj1cl/n6dB1mfD5spPk73Bm2pR0CV8CUpxoksRKByjnua
5zVr6pGw/WjP9/GjqEei5bO1PjFrJHW1pKthIvcasKpkPQquv+/entVnST0K
hTtM654vJXPRaG0Jyllbb0E9Gq4RCwL4CjPqC6Dd5+Mt2ymjLjEXg81lDxv4
l6bUY5C7daApo2I49Vj0Bgz8DlGShViUX3nMG5zZ+hrsKsoI3OhqbjQ0qK7K
PKRcwvYjsaiRrK+VzGuHdkGL6JlbL71W0v5EreR8uqH7gU4yr5PM62D8P5nQ
vB4JidOrst0HVcZ5PZ23y2hBYlEPK9Pzud0H+43m4uC7v+d7sPiD5uPo+280
L7Eo+Z6LH9rx338AnrNdUA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdy3ss1WEcx/GTS0qU+yXEOWKncHLLLZzPOW7HwXFYcijaXGYmSfFHqP2W
/mnrogybaRG55DZaJZeKRjbTSjKa1DBdh3ShWlbN9/kjz/bs2ev7fr78pKzo
VDUejyf9e/+9a2dRbBJzu6stQwAaIHa+Iv+GiHkTol2e39P/wifroTHOzq6j
l9kIb8U9IcoiZjO8UKjqDaKYLWH12KS8lc9sg/nmU8WmyzZkAWpt5S/d+5h3
YtaTS3cpY7bHZMtCtlYSsxDt/mMjoULm3QgpEzkKJ6zJjijMkGcH5jGLMNGh
OTBtzewMjZan48mdO8gukA1f3zijYnaFVF3pxRu1IrthVqVTMShldkdUTmnl
6B1L8l5UPXpl5uDL7IHxvCE9rWkLsicSimpOH0xh9kKjT9vkzLvtZG9IMu18
0mOYfXD/wNis/S9z8j50DEzw3Y8x+6JgoGVKe8mM7IeA+YaSzBRmf9Q1jo4v
fzIli/Expf3MUhMz0N9bPf4wicwBOg2eUd3XTKhLoF+k4ElcyZwEWRdOmhsW
G1OXwvdb79T5RDInhXNCYV1PvRH1AKSVqOXoupG5AGSotKKSywypByJpUNDp
xpG5QLwvPS5pFrMehLjDfbJ4FetBqKoZNL40ZkA9GDPdvzkHTzIXDO3qlcTg
fn3qIUi9WquWX0nmQjC3R+B2dBfrMvAlaedyV/WoyyCO/XpIYcF6KJz0hZ/L
n7EeCu8nXZUDb8g8OVotmu6OhG2jLkdul9LXa2Ur9bD/zYXByU+0/8GcLvVw
FJ1V73idoE09HNarw0Nei2ReBH44XimoO7KZegRs5aVj8fWsK9btK9btR8Lx
lsZGj4ta1CNxeeZEvnSZzFPCWhbhbXJTc81QYot6c96H4g30X4kF75+rUtF3
8R9KGgbn
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd03ss1WEcx/Gf43ZGlnI7IWKpdHRyieOSzue4HPd7silqNTEajVVD9Kut
MrYU1ZTR3OpgGEuM/tAfp1oWlSVZpiE2Mwkzl5Vq5/v84fy2Z7+9fu/n2e95
/njszmbFpgg4jov4N/6/1c+CzDy+s7c9wx70AaaTTU1fpcxCHFfOpil0mY2x
sZTePNVvRzbFlQdiq8xKZhEalHOdTheYrdG4ontP4M+8B/vd86sNLJjt4Vkg
Ta2Y2UPei+K4hETVS+Z9iJsv1XIoYj6ADyXzibrnmA9C3mDiPO7E7IQRyxN2
imlbsgSnVtfy8ZjZGRMeqm3DAcwucI3Ml/Z8tCG7YuSzYaLoJrMbkkpblKNO
zEcwEM+b9KztJrsjY3m1cbmW2QPlr7u6xPrMUnRmLSXNVVqTPVHWJpKn2TF7
ISG1/kVzvxXZG1XP726eqWT2QUNz8Z3Fw8xHoSNWugjHLcm++DXk0zfxiPkY
unsFgzn6zDIkn6+5rsfvIgOLVRJFtxGZBxo6VHVFQyLqcphcDHuVWUDm5ejg
avkSY9b98EPQdblswoK6HxZWUgq/15A5f/BCt8KlKXPq/qi+pBx1tidzATjt
4as39t6MegAEFU82gnkyF4iOtls2om+m1AMRmWOc/1BF5hQQlyoG/PpZV+DQ
jBVvoMN6EPJyxTPDDqwHYSrd0fv3bRPqwaipf2tWOryTejACfaeuDq6TuRCo
7wPrIfgkK9OxGNtBPRQGdavJChWZD0Wu45u1lChj6mFISHRtzbbfTj0MRtmu
PkM3jKiHbzUfjsphw7Wn7obUI9DemnVfclJIXcNcJGyDI7zMm3SpR+JZ7xfz
d9ZkLgqG2i15s+Va1KMQLr3WNSnRph6NnGYfWUctpzaiNeZH0/kFavdpdC6G
zrcpU6+P0Viv0fs0zMVu3Q9it+6H13Cfxnwubuv/EIefXut//CTTsr8fkTNx

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1H9MzHEcx/HvkroclerqdLhKiAqVTj+ce91VV91d191VuxVJOEOMGUth
XY2NpSJlreaP/shQl9EipM6qYXamM8koMw2zRRTSyI/d+/MH3+277x7f5/f1
+fMbuHmPweTEcVzan/vv03GNyXyz2m9dKQgCvcC+vWpbn4SZh67jRv/zc5g9
4Zv/6uXOgUCyD+652VUD55mFyEz6uSXAxDwfTcl92qFo5gC8Tat13ejKHASt
Mau4cjiAHIznZeOtEY3MS3Ama/2q7duYQ3BU3hkaL2dejpmH44zNfsxhuO/z
2DvvqZi8AiYtb33oMeZV+NjRqz4gZo5ASV3z3omHC8mR4PO4bTcymaNQcO3Y
cO3EAvJqFHRPzk4wM0fDNFK6W+DBLIH0iGYo/cR88ho8ax+3HOIzxyC+NXsw
vFZEjoUgu78oIo45DtKrinenLP7keFSV5vXoDzOvRWnRaGGgiFmKmtHiarF9
HnkdRhKPl3zIZ5bBLWVt9KiCGeCXrymydAkdNgN1mmADr4LMyeFhzWhyErIu
R69PYVHAZz/qCnxyz+pZtpJsVmCwdlNOyyNf6gmQXDTkqg6RzQnoFjcIz7mx
nog8idRlyCagngjJmd7tqV5kLgk7tn45uHIp60kIrVI+VDzwoa5E2V1j7pSG
bFbCi+/X+abTm3oyyiuaFltmkM3JyBg4cdK+gPUU9OqsDeabXtRTEKGsv6Gy
kblU2GXVzn5Dc6mnomxkc8VIC5lT/ddVkBknNmhFrKsRPjfkU32/J3U1yiNN
Lxo2kTkNdilO3XZvdKeuQXa9pVEQxnoaRMLX705Xs30aLotartvVHtS1SMj8
IZmpZHsttC2VSab2OdTTsUh1diDnwizq6bD5j72v8SRzOvR3PJkYnOQ7DB3E
07YHMWPsex3G2vp/HhG4OWzVIazN2UVS6Up7/b8detzrkxbuv8mjvR4fY6em
FStcaK9HccnUnYJLZM4Ax//GifYGRFWMfpNbv8scewOMOZGt+4J+OWz9r3MZ
dP5Xh8H8RvYbfko0+w==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd02tIU3EYx/HjrbJhqZnadLqZ1kpZ3s0s99u83+bmpaArWlFhYN5K1HRp
oYLBLAuytMxikalliZapkwos6oVdLAp7oSUiiQrLy5Ks2PN/kQcOh8/5/p9z
gyNKz0w6bMpxXPzf/d/RuE1J7VPbux5kuIFOoP/S9uqdW5hXIN/V57TBICJb
Qz9m8ivvCbMdCkpDJePlzI647tEkiIhldsbGgML6lQ7MQsTlzHx2GhKS3RDQ
oI7e08nsjm7PU196y5k3IE1jtXAghVmM+wguErsyb8ZC5imLomlXshemWlWC
/ovMEgij5po7Apm9UX1Fc9Kuw4XsA//9aQe9Y5h9oS9S9OrbBGQ/5JX6i/SH
mP2ReLl99LUdcwBCnRQDfi3O5EDk764ungxnDoLQ0P566LsTeSs8n1Za1B1h
DsbkT4V+Rsi8DW2iMvHnOj45BClnFgfey5m34+GFYonm6jryDuRO+XTbyphD
8Uz76FpQrSNZitX6luQJX2ZgtS75tqkjWQ1sfVFSWP/EgboMJypqp7OyyGoZ
XJ5/nXubwLocyqQZp9ZSe+py2GgUnMyXzIVhuOF9qjWf9TBUC479qB1ZSz0c
gXzLxukbZHU4+tafFXNurEfAe1+ZtvuOHfUI6DzlE/eyyVwk9qYPj3iNraEe
iU3uy7/NRpG5KCQPVla9FbAehZ69Hn0uPFvq0eCZNReMX7ShHo0ufk3d40lr
6jEIS1kItIhcRT0Gt142nuTlkrlYDFpVHJ1XWFGPRUZ/Z8+7xzzqcRjo/KD/
NEdWx2He60KR9rgl9Xi84U+N11ivpB4Pv/MTszId6wmYDDb8lkuWUU9AQYmh
L+MumVNA2/XR/pWzBXUFVFU+nubnzKknLplPhPH/NqWu/H89lNi127cl221R
alyvRHxQSceIxMzYdUrkNIVI225yNK/6fz1U9D1N6H5Luk5F7zdvNJdEzzdK
80usXmJdEl1/muaTqc9I/wAF+zrq
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1A1MzHEcx/G/K5JDXc5Fpbo0o5KUosR97lRylequu+s0bCxGVpOHJYu/
55kMeZjFGE2kXcRYFDvykIedhxbGPCTlYSimuix52H1/tv//ttvtde//737f
/+9up1yQp8uWcByX/ff579Xx6FApDBdqq3MCQG8gWNbnXRTFPBAnSpKOvpMw
uyMryH38wSYlWY7nigbX+nLmEdhkVu61rWP2wYczXUVtWmZ/bPXwL5f6MQfg
SekQr2et/uRApMrfVMqqmMfAtl9XeauAeSw0pWNci+OYgxA5Wj9lh5w5BN+S
XkXjhh85FObc1OUXFjKHoS9mQ2PrR1/yRFS4HfQ9vJ45HFtOP7h63Y85Ap33
71SvOTCKPAm2e289T41mjsSa2PPL3K74kKNw2MI32+KZJyPQRWK0ezNPwXd7
7q47Z73J0QhcutEQuoA5BkfaQyrknV7kqTivdnEr2c0ci/pHl7sHDGaehvpk
+XzD8ZHk6cg5Uei1OoRZhV+LCguyH4wgA296fA0bw8g80B4Wk3Luhyd1NV78
9q7NWknm1djV6L7jvpZ1DaIqdHO1axXUNdjPTyuTacjcDMR2XntVPG849Rk4
WftUcdeHzMWht8xZ+f6hnHocPCxNSzrWkbl4eEg969rqhlGPx8cD+WqLiswl
4Mrtba/t6z2oJ2DpSvvFfiYyNxOPVSXOni9l1GdiUJl9XsJNMpeItgkBEbnj
WE+EUr14+6o+d+qzYC61HBseQuZnQfZZruhQDKWuRdeQSxt6IwdT12L3Zqea
13MHUU9CTkPN1cZLUupJeFTT9OOZncwl/50/5uvYFrY+WdRTMCd4T6KtgK1P
waEn0p7ySNZnY0/LirWabhfqs0X7p6K6Km9faNZA6qnwS0yJVpzuTz0NRUca
6xTNTg4jDRL/oJ/Syl6V4/o0rKicqjp3nHN0axoidn7pVlt7HJ1LF14Pkfl0
SJ0shZ/29qP16TDNCa/KD/hN63XCz4dO2HmdcD+rDu3RP/s0oV20Xi/aXy/s
vF74eVa9cB4ug36PdB7IQHrxxGDnLc50Xhlw/B9KaP4M4bycQbgfDMJ5eYPo
/Ayi/Y2i+zeK1htF8xuF98uZRPdvEp2fSXR+JtH8mcLrkSnsvMjWTNH3bxYa
5v/n8Qc3Ya1O
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdynss1XEYx/FTCttJRTrIJRQzHeROLufjuF/iJCcptpOy1US1k0SlX+ti
hZWwQmqxYimG3MOpqVyaDSV/tFmOTKVFKyeiVfN8/8h3e/bs9by/ZvFHIhOW
83g837/zby++KZFAWt9ak2gOOkCqrFP38mDWxKSsdWzHMua1kEU1nTHtMyPr
IlKam6STz6yPa+5aMYekzEYIctpdskLIbIp8vWjdCypTsjn224+tLmpj3oxM
i/aS3lxmS0wKXFtSY5mt0KESXn9uymyNTjtR8VznRrIQhRk1uuH7mG3heOm2
/MQq5q0YfsPfo3/RhGwPtSCX03x9ZgfUZ41+bLhrTHZEX++oXsUmZid8G/DO
k74wIjtDYTGYNpLH7IJsEy1Ff5sh2RUvH3d1pxkzuyHhWaPkTsMGsjvGCjrP
T9gxb0NFgE9B7bwB2QMnk666pexk9kTHWHXHe2dmLxwtTI7oUuiTvXF5fnCo
xpdZhPLK18OqST0yIIvZNXsjkcwB/gnKuuybAuo+KOC8yrTFZM4Hr5RlC7Bm
XYwMYXpx8tR66mKMfC5Pib5F5vniXoFcuxms+8JpICfVokWXuh9Kmjz35lWR
OT/Exo8qhRPrqPvDpFnekNlL5vwR32Xe4sixHoDuND/PA5asB+D4wfL2CIEO
9UAonyxwW1zJXCBmrlTpxX3Xph6En6EfNM+FsR4E2bG4Xz0TrAcjVqO0yNCf
zAXDRttquqh/LfUQSA5b9/4wIHMhyHJIeFcsYz0U1YYPGwdC11APhY2XbVTH
uBb1MBQP8WfvO/OpLzFvO3KV8lNilQb1JeaFI/3s3NPEB+rUw1He+lbQY7SS
egTklR6i2lIe9Qh8dZ/7LbYdFy12CRxzvqh8FLOLhoT6zKI5yf//FRLw1R6l
f8qbFv0BE1EZAw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd02lIFHEYx/FRMy2PNrXNK3dbLFTUyvtsfx7pes+uiihCJQnpGuERmJZO
xqovKrIwOrCCwqy028oSEcJuNTIPfJGVkqZWJmVtmFbs83+xOzAMn/ny8H/m
xazN2a3KNeY4jv93/3/qrhm5OL314U21DPQCX25ULdaEMZtDVDxV8NiUWQR5
yRKVT89ash2Gy5c4Xz7CbA/NuNOHjAJmZ4xlHp0+F8IsxUTmBb7UjFkGr968
3jfPpWRXzL2dmg44zrwe8331/Zb5zG54nW5T2hDI7IHxXe1GdVbMnhjhdzQe
uSohe2NgVB3U7M68EZ55GT+ePXIhb4JVaaOmMIvZB36W/tXdk2vIvtjUdPGc
Rs3sh+V8ysuttsz+0BbG7YxudSYHIM1V4hiezRyIqoqeetl3J3IQXPOr0r1z
mINhHTokPbWOOQRepQ4tZQ8cyaEoHJ4XxW5lDsPk6KtfEhfmcMRZR91X1TmQ
N2Msurbyy3ZmOaSfbrcOjdiTgZOJrirzw2QBaFEMfywyYj0Cn6uXXdHUrqYe
gWf1zcopNzIXiZyOd7MLd8TUIyG7ZX66K4nMRSFgNsstYWQV9ShEefb3mmjI
XDRykt2bFixZj8bg0prBNbN21LcguVhUfqKLLGyBTUt/3kwF6zFQxB8avpXJ
egxc2orv1rywpR6LsXz3kD81ZCEW2Qd9s4YmbKgrkNvQaFx+fiV1Bfa6P9Hm
poiox+lbiMMip1zcVrKCejyuOzXfe51AFuKx5yEfFvTLmnoC7s4c3eDYTRYS
sHLaTjwjZj0R6qf3O/raLKgnYs6q7cC8vyX1JJwZsNA2+rOeBK3nsX2XCpZR
T0Z1nTqkXGJGPRkSRVKw+Iop9RTo/mdj6inIyPK5ViRblOs6r9/Bw1jq8dvi
6ryuCzx8D3/+GdGp1bmTx9fg3wuR3nM0r4SFSUvZ5HEjmjewoERiYOW9UW8T
nTuV+udxKv19YGBBZTBvYC4V+8/2tYvfk5FqMJ+qv29nqv73cGm07zf5X+IR
SMs=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1H8s1HEcx/GvX40d+XHuEOUQy48uQkjc63Dn1znn5I/rB+uHfswaWxrZ
rJOENn+0oqWtn8uPUX5shqmcij9qa35Fo6ymaYro14WMavf+/MF3++67x/f5
+fXP9+t2OFudacxxXNK/+//TcM1LhGltXS1Z7qAXGDl7fE4TzGyO+cfXB81M
mW3g9OXo++E+N7I9eCYPCj5fYXbEsnf6xc5MZhcUyz555gQwi1CxkjonWBWR
3WFW5dBkPci8FZ6hq/zJamYvqF+OpPaeZN6G3JC60nEvZh/cvxS+Wv7HlewH
/sLr7oA6ZjGKbg2YTuxj9se0Df98ztIWcgBONL/tETUy70RxR66iVsIcCG1r
Vem14c3kIFj4j0c3pTEHIyuvqbB+woW8C9nlJSWnjjGHoD8orkxuxByK8Iea
N9srnclhGHrXrTe3Yt6N20cCFU+LNpHDUXR2Ns/NmXkPLkQe2m5d70SOgF3W
3rENXx3Jkej/saDrz2CW4FVsOu+XCzNQXhlr5trvYLAWKMj1yG6QkjkpQuFh
jO9C6lLU35pq9j1I5qLwq72kUz8moB4F0aSg8p6GzEXjsNK7bsWS9WhkjLal
D+XbU4+Basdt91xHsjYG6WXy6YjnfOoytOfUaMQCslaGGb4mU19uR12OJwc8
e7bwyFo5vJUe9rJTttRjkSTv6/0YYUM9FprqB3cEfmQuDme6VHtCFzZSX2cu
Hk3Oje2DidbU4zFiVXZiUWlFPQG2M/bCeSGbn4B9vpfjXuXzqCeiTvqst8+J
xmsTYSzyWeI1WFJXQG/VWbQcTNYqMNDx+uebBTY/CTdGeIs1wWRtEgIrZn9L
dRbUlWh5mH1VvN+cuhK1XaPCFy5m1JOhCDnXPik2oZ6MwptDj4QfyJyKvlcj
g6Gi8y1LDONVtN+iwToV5sKWVqLEeoO5lLUdKevmp+B0Q7ik9S5nWF+XAsP/
xZj2V6811OvOq167nk69bv9UOv832j+V+pTkLyikPHI=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdznlIk3Ecx/EHNScu88iW12xqRYeaR4f3PvOY53RuZWAaWkhRgmEoJlaP
WkZ0WVmQWoEY3jMlM7FIMg0zIYucpl0kJB00a4SJaMa+vz/cAw8Pr+f9fH48
bvtyVFkmHMclLt7/n4ZLJxXt6uhuO+wOeoFWa8mjZ2C2gNW3/J7Hlsw2+G5S
l5E17ka2x7S2fn+zhtkBAZ1FP64dZ3ZB6xe+KiWBWQKPiAxVkCOzO8pkW2Pf
jUnIazGodz/zsZN5PWyOLUyOlTBvwPIJlSAuhnkTQgs8TgXZMXtCMpwkThlY
Q/bGjRNt9omZzD74tFyvyJ53JfuiMHDiz7daZj9Ul1UXe/sy+6PJqrVSMSAm
b8U9dVjwFjnzNigFXTW65y7k7ThtYTHXksO8A59T8yN3OjAHwH8gqjx7xJkc
iAPiC7kv05mDoA01z1fPOZGDYZKWMjbVyRyCvg7B95YM5lD0Flw/cVvEHIaG
vLfSqkuOZCn+el4pqstmBtplZ0v+LjgYzANexWN7hXoyJ8OLsEm5aoh1GcY9
DtU8W896OJq14o91tauph6Ph0E0Hzw4yF4GL+SdLQt6LqEfAXGc9cvkgmYvE
nWtHbbuwinoktOZntOJf9tSj4JNeWveonsxHQeBqtvPpq5XU5fDUXdR0XiLz
cqSV+qeOTtlRj8ae6MeWs3fJfDSOjPx+kunGegzspnqeNKlsqccgTVBT6RxF
5mLR7VRxs+unDfVYnPPLmqjKIHNx8LLdMF05zHoc8jZWXL3Szno8FPL+vslQ
1uMR26BpXFdtTT0BVrl+wa9LrKgnoF7W29fvSOYURl1h1BOxO9VPk+tO5/GJ
yOtWhgTMrKCehPu68i1OQ2Q+CcMP3uhHZ4TUlVgzPzQYoLM0GEqUnzJ98CGd
zCvRpsmp8N5jYXDP4vcxikBR4zLaJyP5vO9ms9NmtE/G8VuvH4o+mdI+mf5v
QWrYG5lT4WhTsLS9hqO9amnnVTCRbJoVNs3R3qhz6qUdaqO9GkLTlsKvV6el
/wBm+zwh
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxV03lQjHEcx/Fnsq7aTrXpUq1qwk6jUrKVPltI9+42Sa4xxo5jB9tqNTTY
Dsa4so4SRWgqwoyICK2jKO04otwxmDBomSalS6bv7w/PzDPPvH7v5/v7/fHM
475snVxhwnFc3ND97zl8GcMESVU1F5RC0AKu1GXPNZ3GPAY/nxRntfa7k63g
8LEjYF49sy0k2aJGdS7zeLy8y09+tpTZGccqknTFvsxueJGh8r/e60YWwsa2
821uE7MHytrKK/oOMHvhVn7h/vwUZm88frg61dGTeTIeJvB3VXa5kkUYLMnh
TFXMPvDSzU/+ack8FStqI3jqqxPIvvD5NdFyyXxmP4i/8rzzul3I/lB2dp/u
PMk8DWn99gZFKnMABv9kejR1OJMDYXguVsfkMU/H5UtrD4c6MAehZnkXr6bC
iTwDr+721q1JYRbDIvi5W4EnczDSizwHZY8dySHY/eC9xTs9cyiaz7Y38Vcx
z0TwNe5c6IADOQyvEzcI3hQwA2+deG2mXeOHrQUcnJQr89eQOQlan21u3BnC
ugRp/vWhGoM99XCcEBY6qyrJ2nBopnspqhSsR6Dwyo9dLmNZj4Au0t5nU6uA
+iyMTHOZsrWarJ2Fhqc52zQNdtRnIzvnzut8PVk7G0ZZc+6hQNbnoO8Uz739
kS31Odir0pxZmEjmInHIsz+FOz6OeiTaJ/3a6Cslc3PRHfNpTGasDfUhl4ze
8lFC5qJQUFuWniRiPQrD/wfr0Viauri38bM19WgoikpNMorJXAzCkjsXxTux
HoOUI+dO2ImsqMeCP+52uuqLJfVYJC/wO68Wkrk4lDSc2mCWZkE9DtbfbAVG
AZmLh7naL7g5y5x6PFwHDA+CjKbUE9BivmNlTzzrCbhxT/zD+wOfuhRHW8x6
SgPMhg0pNDXSkKBudp70//31UijvV99svkrvczJMjM5rWVBO50GG7TqlOMN1
NM3LoPuwPiP8N1kvQ8eMPwPhPqNoXg6Do/HrQSs2L8e+nBHVbYvJWjlEF3mj
Aveyefn/+3OJ9D1MaD4R/nu+/5boe8L+ArP7PFY=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxV03tMjXEcx/GHpDoq3Ryn0+VULktaOZIcyvmU7jfnIlELs9niRMWZ3KZH
KdaI1IxcoszQyrKVI5ednViJbLllTNjZIqGT4SRbYef7++M827Nnr+f9+/6e
5/nj8d+Yr9o0meM45b/z/9VymOTCjNbbLZoA0A309JfliGTM9jD4S3udOWYX
dFfczXjf5U/2QHRpcPf2Y8wiFFXnPfJZzeyNVpnRXD+X2Q+/FXMme3/zIwdg
jXaoNlLHPBsPfU93lhYzz4Xt29yWM+HMgRhqL7PJtGMOgs5+56nysxJyMC4U
V54VBTGHoG9fwUFBsy95AZx2XS4rzGKWIvRxb1PQgA95IdZrXKVuJ5jD0La7
HghgXgRRk3p/cLc3ORyaJ8EO26uYF8NB7Lm+ZB5zBC4vUr38c8yLvARJdlyd
GcwyuFdfbL/6UUxeChdbY8X0bOZlOH8hfO0GKXMkbLfy28YHPclRsHl+sW95
GfNyxEYMh2eFMMvR7zXlneCXiAwcyRAkPr1O5gGfsEMvJBtZj4b2dUOX66uZ
1KPxZsLrdraWzMWgXHrTt0/BegxGnDM65oWyvgKOVyOUd+qE1Fegymfzl1rj
DOqxOF15fothJ5mPhfaWwa8jmfU4zO8U/bz0wYN6HPrXVB46YiZz8Tini8yu
bmY9HiWdmTljqawnoDb9wJhRwHoC1h2OH4y67049ES3fxXV7csl8IpoThlVF
jqwn4b5Cf4Zvd6OeBMv/QeaSsUU72jYpk/VkCBpG18U/cKWeArdPekOjisyn
oDEyIDewYzr1VDjluQ0dLnShngpHd0NRwSDradbm0zDBKSc2aFlPh+sXD6FJ
6Ew9HW2m46HiHjK3Er26Fz9ejU6jvhKaLt29Z7fInAJdD6KKtO32FkOBYdnY
eEzIVFqvQNjRr+ZovYPFegV6xKbPNS4CmldaG0q0NOfXhGTTfrwSksQ0mfCa
Lc0rUWXcsTfGbEfzKkjGex4tMbF5FWYln3yZdYXMq6z316us34dTo7xKs3Sv
hPaD2vp5vNr6e/Rq7GhcJr9Rz9H8KkyzadrzuXpEbplfResH5H8BRQ5G4A==

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdznsslXEcx/EnKnKEIqTcztJMTSFxTup8XA4H4VyccumixlQ007RKTc9M
mpbFarRWjcrK7YhNkySXZGujdUNpqUhXKUocjTTf3x+nZ3v27PW8n89vj+Pu
FGWCHsdx8pn733P2+i6xVNfeqU4Sgl6g4/WJ7dYiZkOUTO+9lGDAbIa5Ffnx
Ua8cyRYQKyI8xzXM1lhb3mbnmca8HFd/DRYPSJgdsKumPuaggFmIl5U5qO92
IK/AQOKbHSOVzCuRW9T9cewYszPyJwTXeryZXXATomPO9syrkdZ8P7vrkT3Z
FW83HdnnoWZei8ybBcPJI3ZkNxj/ejvUWcPsjsz9sXsWKZg90KnmzesnbMnr
UDswd6dNIbMnXrTsOloUxrwe98Pt+K6vy8leqE59/6Uimtkb3epevciFzCJs
fH2+tez6MrIYD+9N5XfYM2/Ap2RL75RBG7IPSpOWTN0oZd6IRp9er6dJzJvQ
uKVrYOXkUrIEWfFr2rXZzMAc8arbjxaQeeC02kj2pMqaui/QlxG7KJDM+8K0
SVWiZ826H3aGNqChxYq6H8Rf+vmqAjLnj9FsaZTUnXV/XDYuvGXxzJJ6AOTK
sWVVmWQ+ALXb0uO2JrMuxamMHVYVP5dQl+Jd8TO1mQ3rgZg0SZQ0S1kPhPc+
iXuuFZkLgsb2qdDlgwX1IETJzpi9u0fmZNCO+185tJp1GT4VHPCtlJhTD4Zb
4IXbIR2LqQfjq3l0wlgOmQvB3faTfePHWQ9B4zanZjsB66G65kMh6rxT9OCN
GfXNGJ2qj840IPObEVyqKXO6aEo9TNd8GMp9hHucW1kPxzSnmI5LYz0cyX55
d02KTahHzPyf+JtzvzH1CMSsypd1HhZQl+t2yHU7L0fbqKkqJpV603/mFHhc
9/xnzzh9DwU8cod++zYtoL0C1ZqUc66xhrRXIC9Lv65vuxHtlUg/rm1OKptP
eyXsZWEiy7J5tFdia4y75oBwWjK7V9L5E7PmVNBzcNEKyv/MGirdzqswLNJO
+bmO0V4FgX5l+uezP2gfSX1Q8heUPFI2
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdyXtI02EUxvGfZTac1py6tEznDKu55jWd2tzjZZtubstKDFcWhhk5sqYR
aIWGhpNITBOSIFFRypguMcrKmabiyDBIiQy7GNGyQkVkidAF3/cfDxwOn/MN
zC08kLeOYZiEf/v/rs6cjJfZ88RSIAB5wJCvb7kTQ83CZG1oTuV6ag7GB8d1
ttFAYi9c9/jk/6yd2gcOeYGi9DK1H1qjPF++UVLzEXWicHrem1qAz33NbkV2
PvEO2AXG/P4u6mDU+ItWDpqod8HqF25jpVELcXNKYltyphaB1fprhukNIBbD
RdKxcDSSOgwDqtG7vlZ/4nB4BnwYnzNQR0BvutAvZVNHolrLzatr2U4cBY/F
YdGEmHov5rWW4MFXfsTRcBTbG6KDqGPA2byS2zy2jViCY45bQp8z1LHgfctm
+ALqOLTZlyp0U1uJ4/G95rEifoR6HxwRLiPyFGop+sNMJ89W+xIn4OKwedp1
wYdYBnnnx6u1T6kBdXv1YfYm4jKAF8c3ul3aQnoiApvKvRLHeKQnoudIyfEs
AzGThI3Pg26LfniTnoRGG7e3yUzMJEOolwz16WhPhraIU9ow5EV6Chq15csz
rsRlKegPSfp530i7HDlVCrv0hSfpcqi751UZMcSMAi6ZTt1zg1zSFdArra7L
XcSMEqeLHQ+dsmhXosjSadpf4kF6KtqCVO+iBjikp2L2/c6K0CvETNqanobz
u+vrbjygXQV3A3e26hztKmgUw0NfpLSrsUcqPmT96k66GpPuVad+a4mZdLx+
NLH41sEmPR0Wc2G9WM8iXYOAVE0s794G0jXIuBYe4lzpTLoWWdkRZqPgj2y1
rzGjwzq+cJndsSL7C6Fg8mg=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzglI02EYx/G/B2gN85xmrpymHR4j0w413W/TaW46XRLi8FiFYJlNUUw0
YwVpiRYWhBgZMTsslERGdBArNDOhFMugoiDxqKxU5sR5dex5CXzh5eXzft8H
Xr+D2n15thzHJf7Zf0/rmhR77jc86ijwB11gRLhvwrKH2RGisd6YbgdmF8id
XXvG+v3IHig3mp0TWpjXor0+uWz8CLMAb+Oich+HMguRnphwSGsSkv2hqa1R
mwzMAXj+5ovmUwnzJlSpz8cYFMxbYJxR24duZg6CusNWr/jgSw5B4I0uSVI2
swi5IZGLNVMbyNuQ/uDi0pWTzGFo9l7m5/sxb4fwVrLQZmQ9ORyCgJ6ejBzm
CDwOPtf66auAvAN6ra9Hy0nmnYic7t2WJmXehdaJzIrYaR/ybvQVdp3uameO
hPZEap4shTkKtvoDZfUf15GjsXXhhHhOy7wHBQJtRGM0cwxenzfXS696k2PR
LBmoVcqZxRjsEdi9d2AGZI52C6aOtVbrAPcixdNjVWROAoP36GfTZy/qEhwe
ChTxGsicFM/qLrjq/VmXQpY33FnX6Ek9Dq3XRu8FZ5N1ceizjNdW3+BTj4fW
Zr76TjRZF48Fvb3fWL8HdRly3xlyBsvJOhmalKcsw6tZT8DPwq6ZcLM79QTc
L7qZKeKTuUQ8yQp8uoHnRj0RmuLs+ZfjrtT3wiUkzOfVMlm3F+badq9sE+tJ
EGeYspQ+rCfB6ajb97PFLtTlyGxqu84PIevkWOZUy5pSZ+oKtPTqy3ila6gr
MOR0Nn9O6UQ9GRvll4fUt1dTX2EuBeH1P2YlxlXUU/CiO+Z46UNH6ko0DJdU
SmcdqCsx2TmwWMWn91wqqhsKoip9WU+Fqi4s2P6MPfU02AqDLLy7C+J/RBp4
dm0V3y5NWa1bYWMa/WfOak6FX5GWJalolOZVK+ZX2PjfvwF3aSRO
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzntMzWEcx/GjkqaLpCvpJibsyBFJ5Xy6X1Tnd84R7SRzJ9VCUTLOj8If
oibMZRSiQp3FTOvmnKSlccyMpqKklZhbVKTJpe/zx+nZnj17Pe/t+T7O65Nl
m/QEAoHk7/53jq4vYuvoO1XlCS6gC8RcuT9cEcBsBEVDYOIFS2ZzXLRQ+x7t
ciZbgjObXdJaymwLrbJX25TCbI8NjzP8epYyO6Euva1R8duJ7IIekaMb18Ls
ClHtBMenhcyzkF8w49yzVObZ6O+MvR8dyTwH9o71IpU18zwUruzg8jscyUJs
VPfUnMhhdkfMJ9FgjZB5AUaS4nYV33Egi9CqWN2wL4h5ITYEJ3zVtE8ne0Dz
ofF59H7mRRhf2WUXEsG8GFrBo1duHfZkTyijtvm+TGdeggfD2y3ODU8je2Go
cknsyF7mpbjWO5AlaZ1K9sbVTuX3iUpmH3Sdqs98N5/ZFweOn27dctOOvAwt
1uNLtBJmMcKqkm2+jWMGUte906vcbDtqHmhao+qr9SQL/FBvmbbHqc+Guh/i
zX6sSCoiC/wRpeXqi7ay7g/FE9P4s2+sqQegIbsubfc9Mh8ATjYwTXWQ9UC4
7nj68qcV64Hw6de8zl5jRT0Iemfyf4XyZD4IzYZHmqf3WVIPhntcZlFNMZkP
xi3VYQfbNtZDcKHCJzavjPUQcPMLXFJtWQ+FhbFNdXf1FOqhuFTYaJXzwoJ6
GGpXz9Q4GJP5MFybEd7iUWdOPRxe2qqChg4yH46HL1y//zKZTH05joo2tZ1f
y/pyJPrn1phdMqMeAdOdIu9nB02pR+DBt0lyxQ4T6pHIzdKvaI+bSD0S5WXJ
J4WxRtSjxvQozLttYLj4+ATqEmQohzQJ1w2pSxDhqbz7VqhPnUPKDW/xrcuC
UYPT7TwHPac5Q8Y3hsX/reaw8NjHQT/1z1ELpLodY8xLdd9XSyHNXjDX4JAB
zZfpzoMMxvqlGe/zxtH8MV0twyqFqGynywjNl+sact3/8XJ67yv9X47PXkO/
/YXd4j+MIUt6
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdk3tMU2cYhw8iirICOqwiMArOBQsjCnIRQX7lJndKaQVKgVaHshTjUPAC
To7oLmbq5DK2hblJvBSFYBwxIEytIl6niRJxWaZugbhl2bTARKpYtqXv98c5
TZrm6fP93u97v/Mev7WbVCXTOI777L/v/7/2jyVWqjnbe8boD/oDQz+85gMj
GDsjufCRZIRj7I6b142JT2/4EXvg/ER9v+kw4wWIXvRYllLJ2Bs+bZODugjG
MrRXFNd/4cDYH1cS5Pdv/igjfhu/tFxd7/U143ew4/0mZXMB4wCEKyT6qqWM
5SjvGc9475kvcRD2GFPLE6oYB8OWfmrfNifGS9Fgm76pu/kt4mVYXhvcFpDD
OAQXd5ZqbM98iEPROGvv3eMHGC/H7nVHj42uZByGS8nVX53gGIfjlVW+y73B
mzgCLX0PFwRGM45Eq/fikpIHXsQrMKqbcEtcxzgKpavUF2QOjFfipHGerfXk
QuJoTM3+aO23voxj0Le9add3UsarIH0Y21PR5Ekci0mH0Q3dWsbAwDVvx59n
EvOAVDFU1r51AXkFkppnjZgCiXkF9kfZ1sdvm08+Drxz6K6xYSn5OChV416n
a4m5eNwPKDOc6JpHPh6vyo/UZJQScwno8Bnwl//uQT4BTzdeeR46/ib5RARZ
DnZ0fU7MJyKtcyQ1O4L5JMzQOHRa+uaST8LxqNDrpsPE3Gp8+dt+h0cjzK9G
Q4mlQWdiPlnkkxHoI/XcYGA+RViPT8EHg2OXDX7Mp2LLmdP7lFVzyKfiXmz9
9PkPibk01A6vPTDcznwa3IOWed2ZYj4d0SHpn7jqmU/HksxFHokbmc/A3D/M
l9tUzGegckljQ/337uQzURZ36Lxriyt5EXNZOHbj6FaXCuazMOcvD6lFyrwS
Y7ae/NqZVA9K7FhyzVqSRcwrUdmrjI6coPVmJU57tXfdS3OjfDYykq72D8ew
fDZSTnacWvwNeT4bme0HE0vOSiifjeZBF+uJMBfKq2C83n1h4BwxVLAG1e80
lc2ivAqH9jp2Py6cTXmVKJ+DRalNg9pW8siBr+32rUgLMZ+D2wstfza6s7zI
c2phfaihDaxLvrOd6vNqtCr6+q96svOrRfenEfYHDXK1IR2b/Vn/GuF9mUXM
rcGg5NNSaybLr0G8ejLcKYk9rzWQbA5ZOVDL9hcxl4t3Y4LVF5+wfK6wHp8r
uv9cKMvkt557svnJwxSXPaWvoPMgD23R/qUBfez8eaL+83C3+/4/P02w+88X
euQLz8fnY1xybvdk2BuUFzGnFfYLLfrH3HK05eR5rXA/s1b4fLgC4XoUCNfz
BcL7MBcI3wdOJ3p+OmE/vIjNOmE9rlA4ryiEpfPu6w/nsfktRN3Qluq4FzMp
X4jQA3+/UJjJc0Woqnl5yXhqBuWL8HGdMaral9bzRaL5LcKZjk2NwQXOlC8W
7V8smt9iUb4YQZ3TZ4QfpPqcHs9WvLTFBdP+Mj1MvQ+kN72dqJ4e6RE1XUPB
jnbW62m+p2Lt9fXUj9XOR1i9cTubRf5XkecMmCaTv3Rpm7SzzCCsD4MwrzdQ
/knsv+irUAg=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0X8s1HEcx/FvoohEOBH51S/HLD86Lo7X3eH8POeoFqKxVkPrhzal1r79
YaOYWmnrh6ZhWpZo1Zof24VrqBYTNW39kynXDxLyM9Xu/Vm7+27ffff4Pt+f
z2f7fj2yj6oPmnAcp/57/3vqr4kIwe7Hrc15nqAXCMiq2xYRwmwOra4uq241
sw205auVXX0eZHvk7lnydrvFvAGjRfWaznxmF9hkuKqcY5jdkSuv1zmYM3tC
9iavonTYnbwZB0IVijVVzFtR2zAqvpbDvB1i06YCiTezELZt2bUfXriRfTF8
JkfeqWb2Q/j7qwJueBN5B9K9krzsSpj9kTminenyYQ5A1d4mRc8jV3IghtaW
HJ5TMgfhOya/6R66kHfiVNrlc+ORzCL4OPa/NJvZSA7GfEtI+vIZ5hCYth17
F2zNLEao1bLubLUzeRcavkgPKYOYQ3E65YJv97ITOQzXbxTtnLrNLIHto1an
y0LmcLQV7FsQPdlAjkDfz1lNXxYzkCmcnspzI/OAS/WRT6ntjtSl6Ii/K+zP
IPNSVAzYXHwZx7oMHtXn7aWvBNRlGBfP/5b5kTk5RM4WNT+qHajLIfcdfL2y
mMxFwv2jQ2XNPtYjETb97ENZJutRmEgeqKgUsR6F5DJ/H9Nie+rRSJt8L9qy
ZEc9GlGSkbOv59dTV6BLpbnJt5B5BQ4c37/Q+9mWegwKmh+UqorIfAyi28dy
0c96LHqGNk8tWLEeC9eGxaGMYNbjkBj9XDsisaEeByu7jsJjY+uoxyNfdqnd
+o419XjYfrUXTAjIXAL6nw5OvZu1pJ6AwPJvv6QaC+qJ6NZKCk+2mFNPRHPj
0at+6WROaTjPK1Hf+lbQ62JGPclwnk+CW0yiWHCPdRX9r1V6Q0Xf15TmVbBc
eb9Id2WF3hoV9qYFNJ7wXI7Qr0+m8+f0hpH5ZNp/Rm8N8yitV9P+P2i92rDz
RtYYzXMpRuenGJ7HG3VNCkzchfOWDYu0PtVwHqmG+/P//QdbfV/v
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd03lIFGEYx/HJ9SrTtrzPVQkzNfM+MvW367HeupopgmCC5ZGKoq2Yx0Ja
EkaxWibUX9puRhoh5ZpkElTaocmWYAQSlkVgq2RbJnaxz0vsDgzDZ77v887M
H+NRXJ1dYsRxXMbf899Vd6zE2uXeGbtd4Qm6ASvXxqrXAczmGN8rWDM2Z+aj
6+zcQPK8B9kG3Yve7WFKZgfcPcnv75UyuyDGg5dXn8zsDu+6Ss0pJ2ZPWFcO
16iW3Mm7MTNQ4vjkFrMXmgo/HVJLmb2xkpRv+UDC7IM3Yl50hCezH0QLR+U7
ngrI/ihwn5FG1jAHoLW4qGeGzxyIvjJNwbFrbuQgNHyLiNAWMAdj//PZQZ8l
V3IIsjTa2I8y5lC42m+ol5yZwzCzZ7zvndKFHI4NE1+nXgFzBKzOtCr4cmdy
JPZVK1pe+DMfQMeXMpVa7USOQs7FhJ6hZuaDqHCpDrkcxRwNxcP7j8snHckx
mPaIFopzmWOR6VKkCnFlBhpkO3uksw46y4A807W3h0PJnBCV/cVmp6vsqQvh
1lE+sGZL5kRQbF4XeF2xoy7C1Ku29vopW+px+GBySTvSQ5bFodP+pVxbw3o8
fM8nToue2VCPx4SvaPlmLZlLwPSR/NWv89bUEzAk1mRLt5O5RPzoN2t5L9xF
PRF1pcrxTDsyJ8aYU/fVUQ2fuhj9U30nLOqsqCdhzrKjdD3DkrqBuWRUTKrG
1aMW1JNxoY2nWijcRj0F637yJuXxrdRTsDI8u9lsS+ZSDXqqwXwaJh9FS+vu
mVNPgyby5y+Rvyn1dEg6A32N242pp0P3fxpRz9C3LAOCpPRIuxsm1DMN5jNh
wRts/Ny1hXqWvpGFtPDWkUV/Hq3P0t9/wmA9J9FfD4nB+0iQVxA0VOv5O1Y3
L6Hv0+rMZSP43PJ34cS6zjCwzMAT2fT8VZrP0TdyaP8lmv/vP/TcQPw=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0nlMkwccxvFXRCdiERWwKmc12JQNoaCWyz5UQKjYg4ImRDemQdBivGqI
9ysqHkGoGjUZMSpmQGBqvEAkuKpBSxc0cQMW4xmi8T5iqFKNm6a/3x9tk6b5
vN8+7/umfaMWr8wr9hEEofDb+/un+/VOHVJwsf2sWQY6ANmdGoVMxR4BZVn3
nroh7EA0Cbo1D3qiyEGIGer/ueR3thTr6ipbbWZ2KAo/JF5FMjsSj+/rW/2D
2TL0RJm6Sp5EkqcgaMCRoT3Djsa+433PnJvYckSvsC5V6dgKxCyfctMlZf+I
nOLXT+yOCHIsDiiqq88uY8ehPLvm9mFfdjwefmyxan4LJyvRFTbTcNrETkDF
6sRh5rdh5ETEX/p3009W9nQscRhVqmz2DHweVGwJPBhKnon+Y3b7f75sFRYs
1tp/SZhEToI9rt1S1T2RnAzTocwjpzezU5ByWTiV9nUCORWvavuXtF1gp0Ef
WnQpMYw9CzXr0+vlXVKyGn09mx17U9nAywtHH8Y1jXdbBCrjW8P7DGQhHR9c
Nzrv3Q2hng7l+GO/LqwkCxocqT/RKAvnrsFA6842591g6rPxZ0St9Kgf99lo
HvNGGn2eewYa2vtCHKFkMQNxi7Y3dDQGUc9EySEfiySBLGaiPLhWqKkfRz0L
pt49VXfCyGIW3M/vWOpzsNzyqWXIArI4ByNPfvo5q3MM9WxYShuu6EO4Z+Of
YqefvI17DlKVubsCishiDl7em7pjWkUgdS0mSfuf7T9AFrVY25yiPlfHfS6S
brUfv/GI+1wYyhR/DUzgnovmVFmp/Ppo6rko01g7Ak4EUJ+HUeOula96zn0e
eiW7Swd1Euo6T4s6tLyzTpvYzXs9dH9UZxZf5K73Or/Bs8OAjpvJb+T9o+j7
BkjWKFP+rqBu8+qCET6RCpd/MxlGOCVt275M570Rk7WHewsbR9LeiMr95uSN
ET/QPs/TyEPCvtcf021+tPfqtjy8TXJ91cQOp73J0zBhw1bXVXMTWTTB3plW
brk8gvYmr+vne10/H8aq+Bjfnb60z6fncxjt8z3PLxTQ/y3QvoDuf1Dt3hfQ
7/PFbZuXhfl0/0/dBttJ+/nwH3pqw4uD79X/A1L3cEw=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HlIk3Ecx/FHzcyWV+nmcnPTNCqPssM828d5zWPmZmFKwRRCSypKKZuJ
C0I7R1oIaf9UpKVpp1nqHzMwTNMOakWX4pFRRoaVOVMr9v39s8HDeD3v32cP
bDCv7D3q7dYcx6n+Xf/fza8xGX9zU+vNPG/QDdwtTfdc7M88D3bHj9wbtmF2
hl1Iv3ao14vsivaB6t19lczuyM9e0hamYRZBFL1/mzyAWQqDY1bL6E8p2Rti
90XCBgOzD9ba7JiSVDEvRan1V3VBNvMyiOvHj2eFMa+AsWPktRXH7I9zLxpT
u5sl5EDsiyv8NLCTeRWcPFMvb3BhDkLujXft0mue5NUofts3mpPBvAYn9K1P
mh6IyWsx9euKbWUO8zqk699oR2dF5GAMDIZ4ed9iXo/28Qv5Yh/mEDiWldQ4
V3iQQ/FY25V1UcAchoBCYYO2ZTE5HEnhhxJcs5kj8Gam58twr5AciaCIS1KT
knkDYq/3l5a3uZNlOJx/Z+XjRGZAP6FR7HopMFsH3Bdl7Or0JXNRaKqqidI7
sR6F1pOna4tu8qnL0dwtsP2jIevksJ85ax8ezHo0jpme1gmn3ahHoyd6i3D4
N5mLwYct+rKTE67UY6A96Ddi9CVzsVjIE7R9bFtEPRbLfeyGJuLJXBz8xHxh
TtZC6nF4LquYI3jvQj0ePJsG7eczZF08YnSF00FlrCsQsTq5zFHDugKy9B9b
UzxYT8Ajo8+PqQWsJ0AZ97BjKNKZeiISrjbW+Z53op6IWU41qykgc0lwGXXl
j/EdqSfB6HA0dzLFgXoyOsad0jL3LqCeDMlMT3fI2HzqSmT6lSt6C3nUlRY9
BdbSFSZePdunoNrIm6xZR+e5jRi7/Wy62M2e+kb4354zN1hvRz0VpeV5YUUS
MlKhLTG159XNpfMWNlic51To7Ig8UNAyj/Yqi+ep8C3UNCMPZHsValtf8btE
trRX0+9jRXs1JAplKL+Ouk4N8/+RNe3VSF5f0jwYaEP7NIt9Gj3vl8y8T8Oa
U18nogyTZhssOreJvr8/ZmMTfd532V8h70nb
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdlQlQU1cUhp8rsikKgixqgtQKIhQXFAT5ZausBghLQgKPkOCC44qlLtUH
VVvb6gAynU6tgtpRFMRiVUBUIg4qOipqRbQuUCijVpERStkktcO9nbkvM5nM
l//+5z/n5CaRatZE64ZzHFfx4fnf69Cjw8869mxVWbojyBuQF1gcN3hRHoPE
wWv+UhPKFgg3Gdhyp1FK2Ap8/9jz54ooT4J12SXVmTWUHfDMV7PtkQ9lCX54
19hgNJqyIzYZBewaVi8h7ISQ8OrdJ3IpT0fQSc9wNxXlGfjOaFn/KW/KLggc
fLXHfQxlVzyXaY/uLZ5K2A2j7g00R+oof4JDJ6bbz3k6hbAHHKuflPeupjwb
hiPPFrlYUZ6Dl1k5PiWlkwnPRe/BgsDEBMrz8OtIw6PMQQfCnsh22D4+5xfK
83FR+2yf51zKC3DgTI6B329P2AvNIdu63xjsCHvDqd2kx6OS8kKU/b7n6d2d
lH2QtelNptSesi+M10VY/HnZlvAiHG9za3yRQNkPK6pyVpx9NIkwYDLzS7Vx
B2EBmJAufzy6neqLUd/Zo69PpvpiPAirUTZLqe4PyyvSWTYFNkT3xy6P8ikP
ZYS5APxU3v7tZGOqByDrQH2y7Vprogci66W0+o8QwkIg6n7bsXNj3USiB0ET
6Vw0aEZYCEJfT8DhTFcrogfDKXPYPs+3lkQPxhcH71+wbibMfYrWlc7e77+i
uoi5JSh7Z1eweTnVRcyF4LWlQte9ewLRQ7Ayo+fcsHjCXCguqT66PMWU6qHI
btXsaS0ZT/QwmBzpSQquJSyEYaNz/r680xZED0ebu+Oc1c5UD0ddg1NXvxn1
R6DKLv9A5VtyXoiA1+2qwqtN1B+JDWWndss2U38k/OK7VJH21L8UFq4e9rcN
VF/KzsPJsLahsyZFShgytFx4L8ycT+eRgV+n7r/xgvj1Iuai2PqIQvc3pTbq
LpoXxdbTRyHIt3XrnT6aH417fnkjbZ5Sf7Ro3mjIVrnc/NuWsD4am5yv9eqW
0vlj2H0iBvaTWl7k5lF/DAxclIHPGEf8H85XyXwW9IwlfjlbD3KYWdZkrn1J
zgtyKH48eWiiK82XI145u3S9I9G5WHQOnldkG1F/LHteiMWG4oV+pw9TfyyO
Tgt9PLeG9h/HMuLw15OPd7hnU38cm6ePQ7GP4/IZV2h+PE7Zl5TfCyOMeHZe
QaTr49Fg/vXy3khz4k9A0eIrtVdtCSMBs3zd5NVthIUERARfrW31pf0n4Oe6
I5+ZZtD9Kdh6ULD9Cgq2vl6B2s5xMcp1ZsSvZBlK9rygxCr/nItjD5E8vZLt
j0vE+NdW1h3WREcihktc+kyLST0hUZSfiMiSvUG6s9SvYvuFSrQ/FQLkA56j
gmm+SpSvFvnVov2pYb5+9sL72TRfLcpPYhlJ7D4FEeuTcPGad/uMFrq/ZNyt
eNDV2GNK/Mmi+ZNF/SeLPj+evR8Snr2/4Fk/z7P5As/ut5Bn59HzyNkxouK5
2mSIm3h0m1dmDcyj/adAOTN3ye3PSf+SFNE8KUi/XnHpfiVhPgVTB2/dXNBB
6gkiLhSxPgXTQr9vUBbR/BS2X07DzifRsPuBht0nr2H7F0RcqBHla0Tza9h+
uFT2vCQVva55W4+tMib5qWx9XnReSGW/P4Wpov2n4lxHjrvdLTJPU6ro+69l
9y3R4nqtb2bG+TEkX0v+T0eQfC3eevUN+ruNJvla7MpN994y1Yjka9l59Vrc
sut4lW9B59dif4Np79F5JI/TifJ17H6gY+fldaxf0LH1C3XsfdHrUFa6Jt8t
kczTJKrPpbH9StLY+ZCG3JYNW/z/IfPxaThW9dD6hsMokp+G8Pnby1vcyH4K
08h9GfAbyk8jvw+GIW6i9duGmFv2P/8LsAAeGQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd03ss1XEYx/Gf+6njnoNzyG3unU5uh1zqfM7BcReNmTRrIo0aCyVGZ/7o
OpPKH442tVxWblnDXBLTWKXssLFlrVbKosQWykyXeb5/1Hd79uz1vP/+Ombk
Hc7S5jgOf+bv3n7LMsvkrv7OXCfQAQ32en4SKTMPgx7233V5zKa41l5WVjvr
SLZA8dCaibKB2RoN9y+LtnKYbeE1P6MIlzM7wHi0tDGTx+yE2cWxEd60A9kZ
6nKL/F+1zK6Iq9ZWz2Yyu0NW9/nLYxdmT0hbhMuLH+3JYphC2jF/glmCU5uj
PgZ6zF5Il9eIm1rsyN5o5VYDa9KZfWBpOF4/s7Sb7ItkicVY8R1mP4R46ojS
jjBLoSVUp0xobMn+mB/orT+ezBwAkW62erjNhrwfglTNee8g5kAsVPUqg8dE
5CA815oIcktkDsaIpm9d35A5BCen7R4+ahSSD0DRv3k1opz5IMxzk17rL1mT
ZQjveHexeoAZqP5QUKpYt9q2CigKcM3qyiJzcoz3JO10FrIuR8mFjeHcB5bU
FXi72FyUcltAXYHlxKmqGn8yF4o9VcpXihcW1EORXaNdaORL5sKwdPrpqu/a
Luph8HA2mFuPIHPh6MlvSpUIWA9H7ZPmc8lic+pKePfZuL0vIquUyCn80a2V
wnoEBo+6DNvxWY/ApOyGrtUbM+qRqJjLqJxrJasiEeITe8n4GOtRKOjsuJJQ
wnoU9pq5r6g1ptSjkapuuysQk1XR6LBp7ZmMMaEeg+7l6/tEL42px6Dh2b2z
/EIyFwujMz7BUxVG1GNRN83/2STlU4/716o4+FZ+XZcP7aAej872vFuSNB71
eGz/X23qh/AtcGNLIfkk2+7/mUsAX6etZOHmiuw3uOv8sA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0nsslXEcx/FnHXe5poPcT5FKZyTJLZ9zXA/hnENNTcta92whckkcmz9K
SWFlXVSUXDKrqVUkLGIuJXOm25puo1KpzC2p5vtb49mePXs9799ne/54bLbt
l++Yx3Gc7O/97zlzffPmb7hVe2OfAPQCDoWHgja6M2tA/8CnmBZVZn2UB03a
jSptyEZ4z1O5UlzNbAKhx+XPBSeYzVG3tGA8LZLZGvE1LyIzhMwCFH7vU6qr
MS9Bq8pIdHaPNdkO5b83fekuYbbHTl3HM12pzMtxXH3XZLU7swPUNHJFwzxm
IWoMD94tzrMiO2K6w2ro4mpmJ3w0zxfXv7Qkr4JmUlqhaRazM24LnCBzZ14N
veqSsv4OC7ILEqaMO3fEMa9BV/sb47LFzK4o1jp9KqLHnLwWIxPbzy5LY3aD
pX57nMsrM7I7JE/5zxKzmD2gUhfb56rL7InrBv2P1NoXkb1wMot35/UW5nWo
36h8ZzdpSvZGadP9lr2tzIC49ld2QDpZAQw9Ho7xcmRdhNwUUal9mwl1EQYj
O5O/JJM5MR4aJaVYfzemLkZTcNny7igy54OrL/t7esf41H1gcynTSNRJ5nyR
mjHRuK+CdV+cf2wrUctm3Q+ZF55sNY1l3Q9FiWXPHQWs+yNz0ObBGwnr/jg6
8aTCdGoh9QCUx3Z27z5BVgSgcXGWPSdgPRAee+MLo2uMqAfCsKp3z7d0MieB
uDHccoUV6xIkLTzH5ZYuoB6Eba2Ce84KsiIIx3Ku2lbxWA9GfZRto6W2IfVg
WFT+Uka5GlBfD8OBhqZKOVmxfk4PgZnJ24FTefrUQzDNyaajE/SohyKxVuq5
dkyXeihWegkjHnzQoR6GK20lB7UTWA9D8w+98M1x86lLodQ5sns8lM5Diu47
vT/7xrTpvBTOOUOjogbNGTdI0drslZRwT4P2stmGjP4/LdrLMO6Ql3Ythu1l
sAoMceNXqNJejsNFPXX8fh7t5ThQ6eF9s5ijvRzavKrUj/nD3jN7OX3P+Iy5
8Nkdc6wIx1e3id9i4QfazzEXMdv47z9ak1bi
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxV021IE0Acx/GxkbqWuonpaj4uKV1r+ZBPqdtPnU7nnGAoSBgZ+Wqi0RzU
jLbEknoR+YCUSEXRg80SF+rUUhQNE1pUKKaElSBYkVpSuYY94P9eeHAcn/ve
3bsLP1ZVWM7lcDjKf/P/ujGWVQFF3QNdBiloAzn55SFIZfbCgil4ptubWYhz
QZqh9slwsj9aJx5rtLeZxZgu5NS+MzEHYcSWZozVMIdBJpbHp4qZpRB4PRXN
rYSRI9B9qsx5s595N7Su52bZBeZILNpV81MFzDIMjEunIiKY5VD3D5covoWS
FdjW7G4bsDBHo/7Oh8pnP0PIMeAqPxdLapljcT6yZu2RjDkOcTeijoZ2BZMP
gB89m9lZxByP1vsqn3Y/5gQYnHL+yYYgciJEFR59bZHMSVhsGT2tn5GQkzEx
tN7wIpT5IHRD/J67JTvJKfB8+/L4LJc5FXXKsn2+7TvIafjqOdp0I5tZiSfG
kt8JPWKyCllePPdqFzNwdfg6r76YbAUU1+xLpe5A6ukwV++qsqWTrenYUh28
1+IIoJ6BS2ePBHasbqeeAXXbe7++i2ROJmSHk8YGC1jPhN4orGkZ86euxiFO
krNLRLaqEdMv2fPR5Ec9Cyemvo+UhZOtWRDKYyTOPyLq2VjYL42rjCJbs2GK
am5qtAupa9Ap6eh9nedLXQPRF/+A5QAf6jnQd1zOKu/2pp6DV47J1elfAuq5
WJM3nrlXwaeeC8O4Y/BNH+taXKnjOeZKt1LXwmxxDRseeFDPgy7R0juv4FHP
AzdM5hLY3KqNroPRlqKy3+JQ12Hj/3Hpfv5mW/M3n+foN79n1UPAe2j+1LRC
7xdgKdm1nqH4ofoLGpjzwg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0X9MzHEcx/HPSkSa9Et+9ONCpFuTSB3nXnfXqairu+r8KMuajJWFq4XL
+spvCYmtJaFZRUTIj4xdIzVWfmwy//gxMWO4+VV36RvW+/PH9d2+++7xfX7f
n332+Uoyc/VZDoyx1H/3/+fQZVF4pzbfbsoOBL3AxgNXju+QcTvDWql8uVWU
kN1g7cxtldzh9kSx0q1efpzbB786fIM3reGeAqlzuYNWyh0Ap8SwZ4O2AHIg
qqXTb+3s4J6GVRXuHi713EFw/+hqVG3inonHPRfv75NxzwLrX2h44sQtRVVR
WoSm1J8civ6GOz9Eqx95NhpKLZsLD3OH4dQxSfML0Zc8B9YTveemnuMOh1uA
ISM8insuWmNNFbWMex7U1zK6HlyaQo6ALO5puxDAPR+/vYsd1+2cTI7E5eoc
Q3oIdxSiX5lEj+eTyDKor386Oq+EewHuGrp7gvonkhfiXrxnRmoNtxxyWVxY
4GruRSjO+VJS98KHrIBlRruf03puoKK12nGvgSwAy9bW99kceVcisq3IVN0y
gboSB2XiWnUBmakwsFmSkB/JuwpVN76W+I7mXY3Mu2++i9e8qash5Ct+yoLI
LBqd6uUT3/d5UY9G5UP3ltONZKbB6891+cuqeNcgUxtcL47lfbG9hcWY+6y0
YHqLJ/UYhLT7/Dr7lizEQHcwLGTEbt5j4XfLeH3vIw/qsWiM+aYvGEtmcdDI
ewof29ypx6E8y1KeXkdmS5B1stbBdHo89SUwNl3an7SNzJbCt+FPd/p83pci
WDvVU7OB93gYGxYortS4UY/HisqLZ7ykZJaAQaYbXJ03jnoCtBcOabKaXalr
7S1osTKkLLZriwv1RPiLnY8iLWOoJ6LsndGk6h1FPcneGGYhCeGlX3qV5tFD
NifBcvXpwHYvMtOho01ekNfiTPM67CnLlpn8+bzO/nuzjs5/BM3r0dSYeyw0
jc/rsa3I1pp9fiTN6+33Yx5mlmy/PpJhlR4trMshC8n2+zEP6ywFR3Y53ny9
is4HKfbrCSnD5lPofzGaT8W3KJuoCv2tGJrn/qD4C2EDYPs=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJw1yXlI03EYx/EfWjCdOsuzaelGpaksb9s8fh+3ec2JZYeYSEOR/lBRKxEd
zXWhEaJk/eNRHhmFKGhFmFnSgaEglGiyMiUrMrMSTfJcxZ7vAw8Pr+ctyS5M
y7XiOE7xb/9fy/ziXY8+6OvOk4IemHKsKhXGMAsQ+H5iNd8sITti7lRH3fIw
szNcCmovopnZHU0VGSNDRcye4H3EqeshzN54Kg012a17k6WYG7nyYryfeTf8
umRit0rmvWhYVG/apDH7ol2yYZvpyuyHW8emD96c9iIH4EKeplhdziyDio/c
c17EHIiF3s+y+au7yEHISZnHKzlzMEx99W/1pp3kEOgbpa1HdMyheOx/+e6H
WU9yGGqabHvjTjKHI3GsYSNrwoMcAa/sc2vXo5kP4He6hkufE5Pl6H5XPfn6
ErMCK8fvx37fyhwJc1jB2crnO8hRGH4jN/fmMEejvedlW9WoOzkGwgFvfr+e
mYdo4HC7lTszYL/UOJvc6GaxERAYajyGTpC5WBgFIYbFT67UYyEcXSreNJA5
JW6U3DEFSllXIlxs07bQ7EJdBcmWyenFdWfqKujHyuw5HZlTY/WPqrU0gHU1
moxj5aIuJ+pxqL5n4/9kajv1OAQ98vD5WELm4qErzlob+rqNejyigrWVDjoy
l4DTHZF8T6sj9QSU7RtcyU0lc4nIqO9scQlgPRF2Ts9Ki2ZF1JNg5g6ZdWfI
xiTkK2v7HVocqGvQP6j44TtjR12DhnHhyu0wIfVkdHcVXpNlCqgnQxtR8XBG
Zk1di5/y1U2lbJm3dC2E1p3l3+oWLOZSqH/h/wJr8uzj
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdlQlQlGUYxz9F5ZIAxZVTFlACRSwR4pQ/IIcgyH0tLN/usuiIpSKYaeLG
iNeEI8doadkmDXiQio5xmX6ioGRYHoFXugnhkRnkBYhQDe/bzPvtzDc7v+//
/J/neZ/nnV0H5Yp49ViO4+r/ff77Hv30BkqSTjbV5jqCvMDqYvOq+kDKBtju
z01uNqRshlNHbUL4TgfCFiiUJ+UvrqJsieQzz5LkBZRtYaounWPrTVmKqbsM
uja+kBJ2xFfWqkV3LlOeDtm0iYuydlJ2xp4fW0MEnrILikw3Ojf7UZ6JGQvX
Bt2UUHbDPb3ba3tv2RN2x+4L5V+4FVJ+B35nwp3HSCi/i7fvVt6UaKcRngt7
sxfVdaDsgZSKmJbtnXaE52G2pK9y9xrKnjjqcGel6QzKXti3/ac9EadsCb+H
qI6/K608KXvjs4thsdY6G8I+KG73PfblFsq+6DAoVC22peyHkftOjWUV1oT9
sd8twSJ+DOUAGI14LHty14rwfOhd/7pzfjHlQBzscb/xMJUywA88GCiZTFgD
tPdtLpyeZ0n0IHiU29UWfj6V6EG4PWLTJMsnzAXjaebZOkWrhOjB8DoYnxm5
njAXgvaQVKvf+6cQPQRt1zcVF7QR5hbg9SrtxuilVF+A/IZm6blIqofC60nP
rzX6VA/FUOU4hwc/WxA9DLX9Ox5ZgrAmDPKtYY8Czk8mejj0p41LPH+VsCYc
G/ZdOyX5jeoR6F7m6vtmC9UjEOzOV+TxVF+I87HCXk3jJKIvRG6qfpxqN9Uj
UbeyKs19CvVHou2jBf7ZzlSPQkLHtk+v2lE9CrPsJFZLFCQftwglJwxnnb5H
84uYi4Ys/IzR4DGqR+P+Xi/P2+VUj0G5urc8o5rqMTCq7JeHtZgTfTGuq18a
ujQQ1oiYi0VRt7Kku4YwYuFzuUnbqjMj8bFwCFqyrWCYsBCLnjmOHh+4Un8c
qpwib81rJjriEB3W2tIdQP0iXYiDyfJJf2xdRZiLZxnxeDbcmFakT/3xbD4h
HjaWXQ9Ly6g/AQWuFeVlx6k/Ad/17pxj3f4W8ScgJHHIa3wYYSEBh/0dl7qc
MyX+RBy1qam7GkUYiYhdPvPSCytaPxEFTbH+3v3UL4rnkmD+xELSKyE6kkT9
J2G2uUvfniu0/yR2vlwyex4kwzXGySL0fbqvZKw+7Bd4fD/1J6OtY/rz1xPp
/FPY/BCxJkU0vxR801a5xjif9MulIqZmR6j6pAnxp2Jvh/FAlacx8aci92L9
6WsNhIVU2A+3X/LuNSL+NFZHGq7U//L8Rj/1p7H5hTR8f8H3qUvXROJPR8sz
04T0VYSRjvRZpRGX11J/OnpPXHmzYYoh8adj3cbBs7mHJhC/DPYR0T6SQ+OJ
X8bGa2RsvCDDzk169fcyaf8ZuNgS8GF+owHxZ6DduvdxhRnRNRkYcCv7uHo5
rZ+BlyYNnwx50v4z2XlBxJpMkT8THiV/vgoSCHNylHatXh/8Sp/45dhcmuu7
3p6wRs72I8jZ+XJZovllsfvQiFjIEvXPs34pD5O8uX7Xiuh94Nl6vIg1PLsv
Lc+eT+BxIOhcS6sVyacT1eMUbH9Sheg8Cvb8vEK0X1G8VsHuV1Cw/ekUcIrc
1ZF+gO5fyc5DqmR1KFF7ZEWFu4zcD14JtxPjJnjtoPtRsvdPq2T3KSjZfeqU
7H3jVOz9lKrwl8/gcLA7YahQ3dQp+cGW5OdV5P9Lj9QXxWtFLKjY/nUqtj8u
m9WlIkY2O28+m+1fI4rXZrPzEbLZfnQinVOT3zeO1FfDWO/bdY/Lx5D6aqSk
zz2S5zgSOFpfFK+h8X2julZN6r0cZUGk60Q6l0O4Z5SlIoaI+Rw2nyaHzafN
wVjpzEHjw0OkvkjXiZhb8n++fwCYCCVZ
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0n9MzHEcx/HvLuXHietc336qnNhF+p1U1OtOSaXr7sqYMdWw1i9JWKr1
1WhRaBY2NvqjdUs/Nn+wcscOQyIb52e1YZLyI20S11ph9/7Muu/23XeP7/P7
2uef75KsvbrdIo7j0v7e/57WazSW33zNcDVXDnqBsMBfki0RzHOgTZR0iaeX
kCU4vtyzKeceswzDS/NF3heYXeF2bKJqWQ6zJ6arV3UEhzD7oLygfipMxCxH
a03EC3OPD9kXkwfef/SrYV6OwlNljz5uZ1bgx+vOR18imVfAFBzV12jP7I+S
ssV2zxq9yQHYWxiX+SmDOQgxffU81+tFDsZdmbtkTwpzCM42+ykUlsXkUOwv
OZFhLmEOQ0zvns+ZQ57kcCi6s6r69jOvxptrP9pKxcwR0IsKH5Zf9iCvwfef
6rFxH+ZIdAUZimt73MlRqHUO8i0MYI4G97xgX+6QG3ktBuKqK0YymddBmpve
6zDiSo4Br/yQ13qQORZHp/t1DnOZgZ3JRhjvuFgtAPmNWbOrCsicEqfNkprH
Sawr4VWd0zzmzLoKhto6felVnroK5rz+zq5dZG49LnRLbzS0O1Nfj6qe825b
/clcHLS1wStnHZNRj4PqdprXSm8yF49VnzyEebNYj0f5JbORf7+I+gZoAhvk
xa6sb4BU7GIcNLKeAFVARn1RBllIwCHni9zpJtY3zvxe2Ijhc0XKtljWE1Gc
rb+VykupJ2L8RLvLjjEn6kkYDJSHFviRhSRIh0x3WnSsJ6NyIOvkQCvryfBT
L5XF57O+aaaFTYh8Ymi4/05CPQVbtoW0F8kXUk/B9dG6QPeeBdTVeOlYnW1R
O1JX4+JLsaUpXEw9FXVH7Tre7phHPdWmayDyWTEhbplvNTR42vFi7PVv6oIG
Tl9l/ChP55k0cCwKiTZX0nmcFjcfRI0oPrC9FuOOnUcmw8mCduZ5JpvO6WDx
P1Omz5tLex0OV0zczr3iQHsduu6tO1R8Yw7tddAbXvHdnva0T5v5PdLo/7Cj
vY1NNubS8T1yYkoVMB5r3dtYSEfoyW+/lCaL1ab//Q8di1PZ
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1H9MzHEcx/GvE50r9PP0W5dSXYR+6fTjXl2q6/p9sSn5MZb1w7BKUeS7
bGhLrYX5UW2qJR0SExPrOjWZzciWsaUpbCilmNzSsHt/Zt13++67x/d57/fn
/vpKdu1XZwo4jkv6e/97Gq4JuXjznc72XDfQC7xrK+KeBzMLsfhLobZLxGyB
QY11zOgrCdkGAd+z60Zqme3w6UGltySb2QnlBXfvDYYxu0KuCnCwMmF2w8R0
2cOjL1zJ7sjLWHpWd5F5JY5cqc9bo2b2gib/q9VZD2YpJLPjwx39y8mrYH5m
prbzGLMverbNC9R7Mq9FhaL4taTDhbwOuxPG0Cdj9sOCmSveihFnsj9KfkmU
afnMAZja2VQXZM4cCK3Hy8NDNU7kIEzWN/sECpjXw6S8Kqf1lCM5GJ8dg183
ujDLMGmvXXCw3YG8Ad23G3rmS5lDEDmu8iw7bk8ORUtpwj6lI3MYpAPXrYTn
7cjheCAbR141sxzFoZfDN7szAzu6eXuRNZkH/Guc20svLKMeAV1FlWWjG5mP
QFbJ2z0NAtYV6Pxwy2moWUxdgaDJdK+4IVvqkbhQWZ+jKyTzkdiirLIY7rKh
vhEZQgf+vIzMb0SR7SWuqtmaehS2xnSJ9DetqEdhusm09H0EmYuGqHF6e3Sv
JfVohPrFn1yyk8zFoHmF6k2AzoJ6DA57P/6VmUTmlNCEumV5PVpKXQlza13R
gU9kLtaoxxp1FSxHbcQT4iXUVWhzvHa3P471OORrQuS3Gtj5cUjeK336w56d
H4/YqzdaPWrZ/nhMzd5PKzNlPQFNTxoLzQrY/oS553GJWB3mu6nr42LqiUj3
qVY+O2RGPQkrVOcG0ltE1I3MJc81ktHXG1ZUcF9Iv0+G/+mxnxHaRQZrjTqX
guJj+u7c1oU0n4JxmX5W4UvmU3CiOndDyXJTmk/BxO0Xv4/a0j5OjeqR/BLF
T+pQz93Hq43m1TB8nwQ0nwqBq1RvppmRG+ZTYTb/evHnmm8G86n0fz4arP3f
/wAeJjuz
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1AlMFGcUB/DhkCqgUAorrFy7IPEglEsOEffPvdywB8sSDaaKGBFJQI3F
VEZRo9QSjQe2CVUaIhtWJWDaVbHtqpF4QFSItFFbbQWvxIhHrAVcarPvM5lv
ksnkN/9537zvZTKKL2o0FY6CIKz5cP5/tR9jKpn+x97uKiXoBiyXG9WusczT
UdPjMtkgMHti1ejcit5+BdkbKoW7e99BZl9YEhrbv61k9sfX8hafgHDmYNzJ
srR8PhpMVmJbz85dTaeZQ5EXFj7oVscchhUb2p9EZDPPQ1zU+1/PejEvQFNr
elf0zSByOG5tMs24v445ArbF24ZGnwaSI7Fl7uaQumrmKHSE3TX/MR5Ajobv
0op9U3XMMWh7f3HLuUDmWCiqjh1YvcOfvAi60CB58jLmOBROfPelcWwOOR7X
zB79v/QxJ2DT3o1H1UeYE9FTKQvrdGVejJrakRvV7XJyEvZvflze5se8BPsf
/Jnm97cfORkNAVMx69czL4X2zGSkQyyzCt4D967anvqSgam1K3dfeTzbbhHw
KVgd/8hCFlJgVCYc+72E5SkQp8dsfT0iozwVLcfbTMpAspgK091Lh1qHfShP
w+i0w28tLWQxDROzKlUXMliejsjljR0/m7wpT0f3u+YP3ZGFDPiWnx9szmR5
BlrF2/Uepz6jPBPdr+RH69eQxUys3fDuJweDF+VZmF8Q4p1R/SnlWbg6HPpm
wp0sqBFgnhxeFs9yNY6H5NyJvehJeTYUKZV7NtrIYjbyM/sujySzPAddc05Y
BnM9KOcs5GJmbXTS0PaZlOfCMXjBuJvZnfI8xHzz/J8U6wzK87Bvh9OZ+8td
Kc/HgHzs2UFPspiPINvA9YQxlhcgJOfwcJmJ5QVcfSGC1PmJss5plBeieG/U
QuedzpQXIS++wfIwwsluFMHN6WT9swMO9HwR6sxJqp4fBLutnIVirr4YhrLo
U7XKKZW9vpjWe2m3lbOgof3/azc0NJ9Jqtdw79dI1xe00n6hle5P1KKj9zfZ
NX/av1WLr74fOi/7i/oVdNLnoePmpUP4aWeXuOZPqF6HF4njttQIF6rXS/uB
Hvb/pyPV66XrWfXc/EukOTiLJdz+OQsGbv4Gbn4GaT9WA9d/Keobxi9UdZJR
Kp2PWCqdr7VUup5g5OZv5ObP2WqU9iuUffwe/gPbGJ51
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd02tI01EYx/F/m+bMUCtbXmZTu1jOLHPeq/1S52WbumlS2o0aSTLNblpU
y2kZSBcUQ8Ks1G7mRG1lgkuwRKHbVhlZGdH1VRbW3piZVvicF3rgcPic73le
Ht/t+Wk7eBzHJfzb/8+JNSQTZrSZb+r8QBfI/27taAhjFsB67Um0/I8v2RUa
f11h8CNmN+zcktNtV8XsjvxAwZHPOcwi3JG2T7sdwuyDA9B799kz+8G0SCJz
f+BDXohWqTZDUsW8GHvrdMaiXcxLwD+n15vimAPQOuJtXcYxByKt6enPdxVi
chDGH4u/XZIyr0Bhbp679sF8cjDGRozKCC3zSjTXXgktG/Qmh+DkGbO17T6z
FO9PvQmEgjkUH8t2d57mM4fh96+Ao66VInI4HD09tpYsZY5ArLp+QWa1FzkS
47NLapaomKPgoUvilQ96kqNRqw1R3S9mXoWCTvGhlgjm1eC/qOtfU+pBXoM3
QvsbllRmGWZIjm12HHInAxf0ouyrlWQDsD67YXiEz/pa7A/pXV3wZB71tei5
d/lV13YyF4POwfSU1MtC6jHwMwmqe5LJXCyeNVltC/PmUo+FaGADXCvcqMdB
cypYYldKNsShTZY9fCSXdTks2zb8sL2eQ12O6RnTbg11z6Yej4/nw0IHKsmG
eAwrvwiKVawnYJNDfbWXfBb1BERazLW9712pJ+LrW//jy0vIhkQk3WhuXFTj
Qj0JLV5N7c+VZEMSbGMdmSUObF6BArN6VcSwM3UFYteNhtnHkzklcmPKO53r
WFeix+aSnrVnJnUVsiQViZaDTtRVWKCoepnVMIN6Mm42558N2iigPsVcCk5U
6KIOix2op2Di//Kop062IRX7jNEyUz1HXT25Q43r5n7hQ5E9vVdDf7HvrvAD
f8JdaqjCi9o/BZE5DcSJyZHCRnqPKTZopsxrwPMJGHEyjsr+AtUuFdI=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1GtIU2Ecx/Enb80KtNLlfTVNI81MzWu1X/M2L5tzVppaoilqK4b6phR1
pRgF3lp3RTQsbdGkoiyzsJAkTaWMIrpRRpBgaVGCll3Y/3nhDozDZ9/zOw/s
xVZla1S5Zowxxb/P/7vxmpQIt9+4c1UtBn2B/D1x3TWB3AJIh/RezrOryLZg
/eseufdx20G778DBe8e5HaBvLmzYreF2wW1PwZEaKfdKTIiO/vAQcovh8S2n
7sLYSrIHClPz3py+we2JurK8+vha7jVYP23fm7Odey3kj6MCszy5faD+oLAq
HxeRfdFwbvz63mZuP+xP6Az4nMi9AcKLlX6zv93I/vjpa332WCt3AFoLDrk2
xnAHQmquDGHPXMkbkb1xPGWmnDsIuoddXd4LuYOR0e1+uKnLhRyCjohs+5oY
7lCcLDlUO2HJHYaUvLablwedyeF4Iix8e/Mo9yZ4acUFOyK5N0NT9HFkf5sT
eQvubXoVPKrmluB0wQrW6sINVOWs75+pdjRaC8zpXYPTHclsK0ZyZAl7LjlQ
34roRuupdm8yk6L4hKHMuncFdSkE5XXOA5lkFoHObRYWU1+E1CPQYmPm9CuK
zCJxbmBZd4vBnnokZgtbKuT5ZBaFa53Vbg6v7ahHwW9XZfvdDjKLRobASXsm
lPdoOGT2PK2N5j0Gw1mpU99fLqceg52ZD2RpqWQmQ5+yt1HbvYy6DLrcSV1G
O5nFYqznt9Y7mPdY2PpscB7+s5R6HIovh0uunbelHofYSwb96iYb6vG42x/2
Zc3YEurxEM0NDYZMLqKeAPe4U8/TOsjaBNRXmd96t4t3ORrGikul0wupy1FS
MXNfrbeirkB1gzqsVMS7Yv7zLNFknwif6xZWQbW8K9F+54VwwMXSaChR1jza
I3xvTs+b9F4lRDJ5qFBPZklISfM3FIn/SIz7JJN9Eq4aNCd80wW0T5r/PqYy
OV+FxeZXSsZ1C2ivgvH/yIz2Kvq9Ge2TTc5Ppv2U0dpkfA2dmZP6fpL8BZlk
ObM=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJw103lI02Ecx/EfTvMuXXOaV2pioqbO+1r7bN7zgpFEkSVmoFYoTNIQY0Xg
kUmS0B+pYGoHRqWmSxslhW5apmmeXZglUZpKHlQaGX6fBx4eXs8bHnh4eJwz
chUn9DiOk2zO/+vWWJQIU9sft5x0AW3gu7zM/0MEsxGkHuULCmNmCzQtPX+n
GXEmC5B4MySTV89sA1nv/GBfPrM9vqjLvEPEzE7Itmo7WmfA7ILw/uW56lEn
siuOdKd5Hm5ndkPGg5xEXimzO9zXqm5/Tmf2gMH7rJbrgcxe6FnpePXk026y
N7TrdgV+SmZfTC4fk14zZRZB/97QxPEuR7If5O52xj1yZn/8PG2oVS85kAPA
TzM96HOBOXDzPrpsoYA5CCbnenMcGuzJwXB2mguoEDGHYLDvTdNAtx05FGNX
ea1DCuYw1Bqlnx2esCWHoylXtMctljkC/pfn16Tdu8hizA8unRL7Mu+Hrkdc
kN9lQ5ZgfLS4vzyCGcifatBZTlhvWQXUu9TY57WSOSlq1D8uORizLsVb7cOp
caWQugwvZxo24EFWyXAnb+B1VqUV9UikThqUlRaRVZHIzlwp9NnLehQ8tTYr
jdMC6lGIk1dMtR4ic9Hgm1prZjU7qUfDsVPZUfKCzMWgKcxfd6uWTz0GM5oN
lWcwmYtFlKpwQ1RiST0WfWOuy3/MyFwc+F+7nzUrWI/Dfbu76uGEHdTjsU/s
feDprDn1eDT2NZwxzd9OXQ7LOYFwUUhWybFq3nl+PdCMegIGbBe/VVuYUE/A
lYu8Rx/TyFwivZ8x9URUzSiLZGuG1JPg1aa/LaiSrEpCcd2IRjjNo56Mrf+q
Rz0ZyuZwSesNjnoKnf9LstVTsBD6+6/Me1XyD3/MBMU=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd03lIFGEcxvFZjzRF82q980hEVDS19bZ9XI9ddXfV1QosyTJT0AhNMDay
hcpSVBRF0yTTLFKzSDFBLfcfKwJR8iDoQsyCUjxITPPI2N9LuAPD8Jnvy7zv
vMy4nLmgyNLhOE62c/67ao5FIf9o78CzXFfQDYRmdxgFC5kNYZwqs20zZDbD
aEZPTvlHF7IVuPzUrtYuZhv0TiZcn7jC7ICeyg2IRczOSJSsDLzlMbuioYXv
nf3OmeyGOOlQaUc1szsGbZajfE8xe+Daiqq72Y3ZE/JswdCfLSeyN0Jna9v6
Sph9MNzEuzTjwHwIJRbn6nj5B8h+uCn/sjW0h9kfn/hz50/cdiQHIFA5625q
xHwYvvpj485lDmQBEqaW79sKmAMhmbyzmf7enhyEab2y+pFu5mBkO1YUjKUz
h8CypqW//bsdORQvwz8Ejecyh2E1M3ik6qctORwNjUrBr7vMEbinr1a8VjIf
gWhgo0xczCzEXkm4YF7EDBQ7Wj9YnrXRWAWMnpVIM9vJXCRCjsU2lxqzvmPx
BLqfWlMXoaQ6N/SyE1klwkLI+pbIh089CpMeeacf9u2nHoWUplp7pR+Zi8b6
76jWIm8r6tFwK+LVBC5YUo9B/XQ57/OSBfUYzAxuqryCyFwsjHW7lD9qzKnH
4qRBa6N9DJkT42JnmLC71Yy6GLLYV8NfI8icBNtc8nZG4T7qEuSJql6YtphS
j8PzxSpfuxGyKg7mc1b8RT7r8ZgyuZWzJjehHg/548qYrF4yl4CD8XVTaY+M
qCfgzXBEUWG/IXUp7Z8BdSmSy/289G7oUZdBGnS1b8ZHl7oMOs6e68adG0JN
l9P786hrmUuE5n/WoZ6o1ZN2Pw9JCKiYX41Ur2msSqL94zTj1VrmkncbyVrr
1bJaazynwPE0/ycFrts0v4K+n280v4LWu6SxWstcyu7x+O+/T8M2Pw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1H9MzHEcx/Fv1zVZrVWukyRXM6tY+qGSK/e6U9eVS9f5UX6sHxqzykRs
DekyhDHrhzStiCaEEiep1Y3rhwxLSyalMT8yXBa5Tvm1e39s3Pbdd4/v8/P6
/vH949w3bFVv5HEcp/x9/bmbfyMS4Spt07V0D9ADWFYG2x4QM1tj5PW2HXUc
sz36FzR07mlzJwuwT2p/IewEszNCDzfPK0lkdgV/VMbL9mQWIeje465MjtkD
dUP7o7b0iMhzcLHx04BtBfNcrPAcuNubweyJEtFEQKaC2RtBfpOtjY7M86Ff
ICkz6WeTfWCPwNq3m5h9IU8xtkQb3Mh+UCjet1gfZfaHocMYWeXLHIBBo1XO
pYezyAsxXnE6fF0CcyD4pfn+kXzmIESIavXnOl3JwXj5qK21Ko15Eb7n5764
LGAOQWmnXOUyNJO8GBaGoomfScxiuEl/3IgecyGHwutywcvb25nDMNwaVXZq
fAZ5CdIm9mn1ecwSFH7c7LlXzAy4O6dMPhhwNlsD3OwbXejYQeakGDLd4q7k
si5FX29O15FQ1mXIKr6aM1U3nboMdtneqweLyNxSjJra254/E1JfitqVfP7n
T2QuHNr1u5LjM1gPxwlN2DkHGesReG1VMtZw0ol6BKqb+oRdrmROjtT+5ubq
DwLqciT1aRN7sslcJMZTsibztNOoRyI9YUpc6kkyp0DiIflwmJ51xb/nuSis
SbqjWJvAehQqqzqdjj9xpB6NtB3GmxbxZE00Npaf5+0+40B92b/WLIPjO92d
GjXrSjS5FJc3GuypK7HTq7iosJ7MxSDkYdOZ9iHWYxDqr8y3S2b75VBleN//
OoP15XD4IBCOCO2ox6L7Vu+Xp0Yb6rEYud49meM0lboKBwvSF++ePcVsqKAM
zm145WNJ51X0va3M1qlg/n/g0T4O8Wv9r273+Ckx7+OQVSOW1J/laB8HQ4jp
h8xnzNx1/53n1OCJvE02NRO0VyPg2MdvUt242Ro1bCyv7Hpf9Jn2anrfG9qv
+OtfFlNGSw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0H8sFGAcx/ErEi6FLoTyu4QplPzsPufH4XAOoenQSCy18qMIu26WqNVm
XWilZkqn0Q+WWmyN6sofmpnl2lpUM1NNERW66Ifvs9Y927Nnr+f9fP957NIP
xWUu5XA4ot/7z7m4JvhmCe2drTn2oAsYnrfZ7RDArI/SC2W+VYbMxoh816bK
VduReUj0y9V5e4XZAqeay7PbDzNb4+Bw3quBzcy2qJi1qObO2JLt8bXStv5G
H7MjThbtUhs3Mm/A2fd59QoZszMclEPOtxOYXSB9nvpCz4zZDf1GtebTvTZk
dzg1PhFEpDBvQVHVnY0Ro+vJHpifa470yWD2RIYwZ7J7eB3ZC1cNau9klTJv
xSela62My7wN0g6Hsrr71mRv8HqOJcrEzNuh0hw2vaixIvvg8t2qhT2XmH0h
3deTMpbK7Ad1oN7ReI0l2R8NoT96C08wByDh+MukDAFzIBrc4nlxS5h34HEU
Ly2hYS2Zj6BOzekwGTNwTz211fSZxaLlwKrpW/HjnmSOAD6q4yVXOsypC/Bx
b1vZlxYyJwgri1wShxSsB+H6zyabDXVm1IORlTMa3GVElgejv6VvyvHgGuoh
8LY0uDpZT5aHoLE63+QBWA9FunhT0/wK1kNhp/v6zZSGR10Icb5xSY2KLBci
Td2eOlDEehhG9m/y+1mxmnoYZq4tl40ITKmH/295OB5KnbrXc1mPgCJzQiFV
sh6Bgmzlwxgz1kXg6tws/qAwoS6C6VjXo+Y4MicS+a23T0mKWY8EP2laKrZi
PQrRwqeqkUBj6lE40ikJ8JlZST0awTs13suEZHk0Bo0qs2fFRtTFcBDVDCY3
GVIXY9btXKnygAH1GPSoAgsLOvSpx2h1CWLPeLjqlusuGhLkN/vz2xo49F4C
r7Pj3wVds/y/7tIyJxZJyZ638uwXFg0ty2O15mPpvyZpPg6ffefmg9y/0byW
5f/8C3duNIQ=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1H9Qy3Ecx/FvCfMjlySVRL9ITRRblOy11oZZWWuz6pxf59ep82tzSX4M
R+kkRCRU5Mf5eZbGohTqovPraId/cDg6XJEfjX7g9v780Xa32z32/Ly+u9v3
7uu7aJVqiSPHcUn/3v8/ba9Wkbum4saVVD/QF/j2XD+2MYKZh9vGoLAXA5ld
oFb55nS+8iW7ofDUnqauK8weKFc/Wzx/G7M3fExFmQUa5lFIEpxI1foz++GG
14Fj5pZR5ABkB28Rfq9jHo2clyXFH3KZg/Cqo7JtfBxzMIzra5dVejPz0Z2X
0r6yfiQ5FGWDrjlkzmWeAP3R3OWHPJjDsKa0IkBj9CGHQ3Px6sHdMuaJuFRS
Jtj1eQR5EvrvHMnrWsAsQPu7isSiJm+yEG4NGXM2xzNHoKQ7rzCndDh5MlbL
YjOyljJPgbW580/say9yJIwbTh2LzmeOwrZz713yVcxTcfe5/IjkvSc5Gorr
kI49zDwN+tawKlcxswgOkSHmR/2YgcOKABUv18NmA3DSsbggMJLMibHu95jL
9+4Poy5G205pkjSczMXgQlRZvfyjO/UYLKp+/a3rKpmToLrSldd6gHUJzI3J
Jm0y67HoW+t/lP95KPVYSPhNj3rtIHNSPL5QtWu7xY26FBsyQj5YAsmcDAHp
DvnCliHUZZiXLWuOvkvmpsPHrDNlNbI+HeWrdW0p61mfgYcLk762vWB9BqwL
dZ1bK1ifCUXElmtvQ1mfidKyhqF5FlfqchTeOpOu4ZMNcqzQt5sctKzPgqyq
eQWeDKY+CyLt97nxw8mcAs5prp+y17hQV2Dc4KCvR56QuTjozkeJjCdYj8Np
f/nLSbdZj4cyLbjxhyfr8ZCoO4S9ZYOoz4apde94rwdkw2ycFd+pq/d0pq5E
kWWA9bRggM1Q4qezeWuHYCCdVyK14Xr1UzP1GiX2vdVlxvzqS/sE8Mud+gj3
kJEAK3//xjNp/WifgIa66HR9JY/2dp1TwV9eYEk525/2djao7PYqtEz53RUT
2of2iT2NRPq/ONonwvY8c6S93XlOTfe3F+3VPc8b1D2vV6PGpuNPb7q/ofOc
Bgm7w0KcdjjRXmP3+3au0UCbEn5prV+3yLafg4m5X36Ja6yivxcMcJs=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd02lIE2Acx/E50Aw8Sm1q3gc1c1le826/zfvaTDPDEKZh6hS1pSlmuC6h
QN9kHgllUq0yJDUlDW0emZgauIIMIQjUfCGZwnJ2WLH/E9QDDw+f5/s8L/9u
OSWpuVwOhyP5vf+chrUq4qX3PusqdAdd4Ib3iXe3w5hNMamN4yuNmHeguzkz
TjfjRraB27pPn98dZju0ty1Uz1QxO+LtEcGYUTyzK4o8v7Q1ujG7QxhgoS7T
uZI9Mdi2IA+aYt6D0OnGOWUTMx+XNfYT5wqY98HhkZU+Yz+zAPNLDnmtP1zI
Pqh9L8u2VTAfxPLLho5yR2ZfFAtWjONbnMl+KNd6TV/lMPsjo5ufc6zbiRyA
qcfXpfUFzIG4Lx59MW7PLER3vnJwa9qRHIQaqSJirpI5GNa5uYfT/JlDUDjx
dEjb70AORewVdYKtL3MYbr02s7g2u5scjntOxvXao8wR6Nk2O75pynwIzbyV
iWy1PVkEuX5JX2fNDAy/ag+X19oZrAIsNWl3uXZkjhhVZR4lHWJb6mIEw4OL
NR51CYQPUrMSzpJVEuQVLkZqzFmPxMVLo/NNml3UIyFcy+QnfiBzotBSf1Mx
cob1KIQplM3yJzbUo9ErOrlRXURWRUMynObs7cJ6DHpKT69nVlpTj4FJulHP
6qgV9ViMpWhaVQNkVSx8Bxz2fixnPQ6Kso0+owzW41CWrx6S8ViPR8tzdUW6
gPV4yE9lfZv8tJN6At7k6rbz+8mqBCwecPcv9mI9EWbWIxWly5bUE2Gu9AvT
XjCnngSdef/574Fm1JPQ1VnS4HPclHoyqmo2hwsfmlBPhmE+udSlyMj061S6
b4kMXYrPIZs/JT46gzky8iJ12X895V8jBf51K1/FGj29T/n7/xdPmA3s
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HtMjXEcx/GnHJVL1vWkC6fbEs6iOkXC+VQ61bnUubid494WfzgJyawt
PXKNiikWpi2lSLWppeW2I7Nc1hAOQ4S00XDkErmEne9vVs/27NnreT+f/357
/FIztGm2HMdp/97/ntbLIhUuaLpwdq0/6AVSSl7ZKkKZHdDsYerpsGF2Qve0
N8d33PYju6GSX/wit5R5PK4qZwZtXc3sg44kt4H7EmZfpKxc+fKkHbM/nvS2
XXUw+5IDYZ7SeXOglDkI3Aber03FHAx9l6SrXcQ8Bcs1nc/6TSKyGK66grTX
MuYQDD6STDt2biJ5OlxFz+9YjMyhaIryq/W2YQ7D3mSXtOKKCeRw5OctOf10
ErMEPYW+X7JbfcgRUJj7KjwjmCNRel2m9uryJs/AujWPlgvSmWei4VRbap6Y
OQqmwqbpzo+9yLMQID9sNpxijsbg6J2pZSLm2Xiq2yzsPOJJnoO+Cr1JFMY8
F3nGd/uqH44nS1GqDNQ6FDJjqHkgQJW1kF/Gegzyf94zn41jPQYjM8aEp1/z
oB6LG4dqNb3BZH6YuTjoc97HF3wRUo/D5fMuDpYSMjcPfJb086wg1uchss8Q
rHjuTj0eD4KNq6qayXw8Mmx+7KqJZl2GO7WX8reb3ajLsOaQ7SbHcDKXgIkt
med233KlngD9itZEw2Iyl4jJgfbd/QmsJ0JsKapv3s96EhrXZ34ybGE9CcoZ
uc2vQliXI1R2tEXe7kJdjm+V9lu7Y8icAh3SgwKPTmfqCkgXfV6a7E3mlHA0
uvTu2eBEXYmsySXFBxvInApVAfLHklbWVcg8Ey1tOMF6MvRH68rdxawnwxh7
4NK48nHUU/DVsWXbz4ix1FNgabz7K8d9FHU1na/RVkONdi/L2xInMq+GuFFg
F1lkb7VJDev/wZb2GmgKQqcKdgpor0FO2b2LwhcjaK+BKFEVJawZSXsNsnMH
rqytsaO9FtUXHgpv+lCHFosMYfUb/Qel1r0W4YXv+mNM3602afEhauB3bMhX
qzkdxoyoy35b/NFq6IZ2XjdsP8zc/KHfg7mH9v/9BzGPVVM=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzwtMU2cYxvFTxAgWRJi0sKEtDSBaLCIyUXR9ikXuCKW0wGYCZFMMMlGq
w2aM4waSGImTzZGgEFECKBkGHetQ5moQLTpdugkxk+gcixJ2g12K5ea29P2W
tE2a5tf/eb5zTnDRXs1bbhzHvfnv979fx2dCKcrpudpdIgP9gYc2PjJFzuwB
7fEQwTl7MHkp9KLkUclN5mXwfnardrqeOQAl3XW+gl3MQTA/Km7JUDBLMcTb
qkpmpGQZpm9ExZpuM4fA1P/JyjXNzGEIi2wvuFfKHI5LleMzL2KZV+P7IG/x
j4uZI7BDbGpoaZSQFaj3G3E/G8G8FoGGHRaDZQU5CpK03VMnK5jXYb1XzJG7
48vJ0Qg4MzdQWMO8HheDR8p8QpljoCv8sDa1LYj8Kj4wHi5X6pg3QC62fr3Q
9go5FhrfgtmDzcwbIRrL56Qy5k1o8ig49O2Dl8lx0F8fU3m1M29GnPWrcvVO
5i1YUa6W3Z8MJL+G+KuzRxPfY1ZCsEne+40nM7BWap+Paw9wmAcMhWNuV3aS
ORVKW4sWHXlbTF2F3qC8UksomYtH21yHJOy0iHo8iq798Mf8Z2RuK3reMBbo
97C+FSeW7/6lcdSfuhqD96trDgySeTVm9p2pSi9mPcGlJ6DjYf/JpmHWt2Fm
yS7l9QTWt6HaffC2R8My6okwHpI/Gw4l84n4rfTG39G2l6gnoYkfMvp0kfkk
+AnFfU/7WE9G2oYq06iC9WSsCln001Qi6yloeHJM8GjSj3oKTGVteQp/1lNx
5/Oe8/vL2D4VdZc95dce0/VcGlpaLf7Hh9k+DV/eqn38vIr1dKj5irmoWl/q
6fh5ZGV15PtLqWegvDNOeeksmc/AGt/wyUYr69vRuVlWHN7vQ307WgfPHRQa
llDPRPL5rguhp6kjEzbv3sOzMV50fSasXwz99eC50GFzJjpU/QM3A71pn4V8
+YmkexXU4WI+CwN/+mTn76PzzFnO53EauElXTws7qcPFvAb2iPp32/d40l6D
6Lpfp1RmMpcNy8CWdwxXPGifjYnL1rlKf+q8i83ZkMzfvRM7sZj2WmdDi1PD
QntbDHt+Lbq79n6seJ3ON2uRdSxK7l7jTvscCBd8ahz/SED7HPy+cXo+XmFT
OvY59D6zDptdzOloP+kwdPR+dtrrXPY66PPXde2XvaC93tnQo7L5uz7RkwX0
/C42u1zP5TrfD7nOz8Pn0vs8pfu7mMv73/8ANDGrgQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzwlMk2ccx/FXQDk8JqzUCihtnYtHQ2xRLKXaX8thwSKlpYpoGi8SIypR
MaIIvtGEsnkQUJZNZWbCBkowETynSLUBlB2BLcErwah4IJrV6KQQqZvp/zHx
fZM3bz7v9/k/z/vK1uRbcv04jsv5//749F1undh2/srZPDnoBWaHeiOL45iD
4G754a/RAcwTsa5QeenIPRlZBJWuMrnsJLME+trulwN5zFG4OCfTP3w+sxT8
3ZH8CD9mORovDsjdPVLyV0gM0Tfbypm/RlZ/wtu8XOYZuPM6YeAbNfMsdJVJ
TFwgswLdRftaD38bTY6Bprer2hTHPAf2I5G6ca+mkpWwXq70HithVkG2Jb5/
y+AUciw6w65vri9lnoucyrWSVgXzPDx6rJbJm6LIceg1nWgqB/N8aFK7O3gp
sxr73rU+Xb43khyPKYbvV21PZtagqtGR7boVQU6A1S7aX2Vk1mKd64LywHjm
BTheE5Hd2T6ZvBC/t9gfBdQy61C4qVy93coMjBKVvfGOSHzmgfaCisJ8I5nT
Y3rwn9kxTyZR10OskW4dV0zmDDC/PXfrUhLrBvBBsSVv+sTUE6GadGL1ylIy
n4iC4VNypYb1JNTfd1VV94RTT4L23+u9B+xkLhnFK3Tac1msJwt6Ct7XBMie
dYmop+Cs51C/BGRuEfo2zNSMOL6kvggHm4NnX3sQRt2InzWxN+uqybwRLR2O
B549rKfCUxtY0qdnPRUbCjwXRi1jPQ1JfOGI0hFKPQ1hz503GixkbjG0KpNj
wirWFyOkxmNPaWPdhF+mpd2be2MidRN2zuwYys0gc+lYfrTxp3AF6+lo0MrX
z3B9QX0JUk+dOT39OJlfgtCXIrFbPIF6Bur1rrb2yeOpZyDa+8dvancIdTOm
pX3Xk1NPhhlDisrddRuDab0Z/8QPew0xY3x2mlF35ba4M2o0zWdC0RwwJu5Q
IM1norQiT1MUTeYzUfF4W5FhkOwUrOcsiDamx4tP036wCOYtuNm2YEfBr0E0
L+icFcU//n1V/NCf5q1YlqM6s1X+Qeebt8JPOmt4bMN7n51W+p93PnNZGOvf
uOvF4dc+I+vzzgu6U9A5G2IPvhrUO4doXmDeJjjfhm0NCbqmkxx9/9LPOwTm
l37a7z/pPnOB
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdy3ss1WEcx/HfpBEa5XKQEw5ZuZw4co3Oh+N+PUJF1k5nUZQQEaqd1Yio
ZTWWNKSwcm1dLCI2IaMV2br+44zVzDStCzmq+T5/5NmePXs97+/XUp62O1GN
4zi/v/ffu3LmxEaxDzvbjwpAHxC2zDtWujJrIqGh7bXWoiVZD+4queR2N7MB
Yi82jB8qYjaGKEl25nI0sxlklroD9/jMFshO7fR5r7QgCzDhMXW/qJXZGmn7
2rrbC5lt8PtF05hyP/NWpCUjrdGB2Rb8Y17Tgx/NyfawfrMcIyliFsLEarRf
w5zZERW8X8dT2zaTnWBbU1SfJ2QWoXshv4X7xCc7QzV+7crbauYdcH5nMtu3
hdkFOufLy5tzzciu0ODbjBQvbSK7wZknt2nKZnbHwIPBoVw+sweetg7dGak1
JXui1NDROl3IvBMVyTyu1ozZC9kX1OSaHSZkbwSbjr967se8C12ZcYuuj4zJ
YkjbLYL3dDADvcO3vGSFZMUqcz4w5LnYjZzjUfdB1ePZEv46MucL7bFvGaqz
RtR9IeJVH0woJHMSaPRaVdnPGFKXwD1FLLrEI3N+aOGPCWynDaj7Qbq9RpBl
TOb8/7fCH3XKArkkifWAVT0AypRtnksX9KkHwt9befrlwkbqgZjRj0v8Xkzm
gnC9pyEn1p71ICTerFfLr9lAPRhadT8PBPSTFcGY7FpS2Lmx/RBkHWnojjRi
+yGw9DlcfFKlRz0UOvp9OemfdamHokSU+OGGjPUwxFU21xrakxVhWOailmVZ
NM+Fw8FbGNMztZ56OPrndaPjM3SoR8BcNTLsPqdFPQLxdmVBo6e0qUfCKqR8
Ir6R9UgM9nvnZD3RpC5F2WRmvu8PjRVDCvOgcA+ju2tpXoqoUic79QL1FT+T
Ym+8qOWEYFm8sh8F7TXNeV+ufhX/AfuACUo=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0GlIVFEYh/GDtmhamktp5Taa1DCJSzqZmX/3NG3UaTREhZZp0RYsUzOq
2+aXzBCTQiJsKhCnLBWxLHM006xIgjYJVIxWyEYKTdM2fA8x58Jw+c1z33vO
PR6b9qRozRhjWX9//+5TlzFsnqbxTl2ODPQHNgdsUw4Hc1tAX3kuu9ua2xYf
0gvNHZ97kB2QfSz4o+9Fbifks97qgVzuRXDRT7zMUHK7w1Mvvzdkxi2DPtP1
rGuXO9kLO8/tjik8z+0Nr9Ivb2t2cS9B+FV7334Ftxwl5Zfiq967kRXoXlqT
sXATtw+mj1b4+Rpdyb6Q3Wh5PVzG7YfE0MrqW37c/nBIyrw/f9CFHADrxeUN
V1Xcy9HT2tm6o38RORCDNjafbuZxB6FvwKlYJeNW4mSJuvtx20LyCqx+VZdV
H8sdjB65+s2slgXkldBF/3xScII7BG0Nug5zOfcqlA30RToPOpNDYZmbaPuu
jXs1jl9rt9dkcYdh2dHeLKvvTmQg+sZAcdldsgRMbi0q1PbwHg7/31ucW6t4
D8cbz2xdlzfvEdiv9NY2audTj8CFpqFTLpZkFonOkvaC/NZ51CNRIYVenhtB
ZlGofGTXXFXrSD0KQeUd2+PsyCwadtdf7DAedqAejfEfkboCBZnF4OnGDcPf
eu2px0BhLK1tOkNmsUhQHml668N7LGJaPmXj2Vzqa2Blfr3oczlZWoMDS7vG
tCpb6nG40n053ypvDvU4jMy+fXQi0Jp6PIwNzyYPOVpSj0fA6S+j4QYyW4vi
spyVB91mUl+Lhw9CC/KaLagnmFpKgKJh2oygUnqeJaLoyHhbTs0M6oLZOpi5
y8et9BNhU10wUwldRd87TD3JtEOwlIR9+pCweh2bWs8gmCXja/D4rwifEZpP
Nn2/JNiQLOwvBWnp/rV7Zb9pPoXe957mBRtSTNdjajrvMZpXC/tXmz5vEDpb
b7o/CJbWC+sLZhphXrCkEdbXCPOpwvmnmn6PlGp6PgahszTh/NOE8/vvP4p7
nTk=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1GtIU3EYx/GTmqar1LxPS7OMUrPU1LzUfk6nbl5ycyPRFGqGxpIog6AZ
HSmjyCi7aJgUKWpmWVaCFtSMzBmMvNQqwgQDX0iRhaYzu7LnT2yDMT77Ps/5
n50XW7lrn2K3Dcdxqr/vf5/m16TIU9X5qEMTCPoCl415Tq5RzIugrXrZO23L
7IKRNrfUT29Wkt2hVgs3dDYxe2OoJGJceIjZD4ZxZy+DiDkAfUXS2P32zIG4
dTrm9bAhgLwaS1Nbbp2pYV6DF7kD+v0a5rX4Fld/dXQdczD6+uMcmz77k0PR
WuTzZMFx5jDkjm0ylgYxb0Rh4qXQ5rYV5HCUPx/4GKlkjoA6RfO1Z3Q5ORIS
536TtpR5EyQBd5416v3IURC25NROlzBHo/r3+3P9Jl9yDG5cbyw+Vsm8GQ/a
j530EjPHYswgUPMzQnIc0uPLpe67mOMx7TDRXNzhQ05AkF9JfoOceQvWV7wr
FEx5k7fCUayfyNIwi1DvKrIfNHmRgT1LZ5WlLWQeeFp11rUxkPVERLcqCmRa
T+qJaL02fjekgMyJMXb9lcpFyLoYqncLT53UelBPQsJ0z4eqQjKfBHlVeIhd
pTv1ZGhyHeTqWjfqyQhPqeuWGZZRlyBkuadP8U4yL8GQ6Lyd14gr9RTscGio
85WQ+RT0G1dP/VjMeiqkre03g+qdqadie15E+4FAMpdmaT4N35d0V8xHLaYu
xbnjtl2jBU7UpTh8dK5Hc9OeugwnqjVxWn8H6jLoe7ccOvhwEfV0y3k+HV9i
536Jw9h+Bqo/lmnFM2w/A6tkNca8G3Qel2l5PT4TkWc+zyTqHKlnwSCcnLjo
wu4vC6bQ8+Ute1nfho72fRfD8tn+Nqv9bGj0XY+HuwVmIxuDXa+n3s6S+Wxc
MQpMzVFkXTYm7w/+POLB9uUw/1/Y0L4cNgHBc4K2eZF536rr5PS8f5s7p0BZ
W7zoXgNH+wrLzivoeX03W6eAwPb24YkLX2k/x9LIsTo/h36vifat5jklXX+c
9pWW87zScl5nNc+prM7/7z+LfGaR
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0AtIU1Ecx/G7tOdWWtnSymaaYdMsN03nZv5cOufU3EutlWGSVlpUCmVq
NKSCzCwV7SHUKHpYGtg7FrSiB1KTSjJ6oMUsqIgUqXC9Y/9DbBcul8/93v89
hzOrYKO+cATHccv/3v+ermsgUZh92dpREgx6AdPclu/ieOYxUNYMSXg8Zl8I
NKKK53dmkf3gyMr9sr+Z2R8Lizt9ywuYZ0CRUBTKlzIHoXpZwKG33szBaNsb
+7TbHkSeDemaYGjPM8+BtspS07eFOQzNQT+km9TMYlxsPRFmncgcAfHKuIkP
bovIkWgQ19V1rGNegC3VF9prv8wkR8Fa1lGIVmYJKkPLQ8o2MEvhM/zREfIz
kBwNLnq7wLGVOQaBU793v5vOvBArBEUxlrYZ5Fj4r+wfc3AKcxysq796W89N
J8ugsJ3ML/Jhjodc8PtDlWUaWY50eVWaXwGzAscjDH56HnMCGix9zr7iAPIi
jFUrYj4pmRMh22p0jHL6k4GHi/pVejvZDOTtjzjcu5H1JNQ7yiqV36ZST8Ke
ptSRokdkTokJ5eKc3kbWlehsatN9DGN9MV7ev/TiWZmQ+mK0brI/Xls3hXoy
5MWlh/Iv+VFPRvX93DxnBplLQdeqpYNDzydTT0FT6M9l3DEyp8LBN7W83sFJ
1FV431ya1J7IeioMPXtqnwSy+VR0bktWrJ7DuhpRqiPXNXY2r0Z4oDBgzSoy
l4ZTIZoX0bd9qadB1mW13HtN5jTIVN2725/AugZ7JYWvWvJZT8eVgQPzp9kn
UE/HvIRI481346lnYHypRN5dTTZ7mMvE3SEfg2mzgHompPs+fUuyjaW+BMMR
DVWn15PNS9DSwx8+FcOnnoUQTXOP6cw46lk4sNPrWl8emdPCFF6v7iqn76GF
6Jf9QdwA+16Lih3OWyVnR7ls0+KzzPlLGUnmdO6GDiJ1pkx4diTN67D9aPcN
4RsvmtchI3bHVUckmdN7zOvd1zPrsbu+JL5SNJrm9R7zBvf/w4Bck+R8afDv
RNe8gc5r2GWbASOCxE7+uR8uc0bwvdorPjTyaN4IXW1UuPcub1rfwzaj+/64
bHfDw2YP27I99p/jsT7zIO0/h87nK+3/v/8ANC5ybg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0n8s1HEcx/HvGIujjMuvTtxlMskcLr/d63Ac7pCYhZrIVmmr/Cp3ymlr
+aNbyqKl/NEPCTW186sf1DW/5o/aKhXpD5TKjP7AXJZq9/601Wf77LPH5/n5
bJ8/PsK8I2kFZhzH4ff8s5rGgtQxo+PR/UIRaAPdq0FhaaHM6yCs3x71YwOz
HbIVwojIt0IyH6l9KX0BemZnxOq35Ys0zAIYxvft6Y1j9sDpFy3dYgGzCAUl
ri7lRg+yJzS6vIG9/cxeOLh1cuHVRWZvWI/tbI7PZPaB2vmD/7I7sy8krS4L
s5/cyX6oH6y96nuK2R+eI+fnet2YxagY+noi99JmcgBUkVeau8XMgXh/bWV6
14wbOQg51RN8h8fMEhxI514mlTLvwPT+6bkGAXMwFmv4Ou8JATkECTn612ez
mENxYW28ZnhlEzkMkR8vP2+5zRwOeX6M3DKDOQIVNhYZab2u5Ego+6w6m3Yz
R6HJ8GTg0JALWQonzXxIVSkzUHhL7VrmS9YCg7J260mDM3UZZrraxOJ0slaG
kP5KTeNDJ+rRGDhnOF7W50g9GmFe7e/adGQuBo2lzWP+ItZjsNh1pmdpbCP1
WJzMlkbo08naWCQX22nq+vnU5dC8KbflcslaOXLyJqd8vzhQj8NIZ8edoqNk
bRxM/9eeejxsD9vPVh+zox6Pm8M3yngl66krsGTbU7UqsaGuQMMob6VJwqOe
gC2JdaNZzdbUExCom1uWPbWinvhfT4S60vissMWSehKUwZVdU37m1JPgrlCF
OrZYUFfSe82oK1HcGi59cJ2jroKZh4+R17oqNXUV5kONP6P9lkzmkpGZFXCv
SLRGPfnf81wKeOZ31d9qv1NPofufqaf+9S9muQYa
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdzHlI02Ecx/GfVyaKdx5pTqdY2LA8Uue1z3TOYx6zFNEicimCB+YR2UIc
Ih7ogorAKCFQK2YH2kErsyUdZqHYHxlmImVilrYUtcS0Yt8nqAceHl7P+/k+
XorSvfnGHMfF/d5/TsPSi5wyb9/vLuKDLnBwZVdvaTTzZvTrXi9ZWjHbolVf
PH1kwovsiDptaEldO7MLagr1tybymN3RLWpZlYUxeyK3oP3NwJonmQ+Nz5e8
hUFmH1SX8S5mtTL7QvNB+tG7mHkHFv3qKh3FzH5INAN/yp5ZgP6MUJVEyyP7
w2I043i8L/NuKIXjy587PMgBUPbJWtpDmQNxuM1N7z63jRwEWU99s3szczD2
q4f1xgvu5D3I1JlEqTqZQxB2wt560p85FINdNi/7nrqRw1D1Nn2ysZJZiJ4r
zxS1AuZwOEfc7RiY20qOQL+0t2doiDkSO4dmLFJTmaMwll/pkWfKHI3hk8vq
mDZXsgiJ90udF42YgUpheKNDp4vBKoDXrq7dnkLmxNA5dpnnzjpTF6PctWR0
robMxSC7ej6uZcmJegy0L7LvZGWTuVh02c27+N7cQj0WnWcr7LQgcxL03Kj3
cBl3pC5Bg/Jx1fcLZC4OBxTvPwhmHKjHQTHAvxekInNSPD8uiczzZV2Kx3Ld
edU9e+rxOPfw8rFMAVkVD+mDT4UYsaOegNophXrqKlmVAFtBgNvQBuuJeCU6
ber8jvVEVHTfaJIrWU+Cl7ig6ei6LfX/zMkQGZjcYH2IzctwyTtpLLif9WTE
ZqyFmEmtqSfjyaLNvpwyK+op0N8c+Vm9xYJ6CpQ1q4+KNJuop6L+VFH4CZ45
9VTwElKEThoz6mmwNLmmnD1jRD0NWTmB18v5GyJDlyNIPbci1v0wGHJ8Fa6u
x/gvG6xinjZYJ6f/vtF8+r/vkf73/S8QChtK
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd02lIE2Acx/FpymRzoaZTl7cxr7Dc8prZfk6dt/NICsuDQjSXR2lBF6yQ
8CAiNSGtDFNfuBK8SBNEwbNypoYvPIjQJCVIMRTNtML/Q9QDDw+f5/vA8+rv
eC4vIUOfw+Eofu8/595akQuTOrpb1E6gC8gym3h+cmYjNOxeeJLBZTZBw9o0
b+q9I9kcO4PJxp4NzFbwlonHJ7KZbVCX1X7vtIzZAWlnLOqK9JmdUCs6Hz2r
cyAfQjAvqC3pPrMYn/hSw5OpzK7QJd/yKD3C7I6JlSphoQHzYVhbXWywvGZP
9oSkwzHbj8t8FALTdsOqu3ZkL5xyaw5QuzBLMN3Z1r7dZEuW4ser3dt6aczH
8GXEPn9hw4bsjamUd67uOcw+SE1Yrn+byuwLrq14tOTnQbIfHotz13RlzP4Y
MFMX8aOYZWhcWi9SzYjIAXijNyZziWc+jnnnPunTHmtyICJEH8YHQ5hPIP9R
rmq414osx0xt5qUSLTMw45xdNyQmawDDPL40Z8CSehCePTQyGpoga4JQrdr8
mL4rpK5A9+dWm4+NZI0CmerF4F4B68Hw+bo494JrQT0Yir5EOw97c+ohSC1W
LgX2H6AegkSOn67FlPVQRLWtRsb7sh6K0MCFm2NbZtSV6I/rrdG8JmuU8FJW
d0WOsh6G9dJmy5TvptTDMCEvN7CcI3PCYavdnjrry3o4rrhVVpS3mlCPQJkk
Y7YmnayJQP3I86v8wv3UIzElKM7ajBVQj4S+g/sWX2tMPQqCy5KAyTusR0E9
3Nkz2cWnHo1R0cpypQmPejQezBfcUGxwqcfAPjzGX9hkSD0Ge/OpTz0WBdoA
eWsdh3os/b8t3+sq8Pe9vL5csbpnzX/mxP1rxOGb/9aOwnOR3v/1L0k6Bxg=

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd038s1HEcx/HrEqalU37/KE5umMmv/DzudedHOPlxHEXLplVyolWqnZZv
tbVF5MdlWZolreX6qaWWDGetRaZUVH9IKVSM1kbMqOb9+cN9t88+e3ye+7w/
f32dsvIVe/g8Hk/+b/3fl74piaXyYct9lRB0gBHN4nCJF7MxWsXTgpTfTmQB
0saelb5rYTYHd+nDkOoMszXcui36JhXM9mhb0ehSLmR2RHHoZfWOaUeyEAVv
wutqupg3QSxaHMmtZhbh04YTz7X7mF0RX5ggCglkdkfwaoE8byWzB0JUbWb3
mjeSPXG/+oPcKZrZCyaumhDjtxvI3uCH/Uy1O83sg07NQpXIhtkX012ZC9/u
OpD9gF268IlY5i0w//hLffylPdkf7sO6zlNq5gAMxtU1XQBzIAKUvbdf6OzI
QRjffjOqKZs5GL3fv0w2GzCHIHeoIkGksyWLoSx6n7ZbyhyKzjjzTGW9DTkM
qutq26MezBIIS5A6cNGaDIw+uuXtnULmgFozieHrWSvqUhxoyDI6m0fmpFAf
cc7XSlmXIbtwcG89n3UZ0nvX7K/5bEk9HDkBeaacksyFw6jDudZj3IJ6BLrn
xorPXidzEQjMkfiUWrEeCb++0mMuT8ypR+LKY3FG1R0yLwrz1wycRl+xHoWy
gwWNGcmsb4V15tO+sijW9cyLRnL/ufN9DuupR+NPg9HJr9J11GPgoJ3v3xlg
Rj0GBW6aqsomAfVYaMXCbNfOtdRjYWc9PFZRyboczVPlm217TKnLkSsrbzW9
SubFocd26odGYEI9Dh4PDAz9y4yob0PF8OFC2QyZ2wZ10VyHqtGQejxutAxY
dtmvoh6Ppf+XTz0BfEf3udXaeclS1zMvEZNBcwsyz+klQ8+cntsT9eYnwbd0
YkbaPkv3k5CW7nPnkHCR7ictf689afk8nkLvfT1ziuXz21kfkfwFn4063w==

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd0g1ME3cYx/GDgiC1CIgVKyjWTY1WVJggCvZXXgpCUQrXEjvcEo0xvsX5
ghBf8CAxGlEGIchmwnyJb4GVhenWqRjOKIpzLza+xqiJUev7hEVBkfiWPo/J
9ZLL5XPfe/53/+RGL1hZsMhfEITij+enq/foMmptv51sXaYH3cBVXUpjZRI7
GHvruiuCNewwWEL6N/x7YzQ5EoFud4u+iR2Fi5rk08fL2dHQHf3rVkMeOxbm
/ytzr4xi61H/py1pzPNY8hcIvbimI6aVPRYPbwx+6JLY43GhXBXhZ2FPQPFe
4UpNNNuAb6y37/TKo8hxcC47tnWhyJ4Cz3ZTiU3DnoraH2vWRbpGkuOhKTu0
ZZWDnYBvx8Y0jxvM/gp/FO5XtVfFkKchPbreXpHJToSfXHJn8a1ochJqtw1s
elHBno57jnUZYhQ7GRvnBww6s30EeQbGSfol9gz2THROL6kKu6Qjp6Cy6UFY
XQE7FfrSRweux7Nn4W3Tk0tbNw4nG9F+/5f2u9PYQJkU3lDqjvJaAjo7UkvX
niALJuirYL9ez90EZ/ZNz2o/7mlYEvpaXHF4GPU0uOSQrD1PtdTTob78ctW7
crKUjgeBu3pcDUOpZyDxmef2z0FkKQObvjamHBO5Z+LEd4beQn/umbDumDox
YEskdTMqzxfN77OQJTNaX1c/jgL3LBQH66Qfkrln4b8VZ18l9Ayhno0I9bA2
TxtZyoahq7rF9T332ajaefBLp4q7j4UcHJyR0Hm4MYJ6DsynHi+FO5x6LiaF
j+/e7Q6jnot5u537hhrIggV55nMd91O5W3x6HsKfRWq7tKHU8zApNU5s92io
z8HvXTWTdX9zn4PlaTWnQveRhbnK56W5SBf7EwPN3PNxxHSm49xw6siHY2Jt
9j9lano+H2Nydl1zHAnxWs5Hws7nvSZ5IM1bYTgaMCCxOojmrfT/BNO8FS+S
+96lxQ2geSs2/XS5TXtXRfMFsCRtdt2LI8PHko/lAhQ54ltW698bvfOFtH6P
1yiEWuVc/6Su22vJp8vc/ej9onI9iLS/NzQvwj92Qp+6uZ/mRaxpnmn8db9A
8zZlh03ZJZ8u25TrC3alYVd+n2RXfp9sV+5HKPq83w+w4Xob
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxV02tI01EYx/E1SzRdauqal5nXEo3hbZqp8zfv12mKpauWGpZhNqNIQ1/8
RZDIC1hGLyQo1Fmp1byiFWjYxUKLCKfiC4OIUErNS22aZvicFx44HD7ne56X
xyVXnZbH5/F48s39/9xa8+HCjO5n2gJX0AUCla/P5Psym2AtIOVY2S8XsiVK
y2TTzYPMNpCdL666UMssQmj7fPzKcWZHnLL6qShyY3aGUazab3DJmeyKXfr1
2ZheZnfoqltW75YyH4CpynfYI5rZE0KpRqE1YfbCsqDH2KFuP/kQQpMvRix4
MUvQ/i5n+saEE9kH6RXT+tkCZl+k33s6od8Qk/0wUiBZM8pg9kfnzo2J4nVH
cgBUaTNN71XMUvCOnl3qMziQAyHTaVUdscxBKF99oZnR25MPY6Cm28dqkjkY
XX/+LogbmY+gJUPXJS1kDoHIXnuwYtqOHIqH3yTj3zOZwyATerQZhkRkGSwG
0pv5IuZwVPfPTaqq9pGBPseswrceZA4Yv52tbPsopC4Hcnt0N4vJnBx3NPcf
uDqxHgF1zTU761u21De9Y7XyUQiZFwnvN6Llpi821CPR8aTSSTRF5kVBdPr5
p9oY1qMwmpO5sDhhTT0anUWXF5UlZC4a0WFfyz4Y9lKPwVDqQAPXT+Zi0Fuk
yZLYsvlYeIuFdudyWI/F57wVU88+K+pxELeujZ0MInNx0LglTAa8tKQej+Ex
96VVc9bjUeWXN9WQzXoCmoYbr5pd2UM9Aa8WLdKVl8ypJ4Lv7GUwayVziRgT
XM/XKwTUk7a/55KwIugrX5Oy+WQoveviRkvMqCejYcxMr5GSeQqM2M/P1Fvu
pq6A9rG6XnLChHoK5oIN6xESY+op2PrffOqp241U+Nf8+C0f0If/A2AVC5k=

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxd1HlQjAEcxvFVER2sbIvdzVZMl3W0iN2wj87t2K3ddWRUGsRSOWKGQaws
MY6RnJFyjSNXrpU1TeQa46ZCTAxjKjOuITRyTb/fH3pn3nnn837f5533r9dn
yhxjuoNAIDD8Pf9d246PGvG4c/ayDF/QDTx1OuM/X83ujCP3bU6vO7CF2H6y
MWfSYx+yCE6qvG0bD7J7wUvkm5Q9my1DyaA9J9QqtjduTItRzevE9sUBW7mu
4bY3uR8u760a4Lyb7Qflym8Vt8zsAHSy9/RYG8IOQsqM2pdZ3+VkBU5fyE3S
FrEHQhSo+moNYg/G+INV5sl1fcjB+NVSGjdiKlsJ14T343XNXuQhSKpfHlth
ZQ/FTM+bM8Ui9jD0ji5eYiiUkUOQWaq1+UnYw+HvJzdZS6TkEUiefjOlIZWt
Qk3nZVMTZGw1TvusDHhWJCGHIkM2Z+iOUPZIyK+trq5925s8CuIXmosLtrFH
44di89JDmWwNnIPOrxef7UUG7Pv67F4qIVuAjd/StFnVPamPwZACr7JlO8mW
MRCrvbPdcriHYXV+hnqJnHsYbJUu0cXvxNTDofY79eTYBrIlHIfrqrYW1XhS
j0C4ovqe4yqyJQIhBVfNMR7cI6Ftqq3ouk5EPRKyuiQI88mCKOTseXRJ/KoH
9SikrolqHHWVLIhu16PxZlagujWPuxZlnyXFi83ctdhwpkv/inoP6jEQKoKl
d393px4Dl/3fU6OukQWxeJze3CWgnHssXl9qtfQfzvs4RFgWtQbncY+DXbKl
qPyDkHo8Rirj87qmcY/HgO4BnwofcNfBo6HySqmRuw6qu/aS6y+56/Huub91
UC7Zosc6ZfrzXWncExCo7yuKzOJ9ApKd9xVKI/n7E6GZ8CVZLyUjsd37EjGx
8PheTwW5MhE17mvMP/TutDfAPVsZ+iiXDAPcelxZOLexG+3b9UoDTkqP2R7G
URcY/38exv/fbzGi2b18xc9hbrQ3YpPV8UJ9igvtTbgj+di0RUiGCXKtTiU+
2pH2JrT9zxxob4Kr4/HFTQUdaD8WDt5BLa6lPzVt+7H4oGr5FTbwreYPwmQ8
mg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdz38s1HEcx/FvyUVGOvLrzo9D+jFTXBKu7oXjcEc0ZdmlaVrsKros2/XD
NRPZspVVWzvN0rI42dUwFTm1NSsV1bRSKX+IJapLnRnV7v1p47N99tnj89zn
89lHtLdg+77FHMfF/J3/VuuYlLrtaLlrVPuDNlDkLbnIkzDbIcFrIiuIx+yM
ZcWGpJ4BEdkV1W/Hv5obmD2w3vhktr+UWQjRy9b2viRmP9RIeM9fBDD7I6/M
O/zOdz9yIBRjOXk5D5iDsD+9w9xYw7wGWlW+Z90h5nWoPSEc/BjKHAxVb/Yr
nhtzCITut6X2T33JG5CxW7jr0hHmUKQbZEaBxYccBnVF986MemYxMkSVn1zk
zBvR6Nh8OaXHmxyO9w18Q6WceRNu5Wk65nqF5AiU2dnNNBUwb8YF7amqcVvm
SBR3iuOe3ReQo9AarckdkDJHY49z3wg34UWWQK6S+lXombfgS8712ofhzFsx
HGASX+n0JEtRmH3SFKhkBgbvlUdZRjys1gGTqx/52OaTuRg4mvWjCr079Rh0
OUV0dPPJXCy0JdMmdYMb9Vj8bCtrn3qzknocZPohfvsZsi4OoiXvhn7MuFKX
wbn8cO6Hq2SdDMbfVaMeYD0ej1tbbmgKXajHQ1Uqznr9mU89AZ2qVSYfB7Iu
AWtTA1zjD66gLoc006xKFZB1cjQLDG39iuXUE3Gtp+6oQ5ET9USIz47/iumy
p54037okWILPH68/wHoy/Z9HPRmnz6mjjvkupa6AMqKkbTjEhroCDjZN2rHq
RdSVyMwKu6nxn5NauxITkdOzsSFTVnMp9L6F+gJzqXTfN+oLzG1bcH6BubT5
7yHt//k/++QQIw==
           "]]}}, {}}, {{{}, {}, 
         {Hue[0.67, 0.6, 0.6], Thickness[0.005], LineBox[CompressedData["
1:eJxd1nlQU1cYBfCHQkVwYZFFWQwICkKtuOACwglIWGSTECQQQpYyAlZFsUPF
SmNnOihSLSKIWCiIC5RR6wKu4EMLbhWlhYylVcEiqLVuCKJUbTu93x8JMwzz
4+S8+3Jv3r1xUq2OSRnBcdx3//7+9/f/n2f+1pK6s0dXOIP9A72eedobvmRj
dPanPW5478RsBr7cpP7hVfIEfGn+aGrNHrIt8tefuhacSrZH4JDI6NVMsgBW
f00WFxuSnTGcm1ndcEvA7IIyP4cnBZXkqdBO2vBOmkZ2Q4SopblnEXk6LDf2
iraMJnsiJrJovt3ZycwzIJcm5VyLJc+EidtOH+N2R2Yv1HuP428XkWdBdVRZ
NziNPBtGW3cUB9xwYJ6Dyl35tuczyHNR2HLypMcosjdMclrSHarsmedBrQ4+
m25Dno9uw7xd14/ZMS9AtkH9/d3R5IVINmvr455OYvZBsMxfsPlbsi+Cmldt
2OFKXoR3EmuHrbcmMvvB1Kpj3fmdZH+UC9vyIsPIQPX3ZzabODFrgIzdq6Iu
87YsF+LZtEuORmnMGiHG8+L9I2wpD8C6zqrL5rdsWB4Afty8hgsWzFwgnI8Z
lzZHWLM8EOWfVnfOdGbmFuOnP6reYjrli7H+mwkdoQaUB6HD7RPlgZNWLA+C
x3ZRa8C1CSwXwSd9bYniBLNGBPvf4mFWQHkwNpb/cs6625Llwehzf7HeK5qZ
C0HlvstW27UWLA/B0L5ROT1CZi4UDZdy7w59QXkoPBysJy5XUh6Gx5bSlMEt
lIchpezAiA0V5ixfgsyjR7ZEZzNrlsB3VnjuOAXl4fBf9lIWaUd5uF4egUaZ
a5OjKV0/AqKGh+loozwSFg/4C7Ux1I/U60fBPXLKhKCVlEfBzNPLrvU95dHI
0PZfUDqx6yNa7/XRkI3aW2oXxMzr5dxSmFQNyUXNzFiKK1qXl8NjqK9nfqnu
fHAxujli4FD7t1Y2j/ox+Nl/h6HNberHoD1lcLTbaeqLsfv8wSyJJ92/GB9I
DI4/u0jzJdZdP16Mr4+P9mi8S+sXi6BFPZ/feEP9WBwOfhqTNYY+L7G6683H
6q43J8G61IONUdbUl+jen0aiux68RHc+uTgo1iQNX31A7z8OpiMPZT8qpH6c
Xj9Ob/2XYTDvsE3SS+rrWbNM9354vZyLx9CS+8abwun+45EYfN7kzQ80f/G6
88XH684XJ9Wdb0hxrb6uZm0GzZ9Ury9FT7r7wre59Pwl4MM+O42JIXtekQAx
N7/1qDk9zwl4svLHgdmD7PV8AlyyDAq9n1I/UXc8JOJh8VrhIX8aPxEWpjbn
es9RPxGvlZlvN9VRXwaZ8SRNyQIaX4aQsPzOY1IaXwaPS7YD+7qZeRl8B5ru
5MvZfsQlIe3jgc8+msaMJNRkXG9L3Ub7VRJKBXXje/uY+SRsKruZPDGD9jc5
SmuaAgcOMUOOI7GGhs+f0H4ox2l76crLrmw/5eUocyxq3ONH+2systdNWV0r
ZEYy0rSuM0wLaD9OhtjLmPtVTP1kNF3cP0Irpb4C+Weedsq3MgsUqEkvs/Ws
o+spkLnz8MbRPLNCgW2vFCErO+j6CjhdeZ47352dBxUKZPtW+klcmHkFUvfa
uOZaMXcpUNJUPjI3js4PJW72D/E3k5kFSkwObXYsLGeGEucypcPe9cwKJd4X
n1bf66bzSAkv3yrBmwh2flUo4bq9XfR6DTOvRPgpBLmXMHcp0d/9VWVcB51/
KnDtq9aseMAsUMGr1eXU2CFmqFDQdSdw4j1mhQoy08b4PZbsvNWocDzHqHmj
B3OFCq8TTggfGzHzKtT+KVweOYe5S4Wa5tvKRfF0XqvR8vvUlL4iZoEaU8KK
tQnVzFBj7qxazvQEs0INR+G7E2GDNL4aWuMcdZQ9+75QoUbWC2G42IeZV2P8
4JmQZyuYu9TIdxzLtzXY4R9FBI71
           "]]}, 
         {Hue[0.9060679774997897, 0.6, 0.6], Thickness[0.005], 
          LineBox[CompressedData["
1:eJxdmHtcz9cfxz/MJXKpWCTxFZlWIxpi/Hopcs833ZRv+XS/63stcnl82CXG
EpVtyXwxXVyTMESflVxmzJhsGN8R0+y3fRGS22+/x97nj/Pxj8ez1znnfV7v
c877fD9nUGzm3IT2giAktROE////7z+rr2PowWP701xBf0BhwhcdqwMY26Cq
tT4r3oaxHVb0n1pbcWUQcW947ArzKNzMuC8yPW2WNqUw7o8dUxsCfx3NWIWf
v9hR1/BaReyKoW5dHi+vZTwEYec1X7oUMh6KPvN/erI6lPEwzBjsd6NiMON3
UXTlyLXqhoHEnvjQZWOoaxDj4bi4yPlVResAYi9E7qz7atMKxiMhP6t44eTF
eBT21ARll193IfaGQ5Rt+IiVjN/H3ZJDvV+PYjwaxY7uKR9v7U88BtW/HCrJ
DWE8FvXLyj3Kvncm9oEm8UzU/WjG45DTrX7704Z+xOMRHN17TdE0xh9gYMMn
V67ecyKegA3mW223UhlPxM2w3xaftGX8H9SXVZeMLe5L7AvXNQi7WsQYyJmw
9T+hQ4glwFC4d1kXuQ/pk6BdVfxQpyOWJiF5yc3Ebe2Z7oeDxaWT8noy3Q/7
Qjp0ePiXI+n+OLW2LjurlljyR8kPbtM7fcr0yZjs1sPzlj3TJ+PT5dF9dre8
TfoUlB276vhdf2JpClLinywa8Q7TAxAb6F7+uhvTA7Bsvu+E6hCmT4XH6b5P
vv6tN+lToYm9fcfzfi/Sp2H/o35bcpKJpWnoFNrugLXegfTpsPMc6XzhjT3p
0zFZWvRqZC6xMAMTRs3K7SEyfQaO9SvcfORvO9JnYtcE1+Rh9T1Jn4kHN975
aMRKps+Cyb2wYEMVsTQLi91PP0+Yw/TZ6NarLlvbzPrPxhsh6I1oJBYCccia
P6Lf+R6kB+K9icNDau91J30OGh73DI7UdSN9DrrrR31weSXT1Rj4+vw5H2vX
fxlqbGq0fV462pbaK1hWY/CMjY2R5dReCEL5pPqGU040HoLgH/JyTMcANp8g
TK/Yu9OthOYrB+Hrs9uzbI2kC3NhOqae4NNKjLlI98s/3mMr6z8X4ZGj9upd
Wf+5/PhCMD8eFCwFK+IH8/kUQrBmVMKNTSLlGyEoHTzj2vt1bD1CMDvgVEPT
RGI5hB9PCEVj91XJzwOZ/1CF/1DF/EP59RLCEFG8Z+vbnix+GJ8PKYzfP3KY
on849jnvPnxpJukI59dDUrAcDvs/eztaHVn/eVCnv3vuiROLP0+xX+cp/M/j
/QgRfD4QwbeXInh/cgS6pzs8WKVj+zsShl0f+FZtY/Ej+fMhReI9+2EPi39k
/SMV/ecr+itYms+fL1mhCxp+P0DD+5M0/HrIGkX8KEX+o/D49dGIlZ1Z/CiF
/yh+vwnRvF9EK/pH8+stR/P7U1jA1xsswLgLx8ynLKz/An58eQHujXD1XujO
6peIS74bOvT5lVglQtN5W7HzFGKI+CnhaZdhR4hFRXtJRNftrdEBDcRmEanG
1kPtwql+yiJav+68vGkSsUVU1NcY/O7+aPFINdVfVQzOHTpYodcSIwbZb28S
1pUSizH4K+PkE++nrF7HIFjwubDfnuq7OQbv/e4sde1ALMcgqai9sbs3sUXB
QizfXhULT2ve3sPrWPxYfj5iLJZ9dbnG8TcWPxbPYwyvVhwkNsfy85Vj+fvF
EovmjfpJe3zZ/RPH66o4hf84+A0XC/Uiix+HKROblv7QRvmT4mBMLjsxx5HY
HAdt4+O6mEEs/3GwfWtPzh8FtD6WOLjsetmoGcvWPx7ugYN7T8lg6x/Przfi
+fHEeNypeSV5jGXx4xFwvDkVP7L1j4fDfblu11xiOR6G/ftWq3NY/Hi+vggJ
/PlQKRgJ/H4WE/jzJyXwfswJWNkU+1nTbhY/AQmbS9svMbP4ChYS8WVtWXao
J/lRJfL3PRL58yUm8udHSsQJjdu3A2xZ/hP59ZATUZBgLdCUsf2fiB3jvc+U
bWb7PwmtM+/arJjF4ifx+UYS5k+t7dpWyfKfxJ8nKYk/b+Ykfj5yEn8+LUkK
/8m8P1UyzjYOaXnRjflP5tuLyfx8pWSIuqgX391n+U/m10NO5uu3JRmDJiWt
Nr1m9SuFr88qBSOF/z0kpijyr2BziiJ+imL9Fe2FVP73mypV4T8VvuEtmkBn
5j+Vn7+UqoifyudTTuXvG0sqfz6ENP58qNIU669gMQ0eLo5OSTEs/2n8eTSn
8estp/G/Vy1pvF8hXVH/0/Hv9x+Ln87vJzGdH09S6OZ0fr/K6bi9aczo6wVs
/6fzfoQM/jyoMvj5I0PhPwMn1fIm6Sjzr2BzBjQfekf+fJ/Fz8DMAw9nBI1l
9TcDRW6vIoQtrP4uxIWYeQ8f/8Lq70K0tfpvy/ak+wAL+ftFVOjSQjjY9qm5
V8Pq/0L+PpAV7S0LsfJ0eFTbLHb/ZKLvgppLeQHs/snE/ta85r5g8TMhe/j9
d7eexc+EV9SHZcfLWfxMOOy5kmJdzu6/TBQHrmi705Xdf5n8fWnJRNDakR4d
Pmbxtdj8zYT5BXuJ7RSs0qJq3ycD+t4g9tLCY13ABb9zbH5aBJcUOueMpO8t
tRZj/rz36+7OxKIWdrm6+FvbqL1Wy/uXtPx88rXY3vRxrH8i86NF9KqA5okn
af6VWt6PrOXv74taaGz6SV+MY/lWzN+qRW7OyUWtJcy/js+fnY6fr0qHedPW
2d2uZf51uDkvL3ftM+Zfx39/qhW6qIM16PK6ojGka3UI/aXj6lVL2PeqDpmf
LXbqVUCcr8PdjhufHv6c2KzQK3XYUWSwPwJiWYe46zU1ZX8y/zpc7ZR71eUR
86/j18eqYEEP45E6Vf0MYjs9xjyKHDbzFrFKj9VtF3c6vSL20kMy+baMH0rf
69Dz3/NqPRB76OqGbGJRj4OaHDE8nVirR+wJy6PX1ex7X4/iim/9n+whztfj
bNHuoAfD6D3BrMdhuevULQ9Ir9TjxFEHG2shsazHsbtV/W+VEl/8p/25Ph1f
isQWPTRCsKN6PbFVj07Wno3rk9n7gwGuVTbFDbOJ7QzwweD2eESsMvDz81Iw
DDhyLuJQeATzr9BFA1Y0D6q9PZ35N6D0VfnAoSXMvwHfHw7pOsSJ/Ob/M17/
iIwzbsy/gX9fqTRAsvFe/riJ+TdgVJ8tMZpPmH8Dnx+LgfdrNfD5EIx8fu2M
kHuMPV7nQPFURogRYc8/TyP2MqJ7S0nzzBJiGDHg5M3WS7OJ1UZUpG7u63mQ
WDTib6/xs6taiLVGGK9tP2P/M3svMmKra0l/bRXzb0RKo9tw2/XMvyJepRFr
j/59LXoNsWzE+juGJX7PiC8a0THT1jujgdhiRHhieWvbW/S+ZTUiz/tBu2tB
7P3LhP17MwuHzye2M2GKzVsvW/YTq0yI/aZyXN11Yi8Tfr/XYNfiSu9rMOHF
zj8u5i4lVpvQRTfb7u63xKIJ+zwG+Ey2EmtNEH5aqEu7TyyZ8CzO53z+A+J8
E0R/63jpKbHZhGsJxgHxHej9r9KEUpeOeZfDiGUTbqUsWeqziPiiCVl5B8w5
JmKLCWHeVe45ccRWEzoUfxNdcJW9J2ahtPnpR3OuE9tlIXuz25ugH4lVWTjt
f2BMThd6n/T6h6vPnF3sQowsXD/5oiEjglidhbWN4da7nxGLWWinftxl7EZi
bRYyAux7VZ91xv8AzP0OYw==
           "]]}, 
         {Hue[0.1421359549995791, 0.6, 0.6], Thickness[0.005], 
          LineBox[CompressedData["
1:eJxdmXtczGn7x6fWsRbpIUVSybGe5NTmtH2qTTll6HzSdD7XNE3NTJNM7BYW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           "]]}}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0.},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )},
      Epilog->InsetBox[
        FormBox[
         StyleBox[
         "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False],
          TraditionalForm], 
        Scaled[{0.05, 0.95}]],
      Frame->{True, True, False, False},
      FrameLabel->{{
         FormBox["\"Number of individuals\"", TraditionalForm], None}, {
         FormBox["\"\"", TraditionalForm], None}},
      FrameTicks->{{{{0., 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {0.6931471805599453, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {Automatic, Automatic}},
      FrameTicksStyle->{
       FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
      GridLines->{None, None},
      LabelStyle->Directive[12, FontFamily -> "Helvetica"],
      Method->{},
      PlotRange->NCache[{{0, 500}, {
          Log[2], 
          Log[10000]}}, {{0, 500}, {0.6931471805599453, 9.210340371976184}}],
      PlotRangeClipping->True,
      PlotRangePadding->{{None, None}, {None, None}},
      Ticks->{Automatic, {{0., 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {9.210340371976184, 
          FormBox[
           
           TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {0.6931471805599453, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {7.600902459542082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.517193191416238, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.699514748210191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.85366542803745, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.987196820661973, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {9.104979856318357, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}}], {189., -96.24611797498106}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{{{}, {}, 
         {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[0.005], 
          LineBox[CompressedData["
1:eJxdmHtYjdnbxx9Njk2JH9EBlbP6Jafk0PiWKWFkU1GJdudz7Xb7vJPNzOQw
UYRhhrFpCJPIYZzZIofx1oSpvIaRcWaYrTKS5PVes+4/1tM/rs91r3t91/de
d/d65BKTOTfeQhCEsx0E4f///ffHCQL34wyrT/bpnhW9mvIvu+LvCa3tfh7/
MB4kig/BmNUv3via3jIehvkRo8vkrh8Yj4Bd6JGT5akWTMcdi3+4ccru3ieM
PURxT1F8FNPrwHg0LJxHtFr91Mb2H4M5+aPcLL+2ZPGxGBA4a4Ld3o6Mx0G3
pPVc6t5OjL1wudJHrTjRhfF4lJdlrvdYQOwtWj8B7ocsO3mt6cx4IqsHxScx
/10ZT0aVg/nZettujH1E8c+w9n623u8N7TcFA2dsrIvYTeuBf6yPL20b9+m/
bACuHattvtlixeK+qGzqHhyRRXFfnL408eWw+4wFP1jLR0+6scyaxf3ws7lw
pEOVDYtPxayAi5UPfGxZXMTC5/jxSrHKSsHWGz4X5fsjza/wtM12ivtDkjbi
6mt7yg/AB2HOB6miO4sHoMdfvezMdpQ/jfUHxaeJ8gNF+oHYNXDGrbEVFJ+O
57eHfjVyGZ1/Ov7bY9ir765RfAYiO+/4ztG/B4vPEOXPxEmH9VuP/035M9Hv
p7a6yPFsvfAFv97whWj/WZg8+ovlNlLaf5YoPwguvokrle2UH4QJ1SeNFxso
f7Zo/9ki/xJ8Mzr+9vdSxpCI6inh62eSYLfv+cqL9uy+hTk8Yw4i3NYGVmtY
/xjm8P1mEq0X5vL9g7kY0F511dvM1hvm8v1tErEQzO+PYKRePnbmxnHSD+b7
2RTM95MQgqkhbV4dAxgjBHXWK5LeBlE/h/DrTSGi+oWK6hcK67Sez1dkUb1D
oRy+vmjdQcamUIR/t297b3fKn8cz5vHrDfP4/jOJWJjP9x/m8/1hmI/rU9ZZ
9rnD2DSfzTfqnzDYuo9yrP5A+WGI37rLQm+kfFHcFIZ/VpX1WdhM+eEYdcJx
6J/Kniw/HLK6popoF8aGcAScfpqCa5Qfjs1nS9Sh7iwuRKDlx865D3wpPwKK
pJIzs+0oP0KUH8H7FRbgp8muScPOs/7EAv5+DAugPCmZ7N1C97dAVP9IaIdf
ehs/m+ofid/i/+k67Dj5jxTpR+LRSNcxGcNJfyFfLyzEsgcxqx+UUv5CUf0X
iuq3iN8fi/i4YRHun3pvcBvP6mFahG7FLYsCKik/Ctnl+1dKdJQfxccNUaL7
i+LrLUj5+3IWMaQ4Ezn4XH8rxlIpLkhM3xtO0P2I2CiFn4d0vVz6H6YnxfBB
nR+8mca4QQp385qyowWMhWiER1UERoQxdo7m8xHN3mfG0mhUR4e9avpfxoZo
dO5vGXLhOmNjNDYMfh8ubCP9aJQ3OmzTJZF+NJ5ulPvum0L6MSiKNxdFlpD/
GHQK7XDIfJ78x8Df50HOr63kPwZu/ezsE6PJfwweD2/UjpKQfgxiLrueGGMg
/RhExvx53/0J6YtYiIVkpNFV0bcX04/F1mOTFxSVMUYsakpPr/yyjrE0Fm3F
li6PaxgbYhH7+6lTJX8xNsYis8O7vL2TejP9WJwb+NUwwZVxQywWL5gy+XAI
YyEOU91rf/3ka8bOcdi85oeUChVjxLHvG8bSOPY9Ysf04xApBNtJ1jI2xqGT
uXvd2iTGpjhMHHLgZulqxg1x2PV+94AhWxgL8aiaGmb/sIX04xHl5dPpThXp
xyNztdb+P0WkH48/wtYsz39D/uPhVXQhaXpPFjfG8/5MonhDPN7ZJE4550/+
EzBigXflmdmkn8DnIwFXW5+syttJ+glwsbzT0NRG+gmICRq+u/1T0k/A2Our
1YNPsLgpgb+/hgQEb1nvqBtF+olIjnutGTmU9BNxQub+JtiC9BN5PWkiwgIL
bP88S/qJ8Prr0Z3SzqSfKNJPxMH9ef373ib9RL4eQhJ/HuckeC78suT0buq/
JF5PmoT6Tsvr+zWSfhLfr8Yk/vymJL4fG5J4v0Iy3AoCqv2uUv8no2/Uqetr
Akg/GcGCd3V5D9JPhsnN70WpnPSTMUjdocjrb/r9E603JaPnvtpkcy75F7GQ
gqBsW/3GStJPgdPvH9+8taSfgsAZ+bcOhpN+Cv772NHQzZL0U6Cv1VoLUvKf
gtaWqTvU7qSfwp+3IYXvByGVr6+ziJHK95dUxIZUUf+n8vPAlIrAZ/VnbL4h
/VT+PEIabJdnxd3dQfpp/HxBGtwu9X394z3yL4ob0pBX9a19mDvpp8E850bB
Bi+6/zRcK/21aVA63X8afz4hnffjnM7fB9JF+un8fgYRG9P5eWVKx8rWmr32
70k/HUu31kTZy2j+ZGDpU5ezf05n7JyBV0fnBg/8jDEycPqv4KDZxYylGWhq
vVh5+xbNvwz0X5Gyp7l3H6afgby1qRP1AxibMnDPLb7Cyp1xQwaOmrpN2/ac
9DPRlOcf5j+axZ0zUXmu+KYphjEykb2+bHFXE2NpJo7YP7rbfJexIRPbXbc4
yQ6SfiYGd60O83hI+pk4uaP/lhyHvkw/EwsL3Df/kclYkMHO935aqYqxrQye
zm/bJ5UwdpYhP7Rb4PX9jD1leORa/Dp+C2PIsHWxU8LOIsYSGUbU7evZZRNj
qYhlMnT1u/wsKJWxQYaVbTfqyqcyLpShdmZFxD0XxkYZ5ifsbmn9hPEBGZyM
6Y9DTpM/GV+PGhl6ByWMf3SU6i1Dy1Gr+U6XGZtluNBLrXVuZCxk8fm2WWjc
ZNWe/zfdRxa/3jMLUTNP4VQF3U8W9qRs7et+hLEkC/kT2xOmqum+stj/vxnL
ROsNWbCb6Cz/dDHjwiy+H4xZvN8DWVjzRhqYXkv+ReepycLKDdM6Dqgh/1ns
7wnkX6QvyGGjGTHvjyLyL8fzuIPLGkvJv5zfz1PO1wtyJNu0hKSXkH85jBu6
dLl0nfx/3O/w1ruee8m/HGOK+pXnbib/cpw7v9OiLpz8yxG++KV//mv6npBj
f4il5auXjA/I4WJc2su3ir4v5Aje/OG+xIn8y5E36mj/egn5F7FZtF7I5n8/
bbMRVC25UJJE/rPRJbfA8Zco8p+NtdP6eOjqaT5k48yJnl3M6xlLsoGYn+vX
qWleZPPzRZaN0X22RUfm0fwQcaGIjdnwj79/KH8T+c/G0at9OrZJyX82rG40
Z7XnMq7JFn1vZeMH5e5bnq6MzaLzCAp47Zm7cIaesa0C2sJetdM70DxU8N9n
ngqkjM+wMYSSfwX7+xX5V/Dnlyr470OZgp+/BgUifrVO3nyP/CtwMr+wRF9O
/hWi+1cg5kxDY/th8q+AocuY3KYH5F/B90/Dx/0eHnS6u4v8K3B1eMYBpzby
r+T7wVbJz2dnJd7LXWYpven+lTB0f/PVonHU/0pUzNw94lok9b8oLlXy/SNT
8v1mUOLId7t813Sn/leio6Kf25Jj5F/J1+uAkn+PTKL1NUpsmnBy44sK8i/a
3yzyJ6jgjYEWaKT7V0HSfPjKsc+p/1WQ26fXv1hC/lWwbt7ydOYW8q9CaX2/
hpIfyb+Kf4+kKvTuM86tahn5V/HzxqBCx0yrMemV5F+FDymxKy4/pvmngmLM
RR9lFc0/Fbb0mNLp2luafyqoyvuvC71Dv/8qdDcF77ToS+/dx/xbxZd73CT/
Kn5+CWr+fLZqSMPnvf02lfyrEe7qbbw5j/yr+fkF0XqJGgU3bL/5nxnkX42K
/IIexa7kX83PL4MaNzdII0prqP/V2Hn73o3aFrp/Nf89cUCNKxtK5zwfRv7V
ULYO3X/lF/Kvxr7AW4/kHci/GjNLVoVZ2TA2f9S/8mq593B6/zVYNOJ1c+oA
ev816N5cFvxiNL3/GjwNq9K81ND7r4F56KX+HZPp/dfgomKtJjOQ3n8NSn8L
0/4eRu+/BlYm5ykj9fT+a6CbvP2z0EH0/msw4fiSu7096P3X8N8jRg02fTFo
bpfV9P5rUNPUYqqJYmzSoKzHL4+e7mBcI9Jr0KBD4fX2p0vJvwadneIe+hSQ
fy36jVleOyCG/GvR0eLDqcFfkX8tFNFPLE4kkH8tdh6sLF5xg/xr0bjVI+CY
tT3zr4Xjyon7bw9iLNVizyOPm0/CGMu0MG6eMGR5JGODFg8+X7HkZTTjwo96
5lGne/oyNmqhSS/wVgYzPqBFW4fGxGMRjE1a+J1sWzUtl3GNFu/2PqtZnsO4
QYtD63I9Cr9nbNZiS7FD2C8XGQs6HD309cTonxnb6hCV0XPiG3cH5l+HM/Pq
Hgx5x+KeOrSH2vX75iZj6PBtch9huxNbL9Fh5LyxAxubyb8OfR3Kh37ZQP51
GFCZV1v/iPyL9i8UsfHj/j19zpbdJ/86POv/fooshemZdCgJrT88Lp1xjQ4F
S6POz8lh3KDDzsxRA4dMY2zWYU/lnWifMMaCHqFLbs6P9WVsq8dPz30Tg8aS
fz0uSXZfz/2MsaceFl2/9F45jDH0EIqWr9rsSv71OK/ZmLvNjrFUz9dDJso3
6Pl6F+oRsvTDtd/8GBv1cKt+0jUoiPEBPXQz+rQ7KMi/HsEb/L8tW0z+9eiW
+XDZksvkX4+l707vevaW/Otxv8H90KTRjsx/DlZUpdtlDWJsm4PEfqvlNQsZ
O+egMbKlu38sY88c7C8fNKT7YsbIQbe887scihhLcuBzpNp61y5H/B/BWp3x

           "]]}}, {}}, {{{}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{6., 0.}, {7., 0.6931471805599453}, {8., 
           0.6931471805599453}, {9., 0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEqDgwoQM3hveWvf056z+whfA0Hbua1Va8mf4Ty
tdD4Og5MClq/uFf/gfL1HMRCt+7emM0ENdfAITzKaF2R0n+ovKGDce/b744H
fkL5RmjqjR2KV1vbb1rEAOWbOCzffV3slAwrlG/qENhjqM3SygLlm6HJmzv4
mNdvf6zHDOVboPEt0dxjBfUPI1TeGs19Nmj+tYWHFwBulEpq
           "]]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{24., 0.}, {25., 0.}, {26., 0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{224., 0.}, {225., 1.0986122886681098`}, {226., 0.}, {227.,
            0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{239., 0.}, {240., 1.0986122886681098`}, {241., 
           1.6094379124341003`}, {242., 1.791759469228055}, {243., 
           1.9459101490553132`}, {244., 1.6094379124341003`}, {245., 
           1.0986122886681098`}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{312., 0.}, {313., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{362., 0.}, {363., 0.}, {364., 0.}, {365., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQYbyhwYkMGBMof3lr/+Oek9swfzL5Q5GPe+/e54
4CeE/wBN/gOM/w3CZyhHlRcoRzVfAY1vgKbeAY0fgMZPQNNfgCbfUO7Azby2
6tXkjxD+BDT+AjT1G8pR/XcAjX8BTf0DNP4HNPMZKlDDQ6AC1TwFNHmDClT9
DhVw/wEAJGOA6w==
           "]]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{392., 0.}, {393., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{397., 0.}, {398., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{428., 0.}, {429., 1.0986122886681098`}, {430., 
           1.0986122886681098`}, {431., 1.6094379124341003`}, {432., 
           1.6094379124341003`}, {433., 1.791759469228055}, {434., 
           2.0794415416798357`}, {435., 1.3862943611198906`}, {436., 
           1.0986122886681098`}, {437., 1.6094379124341003`}, {438., 
           1.3862943611198906`}, {439., 0.6931471805599453}, {440., 
           1.3862943611198906`}, {441., 1.6094379124341003`}, {442., 
           1.3862943611198906`}, {443., 
           1.0986122886681098`}}]}}, {}}, {{{}, {}, 
         {GrayLevel[0.5], Thickness[0.005], LineBox[CompressedData["
1:eJxd0n9MzHEcx/GPU6jDiu4biuqGpdqhXPqBexWl0uXqru5qjBnDRAuNJfOd
H2l+DjM/wsgUmfNr5Ed/fDGGJfohbGiGjPyItbj8tnt/bN/Pd7vdHvf8fL7f
z/u7C5lTkDVPwxhb8Pfz79t9dZik7AtXzy7Sg37AO8fiSQviufsgpSJ12MVe
3D7Y335iretBCNkPaD/+3Psg9yAsDB9c2iOfOxBhZZWvy6O4g/G0NC70ys9g
sh77jkgR8xu5h6Mk7mPF5oPcI/HmxeEhtgLuUFS3tZhOJ3CHYUT0Za8ab+4I
xOhWfDReCCIbsK5+9n2tiXsMSm6/XTl79zDyWCQF9H4YEcMdiSMBZa0ZT4aS
o3DUa8+Z+SXc4+BtmV43ayC3EbaXTsPbo4HkaBwwoLnBwT0ezmMzQz74cseg
0XnYXlMdQI6Frex63fIJ3HHoLLhvziscQo7Hvv3Fxs5Dg8kT0HG+4edqHfdE
1C7L/R59cRB5Ejw1v2tHrOc24cte7a8tn/zJgM7fGH5vLVkGrt04pmnJ5T0B
25t8Ntel8Z6AnMrySHtf3hMxg1klyw6JeiKGFzY8cenIbDLeb6s/Z2rUUZ+M
O83rNxTdIbMpaG2vKrIf4H0KnEOb9GFv/KgnwWdj4dzWCrKcBCuLqT/ry3sy
VujK2fbKgdSTkT5+Tc1LA5lNhfv/PID6VHRtcvrP7PSlnoJG004P/2dkOQXN
87q8Qi/znoq20fqoJaN4T0W//AHtZYU+1NNgTr5189VEspwG3/d+UofUn/o0
teVpaLj0sPPxNy31dJS3aF2VRrKcjqitH74mKF7Uzer1shmuiJ0lVfm8Z6gt
Z9C8GurTYc+LdC7V/za5u2BmgbbnqeJ3u3q418MCTXBYt/bkD1pvwafY7l+J
hi63FYuwPxPLTsabzlUw2p+JzC1jwz02eNB5BCuZKN2xKG5VUG86XxaCUsyx
UrUn7c/C6kNNtdKLnrRf6EoWqq4+ku4GkplVPS+s6nlkq/q8ipXer4vOb6P1
n92GjeZto/mFrtjoufzKVhuCZcFKtvr+LEd4fo76fcs56vWK0JldPR/swn67
el5FMHMIz3cI8zuE8wtmucL8guVc4fxCZ3n//QeB/Zjc
           "]]}}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0.},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )},
      Epilog->InsetBox[
        FormBox[
         StyleBox[
         "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False],
          TraditionalForm], 
        Scaled[{0.05, 0.95}]],
      Frame->{True, True, False, False},
      FrameLabel->{{
         FormBox["\"Number of copies of allele\"", TraditionalForm], None}, {
         FormBox["\"Generation\"", TraditionalForm], None}},
      FrameTicks->{{{{0., 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {0.6931471805599453, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {Automatic, Automatic}},
      GridLines->{None, None},
      LabelStyle->Directive[12, FontFamily -> "Helvetica"],
      Method->{},
      PlotRange->{{0, 500}, {0., 9.210340371976184}},
      PlotRangeClipping->True,
      PlotRangePadding->{{None, None}, {None, None}},
      Ticks->{Automatic, {{0., 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {9.210340371976184, 
          FormBox[
           
           TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {0.6931471805599453, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {7.600902459542082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.517193191416238, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.699514748210191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.85366542803745, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.987196820661973, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {9.104979856318357, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}}], {189., -288.73835392494317`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->350,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.784903228687543*^9, 3.7849032951941557`*^9}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2-step rescue (figure 2)", "Subsection",
 CellChangeTimes->{{3.743877527720035*^9, 3.7438775322050953`*^9}, {
  3.745607103583041*^9, 3.745607110055229*^9}, {3.7516382882313538`*^9, 
  3.7516382998958263`*^9}, {3.75164467119193*^9, 3.751644675606662*^9}, {
  3.769379738895834*^9, 3.769379742095487*^9}}],

Cell[CellGroupData[{

Cell["\<\
Population size dynamics (panel A)\
\>", "Subsubsection",
 CellChangeTimes->{{3.7516446783511543`*^9, 3.75164468589506*^9}, 
   3.7516460939453497`*^9, {3.784903216083439*^9, 3.784903219291803*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"n0", "=", "\"\<10000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "\"\<4\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", "\"\<0.010000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "\"\<0.01000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "\"\<0.50\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", "\"\<-0.30\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mutmax", "=", "\"\<2\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"intrep", "=", "500"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"endrep", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nrescued", "=", "1000"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Import", "[", 
        RowBox[{
        "datadir", "<>", "\"\<alleles_N\>\"", "<>", "n0", "<>", "\"\<_n\>\"", 
         "<>", "n", "<>", "\"\<_U\>\"", "<>", "U", "<>", "\"\<_Es\>\"", "<>", 
         "Es", "<>", "\"\<_mmax\>\"", "<>", "mmax", "<>", "\"\<_mwt\>\"", "<>",
          "mwt", "<>", "\"\<_mutmax\>\"", "<>", "mutmax", "<>", 
         "\"\<_rep\>\"", "<>", 
         RowBox[{"ToString", "[", "rep", "]"}], "<>", "\"\<.csv\>\""}], "]"}],
        "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"rep", ",", "intrep", ",", "endrep"}], "}"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rescued", "=", 
   RowBox[{"Select", "[", 
    RowBox[{"data", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", 
         RowBox[{"-", "1"}], "]"}], "]"}], ">", "1000"}], "&"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"extinct", "=", 
    RowBox[{"Select", "[", 
     RowBox[{"data", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", 
          RowBox[{"-", "1"}], "]"}], "]"}], "<", "1000"}], "&"}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"genmax", "=", "150"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nmax", "=", "n0"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fig2a", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
      RowBox[{"extinct", ",", "\[IndentingNewLine]", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "genmax"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "nmax"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\>\"", ",", "\"\<Number of individuals\>\""}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", "Gray"}], ",", "\[IndentingNewLine]", 
       RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"FrameTicksStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontColor", "\[Rule]", "White"}], ",", "Automatic", ",", 
          "Automatic", ",", "Automatic"}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<A\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ListLogPlot", "[", 
      RowBox[{"rescued", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Thickness", "[", "0.005", "]"}]}]}], "\[IndentingNewLine]", 
      "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "genmax"}], "}"}], ",", 
        RowBox[{"Log", "@", 
         RowBox[{"{", 
          RowBox[{"2", ",", 
           SuperscriptBox["10", "4"]}], "}"}]}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "n0", ",", "n", ",", "U", ",", "Es", ",", "mmax", ",", "mwt", ",", "r", ",",
    "mutmax", ",", "nreps", ",", "genmax", ",", "nmax", ",", "nrescued"}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.74267566307705*^9, 3.742675738028081*^9}, {
   3.742675793382869*^9, 3.7426757941699123`*^9}, {3.7426758242657747`*^9, 
   3.7426758650463943`*^9}, {3.7426786610125723`*^9, 3.742678707278528*^9}, {
   3.742678865359585*^9, 3.7426788708994293`*^9}, {3.7431786248700647`*^9, 
   3.74317867251116*^9}, {3.743178774984033*^9, 3.743178793853217*^9}, {
   3.7431788660578403`*^9, 3.743178966613968*^9}, {3.743179006583357*^9, 
   3.743179036592964*^9}, {3.743179072719985*^9, 3.743179135126026*^9}, {
   3.743179179293623*^9, 3.743179217109619*^9}, {3.7431792852033854`*^9, 
   3.7431793547671432`*^9}, {3.7431795886138687`*^9, 3.743179665943205*^9}, {
   3.7431796963860826`*^9, 3.743179703976123*^9}, {3.743180184364689*^9, 
   3.743180184726823*^9}, {3.7432776211771593`*^9, 3.743277700536654*^9}, {
   3.7432777376714373`*^9, 3.743277919986001*^9}, 3.743278353152574*^9, {
   3.743278802125987*^9, 3.743278805400436*^9}, {3.743279048593625*^9, 
   3.743279076393252*^9}, {3.743279166224839*^9, 3.743279168335823*^9}, {
   3.7432792160679407`*^9, 3.743279240129554*^9}, {3.7432795039697323`*^9, 
   3.743279517934054*^9}, {3.743279693387833*^9, 3.7432797386881723`*^9}, {
   3.7438764370845757`*^9, 3.7438764425864573`*^9}, {3.743876481903409*^9, 
   3.743876520919177*^9}, 3.743876570192697*^9, {3.74387660075054*^9, 
   3.7438766008485327`*^9}, {3.743876634210388*^9, 3.7438767564934883`*^9}, {
   3.743876792932558*^9, 3.743876860830018*^9}, {3.743876897126893*^9, 
   3.743876900159235*^9}, {3.743876940413685*^9, 3.743877121718658*^9}, {
   3.7438771591939993`*^9, 3.743877232237978*^9}, 3.7438773082588673`*^9, {
   3.743877547277384*^9, 3.743877581979311*^9}, {3.743878040253003*^9, 
   3.743878115025879*^9}, {3.743878153740271*^9, 3.7438781782680902`*^9}, {
   3.743878209228674*^9, 3.743878398281269*^9}, 3.751032035597732*^9, {
   3.751557238208597*^9, 3.7515572413785*^9}, {3.751642266425297*^9, 
   3.751642291780004*^9}, {3.751642405407435*^9, 3.751642413424761*^9}, {
   3.751642944368513*^9, 3.751642965276479*^9}, {3.751643006499929*^9, 
   3.751643017830043*^9}, {3.75164310796072*^9, 3.75164319536602*^9}, {
   3.751643244195443*^9, 3.751643244919682*^9}, {3.751644767108191*^9, 
   3.751644853831896*^9}, {3.751645517439378*^9, 3.7516455175628643`*^9}, 
   3.75631537536548*^9, {3.756315405600951*^9, 3.756315441682131*^9}, {
   3.756330489799994*^9, 3.756330569589353*^9}, {3.756336972139967*^9, 
   3.756336975148402*^9}, {3.7563370739258347`*^9, 3.7563370750509577`*^9}, 
   3.756337141900384*^9, 3.756384448538844*^9, {3.756390435548498*^9, 
   3.756390460794273*^9}, {3.7563905153381023`*^9, 3.756390538339911*^9}, {
   3.756390573411551*^9, 3.756390603082069*^9}, {3.756390645861824*^9, 
   3.756390669016223*^9}, {3.7563907145658407`*^9, 3.7563907190688457`*^9}, {
   3.7563907756692057`*^9, 3.756390777229246*^9}, {3.7563909270712852`*^9, 
   3.756390927543696*^9}, {3.756491818301785*^9, 3.7564918866254997`*^9}, {
   3.756492188900586*^9, 3.7564922412115183`*^9}, {3.76420257121325*^9, 
   3.764202581590489*^9}, {3.764202665840166*^9, 3.7642026674351587`*^9}, {
   3.764249973555937*^9, 3.764250005225993*^9}, 3.769183496035779*^9, {
   3.771543381033948*^9, 3.771543421430882*^9}, {3.7715436727183723`*^9, 
   3.771543679631844*^9}, 3.782251431169677*^9, {3.784900552337418*^9, 
   3.784900559230588*^9}, 3.784903232484737*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwiHH4eFrogiKUz+Gguttj
kosJjC/gcLhDZN77pQpQvohDp7hdR68wjC/h0Ff/2s2AQR7Kl3GI6bgrIrxH
FspXcFjw16LbolUGyldyCOk4dKbERhrKV3F4MvVI8wt9KShfzeGr0PeUI2qS
UL6Gg85mFjazPnEoX8uhodT+i5WaGJSv47BO9rKS1nMRKF/PQaWccbLZe2Eo
38DBe/NHr0BzGN/QoeDa50OJikJQvpEDj/Ch8oKX/FC+scO2DxP0pc7yQfkm
DiscDx89JskL5Zs6KHtNuxa1ggvKN3M4K/Xh1RQBGN/cYeLj4mqn7+xQvoWD
vIevpdgqVijf0sHHvH77Yz1mKN/KITzKaF2R0n97CN/aoXi1tf2mRQxQeRsH
bua1Va8mM0L5tmjydmj67R3eW/7656T3zB4AskF0Pw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVw2JXt9LX3miKUz+GwIrDq
pbQNjC/gsKk3YffLqQpQvohDmZOV36Pf8lC+hIM8h8LszKtyUL6Mw12xN7nR
M2ShfAUHqeXB079myED5Sg6Nv/cue/VTCspXcShrZ0ri2CEJ5as5HDy9yCah
TQLK13D48C217sFCcShfy2HWyoPOX9eKQfk6DvmMv9tWWYtC+XoOQmuvZn6o
E4HyDRyeZGla/W0XhvINHfYeb7//o14IyjdyEHpx4NDqIEEo39hhvfSa7Ze8
+aF8EwddW72Q/c94oXxThw+bL/6tFeWE8s0cIOHJBOWbOxj3vv3ueOCnPYRv
gca3dOBmXlv1avJHewDSbWr/
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw8LASXqt9XhHK53DoLNm+
464tjC/gYON5z3LdPAUoX8QhTFXvZw8jjC/hMIVzi/eCG3JQvoyDyGE2d+6d
slC+goPzlvhzx9bLQPlKDkEiezSPr5eG8lUc9tncNr+cLQXlqznYWnkaKiVI
QvkaDg9+yoU2GUhA+VoO2w9wuc9/LQbl6zh4vLq+j69bBMrXczi9bevKogJh
KN/A4Y1wZOq3TiEo39Dh9R31Fv0mASjfyKF0d4CNxQ8+KN/YITzKaF2REj+U
b+Kw7cMEfamzMHlTB94iI+vLTbxQvplD9okd+y7v5IbyzR1+6kyqWZ7DCeVb
oPEtHT5svvi3VhTGt0KTt3bwMa/f/liPGcq3cWBS0PrFvfqPPYRv68DNvLbq
1eSPUL6dw3vLX/+c9L5B+fYOxaut7TctYoDqd0CVb0DwAXlYg7E=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVwcBG6E+l4WRHK53C45Cny
64oJjC/gMNdO9t3EhQpQvohD11yX9UYX5KF8CYfihd+vblglB+XLOOwIXsS8
v1sWyldweK6079oCXxkoX8lhuu6SS7v+SUH5Kg5yxS5KVz5KQvlqDtuufzYR
Oi4B5Ws4lNxafELwhjiUr+Uwa+VB569rxaB8HYeTV1paS0+KQvl6DtZZRTMS
tohA+QYOcjuLt7WfFobyDR2OBByY3bBLCMo3cijeuL4zoEoQyjd2kJZ4/GLi
JAEo38TBOeSPGasbH5Rv6qDsNe1a1AouKN/MoW1itlW1PDuUb+4g7+FrKbaK
Fcq3cChebW2/aREDlG/pwM28turVZEYo3wqNb+0QHmW0rkjpvz2Eb+NQO+/y
HrGHzFB5WzS+nQMkPpmgfHs0+xyg5n+EmNfg4PDe8tc/J71vUPMdofxnUHk0
PoMTXD8A8p2TyQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVw2PXkdZ/KBUUon8Ph+Ycn
nZJGML6AQ+79Fa9mzFCA8kUcBC7rvvr4Rh7Kl3AwkV6x3vGIHJQv47Az+MkW
qRZZKF/B4dBqPvXDPjJQvpLDtcnMmy4ESUP5Kg6OuapWmaFSUL6aw1eh7ylH
1CShfA2Hx3eCChvZJKB8LYcbUxOi1lwQg/J1HP4VfVflPCoK5es53Ivoa+/5
LgLlGzjI7Sze1n5aGMo3dDB0m7XT66wQlG/kEMO+aJa0qyCUb+yQ4zRhL99C
PijfxCFKe6LHuQpuKN/U4cRR2/KSXRxQvplD28Rsq2p5dijf3MHHvH77Yz1m
KN/CARLeTFC+pQM389qqV5MZoXwrNHlrB+Pet98dD/y0h/BtHN5b/vrnpPcN
yreF8p9B+XZQ8z5C+fZo8g6o+hsc0Mx3RNXfgOADAB17k1k=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVw2LDyzs7T5xWhfA6H5Knp
HiwWML6Ag3Kd40KtuQpQvojDOlZ+oTYOGF/CwWvDb4YbD+SgfBmH5FtPjjQe
lIXyFRye9Sp8rTokA+UrOSRckt82P1oayldxCGn8f/GKkxSUr+bguTtf/DOj
JJSv4XBAZDV74itxKF/Lgfvyl8J/dWJQvo7DzL55WYfKRKF8PQehtVczP9SJ
QPkGDicrXWxS1IShfEOHpidJvU/WCEL5Rg4nr6l8+c0D4xs7CL4REfsgxgfl
mzgoe027FrWCC8o3dWibmG1VLc8O5Zs5QMKTCco3dwiPMlpXpPTfHsK3QONb
Ohj3vv3ueOAnlG/l8N7y1z8nvW9QvjWavI0DN/PaqleTP0L5tmjydmj67dH4
Dqj8Bhj/GVTeEU3eEU3eCW4/AOuznHQ=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwaNXfzVZ/SRHK53AQabm2
ucccxhdwqC2UXxA+QwHKF3Fgneh7KPi/PJQv4bBZ5Hnc3X9yUL6Mw70frLWr
zslC+QoOW/M/x76ZLQPlKzkwBnzmNJ8mDeWrOOyzuW1+OVsKyldzaF5zSDg0
ThLK13DYxLCooVtAAsrXcuCo65c+FS8O5es4zCtdcctASQzK13PYtL5NTuKO
CJRv4KD7XLqBiwXGN3SIjD/kERUhDOUbOeyLUT0oxy0E5Rs72Id/ifGTFoTy
TRy6jVLvzE4QgPJNHf4zBP5PKOGH8s0cdG31QvY/44XyzR1mX+P+ucyUG8q3
cDDuffvd8QAnlG/p0DYx26panh3Kt3LgZl5b9WoyI5Rv7fDe8tc/J71v9hC+
DVT+oz0ArstpZQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwiPnCf+/AOUUon8PBSGlh
mogJjC/gkK9q9vHECgUoX8RhHSu/UBsHjC/h8NM85PvrE3JQvoxDaNN0lomb
ZaF8BYdH/PwvN5TIQPlKDv28r2YqhElD+SoOMdz7ImYLS0H5ag6MVto7z3NK
QvkaDiXGx2xLz4pD+VoO20+Ls/5JEIPydRwE2gtT7i8SgfL1HOR2Fm9rPy0M
5Rs4zNy/vDxURwjKN3SwD/8S4yctCOUbOVRqHv+Z6i8A5Rs7RM5au1BUB8Y3
cdh73OqdxmMeKN/UYYXj4aPHJHmhfDOHb7w7G/+YwuTNHYx73353PMAJ5Vs4
bFyXP0UvmgPKt3TwMa/f/liPGcq3QuNbO0DihwnKt3HgZl5b9WoyI5Rv68Ck
oPWLe/UfewjfzuG95a9/TnrfoHx7NL4DKr/BAWreR3sAsz+AdA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwmD/x3sroS4pQPofDyzne
jvyGML6Aw50X96cKLlSA8kUcOkqT5z7lgfElHOLTT08J+S4H5cs47K/JCP33
XhbKV3BQZ9f8nbRfBspXctDe08k6N10ayldxyJbJN5lhLQXlqzlcfdvA8fqx
BJSv4VC5MfCHRpU4lK/l0PnrwirJv6JQvo5DhEe/wKP9IlC+nkN2BHtg8nRh
KN/AYamV8Ynlc4WgfEMH2dV/rsWYC0L5Rg6Rs9YuFNURgPKNHdZLr9l+yZsf
yjdx2Hvc6p3GYx4o39ThrNSHV1MEuKB8M4faeZf3iD1khvLNHYx73353PPDT
HsK3cOBmXlv1avJHKN/S4b3lr39Oes/sAci3ZtA=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw2CIiUmF7XhHK53C4KPTC
pMQRxhdwuHDVQGDdOgUoX8TBtkK5xUoIxpdwMN1z4tu/F3JQvoyDyGE2d+6d
slC+gkObmNJVwyQZKF/JIdHXKZTfUhrKV3FQKn+x5LqRFJSv5tA382p1uYck
lK/h8OCnXGiTgQSUr+XQV1bfZHNPDMrXcXjTd26T/SVRKF/PIcKjX+DRfhEo
38Dh9LatK4sKhKF8Q4c3wpGp3zqFoHwjB11BjY+zLgpA+cYOvDlCrzsKYXwT
h/XSa7Zf8uaH8k0dLu64+uXGD24o38xh47r8KXrRHFC+ucOJo7blJbtgfAsH
nc0sbGZ97FC+pUNV/a+D2avYoHwrBx/z+u2P9ZihfGuH4tXW9psWMUD5Ng7c
zGurXk3+aA/h28L5AB/Xb+A=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQEf7MVCt+7emK3kABVwWMPPJJ17RRHK53BInpru
wWIB4ws43Hlxf6rgQgUoX8SB4bdN2AVWGF/CYW38intZ5+WgfBmHc7+Tbr3s
k4XyFRxeeFZ+1/CSgfKVHI5vOXGyUlYayldxmDmryvTLPEkoX83hfIqHT/JK
CShfw+Fzm2uEq5E4lK/l0FBq/8VKTQzK13EQaC9Mub9IBMrXcxDiFt/zbI8w
lG/gMHP/8vJQHSEo39CheOP6zoAqQSjfyOHzv12RTewCUL6xA4/wofKCl/xQ
vomD58p1q1TnwPimDtknduy7vJMbyjdzOCv14dUUAS4o39xh+e7rYqdkWKF8
CzS+pQMk/JmgfCs0vrUDN/PaqleTGaF8G4fwKKN1RUr/7SF8WzR5OwcmBa1f
3Kv/QOXtHYx73353PPATyndA5Tc4oKl3dHhv+eufk943qDwan8EJyn8GlXdC
0+8Mdc9HqLwzXD0AMfCiGw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwOCXI8kPmoiKUz+GQe7/o
9mV9GF/A4TqH3Se++QpQvoiDkeQPdUFBGF/C4ax1p9Gnt3JQvozDixjhX3O2
yUL5Cg5z9ByuXIyQgfKVHNQblDLDXKShfBWHW//Ovn56ThLKV3MwUPj5z3q5
BJSv4aCzmYXNrE8cytdyaHypuP+RpxiUr+PQXnWk4sccEShfz+GNcGTqt04h
KN/AwfLc7gXHHghA+YYOkbPWLhTVgfGNHJgUtH5xr+aB8o0dThy1LS/ZxQHl
mzh82Hzxb60oJ5Rv6jDxcXG103d2KN/MQd7D11JsFSuUb+7QNjHbqloeJm/h
8N7y1z8nPTYo3xLqH5i8FRrfGk29jUPtvMt7xB4yQ/m2Dj7m9dsf68H4dmh8
e4fwKKN1RUr/7SF8B6j//kD4DQ4Oxr1vvzse+GkPAPRwf6g=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwUFkQbW5xUxHK53CIkm53
zjWD8QUc5tyPu+E/SQHKF3FQWenxbSYzjC/hcIlXnlfhmByUL+NwtaTZqPmI
LJSv4KDPeuGyQpcMlK/k8P6r35dvCtJQvooD+83zKbeZpKB8NQdFicS/Z+9K
QPkaDq+3zL1vsEocytdy2Hk6clt4pBiUr+PwlHXat+3TRaF8PYcIj36BR/tF
oHwDh6mqfyMZ5gtD+YYOWSU/tjGGC0H5Rg5XUr9xauwUhPKNHSo1j/9M9ReA
8k0cdG31QvY/44XyTR1mX+P+ucyUG8o3c9DZzMJm1scO5Zs7yHv4WoqtYoXy
LRyKV1vbb1rEAOVbOry3/PXPSe+bPYRvhca3hvKf2QMA4ZhpOw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQEf7MVCt+7emK3kABVwaGud4GVxSRHK53AIZJRd
lW0M4ws4bFqqMEN9jgKUL+LwNmP3heuv5KF8CQeX1xPW926Xg/JlHM5smOrX
lykL5Ss4KCq8MekxlIHylRwUVYwuep6RgvJVHH7qTKpZniMJ5as5TFzEPOGd
nQSUr+FwZnsIl4qkOJSv5WD2KUrD+74olK/jcC+ir73nuwiUr+eg+1y6gYsF
xjdw2Hu8/f6PeiEo39Bht9SUuTvfC0D5Rg4BOVqnv0rC+MYOziF/zFjd+KB8
E4drvB0ZP/14oXxTh+wTO/Zd3skN5Zs5fNh88W+tKCeUb+6gs5mFzayPHcq3
cGibmG1VLQ/jWzpMfFxc7fQdxrdCU2/tULza2n7TIgYo38bBuPftd8cDP+0h
fFs0vp3De8tf/5z0nkH59g7hUUbripT+Q/kODkwKWr+4V/+B8Bsc0NQ7ovIb
YPxvUHknNHk0PoOzAzfz2qpXkz9C5dH4DC5o8i5o7ndFta/BFU3eDU2/G5r9
7nA+AEifx2g=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwMGYoVA66qAjlczj4+cTJ
JzjD+AIONbEnklq2K0D5Ig5euvdt0mVgfAmH2uYvNT7i8lC+jMNq3vWzfE/K
QvkKDpObdx55M18Gyldy+PQjr//kBmkoX8Uhv+jJ+dwlUlC+msPPy/nsLuWS
UL6Gg9H/FMn9CySgfC0Hi6P11fN2iUP5Og43piZErbkgBuXrOYTeZO3sqBaF
8g0cLqzZ29l8TQTKN3SI63B7aXtEGMo3crhkP4lF/K4glG/soOiY3ln6TwDK
N3HQFdT4OOsijG/qkOM0YS/fQj4o38yBSUHrF/dqHijf3OHD5ot/a0U5oXwL
h4mPi6udvrND+ZYOy3dfFzslwwrlWzm0Tcy2qpaHyVs7BPYYarO0skD5Ng7c
zGurXk1mhPJtHYpXW9tvWsQA5ds5vLf89c9J75s9hG8PVf/RHgC7YXfi
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw+PBlXiv3VUUon8NhUqT4
9y59GF/AwUbt/7OcaQpQvojDn/xy1pqP8lC+hIORX7X5rotyUL6Mg+vb3E3+
h2WhfAWHeSmijoe6ZaB8JYe+H/9XyNVJQ/kqDimHtxn28EpB+WoOdbLiSz89
lYDyNRxY87mNc4+KQ/laDnvfBPv5LxaD8nUcVgu+k1DbLArl6zksftKa5Jwm
AuUbOBwJODC7YZcQlG/o8ExfyThPUxDKN3JYcnJxGXcJH5Rv7DChhXnH/Vgu
KN/EYfnu62KnZFihfFOH95a//jnpsUH5Zg618y7vEXvIDOWbOxSvtrbftIgB
yrdwYFLQ+sW9+o89hG+JxreCmvcNyreG8p9B+TZwPgCvwXDA
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwqPLJ5JK7rAjlczgwfyiP
YjSC8QUcgoQ+xfd1K0D5Ig5uoR9m73khD+VLONSU3LjmtkcOypdx2BG8iHl/
tyyUr+DwZBnj0dBqGShfySFgu5aiubM0lK/isH1zq1XiNkkoX81BUjo7Y3qu
BJSv4XDIe4XWxRhxKF/LYWqD7WJBJzEoX8dBkeXug89/RKB8PYeYZuOoGy+E
oHwDhyup3zg1dgpC+YYOQi8OHFodBOMbOfDmCL3uKBSA8o0deIQPlRe85Ify
TRyOfuYPjirkgfJNHZS9pl2LWsEF5Zs5yHv4WoqtYoXyzR18zOu3P9ZjhvIt
HCDhzQTlW6LxrRzCo4zWFSn9t4fwrR3eW/7656T3zR4AfFpknw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwePtlgkDeWUUon8Nhr4tC
0TpbGF/A4WWVofW81QpQvojDkT+bSos0YHwJh6NzGCsey8hD+TIOU1dqamj8
lIXyFRziDdS/i12RgfKVHNqZ/Mt3H5eG8lUc+hvjDwfWSEH5ag61K6eaR9tK
QvkaDnME7dku/hSH8rUcLByUmRw+iUH5Og6rBd9JqG0WhfL1HNbJXlbSei4C
5Rs4RMYf8oiKEIbyDR24Fv+IczsqCOUbOZRqTpk8aZMAlG/s4Ot27OgTWxjf
xME55I8ZqxsflG/qcI23I+OnHy+Ub+Zg3Pv2u+MBTijf3GH57utip2RYoXwL
ByYFrV/cq//YQ/iWDu8tf/1z0vsG5Vuh8a3R+DZQ/jN7AKTSbiQ=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwEEo5ajf3nCKUz+Fwsflx
31otGF/AobZQfkH4DAUoX8Rhe3yd8dWP8lC+hENZTq5E8kk5KF/G4YnBtSfi
C2WhfAUHDzfhU1uWyED5Sg7rN6qo8ddKQ/kqDqtfO6b7mUhB+WoO8bkb58+4
KgHlazgIH1bUFZ8vDuVrOVzOubPzRIoYlK/jINBemHJ/kQiUr+cgxC2+59ke
YSjfwMFt78ssh4uCUL6hQ/Fqa/tNiwSgfCMHX7djR5/YwvjGDrxFRtaXm3ih
fBOHizuufrnxgxvKN3U4K/Xh1RQBLijfzOG95a9/TnpsUL65w/Ld18VOybBC
+RZQ+xigfEuo+m/2AHIhY7g=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQDQEf7MVCt+7emK3kABVwKBI/lshzWRHK53BYEVj1
UtoGxhdwEJtop3NhvgKUL+IQvyhEM5kbxpdwuFAh/XflDzkoX8ZBUHV+2MVL
slC+gsPbor/TebbJQPlKDj3Xwj887ZWG8lUcyvo2L6gqlYLy1RziczfOn3FV
AsrXcDCeLLuxbqY4lK/l8Kbv3Cb7S6JQvo5DYI+hNkurCJSv5/Bc81OlYYAw
lG/g0N27VHUtM4xv6DBz//LyUB0hKN/IQVri8YuJkwSgfGMHHuFD5QUv+aF8
E4dtHyboS53lg/JNHZacXFzGXQLjmzlMaGHecT+WC8o3d9i4Ln+KXjQHlG8B
dR8LlG/p0DYx26panh3Kt3KonXd5j9hDZijf2oGbeW3Vq8mMUL4Nmn5bNL6d
g495/fbHejD99mjmOaCqb3BwkPfwtRRbxQqVd0TlNzg6LN99XeyUDEzeyYFJ
QesX9+o/9hB5J6j7PkL4DM4O7y1//XPSe2YPAM2ijTs=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEf7MVCt+7emK3kABVwaPtpuODpNUUon8PBJlkx
J9ENxhdwSOhqj/qyVQHKF3HYqveC0UAOxpdwUDnd/3afrDyUL+PgVs9zhpNP
DspXcKjpVDHr/CAD5Ss5GJ90nZBzTRrKV3FY9vJbi/9tKShfzcHsV+7+vesl
oXwNhxk+KkEcvRJQvpaD37mAI8szxKF8HYcF/ExSf1zFoHw9h8Men+cp7hGF
8g0cZG5HOAhMFIHyDR02FxR/jqoQhvKNHKLd93P92iAE5Rs7CL04cGh1kCCU
b+JgeW73gmMPBKB8UwfnkD9mrG58UL6Zw8UdV7/c+MEN5Zs7nDhqW16yiwPK
t3Bom5htVS3PDuVbOvzUmVSzPIcTyrdy+LD54t9aURjfGk29DRrf1qGq/tfB
7FVsUL6dg495/fbHesxQvr1DYI+hNksrC5Tv4CDv4WsptooVwm9wQFPv6ABJ
D0xQeUc0/U4O3Mxrq15NZoTKOznUzru8R+whTL+zw3vLX/+c9L7ZQ+Rh/GcQ
PoMLKr8BwQcA9ciikw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwKN2XpWd3RhHK53A4bj/r
s4YVjC/g8LLK0HreagUoX8ShszL/TQoPjC/hsFBs46TkB3JQvoxDQlONpud6
WShfwSH7nA5n0UQZKF/JQezWqibvRmkoX8WBPW3nqZtlUlC+msOktxkaddaS
UL6Gw4OfcqFNBhJQvpaDhYMyk8MnMShfx6FH/MKkb4WiUL6eQzCDxbmNgiJQ
voFDScbyff5iQlC+ocNuqSlzd74XgPKNHJxD/pixuvFB+cYORz/zB0cV8kD5
Jg4njtqWl+zigPJNHWrnXd4j9pAZyjdzYFLQ+sW9+o89hG+Oxrdw4GZeW/Vq
8kco39LhveWvf056z6B8KzR5azS+jYNx79vvjgd+Qvm2cP0ALCpygg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwWMzOZs58SRHK53D4uFMi
ssAKxhdwkCi5sO3dPAUoX8RBuPaZWycnjC/hcGpZSuaV23JQvowDQ/WX8zJH
ZaF8BYf8ztbW3DQZKF/JQVQ2ViuYSRrKV3HYzH7p2C8OKShfzcGyPOQx2y8J
KF/D4XXKpqZPa8ShfC2H7Qe43Oe/FoPydRxmnRLatWCdKJSv53BA2+ntmiIR
KN/AwXvzR69Ac2Eo39Dhkv0kFvG7glC+kUO3Ueqd2QkCUL6xg+AbEbEPYnxQ
volD9okd+y7v5IbyTR3OSn14NUWAC8o3Q+ObO7RNzLaqlmeH8i0caudd3iP2
kBnKt3TwMa/f/lgPxrdyWL77utgpGVYo3xpNv41D8Wpr+02LGKB8Wwdu5rVV
ryZ/tAcAK+Fu9g==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwqJy81Jb7oiKUz+HAUfvj
3kZLGF/AIWZ9QYvLbAUoX8Th2tHnNxgZYHwJB5fXE9b3bpeD8mUcnJZcWzGx
QxbKV3DYWPj09ZpIGShfySG/xj/V1VcayldxmLfANDLBUArKV3Pom3m1utxD
EsrXcHCbzflxubYElK/l0FdW32RzTwzK13GY2Tcv61CZKJSv5xCT9Oixzgth
KN/AYe/x9vs/6oWgfEMHXUGNj7MuCkD5Rg48wofKC17yQ/nGDn5r+lxTt/JC
+SYO2Sd27Lu8kxvKN3U4cdS2vGQXB5Rv5lA77/IesYfMUL65A5OC1i/u1X/s
IXwLNL6lQ/Fqa/tNixig6q0cuJnXVr2a/BEqb+1g3Pv2u+OBn1C+jcN7y1//
nPS+Qfm2aHw7KP+ZPQAM7X4K
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwUBaw3zLhkiKUz+FgpLQw
TcQExhdw2H54mrruPAUoX8TB5d+rXn0OGF/Cwe72FDGGW3JQvoyDC7MHw7fJ
slC+gsOWm9vmtIfIQPlKDr7WfZu3/pCC8lUc+idGCzVfkITy1RwmKzx9EeAo
AeVrOESd582c+VAMytdyaG45fGf6AVEoX8fhgLbT2zVFIlC+noPczuJt7aeF
oXwDh4TC2N+nXghC+YYOvDlCrzsKBaB8Iwce4UPlBS/5oXxjB8E3ImIfxPig
fBMHZa9p16JWcEH5pmh8Mwfj3rffHQ9wQvnmDm0Ts62q5dmhfAuH5buvi52S
YYXyLR0g4c8E5Vs5BPYYarO0skD51mjyNmh8W4fwKKN1RUr/7SF8OzS+vUPx
amv7TYsYoOodHN5b/vrnpPcNIt/gAHXvT3sA0hd+6g==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwiPnCf+/AOUUon8Phx3+D
mA5DGF/A4Xgiv8iiWQpQvohDbPr1B7k/5KF8CYc8I4mGDXvloHwZB7aGkNc3
pspC+QoOJY6+8m2lMlC+ksOWdc0d4k7SUL6Kg+vRvOpJqlJQvppD7cqp5tG2
klC+hsOnGdz/et6LQ/laDgv4maT+uIpB+ToOuwp0vgcziUL5eg7pU5lKeI1F
oHwDh97NnNr77gtB+YYORwIOzG7YBeMbOXAt/hHndlQQyjd2kJZ4/GLiJAEo
38RhvfSa7Ze8+aF8UwfBNyJiH8T4oHwzB+eQP2asbjC+ucNPnUk1y3M4oXwL
h4mPi6udvrND+ZYO8h6+lmKrWKF8K4fwKKN1RUr/7QHVwmCe
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwyLz2uGzrWUUon8Oh32fV
iiJ9GF/AQdvCaglHmwKUL+LgPl1PR+OmPJQv4dB7qCOVbZEclC/jMO+v0c3P
PrJQvoJDzKdXQt+/SUP5Sg7LXn5r8b8tBeWrOPhFVBt+vCYJ5as5KPuWhjXE
SkD5Gg6RShYLboSJQ/laDur3AheWsopB+ToOfxazKD6/IALl6zmUi85m6F8m
DOUbOPRu5tTed18Iyjd0SJ27jKl6gSCUb+Qgu/rPtRhzGN/YoXR3gI3FDz4o
38RhQgvzjvuxXFC+qUPtvMt7xB4yQ/lmDoE9htosrSxQvrmDce/b744HftpD
+BZofEs4HwCe32QO
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwkHdPUz56RRHK53Cw+rC4
K9gYxhdwSA/c+2X1XAUoX8SB40b7OyNOGF/Cga9G/QXfcTkoX8ZhR/Ai5v3d
slC+goOx/0k2g3IZKF/JYcO8nLAYbWkoX8VhvbachcsHSShfzaHE0qpDeKkE
lK/hsFBpjkzBJnEoX8shIOib9PomMShfx8Fs8pEMTyFRKF/PgV2OJeTIJWEo
38Bh+sMexnsfhaB8Q4fijes7A6oEoXwjB1+3Y0ef2ApA+cYOpbsDbCx+8EH5
Jg7ZJ3bsu7yTG8o3daiq/3UwexUblG/mIO/haym2ihXKN3dgUtD6xb36jz2E
b+HAzby26tXkj1C+pcN7y1//nPS+QflWUP4zKN8ajW+Dpt8WjW+Hpt4eje8A
5wMAdw6Afg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwWMXgV3TvqiKUz+Hwccpc
URMLGF/AQWrR2tP98xWgfBEHlZUe32Yyw/gSDoe8Tq6U3C8H5cs42GgxS0VH
yUL5Cg5m0v7pPLYyUL6SQ82BOtVzEtJQvorDPn+he7tXSUL5ag5n7J64BZ2V
gPI1HF5vmXvfYJU4lK/lsICfSeqPqxiUr+OQfHvPnuVvRKB8PYdziREfP98U
hvINHBYuOSHaf00Iyjd0KNWcMnnSJgEo38hhtY1ShsZhfijf2GHvcat3Go95
oHwTh4mPi6udvrND+aYO7y1//XPSY4PyzRyq6n8dzF4F45s7LN99XeyUDCuU
b+EACW8mKN/Swbj37XfHAz/tIXwrNL61Azfz2qpXkz9C+TZQ+55B+bZwPgB0
hHfu
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVweC8/Ydfhm4pQPofD7T8H
ufW8YHwBh0v7yjMfrlKA8kUcEj8vEzIRhfElHKYJLrU1+yMH5cs4MFR/OS9z
VBbKV3CI2xisvXOBDJSv5ND34/8KuTppKF/FofDWHwH3eCkoX81h5TO9Gy8i
JKF8DYeN6/Kn6EVLQPlaDkcPLr5xIEkcytdxYPvAf21ihhiUr+fwmy/d/qCr
KJRv4PAu98hX42/CUL6hw97j7fd/1AtB+UYO0hKPX0ycJADlGztEzlq7UFQH
xjcBqrd6p/GYB8o3dZD38LUUW8UK5Zs5BPYYarO0skD55g7czGurXk1mhPIt
HGrnXd4j9pAZyrd0CI8yWlek9N8ewrdyeG/565+T3jco3xrKfwbl20DN+wjl
28LlAefneAQ=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw8OTwCom8pgjlczg8iZzw
Zr4VjC/g4PtQ5mrAAgUoX8SBdcohBV5uGF/CQWxZs8Hvv3JQvowDr+Eh//pT
slC+gkMrB8eftfkyUL6SQ6KvUyi/pTSUr+Jw5IbXLOenklC+msODE68Fc8Vh
fA2Hso1yk0LvikP5Wg6NLxX3P/IUg/J1HFYWnL2Y0ScK5es5LH7SmuScJgLl
GzhoqrA/+e4uDOUbOnT3LlVdywzjGzmUZCzf5y8mBOUbO1RqHv+Z6i8A5Zs4
zL7G/XOZKTeUb+owoYV5x/1YLijfzEFnMwubWR87lG/u0DYx26paHsa3cAjs
MdRmaWWB8i0dmBS0fnGv/mMP4Vs5vLf89c9J7xuUb+1g3Pv2u+OBn1C+jQM3
89qqV5M/Qvm2aHw7qP5n9gBfLHLj
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwOCXI8kPmoiKUz+Ew0fiJ
iqAVjC/gMM9wc8zOfgUoX8Qh5d6rbROfykP5Eg6rez8U1fTLQfkyDlxt8hz/
EmShfAWHT7PC3J96y0D5Sg7XJjNvuhAkDeWrONQ9WekppiIF5as5ZF11ZZ0r
KAnlazjEe+9x2HNIHMrXclApvHjzp6gYlK/j4FcsUD3tqAiUr+dwLjHi4+eb
wlC+gYOmCvuT7+4wvqHDt6514rFfBKF8Iwf78C8xftIwvrGDr9uxo09sBaB8
E4dvvDsb/5jyQPmmDieO2paX7OKA8s0cqup/HcxexQblmzv4mNdvf6zHDOVb
OEDCmwnKt3Qw7n373fHAT3sI38rhveWvf056z6B8azS+jQM389qqV5M/2gMA
YNdx/Q==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwMOXSXstxXRHK53CQc3ll
t8wZxhdwCNqQbyy8UwHKF3Hgd5/sImUI40s4BG3vs9yiJg/lyzicDTn584W0
HJSv4DD52Pbt2uyyUL6Sw7sklrsbXkpD+SoOx+6opT6fKgXlqznc+LBg8d5i
SShfw+Hw8i1zzGdJQPlaDqXmaqlbU8WhfB0HI/H5iTFtYlC+noMiy90Hn/+I
QPkGDkLc4nue7RGG8g0d9sWoHpTjFoLyjRz+MwT+Tyjhh/KNHXKcJuzlW8gH
5Zs48BYZWV9u4oXyTR3k/509bfGBC8o3c9DZzMJm1scO5Zs7vLf89c9Jjw3K
t3ConXd5j9hDZijf0iGwx1CbpZUFyrdyMO59+93xwE97CN8aqv+ZPQAXImcT

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwOMAg9ffVWUUon8NhBmOS
cocVjC/g8HqFkfSnhQpQvohDJcecqVZ/5KF8CYdnySxHdefKQfkyDluC7az1
3WShfAUHq3KNeZe2SUP5Sg6OuapWmaFSUL6Kw8mrbrkHzSWhfDWH5auv3Pj+
RhzK13CwcFBmcvgkBuVrOZy80tJaelIUytdxmLvDJnryOhEoX8/Bx7x++2M9
YSjfwCGGfdEsaVdBKN8QjW/kUKl5/GeqvwCUb+xwjbcj46cfL5Rv4qDsNe1a
1AouKN/U4cRR2/KSXRxQvpnD8t3XxU7JsEL55g46m1nYzPrYoXwLNHlLB27m
tVWvJjNC+VYOTApav7hX/7GH8K0dildb229axACVt4H6hxnKt0XTb4em3t4h
PMpoXZHSf6h5Dg7GvW+/Ox74CeE3OMDtAwDBvXu8
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwmPEh51nBPUUon8Nh8ddn
C5/Yw/gCDtl+j7i01ytA+SIOQk93h1nzwvgSDoULt6qEbpKD8mUcNK7PWMbc
KwvlKzi0cnD8WZsvA+UrOST6OoXyW0pD+SoOfY8Kt8iKSkH5ag6Zuydkbr0p
AeVrOPB+mfPSe444lK/lsPN05LbwSDEoX8ch9CZrZ0e1KJSv51A77/IesYfC
UL6BQ2T8IY+oCBjf0GHm/uXloTpCUL6Rw+s76i36TQJQvrGDrq1eyP5nvFC+
iYP8v7OnLT5wQfmmDlX1vw5mr2KD8s0cThy1LS/ZxQHlmzss331d7JQMK5Rv
gca3hLqPGcq3cuBmXlv1ajIjlG/twKSg9Yt79R97CN/G4b3lr39Oet+gfFu4
PACCq3Lh
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw4Fr8I87tqCKUz+EQ8DB7
71dVGF/Agd1etOtymwKUL+Lwmq9ny+J/8lC+hIPd7SliDLfkoHwZh1s7Nm/5
s0oWyldwuPYwcuqeFBkoX8mhnCHe/t5nKShfxWH/Ru8erlOSUL6ag9a1tUIc
MySgfA2HYEMOhpvB4lC+lkPlBJGrnoxiUL6Ow4U1ezubr4lA+XoOcR1uL22P
CEP5Bg4+5vXbH+vB+IYOP7yfcjT6CEH5Rg6Rs9YuFNURgPKNHbJP7Nh3eSc3
lG/i8FNnUs3yHE4o39ThxFHb8pJdHFC+mUPtvMt7xB4yQ/nmaHwLh/Aoo3VF
Sv/tIXxLByYFrV/cq/9A+VYO7y1//XPS+2YPAFIwaLA=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw8Gw3E+U4rwjlczjIrv5z
LcYcxhdwWK63OS1jjgKUL+Jw7ejzG4wMML6Ew9pTiQ+6bspB+TIOW93t5i/b
KQvlKzi479ApWNsuA+UrORiLJ6mtKZOG8lUctM+94PTzk4Ly1RykO63W31GR
hPI1HM65x3F/lZGA8rUc1lgvOeb1QgzK13GYpbCV/9lzUShfz6G96kjFjzki
UL6Bg5NewpSiBGEo39Ah2n0/168NQlC+kYPlud0Ljj0QgPKNHTxXrlulOocf
yjdxiJy1dqGoDkze1GG99Jrtl7xh8mYOgm9ExD6I8UH55g7y/86etvjABeVb
OExoYd5xPxbGt3T4qTOpZnkOJ5Rv5VBV/+tg9io2KN/aITzKaF2R0n97AKQK
aLE=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwMC/fZmV0QxHK53DIXPL8
pJg1jC/gcOfF/amCCxWgfBGHux8ZGvmEYXwJh/j001NCvstB+TIOe19PzW96
KAvlKzjEffasC1wkA+UrOax74Lt+Qps0lK/icOWa74UibykoX81BUSLx79m7
ElC+hoPV68cN66eJQ/laDg2l9l+s1MSgfB2HJD/NFf94RKF8PYeqSu3n11RF
oHwDh0ezzUxvTxaC8g0dTl5T+fKbRxDKN3L4zxD4P6GEH8o3dth73OqdxmMe
KN/E4RvvzsY/pjC+qcOEFuYd92O5oHwzh6r6XwezV7FB+eYO8h6+lmKrWKF8
CwcmBa1f3Kv/2EP4lg7czGurXk3+COVbofGtHd5b/vrnpPcMyrdB49vC+QCi
k3kX
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVw0J2ixZtzShHK53BIPlLA
22wH4ws4tFx7ar9xiQKUL+LA+PBWtKcUjC/hcJ9rb8VnRnkoX8ah2VWUreqs
LJSv4MDTPG3a2koZKF/J4dT+fxPPyktD+SoOBzcvOsKsJQXlqzmInL1z8t9L
CShfw+Ep0/aySY/EoXwtB8UFjSKOZ8WgfB2HHvELk74VikL5eg4Gsc3L964Q
gfINHGrnXd4j9lAYyjd0gPhfCMo3clB0TO8s/ScA5Rs7lO4OsLH4wQflmzjo
2uqF7H/GC+WbOlzccfXLjR/cUL6Zw1mpD6+mCHBB+eZo8hYOyl7TrkWtgMlb
Osj/O3va4gOMb+Wgs5mFzayPHcq3dmibmG1VLQ/j20Ddzwzl2zpwM6+tejWZ
Ecq3Q5O3d3hv+eufk943ewDckn0b
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwcDh1Ibf/piKUz+Hwccpc
URMLGF/AoeXaU/uNSxSgfBGHjtLkuU95YHwJhw91H2oWn5GD8mUcHF45XAtd
JAvlKzg8a97Q+y1cBspXcph9jfvnMlNpKF/F4bCPSHzoIkkoX81hzZWIytsR
ElC+hsNHvtDDmvriUL6Ww1WNnMRl20WhfB2HuTtsoievE4Hy9Rxikh491nkh
DOUbOPRu5tTed18Iyjd0+Na1Tjz2iyCUb+RgeW73gmMPBKB8Y4fdUlPm7nwP
45s4RM5au1BUB8Y3dbjG25Hx048Xyjdz+Ma7s/GPKQ+Ub+4QpT3R41wFN5Rv
gca3dNi4Ln+KXjQHlG/lsHz3dbFTMqxQvrVDeJTRuiKl//YQvo1D8Wpr+02L
GKDytmjydg7GvW+/Ox74CeXbO7y3/PXPSe+bPQANxX+8
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQEf7MVCt+7emK3kABVw8P+9k2/9OUUon8OB5UG0
aZMljC/gIDbRTufCfAUoX8Thee4exom8ML6EQ9mhj7krvshB+TIOLsweDN8m
y0L5Cg4fb8b2RSTKQPlKDumyvUUXYqWhfBWHU4znrdQDpaB8NYeaY+vucX2S
gPI1HIQPK+qKzxeH8rUcdvdMWF69UQzK13F4b/nrn5MejK/n0F51pOLHHBEo
38BB97l0AxcLjG/oMP1hD+O9j0JQvpFD05Ok3idrBKF8Y4fP/3ZFNrELQPkm
Dtd4OzJ++vFC+aYO2Sd27Lu8kxvKN3Ooqv91MHsVG5Rv7lC82tp+0yIGKN/C
wbj37XfHAz/tIXxLNL6VQ3iU0boipf9QvjUa3waNb+vApKD1i3v1HyjfDs0+
ewdI/DJB+Q4O3Mxrq15NZoTwGxyg4fUNqt8Rld/giOY+JzR5GP8ZVN4Zav5H
qLwzmvkuqO5rcEEz3xXVPw2uaP5xQ/VPgxua/91RzWtwR5P3QJP3QAtPT1R+
gyfcfwDTT91N
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwsLimL7z+jiKUz+EQG8k/
/aobjC/g8H3qjw33tihA+SIOh/8FKnJowfgSDg+3/SvOcZGH8mUcBGeqXXht
LQflKzjYqyTkSTHJQvlKDhuOb/FoeCsN5as4OGudjb27TgrKV3NYMNNSrT1G
EsrXcCjbKDcp9K44lK/lcPv4llvXi8WgfB2Hi2vOf1bJFYXy9Rxq513eI/ZQ
GMo3cNhesCxSTxTGN3QouPb5UKKiEJRv5PD6jnqLfpMAlG/soGurF7L/GS+U
b+JwccfVLzd+cEP5pg7y/86etvjABeWbOch7+FqKrWKF8s2h9jND+RYOkPBm
gvItHcKjjNYVKf23h/CtHJgUtH5xr/4D5Vs7cDOvrXo1+SOUb+Pw3vLXPye9
Z/YAax1x0A==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwkNoscunoKUUon8NBr/HH
zFBNGF/AYZ7h5pid/QpQvojDHcNpc1y+yEP5Eg53th+KenVLDsqXcUhoqtH0
XC8L5Ss4ME75vE82QwbKV3JIuCS/bX60NJSv4tBY+bZcUVoKyldz4NJujuX8
IAHlazgcESmvVPgkDuVrOawPYWH5+E4MytdxWC34TkJtsyiUr+cgtPZq5oc6
ESjfwMF780evQHNhKN/QYV+M6kE5biEo38hBWuLxi4mTBKB8Y4ejn/mDowp5
oHwThwktzDvux3JB+aYOxr1vvzse4ITyzRxq513eI/aQGco3dwiPMlpXpPTf
HsK3QONbQvX/hPKt0PjWDu8tf/1z0vsG5dugydtC5Z9B+XZwPgBgL3wR
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwsJ3pV3/3vCKUz+Fg2Jd/
i1Udxhdw2LzX6qR1rQKUL+Iwe2HUl6hL8lC+hEN/9OzO/lI5KF/G4d4qoTVd
7rJQvoLD9dDbTCG8MlC+ksO89zorRb5KQfkqDv9CxWS7b0hC+WoOe4ojf5tt
k4DyNRx6dr2/FdctDuVrOWSZ5/E1hIpB+ToOybf37Fn+RgTK13NQKWecbPZe
GMo3cNhesCxSTxTGN3Q4eU3ly28eQSjfyOEab0fGTz9eKN/YgbfIyPpyE4xv
4jChhXnH/VguKN/Uwbj37XfHA5xQvpnDe8tf/5z02KB8c4fi1db2mxYxQPkW
DkwKWr+4V/+xh/AtoeqfQflWDtzMa6teTf5oDwBxPGd6
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwiNYS0J1xVRHK53DY3PfH
wd0JxhdwWPkv8t3FxQpQvojDEZcKFhEZGF/CwXq/uxqjmDyUL+Oga6sXsv+Z
LJSv4DAraO6O5JsyUL6Sw4qFi9ObW6WhfBWHBcnGPocapaB8NYeTV91yD5pL
QvkaDi3/7wSxcUpA+VoOB/jM9x4SEofydRzOOkdIPv0hCuXrOWxa3yYncUcE
yjdwiIw/5BEVIQzlGzokFMb+PvVCEMo3cgjI0Tr9VVIAyjd2OPqZPziqkAfK
N3FQ9pp2LWoFF5Rv6lBV/+tg9io2KN/MIbDHUJullQXKN3coXm1tv2kRA5Rv
4cDNvLbq1WRGKN/SgUlB6xf36j/2EL6Vw3vLX/+c9J5B+dZQ/jco3wYuDwC/
eWxH
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVwWHdwxbuFVxShfA6HSzHm
PXvMYXwBh8YTbdLLVipA+SIOOZHr5Z7zwfgSDv+sGi8/fSkH5cs4vIgR/jVn
myyUr+CwOF9eZEmdDJSv5ODseU/mnac0lK/icCu1RC6FRQrKV3MwUPj5z3q5
BJSv4XD04OIbB5LEoXwthxW3D0+de00UytdxOKDt9HZNkQiUr+fwclqR41p7
YSjfwGFfjOpBOW4hKN/QQdExvbP0nwCUb+TwnyHwf0IJP5Rv7DD7GvfPZabc
UL6Jg85mFjazPnYo39QBEn5MUL6Zw3vLX/+c9L7ZQ/jmUP4zewAYeF2m
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVwOLCv9ZfnJUUon8PhlM2N
TdP1YHwBh9N+Ll+W9CpA+SIOHrJnesVeykP5Eg7BR9eF3TokB+XLOHhvauuW
6ZaF8hUc7jakZK0OloHylRx+NZxbYBUuDeWrONxKLZFLYZGC8tUcknZssDx0
WwLK13Do2fX+Vly3OJSv5TDnvKonW5cYlK/j8Gcxi+LzCyJQvp6Dzoe+ddv7
haF8A4cjAQdmN+wSgvINHWLYF82SdhWE8o0cVtsoZWgc5ofyjR2cQ/6Ysbrx
QfkmDkc/8wdHFfJA+aYOxr1vvzse4ITyzRzaJmZbVcuzQ/nmDieO2paX7OKA
8i0cAnsMtVlaWaB8SzS+lUPtvMt7xB4yQ/nWaPI2Dj7m9dsf68HkbR2YFLR+
ca/+Yw/h2zm8t/z1z0nvG5RvjybvgCrf4ODAzby26tXkj1B5R1R+AxqfwQnq
35/2ADc0j74=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw8OTwCom8pgjlczhsfpB/
+LITjC/gMHHL9GcMqxWgfBEH46NO28xEYHwJB8XnyzVOnJKD8mUc/l2ZMuHm
fFkoX8GhxNFXvq1UBspXcnBNdnZlC5WG8lUc4vOErL7rSEH5ag66jTfjuL9I
QPkaDiXGx2xLz4pD+VoOx3oOlZftF4PydRw+BF7un2omCuXrOczya/z1mEsE
yjdwmJz6YXLMciEo39Bht9SUuTvfC0D5Rg4BOVqnv0rC+MYOKxwPHz0myQvl
mzjMvsb9c5kpN5Rv6qCzmYXNrI8dyjdzaJuYbVUtD+ObOyzffV3slAwrlG/h
wM28turVZEYo39KBSUHrF/fqP/YQvhWavDWavI3De8tf/5z0nkH5tnA+AP1J
cGc=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwSK24NOHQNUUon8Nh0uoW
z7WmML6AQ8jzpyd3TVaA8kUcFjE82sPOCeNLOEwIXCpcd0UOypdx2Hrv5pNN
RbJQvoLD3hBvNQNnGShfyWHee52VIl+loHwVB7+IasOP1yShfDWHVFVDRrvT
ElC+hsPBw0uZrkWKQ/laDpdz7uw8kSIG5es4LN99XeyUjCiUr+fALscScuSS
MJRv4BB8rbPnkiyMb+hQkrF8n7+YEJRv5PBMX8k4T1MQyjd2yD6xY9/lndxQ
vonDWakPr6YIcEH5pg4fNl/8WyvKCeWbOVTV/zqYvYoNyjd3eG/565+THoxv
4cDNvLbq1WRGKN/SIbDHUJullQXKt0KTt0bj2ziERxmtK1L6bw/h2zoY9779
7njgJ5RvB7XvGZRvD9X/Ecp3QFXf4ACXBwAA34aH
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw6BV/73XnpCKUz+Gguttj
kosJjC/gUPIqPXPRKgUoX8TBtkK5xUoIxpdw+FXNkKDGIg/lyzgILXf5yPBH
FspXcHALOy075a0MlK/kYB56fu3JQ9JQvopDWd/mBVWlUlC+msOKVbs6uBQl
oXwNhyqbhXahKhJQvpbD9gNc7vNfi0H5Og6CE/wYHI1gfD2HTevb5CTuiED5
Bg7B1zp7LskKQ/mGDkIvDhxaHSQI5Rs5eK5ct0p1Dj+Ub+zAW2RkfbmJF8o3
cVD2mnYtagUXlG/q8GHzxb+1opxQvpkDJDyZoHxzNL6FQ3iU0boipf/2EL6l
w3vLX/+c9L5B+VYOxr1vvzse+GkPAFmiY6A=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwmPV6ZdPPC4pQPoeDjHNZ
rJMujC/gUMk7a/2biQpQvoiDFbeAdx4zjC/hEKEss9f+tRyUL+MQ67pWm3Gb
LJSv4KBxKqntdrEMlK/k8F+oaY6GjzSUr+Kw+rVjup+JFJSv5qD/33Dza2ZJ
KF/DofSX+vqTp8ShfC2HZX9XyKvNEYPydRxW3D48de41UShfz8HszbO7a9hh
fAOHWX6Nvx5ziUD5hg6TUz9MjlkuBOUbOeyLUT0oxw3jGzt0G6XemZ0gAOWb
OOw9bvVO4zEPlG/q8GHzxb+1opxQvpkDJDyZoHxzBx/z+u2P9ZihfAuH8Cij
dUVK/+0hfEuH95a//jnpfYPyraD8Z/YADAtnsg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw2JXt9LX3miKUz+FwwyhD
3t0Txhdw8DWdfvDtMgUoX8Th0iIp6SfcML6EQ/vSh3nHvstB+TIOe0vu+Qid
k4XyFRwk1gbX6ZySgfKVHFJ+PJkzYZE0lK/i8CX/vG9UoRSUr+YgyT/FaoGl
JJSv4fD3iHz3llviUL6WQ1X9r4PZq8SgfB2HdbKXlbSei0D5eg5zG65W8a8T
hvINHPbFqB6U4xaC8g0dKjWP/0z1F4DyjRxynCbs5VvIB+UbO/it6XNN3coL
5Zs4fOPd2fjHlAfKN3U4K/Xh1RQBLijfzGHvcat3Go9h8uYORz/zB0cVwvgW
Dj91JtUsz+GE8i0d2iZmW1XLs0P5Vg4+5vXbH+sxQ/nWDtzMa6teTWaE8m0c
mBS0fnGv/mMP4ds6vLf89c9J7xmUbwfnAwAUOnee
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVwaHznF69xUhHK53CQ3LRK
abEjjC/g4C/yYLXgOgUoX8ShR0B3AxcXjC/hkGLAve7RNzkoX8ZhRdYUc/51
slC+goP7Dp2Cte0yUL6Sg1nmkVuzl0hD+SoO9+48T++fIQXlqznsOHZT0aRA
EsrXcJBf3Nuk7isB5Ws5hC2bbRTOIw7l6zicdY6QfPpDFMrXc7jO1n5d9pMI
lG/gMFX1byTDfGEo39AhoTD296kXglC+kUPkrLULRXUEoHxjh/Aoo3VFSvxQ
vonDNd6OjJ9+vFC+qcPFHVe/3PjBDeWbOZyV+vBqigAXlG/uoLOZhc2sjx3K
t3Coqv91MHsVG5Rv6bB893WxUzKsUL6Vg7yHr6XYKhjfGmr/f3sI38aBm3lt
1avJjFB5WzS+nQOTgtYv7tV/oOrtHYpXW9tvWsQAlXdwMO59+93xwE+IfIMD
VP9HqHpHOB8AEF6Cyw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwiLq8mu/lJUUon8PBM/z5
Ty5LGF/A4QGnxesTUxWgfBGHMicrv0e/5aF8CYcep6qbitvkoHwZh4XTeyT2
F8hC+QoOe1PuTTYzkYHylRwOaM2/5CkqDeWrOJwxe84VelcSyldzsBNTXfPr
iASUr+FQtlFuUuhdcShfy8Ehadv1SeViUL6Ow8U15z+r5IpC+XoOTgeD5bTl
RaB8A4eNn6TmV2UIQ/mGDvtiVA/KcQtB+UYOQi8OHFodJAjlGzvw5gi97igU
gPJNHHiLjKwvN/FC+aYOF3dc/XLjBzeUb+Yg/+/saYsPXFC+ucOJo7blJbs4
oHwLh+W7r4udkmGF8i0dqup/HcxexQblWzn4mNdvf6zHDOVbO4RHGa0rUvpv
D+HbOHAzr616NfkjlG/r8N7y1z8nvW/2AMrCdGc=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwOLHlwguRS4pQPoeDTeR5
Cxs7GF/A4eHcaYnJqxSgfBGHP1e225xmgfElHP5ZNV5++lIOypdxsCsKcLSa
LwvlKzhcZPjv/LdGBspXcujnfTVTIUwayldxeLnfc/asn5JQvppDRYPg9PKL
ElC+hsPbNs5VrR3iUL6WQ+NLxf2PPMWgfB2HD4GX+6eaiUL5eg7nEiM+fr4p
DOUbOPzwfsrR6CME5Rs6yK7+cy3GXBDKN3LgLTKyvtzEC+UbO2Sf2LHv8k5u
KN/EQdlr2rWoFVxQvqmDce/b744HOKF8MwedzSxsZn3sUL65w3vLX/+c9Nig
fAsHH/P67Y/1mKF8S6j+n/YQvpUDN/PaqleTP0L51lD9z+wBeUBwWA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwaGud4GVxSRHK53AwUlqY
JmIC4ws4LFn+/pFDrwKUL+KwPGb5yXs35aF8CQfdWKnLkxbIQfkyDpLSAR0m
nbJQvoLDp1lh7k+9ZaB8JYf9uyb3TxGQhvJVHLI3VhQkf5aE8tUc5D2Pyk2e
JwHlazgcPbj4xoEkcShfy6Gh1P6LlZoYlK/jYJ1VNCNhiwiUr+eQHcEemDxd
GMo3cFhqZXxi+VwhKN/QgWvxjzi3o4JQvpGDomN6Z+k/ASjf2OEab0fGTz9e
KN/E4RvvzsY/pjxQvqnDhBbmHfdjuaB8MzS+uQMkfJmgfAsHJgWtX9yr/9gD
AGTqW5k=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwsPdfHel1VhHK53Ao2nI7
ol4PxhdwWPkv8t3FxQpQvoiD1emZ35O/y0P5Eg6HvE6ulNwvB+XLOCyc3iOx
v0AWyldwMLsaKcOiKgPlKzn4Wvdt3vpDCspXcZh+5OzSkN2SUL6ag7znUbnJ
8ySgfA0Hnc0sbGZ94lC+lsPWmKqE8BwxKF/HoTba3mZLiCiUr+cQ9em2mepf
YSjfwKFS8/jPVH8BKN/QgUlB6xf3ah4o3whqPjuUb+xQO+/yHrGHzFC+iQM3
89qqV5MZoXxTB+Pet98dD/y0h/DNHN5b/vrnpPcNyjeHmv8HyreA6v8I5VtC
1T+D8q3g5gEAyG9oOg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw8P+9k2/9OUUon8PBM/z5
Ty5LGF/A4aBX8H7eSQpQvojDBMYzS15/lofyJRxy2DoZLPbKQfkyDo1/T376
GyAL5Ss4NNWdm6r0RRrKV3KYurY94vBJKShfxaFv5tXqcg9JKF/NYcbBeczt
YRJQvoZDsCEHw81gcShfy8Ehadv1SeViUL6Ow8U15z+r5IpC+XoOHl49tzZF
ikD5Bg5C3OJ7nu0RhvINHQzdZu30OisE5Rs5JBTG/j71QhDKN3ZQdEzvLP0n
AOWbODiH/DFjdeOD8k0dmBS0fnGv5oHyzRyMe99+dzzACeWbOyzffV3slAwr
lG/hoLOZhc2sjx3Kt3R4b/nrn5MeG5Rv5VA77/IesYfMUL411Pw/9hC+DdT8
n1C+LVT/MyjfDs4HAGQneEw=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7MVCt+7emK3kABVweCYZNkvwiCKUz+Hwc82q
HlMdGF/A4d6r92r2XQpQvoiD4J6kJfdOy0P5Eg5Vlne+vV4iB+XLOOwIXsS8
v1sWyldwaOXg+LM2XwbKV3LYYLfDakeMNJSv4nB0K/ubtQlSUL6aw4MTrwVz
xSWhfA2HcLYvd8JMJaB8LYeH2qmHuHXEoXwdh5JfK5UMrcSgfD2HP4tZFJ9f
EIHyDRy8N3/0CjQXhvINHS7ZT2IRvysI5Rs5rLZRytA4zA/lGzsc/cwfHFXI
A+WbOKxwPHz0mCQvlG/qYNz79rvjAU4o38xh+e7rYqdkWKF8cwd5D19LsVUw
voVDYI+hNksrC5Rv6QAJfyYo3wpq3k97CN8ajW/jwM28turVZEaoeluH4tXW
9psWMUD5dg7hUUbripT+Q9Xbo+l3QOU3oPEZHB2YFLR+ca/+A5V3hNr3ESrv
hMpvcELT74ym3xlNv4vDe8tf/5z0ntkDAJq8pbw=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwsFt3Z8+1K4pQPodD1GeT
gw5WML6Ag7Sf2v+NCxWgfBGHpV3W/zt/y0P5Eg4FGwquTDgrB+XLOGztfvRy
20JZKF/BoSk0bFm0vwyUr+QQ+yrn0XshaShfxaF/YrRQ8wVJKF/N4erbBo7X
jyWgfA0H1nxu49yj4lC+lgPbB/5rEzPEoHwdB4sse6NecVEoX89B50Pfuu39
wlC+gcNSK+MTy+cKQfmGDsUb13cGVAlC+UYO3Uapd2YnCED5xg45ThP28i3k
g/JNHKK0J3qcq+CG8k0dPmy++LdWlBPKN3Mw7n373fEAjG/uMPFxcbXTd3Yo
38JB3sPXUmwVK5Rv6cCkoPWLe/UfewjfCo1v7RAeZbSuSOk/lG/j8N7y1z8n
vW9Qvi0a386Bm3lt1avJH6F8e6j8MyjfAc4HACjRhB0=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwWHdwxbuFVxShfA4HhzS3
yjfWML6Aw1w72XcTFypA+SIOG37JntdlgPElHFZ9Uhd/f18OypdxKK7sSrhc
KQvlKzgkXdu87KC5DJSv5JA4JWSbh7I0lK/isMLNceqmP5JQvppDfO7G+TOu
SkD5Gg6ZfD9CcpeLQ/laDsv+rpBXmyMG5es4/OZLtz/oKgrl6znEX98ad7lC
BMo3cIiMP+QRFSEM5Rs6zNy/vDxURwjKN3J4fUe9Rb9JAMo3duARPlRe8JIf
yjdxuMbbkfHTjxfKN3WI0p7oca6CG8o3c5D/d/a0xQcuKN/cQdlr2rWoFTC+
hcPy3dfFTsmwQvmWDpDwZ4LyrRy4mddWvZrMCOVbOzApaP3iXv3HHsK3cXhv
+eufk943KN8Wyn9mDwBq13RC
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw4P4qp7vivCKUz+Hwco63
I78hjC/gMEXaLHjfTAUoX8ThbcbuC9dfyUP5Eg4a7akKN6bJQfkyDjyqkzcv
9ZeF8hUcNpkLyt5mk4HylRz275rcP0VAGspXcUg5vM2wh1cKyldzWLrp6OKO
yxJQvobDyalrAl9riEP5Wg51OlWz8z6IQvk6DtVXK3kZEkSgfD2H55qfKg0D
hKF8AwfDXdLqj0qFoHxDhyup3zg1dgpC+UYOlud2Lzj2QADKN3bgET5UXvCS
H8o3cSjdHWBj8YMPyjd1UPaadi1qBReUb+ZQVf/rYPYqNijf3IGbeW3Vq8mM
UL6FQ/Fqa/tNixigfEsHJgWtX9yr/9hD+FYO7y1//XPS+wblW6PxbdD4tg7G
vW+/Ox74CeXboZlnj6beAeqejxB+gwNcPwAc+Yen
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwmLhUyeX9eUUon8Phhf3N
t8laML6Aw81qR1+xGQpQvojDhCC3pZM+y0P5Eg6XXfs0uQ7IQfkyDiV/xc+m
FspC+QoOlp9OGgQ4yUD5Sg6ikRcrDa2koXwVB7liF6UrHyWhfDWHq28bOF4/
loDyNRx+bOcOlzkhDuVrOVTV/zqYvUoMytdx0Iq2OLrPXxTK13Ngl2MJOXJJ
GMo3cOjdzKm9774QlG/oMHP/8vJQHRjfyKF44/rOgCpBKN/YoXi1tf2mRQJQ
volDeJTRuiIlfijf1MFvTZ9r6lZeKN/M4afOpJrlOZxQvrnDe8tf/5z02KB8
Cwcf8/rtj/WYoXxLqPw3ewjfCsp/BuVbw/kAUExrEw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQEf7MVCt+7emK3kABVwMC/fZmV0QxHK53Dw+Jot
XeYE4ws48J0uPiq7UQHKF3E48DWKRVcdxpdw2BKVvSRfTB7Kl3HQSBa3zHki
C+UrOPyZu9Xl/QEZKF/J4dK6BeHbV0lD+SoOZX2bF1SVSkH5ag4nr7rlHjSX
hPI1HMLTVvz4xSwB5Ws5ZOv9vn/ppBiUr+OwsuDsxYw+UShfz4FdjiXkyCVh
KN/A4Y1wZOq3TiEo39Bht9SUuTvfC0D5Rg7bPkzQlzrLB+UbOwi+ERH7IAbj
m6DxTR0u7rj65cYPbijfzOHoZ/7gqEIeKN/c4RvvzsY/pjC+hUP2iR37Lu+E
qbdE02/lYNz79rvjAU4o39rhxFHb8pJdHFC+jYOPef32x3rMUL6tAyT+mKB8
Owd5D19LsVWsUL49mnoHh/Aoo3VFSv/twdwGBwdu5rVVryZ/hPAZHB3eW/76
56T3DCrviCbvBHXfT6i8E1weAAkamVs=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVweGx7dgXfOUUon8NhRsvj
uCxLGF/AwWfa/jN96xSgfBEHmWL7S4L8ML6EwzTBpbZmf+SgfBmHLzV++79s
koXyFRxWOCeJ9rrLQPlKDhl2IfsUGKWhfBUH610Ma23/SUL5ag5JOzZYHrot
AeVrOISnrfjxixnG13JQXNAo4nhWDMrXcWCaMf+3R4MolK/nMFX1byTDfGEo
38DhxxL2uieOQlC+ocPrO+ot+k0CUL6RQ47ThL18C/mgfGMH49633x0PcEL5
Jg4/dSbVLM+B8U0dlu++LnZKhhXKN3Ooqv91MHsVG5Rv7vDe8tc/Jz0Y38Kh
dt7lPWIPmaF8Swdu5rVVryYzQvlWUPt+2kP41lD93+wBRJdr6w==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwCNu5dkr2BUUon8Nh7vKj
3rZmML6Aw9GDWrW8yxWgfBGHv162ao+EYXwJh/jLbvb1b+WgfBmHf1emTLg5
XxbKV3DgvLOlf9EEGShfyeFgzP97iX7SUL6Kg/zRtqvXn0lC+WoOqaqGjHan
JaB8DQer148b1k8Th/K1HGatPOj8da0YlK/jkN9bKSk8WRTK13O4ztZ+XfaT
CJRv4DC34WoV/zphKN/Q4ZL9JBbxu4JQvpEDb47Q645CASjf2KF0d4CNxQ8+
KN/E4eKOq19u/OCG8k0dlL2mXYtawQXlm6HxzR1+6kyqWZ7DCeVbOGxclz9F
L5oDyrd0OHHUtrxkF4xv5fDe8tc/Jz02KN/awce8fvtjPWYo38aBSUHrF/fq
P/YQvi1U/Tco3w7OBwA9Onrw
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw+Nmd83/GRUUon8Phfeil
7/7qML6Agwlz5m/5WQpQvojDs45Fqv335aF8CYfrNQUtXOvkoHwZh8bCNXuX
lshC+QoOjWZa7V6eMlC+kkPY9QNssiLSUL6Kw79QMdnuG5JQvppDTyiXx6X1
ElC+hoPF0frqebvEoXwth3exB7cnHhOD8nUcTv960dW2VBTK13MI7DHUZmkV
gfINHMpFZzP0LxOG8g0dthcsi9QThfGNHGLYF82SdhWE8o0dcpwm7OVbyAfl
mzh8493Z+MeUB8o3dTgr9eHVFAEuKN/MQWczC5tZHzuUbw61nwXKt3AIjzJa
V6T03x7Ct3QoXm1tv2kRA1TeysG49+13xwM/ofLWDu8tf/1z0vtmDwB+/2eK

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwSE/2n8h4TRHK53BInpru
wWIB4ws4FHY4vn45RwHKF3HIfuTHVvdKHsqXcChe+P3qhlVyUL6MQ/brVHXW
NlkoX8Ghuaqx2D5MBspXcqhVi9t9k1sayldxuPXv7Oun5yShfDWHG4KfJDNL
JKB8DYedMpG5J1TFoXwth/eWv/456YlB+ToOHwIv9081E4Xy9Rxikh491nkh
DOUbOBjuklZ/VCoE5Rs6KDqmd5b+E4DyjRyWKXvdMjkE4xs78AgfKi94yQ/l
mzh0G6XemZ0Akzd18FvT55q6lRfKN3O4uOPqlxs/uKF8c4cJLcw77sdyQfkW
DhvX5U/Ri+aA8i0dqup/HcxexQblWznIe/haiq1ihfKtHQJ7DLVZWlmgfBuH
8CijdUVK/+0hfFsHbua1Va8mf7QHADukcNA=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVw+Hk2/6DiXkUon8PBJDn/
3kdRGF/AYUPq3jkLJyhA+SIODjuZev+9lYfyJRyKF36/umGVHJQv4zCV48TC
KzmyUL6Cw8ebsX0RiTJQvpLDqf3/Jp6Vl4byVRwaK9+WK0pLQflqDlffNnC8
fiwB5Ws4iPqlmT/bLg7lazk4JG27PqlcDMrXcQi9ydrZUS0K5es5+BULVE87
KgLlGziolDNONnsvDOUbOixcckK0/5oQlG/kcMl+Eov4XUEo39jBc+W6Vapz
+KF8E4ejn/mDowp5oHxThxNHbctLdnFA+WYOG9flT9GLhvHNHT5svvi3VpQT
yrdwaJuYbVUtzw7lWzrUzru8R+whM5Rv5RAeZbSuSOm/PYRv7QCJHyaovA2a
eluHwB5DbZZWFijfzsG49+13xwM/ofrt0fgODtzMa6teTf5oDwDAyILg
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQDQEf7MVCt+7emK3kABVwsPv8wHPZdUUon8PhaojO
EUZPGF/AoeiE/4rU7QpQvoiD833NpxckYHwJh5w/x4zYWeWhfBkHdvZ7H6c+
lYXyFRyct8SfO7ZeBspXchBdX3y+rFgayldx0PxTY/8zXwrKV3NQlcmIXhQo
CeVrOMgv7m1S95WA8rUcgmf+fxwgIw7l6zisuH146txrolC+noN2v9s5p9Mi
UL6Bw+aC4s9RFcJQvqHDD++nHI0+QlC+kcMyZa9bJocEoHxjh/Aoo3VFSvxQ
vomD4BsRsQ9ifFC+qUOU9kSPcxXcUL6Zw4fNF//WinJC+eYOVfW/DmavYoPy
LRwCewy1WVpZoHxLB0j4M0H5Vg7vLX/9c9KDqbdG02+Dxrd1kPfwtRRbxQrl
26GZb4+m3sHBx7x++2M9Zgi/wcGhdt7lPWIPoXwGR1R+g6ND8Wpr+02LGKDy
TtDw+G8PkXdy4GZeW/Vq8kcIn8EZ6v5v9gCp55V0
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwYLd4UPXknCKUz+GwJctg
nbcijC/gYBPhX1fcoADlizgsvPsjtOq8PJQv4XCnfdlOuflyUL6MQ4nbKbG1
wbJQvoLDp3nLtE2ZZKB8JYfyuar/Ay9KQfkqDrUbr0/1S5eE8tUcqmwW2oWq
SED5Gg4zLHdPe3tIDMrXctCKtji6z18Uytdx8PDqubUpUgTK13MwdJu10+us
EJRv4MDNvLbq1WRBKN/QYb30mu2XvPmhfCOHJScXl3GX8EH5xg5R2hM9zlVw
Q/kmDj91JtUsz+GE8k0dNq7Ln6IXzQHlmzmcOGpbXrILxjd30NnMwmbWxw7l
WzjIe/haiq1ihfItHXzM67c/1mOG8q0caudd3iP2EMa3dmBS0PrFvfqPPYRv
g8a3hfrnoz0AcfBtHw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw4N6oeSXygiKUz+GgGrTV
/6spjC/gEK4yXSlougKUL+Kw4ZfseV0GGF/CwXTPiW//XshB+TIOPWKfuPfM
kYXyFRyuxZ7R0MqVgfKVHNw7l3uJG0pD+SoO/0LFZLtvSEL5ag4vI85WvKuQ
gPI1HDKvqepxTxSH8rUceFaaB+6ZLwbl6zisuH146txrolC+noPJpd5y1V0i
UL6Bw1TVv5EM84WhfEOHrJIf2xjDhaB8I4dL9pNYxO8KQvnGDsuUvW6ZHBKA
8k0cBN+IiH0Q44PyTR3OSn14NUWAC8o3c6idd3mP2ENmKN/cARK+TFC+hYOP
ef32x3oweUuH95a//jnpPbOH8K3gfACKzmUL
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVw+HT6zOed5xWhfA6HSatb
PNeawvgCDvPs1rOyTlSA8kUcMg4/ZLzwUx7Kl3D4oHqO3eG6HJQv45D95cfK
L4tkoXwFh4qoiXXvXWSgfCUHUdlYrWAmaShfxWHDT6E+pbeSUL6ag82ua60X
uySgfA0Hnc0sbGZ94lC+lgP35S+F/+rEoHwdh8yUrxX66qJQvp5DMIPFuY2C
IlC+gcPCJSdE+68JQfmGDi4NFX8N2wWhfCMHHuFD5QUv+aF8YwfBNyJiH8T4
oHwTh+wTO/Zd3skN5Zs6fNh88W+tKCeUbwZ1HzuUb+4w8XFxtdN3GN/Coar+
18HsVWxQvqWDvIevpdgqVijfyqF23uU9Yg+ZoXxrByYFrV/cq//YQ/g2aHxb
h+LV1vabFjFA1ds5GPe+/e544CdU3h6N74Cqv8HBITzKaF2R0n+ovKMDN/Pa
qleTP0Ll0fgMTg7vLX/9c9J7Zg8Am4uRrA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwOHUi2/XdSUUon8OB+UN5
FKMRjC/gYPf+xpPHExSgfBGHwl3ffFPey0P5Eg4Lk983bt0iB+XLOFT/VPSI
LJaF8hUczEsK7+QbyUD5Sg4b5uWExWhLQ/kqDgyT27tmKklB+WoOCT+f/+wV
loTyNRwOiKxmT3wlDuVrOQR82XJyhwuMr+Ow4vbhqXOviUL5eg6b1rfJSdwR
gfINHMpFZzP0LxOG8g0dot33c/3aIATlGznIrv5zLcZcEMo3dlim7HXL5JAA
lG/isO3DBH2ps3xQvqmDste0a1EruKB8M4e2idlW1fLsUL65w/Ld18VOybBC
+RYOkPBmgvIt0fhWDsa9b787HvhpD+FbO3Azr616NfmjPQBxp2yG
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwiHH4eFrogiKUz+GQfGin
x1JrGF/AIdCpyeXMXAUoX8SBa2Xr2R2MML6Ew6c7prGf18tB+TIOqbI/Zm6I
lIXyFRwsqoX4HujJQPlKDu+/+n35piAN5as4xJz35Nx7WxLKV3M4Y/fELeis
BJSv4SDql2b+bLs4lK/lEBD0TXp9kxiUr+MQPGeKdJWhKJSv51BVqf38mqoI
lG/gsPd4+/0f9UJQvqHDyWsqX37zCEL5Rg7hUUbripT4oXxjhyjtiR7nKrih
fBMHZa9p16JWcEH5pg46m1nYzPrYoXwzh+W7r4udkmGF8s0duJnXVr2azAjl
W0DN/28P4Vs6vLf89c9J7xuUb+Vg3Pv2u+OBn/YA1INmRw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwEHstpz/tviKUz+FgfyNX
/mkAjC/gELQh31h4pwKUL+JgeIRzaoIsjC/hYLRVMcuCXR7Kl3FgZ7/3cepT
WShfwWGy/smVYstloHwlB9dkZ1e2UGkoX8Uhe2NFQfJnSShfzYFda1uP2BYJ
KF/DYc112QfLl4hD+VoOW2OqEsJzxKB8HYeZffOyDpWJQvl6DucSIz5+vikM
5Rs4aMuKSaYnCkH5hg7FG9d3BlQJQvlGDievqXz5zQPjGzsE5Gid/iopAOWb
oPFNHVY4Hj56TJIXyjdzUPaadi1qBReUb+5g3Pv2u+MBTijfwmHjuvwpetEc
UL6lQ1X9r4PZq9igfCuH4tXW9psWMUD51lD9P+0BQgZmcA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwcPbwrLU4qwjlczjYzZM5
cc8AxhdweGx+fwLzbAUoX8RBzHSZ30YOGF/C4dLBhHdbT8tB+TIOx0w9JebM
lIXyFRzmpYg6HuqWgfKVHJau7ur7pC8N5as4pBzeZtjDKwXlqzkwinR8/vdX
AsrXcOCo65c+FS8O5Ws5KG3imHXUVwzK13G4F9HX3vNdBMrXc4hJevRY54Uw
lG/gEHyts+eSLIxv6PB4z98GbXMhKN/I4fO/XZFN7AJQvrGDc8gfM1Y3Pijf
xGHjuvwpetEcUL6pQ2CPoTZLKwuUb4bGN3fwMa/f/liPGcq3cAiPMlpXpPTf
HsK3dGBS0PrFvfqPPQCdKl0+
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwODCPa9vLU4pQPofDpLtv
ld9ow/gCDvuPKMsdmqIA5Ys4fDnQuIDjhTyUL+HwVGVW4/RjclC+jIPalq/T
zdfIQvkKDlvOPTx4oVYGyldykE9q/D3VVhrKV3GYLmS7f91jSShfzUHk7J2T
/15KQPkaDpbuVxw2rReH8rUc+srqm2zuiUH5Og7/ir6rch4VhfL1HK6ztV+X
/SQC5Rs4yO0s3tZ+WhjKN3TIKvmxjTFcCMo3ckgojP196oUglG/sUKo5ZfKk
TQJQvonDf4bA/wkl/FC+qUPp7gAbix98UL6Zw+xr3D+XmXJD+eYOxr1vvzse
4ITyLRw+bL74t1YUxrd0OHHUtrxkFweUb+WwfPd1sVMyrFC+tUN4lNG6IqX/
9hC+jQOTgtYv7tV/oHxbqPk/7QF01nsU
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwWPmpbcevS4pQPofD2t+l
2zT1YXwBh20PbeV9pilA+SIOOjYZP9OZYHwJh9S2ZdlFL+WgfBmH7C8/Vn5Z
JAvlKzjos164rNAlA+UrORROXb/odbA0lK/ikHJ4m2EPrxSUr+YgcvbOyX8v
JaB8DYcf27nDZU6IQ/laDltjqhLCc8SgfB2Hx41CGgXJolC+noPuc+kGLhYR
KN/AYe/x9vs/6oWgfEMHTT9lEddcQSjfyKFS8/jPVH8BKN/YYYXj4aPHJHmh
fBOHD5sv/q0V5YTyTR02rsufohfNAeWbORSvtrbftIgByjdH41s4MClo/eJe
/ccewrd04GZeW/Vq8kco3wrOBwCoQGdj
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwKHDbKR19UxHK53CINTkX
tMMBxhdwuLSvPPPhKgUoX8Sh8mzf2d+sML6Ew84T7B83vZaD8mUc7pjxcN7d
JQvlKzj0zI+auHOODJSv5JAu21t0IVYayldxWHe+MtDKXArKV3O4J81yn+ub
BJSv4dBj9S/NuVwcytdyWNTIs2lJoBiUr+OgfVzi65KHIlC+nkN2BHtg8nRh
KN/AYV+M6kE5biEo39BBV1Dj46yLAlC+kUOO04S9fAv5oHxjh4s7rn658YMb
yjdxWL77utgpGVYo39TBx7x++2M9ZijfDI1v7hDYY6jN0soC5Vs4QMKbCcq3
RFNv5RAeZbSuSOm/PYRv7fDe8tc/J71vUL4NGt8Wyn8G5dvB+QCYlnhh
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwMD8kELLjpCKUz+HwPvTS
d391GF/AoWfh8vsVkxWgfBGHOs4FqZyMML6EQ8GGgisTzspB+TIOXtdkTreu
kIXyFRzigl4tOR0nA+UrOcgI7GSf4iYN5as4KJW/WHLdSArKV3OYWyuTtnSy
BJSv4fCRL/Swpr44lK/lsKiRZ9OSQDEoX8dB+7jE1yUPRaB8PYftBcsi9USF
oXwDBxsjn3a+BEEo39DB1+3Y0Se2AlC+kYPfmj7X1K28UL6xw8UdV7/c+MEN
5Zs4fNh88W+tKCeUb+qwfPd1sVMyrFC+mcN7y1//nPTYoHxzBx/z+u2P9Zih
fAuH4tXW9psWMUD5llD13+whfCsHbua1Va8mf7QHADZ6ZyA=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw2Nj9d5HaFUUon8Pho/Fr
XzdrGF/AYdNd918FCxSgfBEHfvv+9D18ML6Ew9r4FfeyzstB+TIOP2d/X6m8
UhbKV3DYcu7hwQu1MlC+ksOvXRbR/6uloXwVh3XnKwOtzKWgfDWHvplXq8s9
JKF8DYc4ra9fsuUloHwth/UhLCwf34lB+ToOp3+96GpbKgrl6zkE6C9QKpEQ
gfINHH4sYa974igE5Rs66ApqfJx1UQDKN3IIjzJaV6TED+UbO1zccfXLjR/c
UL6Jw8THxdVO39mhfFOHtonZVtXyML6Zw3vLX/+c9NigfHOoef/tIXwLB0h4
M0HlLdHkrdD41lDzvkH5Ng7czGurXk3+aA8AR9lz7g==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwWGZZ8rH9siKUz+Hg5P88
9ZU/jC/g0Puq7M3VHQpQvojDCv0Y/TRBGF/C4Y2Nxr3PV+SgfBmHTcnic7zb
ZaF8BYfHUWUuIRIyUL6Sw8TnBSmND6WgfBUHQ6dlqksXSEL5ag7nUzx8kldK
QPkaDj273t+K6xaH8rUclDZxzDrqKwbl6ziE3mTt7KgWhfL1HJwOBstpy4tA
+QYOMc3GUTdeCEH5hg4lGcv3+YvB+EYO0hKPX0ycJADlGzuU7g6wsfjBB+Wb
OHzj3dn4x5QHyjd1qKr/dTB7FRuUb+awfPd1sVMyrFC+uQM389qqV5MZoXwL
B0h4M0H5lg5MClq/uFf/sYfwrRzeW/7656T3zB4AP9Jlyw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVw+L15m9Xbw4pQPoeDsmWv
i7k6jC/g0Oocv+V6iwKUL+Kw8O6P0Krz8lC+hIPS+r03Pk6Ug/JlHHLVT+2V
rZaF8hUcHkeVuYRIyED5Sg5PP222OLBJCspXcZgh9vZE4nJJKF/N4WXE2Yp3
FRJQvobD5zbXCFcjcShfy8FsZVCsV7UYlK/jUBttb7MlRBTK13OI63B7aXtE
GMo3cNh7vP3+j3ohKN/QgZt5bdWryYJQvpHDf4bA/wkl/FC+sUN4lNG6IiUY
38SBt8jI+nITL5Rv6iD/7+xpiw9cUL6Zw3vLX/+c9NigfHMHH/P67Y/1mKF8
CzS+JdR+RijfyoFJQesX9+o/9hC+NVT+I5RvgyZvC7XvG5RvhyZvD9cPACU8
ezw=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw0DD4mOJ8WhHK53BQlNzq
c9QUxhdwuOW+7tG9mQpQvojD9JtOFe2f5KF8CQfZ8C92D8/LQfkyDkmmr8J/
1clC+QoOc9Y2PDznKgPlKzk8fqCz2dpIGspXceD6b5z15p4klK/mcCN9Sv66
tRJQvoZD5cbAHxpV4lC+lsPX7a07v90ShfJ1HFpYTp7imC4C5es5eG/+6BVo
LgzlGzj8WMJe98RRCMo3dOg2Sr0zO0EAyjdyWHJycRl3CR+Ub+wwoYV5x/1Y
LijfxOGs1IdXUwRgfFMHeQ9fS7FVrFC+mUN4lNG6IqX/9hC+uYNx79vvjgd+
QvkWDtzMa6teTf4I5VuiyVvB5QEZImv1
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwUHc4JNF9WhHK53DQ+Rl+
6bMSjC/gMC3NulalRAHKF3G4WN28f3KXPJQv4VDI6P/0doYclC/jkN2qYleo
KwvlKzisfBNZZfdJGspXcmDRXmHIcV8Kyldx+PywdWHYVUkoX83h/7SdyY8e
SkD5Gg6Z11T1uCeKQ/laDmwf+K9NzBCD8nUcnHWunmduFYXy9Rxkbkc4CEwU
gfINHDZ+kppflSEM5Rs6PJptZnp7shCUb+Qgu/rPtRhzQSjf2IFH+FB5wUt+
KN/EYYXj4aPHJHmhfFOHKO2JHucquKF8M4eN6/Kn6EVzQPnmDrXzLu8Re8gM
5Vs4VNX/Opi9ig3Kt0STt3IoXm1tv2kRA5Rv7RAeZbSuSOm/PYRv48DNvLbq
1eSP9gBHmmzV
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBwAGIQDQEf7MVCt+7emK3kABVw2Hdmg3vzdUUon8PBIc2t
8o01jC/g4LliXezFBQpQvojDtxtX967+Lw/lSzhc41fb8GipHJQv47AwZn0t
a7QslK/goKjwxqTHUAbKV3KYU3glxOSpFJSv4mD2K3f/3vWSUL6awwwflSCO
XgkoX8PB0v2Kw6b14lC+loPgBD8GRyMxKF/HYZ3sZSWt5yJQvp6DzO0IB4GJ
ML6Bw3PNT5WGAcJQvqHD4z1/G7TNhaB8IweXhoq/hu2CUL6xg6/bsaNPbAWg
fBMHHuFD5QUv+aF8U4cVjoePHpPkhfLNHE4ctS0v2cUB5Zs7tE3MtqqWZ4fy
LRwCewy1WVpZoHxLh+W7r4udkmGF8q0cuJnXVr2azAjlWzsUr7a237SIAcq3
cQiPMlpXpPTfHsK3har/COXbOTApaP3iXv0HyrdH0++Aym9wcPAxr9/+WI8Z
Ku/oAEkPTFB5R4f3lr/+OemxQeWdHKrqfx3MXgXlNzg5yHv4Woqtgrnf2aF2
3uU9Yg+h5jU4o5rH4IJmvouDce/b744HfkLd64rqnwZXNHk3qHu+QeXd0Pzr
jibvjhY+HlD5Z1B5DzR5T1T7GjxRzWPwQtPvhRa+3mj+80Zzvw9qfDf4oMW3
L2r8Nvii+c8PzX9+qO5h8EeTR+MzBMD5AAZdEbc=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwUBLiEPa4oAjlczjU6ij9
m2sP4ws46FbO+ZK2UgHKF3H48MA8ql8IxpdwKJGxrDnzSg7Kl3FodhVlqzor
C+UrOIQeYLZtWCoD5Ss5NPs/it5bLg3lqzjMW2AamWAoBeWrOeg23ozj/iIB
5Ws4iPqlmT/bLg7laznMK11xy0BJDMrXcfhduKDeN0MUytdzmOXX+OsxlwiU
b+AQfK2z55KsMJRv6CC7+s+1GHNBKN/IoVLz+M9UfwEo39ghx2nCXr6FfFC+
iYNx79vvjgc4oXxThxNHbctLdnFA+WYOEx8XVzt9Z4fyzR2q6n8dzF7FBuVb
OPiY129/rMcM5Vs6cDOvrXo1mRHKt3J4b/nrn5PeM3sAC1pjnA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwSKkw3DHlliKUz+Fgkf7c
eqkHjC/g0N33NaZgqQKUL+Kg6lnheFMMxpdwCEr9ZWX2RQ7Kl3F4fr7+6edr
slC+gsO8rvOzPPbIQPlKDi0sgQsv7JOG8lUcsn49Tv0XLAXlqzlcPi7DfItd
EsrXcIj33uOw55A4lK/lYKW24caaXjEoX8dh+e7rYqdkRKF8PQeVcsbJZu+F
oXwDh5n7l5eH6ghB+YYOr++ot+g3CUD5Rg7KXtOuRa3ggvKNHarqfx3MXsUG
5Zs4MClo/eJe/ccewjd18DGv3/5Yjxkqb4bGN3cw7n373fHAT6h6CzS+pcN7
y1//nPS+QflWaPLWaHwbB27mtVWvJn+0BwDBJnYw
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw4L1yL6vmmiKUz+Hwccpc
URMLGF/AgctvR4vAAgUoX8SB7+eP1pVsML6Ewz+rxstPX8pB+TIOGsniljlP
ZKF8BYfJ+idXii2XgfKVHDbY7bDaESMN5as43FdyebzLXwrKV3OwtfI0VEqQ
hPI1HK5frT3VZSMB5Ws5yHVkrfwiKg7l6zisFnwnobZZFMrXc6i+WsnLkCAC
5Rs4xDQbR914IQTlGzpcSf3GqbFTEMo3cijVnDJ50iYBKN/YwW9Nn2vqVl4o
38SBSUHrF/dqHijf1EHZa9q1qBVcUL6Zw4fNF//WinJC+eYOEx8XVzt9Z4fy
LRwCewy1WVpZoHxLNL6Vg85mFjazPph6azR5GwdIfDFB+bYO4VFG64qU/ttD
+HYOxr1vvzse+Anl2zu8t/z1z0nvGZTv4MDNvLbq1eSPEH6DA1weABE5fTA=

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwyLV0ur3qtiKUz+Fgtiqw
KNsOxhdwKHmVnrlolQKUL+IgZhQT8kEKxpdwWGEcf32XuDyUL+PwYd3X1qIL
slC+gkNY4oR272UyUL6SQ36Nf6qrrzSUr+KgVP5iyXUjKShfzeFe2MPKI9yS
UL6Gw6m49Z/2mUtA+VoOH/lCD2vqi0P5Og4fAi/3TzUThfL1HGKSHj3WeSEM
5Rs4QPwrBOUbOpy8pvLlN48glG/kIPhGROyDGB+Ub+wwoYV5x/1YLijfxGHj
uvwpetEcUL6pw8THxdVO39mhfDMHH/P67Y/1mKF8c4fwKKN1RUr/7SF8Cwcm
Ba1f3Kv/QPmWDsa9b787HvgJ5Vuh8a3R1Ns4vLf89c9J7xuUb4vGt0NTbw+V
f2YPAIaOfyg=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwyLz2uGzrWUUon8PhhTZv
Q7otjC/gwOe+fE3vNAUoX8Th0ITV55U+ykP5Eg6JB35F7zwiB+XLOIj9XH7+
9wxZKF/BQaL0Y8GUZhkoX8nh9pHfR3MjpaF8FYcJLcw77sdKQflqDrUbr0/1
S5eE8jUc+L+sC35rJAHlazlEnefNnPlQDMrXcVBkufvg8x8RKF/PoapS+/k1
VRjfwMF780evQHNhKN/QQXb1n2sx5oJQvpGD5bndC449EIDyjR2u8XZk/PTj
hfJNHH7qTKpZnsMJ5Zs6BPYYarO0skD5Zg7hUUbripT+20P45g618y7vEXvI
DJW3cPAxr9/+WA/Gt3Qw7n373fHAT6h6KwcmBa1f3Kv/2AMAzAZrXQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQEf7MVCt+7emK3kABVwMC/fZmV0QxHK53DY1Zy4
ntkFxhdwWNm4W7x0rQKUL+LAcaP9nREnjC/hYHk+zr70lhyUL+Pg9HD6vui5
slC+gsOaDwf6kqJloHwlh3iBi88Z3ktB+SoOyw7tPZZ1QhLKV3PYUxz522yb
BJSv4fA6ZVPTpzXiUL6Ww3vLX/+c9MSgfB2Hkp2HFA57iUL5eg6z/Bp/PeYS
gfINHBYuOSHaf00Iyjd0kF3951qMuSCUb+TwTF/JOE8Txjd2qNQ8/jPVXwDK
N3FYcnJxGXcJH5Rv6sCkoPWLezUPlG/m8I13Z+MfUxjf3OHEUdvykl0cUL6F
Q1X9r4PZq9igfEuH5buvi52SYYXyrRwCewy1WVpZoHxrNHkbNHlbh9p5l/eI
PWSG8u3Q1Nuj8R0cuJnXVr2azAjhNzg4GPe+/e544Kc9RN4Rld/gCA3fZ1B5
Jyj/G1QewQcA0W2ZDQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw4Pvywn3VCUUon8PB8m2g
YJIRjC/gMOd+3A3/SQpQvojDtaPPbzAywPgSDts3VL0JuSYH5cs4vGycYLNm
nSyUr+Cw4K9Ft0WrDJSv5PDwhKjH+yppKF/FoV/Ff451vxSUr+ZwTtHW0T1U
EsrXcHhvYOW76Ys4lK/l8C724PbEY2JQvo7DxTXnP6vkikL5eg66z6UbuFhE
oHwDh3Xu74PKeYShfEOHgmufDyUqCkH5Rg6afsoirrmCUL6xwzN9JeM8TRjf
xOHzv12RTewCUL6pwzXejoyffrxQvpnDWakPr6YIcEH55g7Ld18XOyXDCuVb
OIRHGa0rUvpvD+FbovGtHLiZ11a9mvwRyrd2eG/565+T3jN7AGLsaoM=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwmHHh08fvdxWhfA4H0/nT
Hl11hfEFHHYrhdrs3KgA5Ys4vFd8+0BEE8aXcLDxzXP6qCUP5cs4JFUZrLz7
SRbKV3AIYN+56MMpGShfyWHb8Q/f7KdLQ/kqDmb/X2170isF5as5SPJPsVpg
KQnlazhMVnj6IsBRAsrXcpjoLq5XdV0MytdxOHmlpbX0pCiUr+cQ4dEv8Gi/
CJRv4LC9YFmknqgwlG/ooOiY3ln6TwDKN3KInLV2oagOjG/skOM0YS/fQj4o
38Qh+8SOfZd3ckP5pg7GvW+/Ox7ghPLNHKrqfx3MXsUG5Zs7BPYYarO0skD5
Fg7czGurXk1mhPItHSDhzwTlWzm8t/z1z0nvmz0AQiBoyQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwuLzQu5rjjCKUz+FQ/aJQ
T0MbxhdwmJjI4X2sVwHKF3G49m9a+x0OGF/CofXary+15+SgfBmH55u+xBbm
y0L5Cg6O0o3m7N4yUL6Sw+W7+79x8EpD+SoO8kfbrl5/JgnlqzkEbFTwDNsh
AeVrOPzYzh0uc0IcytdykOvIWvlFFMbXcZilsJX/2XNRKF/Pob3qSMWPOSJQ
voHD9Ic9jPc+CkH5hg42Rj7tfAmCUL6Rg334lxg/aRjf2MFz5bpVqnP4oXwT
B8E3ImIfxPigfFOHvcet3mk85oHyzRyMe99+dzzACeWbOyzffV3slAwrlG/h
UFX/62D2KjYo39JB3sPXUmwVTN7Kwce8fvtjPWYo39qhdt7lPWIPYXwbNHlb
NL6dA5OC1i/u1X/sIXx7h/eWv/456X2D8h3gfAD+0X6K
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwiDN8sVblmiKUz+Gw7Z35
Z01dGF/AQf/IxocFkxSgfBGH+8y3Kz7ckofyJRwqg045tB2Xg/JlHM79Trr1
sk8WyldweMI5V824TwbKV3K4feT30dxIaShfxeHWv7Ovn56ThPLVHDJ3T8jc
elMCytdwyF2SxN6WJw7lazks4GeS+uMqBuXrOGSmfK3QVxeF8vUc3uUe+Wr8
TRjKN3DwMa/f/lgPxjd0sDHyaedLEITyjRzWS6/ZfsmbH8o3dvjGu7PxjykP
lG/icOKobXnJLg4o39RBZzMLm1kfO5Rv5lA77/IesYfMUL65Q/Fqa/tNixig
fAs0vqWDce/b744HftpD+FYO7y1//XPS+wblWztwM6+tejX5oz0AY9Nv8A==

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw2DQjyuPbOUUon8PhUox5
zx5zGF/AQdXiv/DjWQpQvojDwq1FQnsEYHwJh7PWnUaf3spB+TIOl6ZsmvP8
gCyUr+AwuXnnkTfzZaB8JYddez481q2XhvJVHJy1zsbeXScF5as5zBB7eyJx
uSSUr+Gg1O0Qdn2qBJSv5fC3SNG31EIcytdx2Psm2M9/sRiUr+fwuFFIoyBZ
FMo3cDiXGPHx801hKN/QoelJUu+TNYJQvpFDqeaUyZM2CUD5xg4rHA8fPSbJ
C+WbOHzYfPFvrSgnlG/q0DYx26panh3KN3MoXm1tv2kRA5Rv7hAeZbSuSOm/
PYRv4WDc+/a744GfUL6lw3vLX/+c9L5B+VZQ/jMo3xrOBwDBSHPc
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwOCb5O6D5liKUz+Hw7EWB
2RNjGF/A4ehBrVre5QpQvoiDX7rp/t//5KF8CQenSwZFzzfIQfkyDgdfn7ga
WicL5Ss4CKemBgYby0D5Sg6Nv/cue/VTCspXceD6b5z15p4klK/mcP1q7aku
GwkoX8PhUE+/4GIlcShfy+Hj9qBgZTsxKF/HYZ3sZSWt5yJQvp7Dz8Tiv41b
haF8A4cjAQdmN+wSgvINHVLnLmOqXiAI5Rs52Id/ifGThvGNHTxXrlulOocf
yjdx0LXVC9n/jBfKN3XgLTKyvtwE45s5/NSZVLM8hxPKN3dYvvu62CkZVijf
wqF23uU9Yg+ZoXxLh/Aoo3VFSv/tIXwrh/eWv/456X2D8q0dmBS0fnGv/gPl
26DxbaHqn9kDABT0dls=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwcOM5L3HlmiKUz+EgMmX2
6z0mML6Ag0G1n8zd1QpQvoiD7h+ZeU8YYXwJB5XSt9Mrn8hB+TIO3X27z289
JAvlKzhc5V7LKtsoA+UrORiLJ6mtKZOG8lUcNiT4mG9zlYLy1Ryuvm3geP1Y
AsrXcOic6s4qf0EcytdyyNb7ff/SSTEoX8ehcoLIVU9GGF/PYfnu62KnZESh
fAOHWX6Nvx5ziUD5hg5soYybPxwWgvKNHB7NNjO9PRnGN3bgZl5b9WqyIJRv
4sCbI/S6o1AAyjd1WG2jlKFxmB/KN3PY9mGCvtRZPijf3GHvcat3Go95oHwL
hwktzDvux3JB+ZYOZ6U+vJoiAONbObRNzLaqlmeH8q2h7meF8m2g7mGE8m2h
/I/2EL6dw3vLX/+c9J7ZAwD3IXQO
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwSE/2n8h4TRHK53CoFFJp
UbCF8QUc1K4sDb6xRgHKF3HY4GBZoyEP40s43Nn2TFVTQh7Kl3Ew4TFtO/tK
FspXcHhg4bdf4o0MlK/kcGndgvDtq6ShfBWHxgS37dPzpKB8NYfgHX8MGE0k
oXwNhwVTOTiOXxKH8rUc5vFM3yZyRQzK13GYdUpo14J1olC+noNfsUD1tKMi
UL6Bg495/fbHesJQvqGD4S5p9UelQlC+kYOuoMbHWRcFoHxjh/Aoo3VFSvxQ
vonDtg8T9KXO8kH5pg57j1u903jMA+WbOcj/O3va4gMXlG/usHz3dbFTMqxQ
voUDN/PaqleTGaF8SwcmBa1f3Kv/2EP4VlD5j1C+tcN7y1//nPSe2QMA7Shm
lg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVweGPy6eT+44pQPodDnWhE
8gk9GF/AgeNq9Iz8+QpQvojDT4O+g5EMML6Ew/YNVW9CrslB+TIOx0w9JebM
lIXyFRxaOTj+rM2XgfKVHL7IXZ5yq0cayldx6G+MPxxYIwXlqzkY2ixW+OUr
CeVrOFz4/OPAhXgJKF/L4XOba4SrkTiUr+Pw3vLXPyc9MShfz0HhsejUxZGi
UL6BQ9Px8NhfPiJQvqHDkYADsxt2CUH5Rg5XUr9xauwUhPKNHXKcJuzlW8gH
5Zs47D1u9U7jMQ+Ub+qQfWLHvss7uaF8M4e2idlW1fLsUL65w/Ld18VOybBC
+RYOkPBmgvItoe79Zg8AVJtlzw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwmHBcarPeVUUon8Mh7Yn0
tWA7GF/AYeW/yHcXFytA+SIOd55Lp8/+Kw/lSzhwaUyx5rgiB+XLOEhKB3SY
dMpC+QoOz5X2XVvgKwPlKznYHFiakMYvDeWrOOzf6N3DdUoSyldz+D9tZ/Kj
hxJQvoaDmJVCEU+tOJSv5ZCe/cz5AK8YlK/jcC+ir73nuwiUr+cQ9em2mepf
YSjfwGHv8fb7P+qFoHxDhxj2RbOkXQWhfCMHXUGNj7MuCkD5xg5LTi4u4y7h
g/JNHJxD/pixusH4pg4rHA8fPSbJC+WbORj3vv3ueIATyjd3aJuYbVUtzw7l
WzjIe/haiq1ihfItHQJ7DLVZWlmgfCuH8CijdUVK/+0hfGsHSPwwQeVtHJgU
tH5xr/4Dlbd1eG/565+T3jco3w6Nbw/lP7MHAD2xeMA=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwuLta2P3NdUUon8Mh7Yn0
tWA7GF/AoerftGmBSxSgfBGHwE2va/bww/gSDr9na7X94JCH8mUcjon4llm+
koXyFRye9Sp8rTokA+UrOZiHnl978pA0lK/i8C+6K11zgxSUr+YwacH9X/ez
JKF8DQfLnfX3RfUkoHwth1n+P+8n/BeD8nUcFB6LTl0cKQrl6znoPpdu4GIR
gfINHGKajaNuvBCC8g0dfng/5Wj0gfGNHJYpe90yOSQA5Rs78AgfKi94yQ/l
mzjo2uqF7H/GC+WbOkxoYd5xP5YLyjdzmPi4uNrpOzuUb+4ACV8mKN/CITzK
aF2R0n97CN8STd7Kwbj37XfHAz+h8tZofBsHbua1Va8mf7QHAJk6chk=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVwiOK9zFZ6VRHK53CYJ/XO
WtsBxhdw4PaKrjw3TwHKF3EQrn3m1skJ40s45OjrTZH6Kgflyzictp75fe0e
WShfwUHSfX514CwZKF/J4faR30dzI6WhfBUH+aNtV68/k4Ty1RxSVQ0Z7U5L
QPkaDn+LFH1LLcShfC2H079edLUtFYXydRw8vHpubYoUgfL1HHQ+9K3b3i8M
5Rs47D3efv9HvRCUb+hQqjll8qRNAlC+kUOO04S9fAv5oHxjB+eQP2asbjC+
iYP8v7OnLT5wQfmmDh82X/xbK8oJ5Zs5LN99XeyUDCuUb+7ApKD1i3v1H3sI
38IhPMpoXZHSfyjf0uG95a9/TnrfoHwrNPXWaOptHCDxxQQ13xZNvx2U/wzK
t0fjOzhwM6+tejX5I4Tf4IAm7wjnAwBDp43d
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7MVCt+7emK3kABVwaLg95478bUUon8NBw0hn
npM3jC/gsHjZnz1aKxSgfBGH70x5a60FYXwJh6YT0XqRr+SgfBkH1j/LNZ0e
y0L5Cg4xPGmmC9bIQPlKDisWLk5vbpWG8lUcLq95foYnUwrKV3NgFOn4/O+v
BJSv4bBgKgfH8UviUL6Ww/bT4qx/EsSgfB2HTevb5CTuiED5eg46H/rWbe8X
hvINHFLnLmOqXiAI5Rs6SEs8fjFxkgCUb+TgHPLHjNWND8o3dpD38LUUW8UK
5Zs4BPYYarO0skD5pmh8M4faeZf3iD1khvLN0fgWaHxLNL6VQ/Fqa/tNixig
fGsH49633x0P/LSH8G0cuJnXVr2azAiVt3V4b/nrn5PeM6i8HZT/Dcq3d2BS
0PrFvfoPlO+AKt/ggGa+I6r6Bkc085zQ9Duh2e8Mdd9HqDwan8EFzgcA3aGm
Yg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwWMPPJJ17RRHK53BYUrp3
XZwTjC/goFs550vaSgUoX8ShhJk7O1caxpdwSDHgXvfomxyUL+PwYd3X1qIL
slC+gsOpDCnlQ00yUL6Sg2jkxUpDK2koX8XhsfJB43n7JKF8NYeAjQqeYTsk
oHwNB94vc156zxGH8rUcGudeiJcsEIPydRyWTi0W3OkgCuXrOcRwSDXMsBSB
8g0ckk4o7TJuEIbyDR1m7l9eHqojBOUbOZRqTpk8aZMAlG/ssOTk4jLuEj4o
38TBb02fa+pWXijf1CFKe6LHuQpuKN/M4cRR2/KSXRxQvrlDVf2vg9mr2KB8
C4fAHkNtllYWKN/Swce8fvtjPWYo38ohPMpoXZHSf3sI39rhveWvf056z+wB
fnVk3g==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwUBLiEPa4oAjlczicWa7a
8tASxhdwcGApPia4RAHKF3H4adB3MJIBxpdwOLUsJfPKbTkoX8bB65rM6dYV
slC+ggPvtatvuZJloHwlh4LIo1cPqElD+SoOxr1vvzsekITy1RzWXImovB0h
AeVrOHDU9UufiheH8rUc1O8FLixlFYPydRy0oi2O7vMXhfL1HNqrjlT8mCMC
5Rs4bC9YFqknKgzlGzoUXPt8KFFRCMo3cjh5TeXLbx5BKN/Y4fUd9Rb9JgEo
38ThGm9Hxk8/Xijf1CFKe6LHuQpuKN/MQf7f2dMWH7igfHOHs1IfXk0RgPEt
HNomZltVy7ND+ZYOVfW/DmavYoPyrRwg8cEE5Vs7vLf89c9J75k9AKATaic=

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwOGx4V7j/giKUz+HQ7Ppc
tcAQxhdwKDgcuE5gugKUL+LwXLBp9XwWGF/C4c0bm8at1+WgfBmHwFfzf1Z2
yUL5Cg45qz22q0nJQPlKDhOfF6Q0PpSC8lUc5IpdlK58lITy1Rw+zdVz28EL
42s43FbOWnRcTQLK13J4b5/n+ZBVHMrXcYg3s2W7e1YUytdziPDoF3i0XwTK
N3DIjmAPTJ4uDOUbOszcv7w8VEcIyjdyeH1HvUW/SQDKN3bwW9PnmrqVF8o3
cTj6mT84qpAHyjd1mNDCvON+LBeUb+Zw4qhteckuDijf3OG95a9/TnpsUL6F
w/Ld18VOybBC+ZYOkPBngvKtoOq/2UP41g7czGurXk3+COXboMnbosnbwfkA
ev13rA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwmF1xLSj0tCKUz+HQ7Ppc
tcAQxhdwuHTy1i6VqQpQvoiDjk3Gz3QmGF/CITNug8653XJQvozD3ZNPfa93
ykL5Cg5Zb+rLPwXKQPlKDmIvohgUlKShfBWHzw9bF4ZdlYTy1RwYJ1z697JR
AsrXcJiz/V23LKc4lK/lcNY5QvLpD1EoX8fBOqtoRsIWEShfz2HjJ6n5VRnC
UL6BQwz7olnSroJQvqHD53+7IpvYBaB8I4fZ17h/LjPlhvKNHS7uuPrlxg8Y
38Thp86kmuU5nFC+qUNgj6E2SysLlG/m4GNev/2xHjOUb+4ACV8mKN/CoXi1
tf2mRQxQvqUDk4LWL+7Vf+whfCuH95a//jnpfYPyraH8Z/YA7t1tiA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwqLmmvr/1jCKUz+GwL3gN
9wY9GF/Aoe/B+tz1fQpQvohD790pblNvyUP5Eg4a7akKN6bJQfkyDr+3/29k
jJeF8hUcLBk35J+zk4HylRwSp4Rs81CWhvJVHJYd2nss64QklK/mwC6T8tS2
XwLK13Co3Bj4Q6NKHMrXcnBR5dO5LygG5es4tLCcPMUxXQTK13Pw3vzRK9Bc
GMo3cPixhL3uiaMQlG/oULxxfWdAlSCUb+TAI3yovOAlP5Rv7JDjNGEv30I+
KN/E4RvvzsY/pjxQvqnDT51JNctzOKF8M4faeZf3iD1khvLN0fgWDu8tf/1z
0vtmDwCLB15z
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwsOe9OnXmZUUon8Ph7WNj
16mmML6AwxPzhkzD6QpQvoiDCp/tychv8lC+hENQ6i8rsy9yUL6Mw2re9bN8
T8pC+QoOX3+lzNKskYHylRxkBHayT3GThvJVHKZnijMslJGC8tUcXNc/aJu4
RwLK13DIXZLE3pYnDuVrOTTOvRAvWSAG5es4ZKZ8rdBXF4Xy9RwC9BcolUiI
QPkGDicrXWxS1IShfEOHx3v+NmibC0H5Rg7Fq63tNy0SgPKNHbZ9mKAvdZYP
yjdx+Ma7s/GPKQ+Ub+qg7DXtWtQKLijfzOGnzqSa5TmcUL65g7yHr6XYKlYo
38LBx7x++2M9Zijf0oFJQesX9+o/9hC+lcN7y1//nPS+QfnWaPI2DuFRRuuK
lP7bAwC6MGfS
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVweKL/cm7LeUUon8NB4Ctr
rY4JjC/g4PtQ5mrAAgUoX8ThQoeEDwM7jC/hIBXa9MfkkRyUL+Mg2vr0qvQh
WShfwaHrv/zSj7EyUL6Sw8GY//cS/aShfBWHn1FbHN+wSkH5ag5c2s2xnB8k
oHwNh/iDDZJcwjC+lsM8nunbRK6IQfk6Ds46V88zt4pC+XoOUZ9um6n+FYby
DRxOVrrYpKjB+IYOsqv/XIsxF4TyjRw+/9sV2cQuAOUbO3zj3dn4x5QHyjdx
YFLQ+sW9GsY3dVD2mnYtagUXlG/mENhjqM3SygLlm0PV/7GH8C0c3lv++uek
9wzKt4TzAa/uXus=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwEEo5ajf3nCKUz+HAvaOo
vlANxhdwYJzHnNxZpQDlizi0Hj/2w2+vPJQv4aDCy6N3c5kclC/jwKLCdnR9
tCyUr+DQJqZ01TBJBspXclhttfHO4xdSUL6Kw+9Vry6010hC+WoOExcxT3hn
JwHlazhsnbXMsY9fHMrXcpgom/lm1mNRKF/HQbvf7ZzTaREoX89hll/jr8dc
ML6Bg+EuafVHpUJQvqHDbqkpc3e+F4DyjRxW2yhlaBzmh/KNHUp3B9hY/OCD
8k0corQnepyr4IbyTR1mX+P+ucwUxjdz+LD54t9aUU4o39xh+e7rYqdkWKF8
Cwcf8/rtj/WYoXxLh/Aoo3VFSv/tIXwrNL61w3vLX/+c9L5B+TYOxr1vvzse
+Anl28L5AEABc6A=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwmLhUyeX9eUUon8Mhf2M2
+1sTGF/AQTNVYM3RlQpQvohDFh9jSaQcjC/hcPbJSwk+XXkoX8ah9ULbqvvf
ZKF8BQeHgKQZge9koHwlhwn9F3xFvkpD+SoOtpucXkxYKwXlqzlMF7Ldv+6x
JJSv4XB7fnph52oJKF/LIaP6XtoiJnEoX8dhteA7CbXNolC+nkP89a1xlytE
oHwDh1l+jb8ec8H4hg7TH/Yw3vsoBOUbObjtfZnlcFEQyjd2KF5tbb9pkQCU
b+Lw+d+uyCZ2GN/UQddWL2T/M14o38xh73GrdxqPeaB8c4co7Yke5yq4oXwL
h6r6XwezV7FB+ZYOgT2G2iytLFC+FdQ+Bijf2sG49+13xwM/7SF8G4f3lr/+
Oel9swcAZrJwQA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwUL79b6baJUUon8Ph+fEz
vxbrwvgCDq8a5PLSpipA+SIO04OF9KdelYfyJRwmRNjH2KfIQfkyDs4yU8Ma
XWWhfKC+wLQvO39JQ/lKDvPP8/BNviQF5as46CxdIK7VIwnlqzmsuRJReTtC
AsrXcAg25GC4GSwO5Ws5PFp4JVRASgzK13FY/KQ1yTlNBMrXc4iMP+QRFSEM
5Rs4ZJX82MYYLgTlGzrYGPm08yUIQvlGDts+TNCXOssH5Rs7XNxx9cuNH9xQ
volD28Rsq2p5dijf1IGbeW3Vq8mMUL6ZA5OC1i/u1X/sIXxzqPxHKN8CjW/p
8N7y1z8nvWdQvpWDce/b744HftoDAGaQZXI=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwcNv7MsvhoiKUz+HwMc+O
7b8VjC/gMPG+g1rQYgUoX8RB6OnuMGteGF/CYQ7PguuLPshB+TIODNVfzssc
lYXyFRxuvvq5fVKPDJSv5LBhXk5YjLY0lK/ikHJ4m2EPrxSUr+bALpPy1LZf
AsrXcHjKtL1s0iNxKF/LYXfPhOXVG8WgfB2HeDNbtrtnRaF8PQftfrdzTqdF
oHwDB+/NH70CzYWhfEOHb13rxGO/CEL5Rg7LlL1umRwSgPKNHf4zBP5PKOGH
8k0cVjgePnpMkhfKN3U4+pk/OKqQB8o3czDuffvd8QAnlG/usHz3dbFTMqxQ
voUDJLyZoHxLh+LV1vabFjFA+VYOTApav7hX/7GH8K0d3lv++uek98weAOuW
atI=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwYNc3+PbsmCKUz+GQeMiV
L84axhdw+Lp1bXXhEgUoX8RBfM3U6xP5YXwJh07ZS8yPfslB+TIOrRfaVt3/
JgvlKziEJU5o914mA+UrOairyQe3LJCG8lUc5rzujevtkYLy1Ryyl1ZJlelI
QvkaDsKHFXXF54tD+VoOrqmPN/fMEIPydRxWC76TUNssCuXrOVRVaj+/pioC
5Rs4LFxyQrT/mhCUb+jgtvdllsNFQSjfyEHRMb2z9J8AlG/s4Ot27OgTWxjf
xOEb787GP6Y8UL6pA5OC1i/u1TC+mUP2iR37Lu/khvLNHX7qTKpZnsMJ5Vs4
LN99XeyUDCuUb+kQ2GOozdLKAuVbOXAzr616NZkRyrd2eG/565+T3jd7CN8G
zgcAqXxtcg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwWMPPJJ17RRHK53AQ+Ra6
RdgBxhdwkPZT+79xoQKUL+Jw7H/RmvsiML6Ew5s3No1br8tB+TIOrm9zN/kf
loXyFRzaxJSuGibJQPlKDvt3Te6fIiAN5as4/AsVk+2+IQnlqzn0Vzou0zgp
AeVrOBwRKa9U+CQO5Ws5WKltuLGmVwzK13H4zZduf9BVFMrXc5DbWbyt/bQw
lG/gEHyts+eSLIxv6ND0JKn3yRpBKN/IYZmy1y2TQwJQvrHD53+7IpvYYXwT
NL6pA5OC1i/u1TxQvpmD/L+zpy0+cEH55mh8C4fsEzv2Xd7JDeVbOpw4alte
sosDyrdykPfwtRRbxQrlWzv4mNdvf6zHDOXboPFtofb/sYfw7Ry4mddWvZr8
Ecq3d3hv+eufk943KN8Byn8G4Tc4wNUDALEmhTs=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwWG3BFtt0UhHK53BQSTf1
UzWD8QUcGD8wBqmsUoDyRRwyl03/b8kD40s4WJ6Psy+9JQflyzgcvy73dvdG
WShfwaHwyplwrjYZKF/JQTd/Wd1ZPWkoX8Whjd1egU9dCspXc7j6toHj9WMJ
KF/DYaHSHJmCTeJQvpZD40vF/Y88xaB8HYfgOVOkqwxFoXw9B6eDwXLa8iJQ
voHD9oJlkXqiwlC+ocOj2WamtycLQflGDs/0lYzzNAWhfGMHX7djR5/YCkD5
Jg6eK9etUp3DD+WbOuja6oXsf8YL5Zs5HP3MHxxVyAPlmzuclfrwaooAF5Rv
4SDv4WsptooVyrd0qJ13eY/YQ2Yo38qBm3lt1avJH+0hfGs0vo3De8tf/5z0
ntkDAJsiZxQ=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVw8JnUnR18XBHK53C4/iHo
qawejC/gcM0+7oPoZAUoX8RhAuOZJa8/y0P5Eg6nV8lVHF0hB+XLODg9nL4v
eq4slK/gUPf4pFV5vQyUr+Twq+HcAqtwaShfxSHU5laKyi1JKF/N4bjjBq5H
hySgfA2HowcX3ziQJA7lazks4GeS+uMqBuXrOMzsm5d1qEwUytdz+PXDeVG5
jgiUb+Bg6DZrp9dZISjf0EHTT1nENVcQyjdyeH1HvUW/SQDKN3YIjzJaV6TE
D+WbOOja6oXsf8YL5Zs6TGhh3nE/lgvKN3Ooqv91MHsVG5Rv7gAJXyYo38KB
SUHrF/fqP/YQvqWDce/b744HftoDAA5OY2c=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw6Pm3d7v2dUUon8NhtV1X
3kkfGF/AIbQ1tT1/nQKUL+LA/yrGjYUDxpdw4NKYYs1xRQ7Kl3E43fH88vPl
slC+gsOMntyft9tkoHwlh0bTzq+mWtJQvopDn/UUzUYuKShfzUHe86jc5HkS
UL6GA1+FVti9yeJQvpbDo4VXQgWkxKB8HYd8xt9tq6xFoXw9hydZmlZ/24Wh
fAMHV9snNed/CUH5hg5ci3/EuR0VhPKNHIpXW9tvWiQA5Rs7lO4OsLH4wQfl
mziclfrwaooAF5Rv6vBTZ1LN8hxOKN/MYeO6/Cl60RxQvrlDYI+hNksrC5Rv
4eBjXr/9sR4zlG/pEB5ltK5I6b89hG/l8N7y1z8nvWdQvjWU/80eACjGaHQ=

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwsHJ9vGXVRUUon8PhkK6r
9FMzGF/AYYq0WfC+mQpQvohDxuGHjBd+ykP5Eg55RhING/bKQfkyDpebbkfX
zJaF8hUc2kOVJKTDZaB8JYczVacSF4lLQ/kqDts3t1olbpOE8tUctK6tFeKY
IQHlazhkXlPV454oDuVrOTS+VNz/yFMMytdxuLBmb2fzNREoX8/hZ2Lx38at
wlC+gcM69/dB5TwwvqFDwbXPhxIVhaB8I4fijes7A6oEoXxjh20fJuhLneWD
8k0cmBS0fnGv5oHyTR0mtDDvuB/LBeWbOUx8XFzt9J0dyjd3qKr/dTB7FRuU
b+Eg7+FrKbaKFcq3dPAxr9/+WI8ZyreCmv/HHsK3dnhv+eufk94zKN8Gyv9m
DwAwcW5A
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwiDW24dh4TRHK53Bw4FZI
eGMO4ws4POC0eH1iqgKUL+LA8Nsm7AIrjC/h4JrCqht0WA7Kl3F4KfWKU69S
FspXcHiutO/aAl8ZKF/J4fiWEycrZaWhfBWHyuAunRP/JaF8NQdJhaNhj1lh
fA0HS/crDpvWi0P5Wg6ffx07eueWGJSv47Cy4OzFjD5RKF/Poa+gdFV0sAiU
b+BQLjqboX+ZMJRv6PCta5147BdBKN/IYbfUlLk73wtA+cYO2z5M0Jc6ywfl
mziscDx89JgkL5Rv6mDc+/a74wFOKN/Moar+18HsVWxQvrmDj3n99sd6zFC+
hUPtvMt7xB7C+JYO3Mxrq15NZoTyrRyKV1vbb1rEAOVbo8nboMnbOoRHGa0r
UvpvD+HbQd3z0x4AkFt2hQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwmF1xLSj0tCKUz+GQ9/Np
6iQjGF/AgevW0fzW2QpQvoiD4IWvtR4sML6Ew4TApcJ1V+SgfBmHGdvdY30P
yEL5Cg6K2Qsmp7XIQPlKDuFJXifijaWhfBWHJ1OPNL/Ql4Ly1Rz6Zl6tLveQ
hPI1HLZKPrv/5b44lK/l0MD/vSXOFMbXcZilsJX/2XNRKF/P4c9iFsXnF0Sg
fAOHqE+3zVT/CkP5hg5vhCNTv3UKQflGDk1PknqfrBGE8o0dLM/tXnDsgQCU
b+Kw5OTiMu4SPijf1GFCC/OO+7FcUL6Zw4fNF//WinJC+eYO7y1//XPSY4Py
LRwCewy1WVpZoHxLByYFrV/cq//YQ/hWDtzMa6teTf4I5VtD9X+zBwCyQW7z

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVw8OIXPP78giKUz+GQlH2O
L9EFxhdwuDsl9c6pnQpQvojD1fa85h/qML6Ew/5azudC/PJQvoyDGM+Z+dff
yUL5Cg6PHlsoKm2SgfKVHOZumfA/YbY0lK/i8J+rNWmevBSUr+ZQc2zdPa5P
ElC+hkPmNVU97oniUL6Ww+3jW25dLxaD8nUc7kX0tfd8F4Hy9Rw2fpKaX5Uh
DOUbOPzwfsrR6CME5Rs66ApqfJx1UQDKN3IIjzJaV6TED+UbO8j/O3va4gMX
lG/ikH1ix77LO7mhfFOHE0dty0t2cUD5Zg6Q8GSC8s0dmBS0fnGv/mMP4Vs4
vLf89c9J75k9AP9RYjs=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw8Gw3E+U4rwjlczgkHnLl
i7OG8QUcbDzvWa6bpwDlizhMljkx9ygzjC/hMCFwqXDdFTkoX8ZBtz/BQWaO
LJSv4GBRLcT3QE8GyldyOKA1/5KnqDSUr+IQ8nljzu7LklC+msPLiLMV7yok
oHwNh62zljn28YtD+VoOjxZeCRWQEoPydRxiOKQaZliKQPl6DtqyYpLpiUJQ
voFD8cb1nQFVglC+oUPp7gAbix98UL6Rw9HP/MFRhTxQvrHDhBbmHfdjuaB8
E4eN6/Kn6EVzQPmmaHwzh6r6XwezV7FB+eYOkPBlgvItHIpXW9tvWsQA5Vs6
GPe+/e544Kc9hG/l8N7y1z8nvWdQvjWcDwCwN2Yu
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwUBLiEPa4oAjlczgEVPHk
P7SD8QUclGWfH1VfqQDlizioelY43hSD8SUcXp/XT5J9LAflyzjc4+Q20t0i
C+UrOMR99qwLXCQD5Ss5xKaufGxXIA3lqzj0iBqoFOhJQflqDvv2yIUwv5GA
8jUctko+u//lvjiUr+VwrOdQedl+MShfx+E3X7r9QVdRKF/PYXNB8eeoCmEo
38Bhe8GySD1RGN/QwaWh4q9huyCUb+RgeW73gmMPBKB8YwfeIiPry028UL6J
Q/aJHfsu7+SG8k0dzkp9eDVFgAvKN3P4sPni31pRTijf3EFnMwubWR87lG/h
ENhjqM3SygLlWzoUr7a237SIAcq3cgiPMlpXpPTfHsK3djDuffvd8cBPKN/G
4b3lr39Oes/sAU7PanU=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwOLiF0SVvvyKUz+FQtOV2
RL0ejC/gsO2hrbzPNAUoX8Th+Y8TOjZ8ML6EA5/+vF0F3+SgfBkH17e5m/wP
y0L5Cg6KQnVyzP0yUL6SQ/O3/c8im6ShfBWHN4nLFhwxlYLy1Rw8d+eLf2aU
hPI1HLZKPrv/5b44lK/lMI9n+jaRK2JQvo7Dm75zm+wviUL5eg7X2dqvy34S
gfINHHSfSzdwscD4hg7emz96BZoLQ/lGDoZus3Z6nRWC8o0dvnWtE4/9Igjl
mzhcSf3GqbETxjd1CMjROv1VUgDKN3NY4Xj46DFJXijf3OHD5ot/a0U5oXwL
h7aJ2VbV8uxQvqVD8Wpr+02LGKB8Kwdu5rVVryZ/tAcAFwtl8w==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVwaPr14+3PK4pQPodDpZBK
i4ItjC/g8LbqI1fWCgUoX8RhhX6MfpogjC/h4L/5qUTqOzkoX8ZBbcvX6eZr
ZKF8BQdj/5NsBuUyUL6Sw+MHOputjaShfBWHs1IfXk0RkILy1RxupE/JX7dW
AsrXcKgqUc5f7SgO5Ws5LOBnkvrjKgbl6zgsnVosuNNBFMrXc4j6dNtM9a8w
lG/gEO2+n+vXBiEo39BB6MWBQ6uDBKF8I4f10mu2X/Lmh/KNHY5+5g+OKuSB
8k0clL2mXYtawQXlmzpU1f86mL2KDco3cyhebW2/aREDlG/uEB5ltK5I6b89
hG+BxrdE41uh6bdG49s4cDOvrXo1mRHKt3WonXd5j9hDZijfzsHHvH77Yz0Y
394BEr9MUL6Dw3vLX/+c9L5B7GtwcGBS0PrFvfoP1H5HqPwzewAZoIXr
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwyDziovjgsiKUz+Hg7Wrw
44IhjC/gMOd+3A3/SQpQvojDjnDdRUkv5KF8CYcDR9d+fbVTDsqXcWDaEhnx
e64slK/gkN/Z2pqbJgPlKzlcTD/iIckuDeWrOEyseB6/UFIKyldzyLrqyjpX
UBLK13CY+Li42um7OJSv5bC7Z8Ly6o1iUL6OQ3PL4TvTD4hC+XoOQmuvZn6o
E4HyDRyea36qNAwQhvINHX54P+Vo9BGC8o0cFB3TO0v/CUD5xg6+bseOPrGF
8U0cImetXSiqA+ObOuw9bvVO4zEPlG/mEKU90eNcBTeUb+4g/+/saYsPXFC+
hYNx79vvjgc4oXxLh8AeQ22WVhYo3wqNb+1QvNraftMiBijfxqGq/tfB7FVs
UL6tQ+28y3vEHjJD+XYOkPhkgvLt0fQ7OLy3/PXPSe+ZPQCiun9p
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwuCApsvz3KUUon8PBa85p
W3MVGF/AYfbS64HxrQpQvoiDW+iH2XteyEP5Eg6FC7eqhG6Sg/JlHAx33KjR
nSAL5Ss4WH46aRDgJAPlKzn4Wvdt3vpDCspXcXBk774rsFkSyldz4HQ68cov
WwLK13DgqOuXPhUvDuVrORz2+DxPcY8olK/j4OHVc2tTpAiUr+cQ02wcdeOF
EJRv4FBw7fOhREUY39Dh5DWVL795BKF8I4clJxeXcZfwQfnGDnuPW73TeMwD
5Zs4zL7G/XOZKTeUb+qgs5mFzayPHco3c6idd3mP2ENmKN/cITzKaF2R0n97
CN/C4b3lr39Oes+gfEs4HwAHtWRn
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwKP0il/jljiKUz+HgkOZW
+cYaxhdw4Fhvmu87TwHKF3F4Jbt0pTY7jC/h8Gb234rg33JQvozDpSmb5jw/
IAvlKzjwNE+btrZSBspXcpBPavw91VYayldxyN5YUZD8WRLKV3NQlEj8e/au
BJSv4cD/ZV3wWyMYX8thhuXuaW8PiUH5Og6zTgntWrBOFMrXc5i7wyZ68joR
KN/AITL+kEdUhDCUb+ggoGMofe6/IJRv5CC7+s+1GHMY39jh879dkU3sAlC+
iUPp7gAbix98UL6pQ/aJHfsu7+SG8s0cJrQw77gfywXlmzu0Tcy2qpZnh/It
HOQ9fC3FVrFC+ZYO3Mxrq15NZoTyrdD41mh8G4f3lr/+Oel9s4fwbdH4dlD+
MyjfHo3vgMpvQOMzOKLJI/gALiSTjg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw2GK2N3PPRUUon8Oh32fV
iiJ9GF/AYen9Q59kJihA+SIOyk+mlhz7IQ/lSzi8kpnstO+OHJQv4+Cx7cgj
9z5ZKF/B4dBqPvXDPjJQvpLDVN/LNvK/paB8FYd/oWKy3TckoXw1hzVXIipv
R0hA+RoOH/lCD2vqi0P5Wg7vLX/9c9ITg/J1HO5F9LX3fBeB8vUcgq919lyS
FYbyDRy4Fv+IczsqCOUbOgTkaJ3+KikA5Rs5LDm5uIy7hA/KN3b4qTOpZnkO
J5Rv4tA2MduqWp4dyjdF45s5BPYYarO0skD55g7czGurXk1mhPItHCDhzQTl
W6LxrRyKV1vbb1rEAOVbOzApaP3iXv3HHsK3gZr3Ecq3hfMBzplxJw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVweB5VwSx6RRHK53B43KfA
c8kRxhdwkHw5l7FpiwKUL+LwZKth8itpGF/CISj1l5XZFzkoX8YhfJNGUsQm
WShfwYFJ/rOpV4MMlK/kUP7J0SfYWhrKV3Goe7LSU0xFCspXc7iRPiV/3VoJ
KF/DIdiQg+FmsDiUr+WQZZ7H1xAqBuXrOGj3u51zOi0C5es5zPJr/PWYC8Y3
cNhesCxST1QYyjd0ENAxlD73XxDKN3KQlnj8YuIkASjf2OE/Q+D/hBJ+KN/E
wW9Nn2vqVl4o39Thp86kmuU5nFC+mcNZqQ+vpghwQfnmDu8tf/1z0mOD8i0c
lu++LnZKhhXKt3SAhD8TlG+Fxrd2CI8yWlek9N8ewrdxMO59+93xwE8o3xZN
3s6BSUHrF/fqP1C+vQM389qqV5M/QvkOUPd8g/Ab0PgMjnA+ADE7hQ4=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVweB5VwSx6RRHK53CQYp62
YIk5jC/gsHi3iH/2XAUoX8ThDO+8hzIsML6Eg05m+NeTh+WgfBmHwFsNUkVr
ZaF8BQffHz+NgnNkoHwlh1q1uN03uaWhfBWHuLSFjWwNklC+msOpuPWf9plL
QPkaDutDWFg+vhOD8rUcVgu+k1DbLArl6zgc0HZ6u6ZIBMrXc4hpNo668UII
yjdwkF3951qMuSCUb+gQOWvtQlEdASjfyKFS8/jPVH8Y39hhhePho8ckeaF8
Ewdlr2nXolZwQfmmDvIevpZiq1ihfDOH2nmX94g9ZIbyzdH4Fg6Q8GaC8i0d
jHvffnc88NMewrdyeG/565+T3jN7AFOWZKk=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwSHmqmrr7jCKUz+GwzWQ7
4xZjGF/AYUZD0vGoNQpQvohDQI7W6a+SML6EA5/+vF0F3+SgfBmHBVOY614e
loXyFRze3ZPeU9chA+UrORxqk44KiZCG8lUcDldMq5svJgXlqzlIKhwNe8wq
CeVrOLw3sPLd9EUcytdyiGEIFguYKAbl6zisFnwnobZZFMrXczig7fR2TZEI
lG/g8FzzU6VhgDCUb+gwc//y8lAdISjfyMHGyKedL0EQyjd24BE+VF7wkh/K
N3EQfCMi9kGMD8o3dXAO+WPG6gbjmzl8493Z+MeUB8o3d9i4Ln+KXjQHlG/h
sHz3dbFTMqxQviUa38pB3sPXUmwVjG/tUDvv8h6xh8xQvo0DJL6YoHxbByYF
rV/cq//YQ/h2Dsa9b787HvhpDwDALm83
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwOPe+0c7wtiKUz+FwZrlq
y0NLGF/AweIrb3PfMgUoX8Th+o3fnFLSML6Ew8c3T0q6X8hB+TIOP2d/X6m8
UhbKV3Dw/fHTKDhHBspXcgjpOHSmxEYayldx0G33XbnytCSUr+Zwe356Yedq
CShfw+GQ9wqtizHiUL6Wg0PStuuTysWgfB2Hkp2HFA57iUL5eg7BDBbnNgqK
QPkGDuvc3weV8whD+YYOe4+33/9RLwTlGzm4NFT8NWwXhPKNHSo1j/9M9ReA
8k0ceIuMrC838UL5pg4/dSbVLM/hhPLNHLiZ11a9mswI5Zs7MClo/eJe/cce
wrdw8DGv3/5Yjxkqb+mwfPd1sVMyrFC+lUN4lNG6IqX/UPXWUPM+2gMArGhs
Bw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwiDW24dh4TRHK53BgPPrj
aIk5jC/g4MlgqW+0SAHKF3GYLHNi7lFmGF/CYdUndfH39+WgfBkHh1cO10IX
yUL5Cg5f7z8qE4+VgfKVHGZf4/65zFQayldxUCp/seS6kRSUr+ZQ0SA4vfyi
BJSv4bB89ZUb39+IQ/laDvt2CXF8mCIG5es4/Cv6rsp5VBTK13NQKWecbPZe
GMo3cNh7vP3+j3ohKN/QwW3vyyyHi4JQvpGDrqDGx1kXBaB8Y4f/DIH/E0r4
oXwToH6rdxqPeaB8U4co7Yke5yq4oXwzB53NLGxmfexQvrlDVf2vg9mr2KB8
Cwd5D19LsVWsUL6lw/Ld18VOycD4Vmh8awdI/DBB+TYO3Mxrq15NZoTybdHM
t0OTt3coXm1tv2kRA5Tv4GDc+/a744Gf9mBug4MDk4LWL+7Vf+wBx42CDg==

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVw4PGSr7p5RBHK53B4fvzM
r8W6ML6AQ3NV67aELgUoX8Sh4F8v7+s/8lC+hIOFL1dV4lM5KF/GQV709SGP
vbJQvoLDV7v9wuvcZKB8JQeu/KdN9SekoHwVh4xrchs2L5WE8tUcXDmY/3zZ
KAHlaziUmqulbk0Vh/K1HMw+RWl43xeF8nUc/ixmUXx+QQTK13Ngl2MJOXJJ
GMo3cPixhL3uiaMQlG/o4Ot27OgTWwEo38jhGm9Hxk8/Xijf2OEb787GP6Y8
UL6JQ9vEbKtqeXYo39RBZzMLm1kfjG/mULza2n7TIgYo39zhveWvf0563+wB
XpxY/w==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwOLzOJOX6JUUon8MhSywh
6qstjC/g8KucOdl/vgKUL+JQebbv7G9WGF/CYYvc95CJ9+SgfBmHnicbpCp2
y0L5Cg6HWh16r+fJQPlKDnbXN8ZtcpeG8lUcDl/c9Z2NRwrKV3NgtNLeeZ5T
EsrXcFioNEemYJM4lK/l0FBq/8VKTQzK13EQWns180OdCJSv53B629aVRQXC
UL6BQ1bJj22M4UJQvqFDDPuiWdKuglC+kYO0xOMXEycJQPnGDjlOE/byLeSD
8k0csk/s2Hd5JzeUb+pw4qhteckuDijfzEHZa9q1qBVcUL65w8THxdVO39mh
fAuHwB5DbZZWFijf0qF23uU9Yg+ZoXwrh/Aoo3VFSv/tIXxrByYFrV/cq/9A
+TYO3Mxrq15N/gjl28L5ALcEceg=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwsHJ9vGXVRUUon8Ph++pd
ZVfMYXwBh6SGCXYbFyhA+SIOBf96eV//kYfyJRwWrlKTNr4rB+XLOPit6XNN
3SoL5Ss4+P74aRScIwPlKzlcTD/iIckuDeWrOFQGd+mc+C8J5as5cHebV67d
JwHlazgcPLyU6VqkOJSv5dBQav/FSk0MytdxuBfR197zXQTK13M4vW3ryqIC
YSjfwOFIwIHZDbuEoHxDB67FP+LcjgpC+UYOlud2Lzj2QADKN3bwdTt29Ikt
jG/ioGurF7L/GS+Ub+rwYfPFv7WinFC+mYPOZhY2sz52KN8cjW/hsHFd/hS9
aA4o39Khqv7XwexVbFC+lcPy3dfFTsmwQvnWDrXzLu8Re8gM5ds4cDOvrXo1
mRHKt4XyP9oDAG2Oc4U=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw6P+uwjL3tCKUz+Gwoz9z
WYwJjC/gsM5zibb+fAUoX8RhR7juoqQX8lC+hMPUdc1iJRPloHwZB1fhrUne
KbJQvoLD4/knTvxnkYHylRxaHr0IKPgoBeWrOLzc7zl71k9JKF/NYemmo4s7
LktA+RoOVq8fN6yfJg7laznEMASLBUwUg/J1HILnTJGuMhSF8vUcqiq1n19T
FYHyDRximo2jbrwQgvINHWyMfNr5EgShfCOH0t0BNhY/+KB8Y4eLO65+ufGD
G8o3cfjGu7PxjykPlG/qwKSg9Yt7NYxv5jChhXnH/VguKN/c4cRR2/KSXRxQ
voXDWakPr6YIwOQtHd5b/vrnpMcG5Vs5BPYYarO0skD51g7czGurXk1mhPJt
HHzM67c/1mOG8m0djHvffnc88NMewrdzCI8yWlek9B/Kt0eTd0DlNzhA7X9m
DwDydoaN
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwEOUr9PlwWxHK53CQiRJY
UeAN4ws4pK+PmfR3iwKUL+IQvyhEM5kbxpdw0InbUrf3vRyUL+PgVNQ+8cIS
WShfwWGZ7D/+mmwZKF/JIaTj0JkSG2koX8Uh5PPGnN2XJaF8NQd2rW09Ylsk
oHwNhwMiq9kTX4lD+VoODRzGdZ+fiEH5Og7Tly1coSQH4+s57CrQ+R7MJArl
GzhEfbptpvpXGMo3dHC1fVJz/pcQlG/k8GMJe90TRxjf2CF17jKm6gWCUL6J
Q6nmlMmTNglA+aYOpbsDbCx+8EH5Zg6Rs9YuFNWByZs7CL4REfsgBpO3cFD2
mnYtagUXlG/psHz3dbFTMqxQvpVDYI+hNksrC5Rv7cDNvLbq1WRGKN/G4b3l
r39Oet/sIXxbNL4dVP1HewBGbHLp
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw2GK2N3PPRUUon8PB8m2g
YJIRjC/gIBZmbV20SAHKF3HQscn4mc4E40s4lOXkSiSflIPyZRymcLZcXNor
C+UrOBxazad+2EcGyldyOLX/38Sz8tJQvorDq6ZmNeF1klC+msOFzz8OXIiX
gPI1HM5sD+FSkRSH8rUc2A8qz9F5Iwrl6zgYxDYv37tCBMrXc/iZWPy3casw
lG/gMHP/8vJQHSEo39BB009ZxDVXEMo3cijVnDJ50iYBKN/YwTnkjxmrGx+U
b+Iw+xr3z2Wm3FC+qcOEFuYd92O5oHwzB53NLGxmfexQvjka38JB3sPXUmwV
K5Rv6VC82tp+0yIGKN/Kwbj37XfHAz/tIXxrByYFrV/cq/9A+TYO7y1//XPS
+2YPALtrZ4o=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwqDuU/b3/lCKUz+GQ23bK
bK4ZjC/gwM7Hw3JumQKUL+IQc53D+DUTjC/h8OaNTePW63JQvoxDdboRG5+D
LJSv4BActFHM56M0lK/kMJcjofLSDSkoX8XhsfJB43n7JKF8NYemnLfdy69L
QPkaDsGGHAw3g8WhfC0H9oPKc3TeiEL5Og7x17fGXa4QgfL1HJ5rfqo0DBCG
8g0cUucuY6peIAjlGzrEsC+aJe0K4xs5vL6j3qLfJADlGzt0G6XemZ0A45s4
5DhN2Mu3kA/KN3W4uOPqlxs/uKF8M4cPmy/+rRXlhPLNHQJ7DLVZWlmgfAuH
4tXW9psWMUD5lg5MClq/uFf/sYfwrdD41g7czGurXk3+COXboPFtHd5b/vrn
pPfMHgASKW/4
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwWMXgV3TvqiKUz+Eg8537
3xsXGF/AwaDaT+buagUoX8Th97db1QK8ML6Ew3qH2L6q+3JQvozDKvXC9e/a
ZaF8BYcZPbk/b7fJQPlKDjL7Zj5pi5KG8lUcguNEuqd6SEH5ag4Vuf0WpcGS
UL6Gw/+s5I4Tz8WhfC2Hd7EHtyceE4PydRwurjn/WSVXFMrXc5CI33Opz00E
yjdwYAtl3PzhsBCUb+ggoGMofe6/IJRv5HDymsqX3zwwvrEDb47Q645CASjf
xEHXVi9k/zNeKN/UYUIL8477sVxQvpnDxMfF1U7f2aF8c4faeZf3iD1khvIt
HOQ9fC3FVrFC+ZYOy3dfFzslA+NbOfiY129/rAdTb+1QvNraftMiBijfxiE8
ymhdkdJ/ewjf1oGbeW3Vq8kfoXw7NL69w3vLX/+c9J7ZAwCYcXs/
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwONrL7nfkgiKUz+HwJHLC
m/lWML6Aw8qd7+7yzFOA8kUcOkqT5z7lgfElHO6x/uf9v04OypdxOLiB9/Ou
6bJQvoKDu0PHR4Y8GShfyaH2rLVbmZg0lK/i0PeocIusqBSUr+agKJH49+xd
CShfw2Fl1lwJna3iUL6Wg87WxaF/dotB+ToOvwsX1PtmiEL5eg5b7dN+1OSI
QPkGDu9yj3w1/iYM5Rs6RLvv5/q1QQjKN3JInbuMqXqBIJRv7PBMX8k4TxPG
N3EIjzJaV6TED+WbOlzj7cj46ccL5Zs5RGlP9DhXwQ3lmztsXJc/RS+aA8q3
cNDZzMJm1scO5VtCzftvDwCsUGAT
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQEf7MVCt+7emK3kABVwMEx55Xf8rCKUz+HAo3RD
R8MexhdwkFq09nT/fAUoX8Th3+3Mec94YXwJh7S6tGfL78pB+TIO+tl+T6+s
kYXyFRzspP0uGq+TgfKVHPi/7fL4kC0N5as4xOcJWX3XkYLy1RySdmywPHRb
AsrXcOCo65c+FS8O5Ws5lPxaqWRoJQbl6zgk+Wmu+McjCuXrOWRHsAcmTxeG
8g0c9h5vv/+jXgjKN3TgWvwjzu2oIJRv5KDomN5Z+k8Ayjd2iJy1dqGoDoxv
4uAc8seM1Y0Pyjd1KN0dYGPxA8Y3c1jhePjoMUleKN/cIfvEjn2Xd3JD+RYO
P3Um1SzP4YTyLR02rsufohfNAeVbOVTV/zqYvYoNyrd2WL77utgpGVYo3wZN
vS0a387hw+aLf2tFYebbO0x8XFzt9J0dyndANa/BwYGbeW3Vq8mMUHlHh/Ao
o3VFSv/tIfKOaPJOaPJofAZnVPUNzg7Fq63tNy1igOp3cWBS0PrFvfoPVL+L
w3vLX/+c9L5B9btC9X+0BwC3JaZ/
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw2M6hcy/wqiKUz+GQp+ac
JOEE4ws4TJ/RXHBiswKUL+JQffbAxsMaML6Ew8tJ7c0r2OWhfBmHx58y3+36
KgvlKzjcjhZjn3RJBspXcnj2ceaLS8+koXwVh9uXCzRyDktB+WoO4tXvLRpL
JaF8DQeH+3XRgm4SUL6WQwP/95Y4U3EoX8fhqkZO4rLtolC+nkPT8fDYXz4i
UL6Bw/aCZZF6osJQvqFD05Ok3idrBKF8I4fIWWsXiuoIQPnGDktOLi7jLuGD
8k0cvvHubPxjygPlmzqcOGpbXrKLA8o3c3hv+eufkx4blG/uIO/haym2ihXK
t3BgUtD6xb36jz2Eb+lg3Pv2u+OBn1C+FVT/MyjfGs4HAGS9bsw=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwaGud4GVxSRHK53Aoeb+m
u9caxhdweLPCRbposQKUL+Lg8u9Vrz4HjC/h8MZG497nK3JQvoxDcIpNl/QJ
WShfwWHO2oaH51xloHwlBz7rGwozVaWhfBWHiRXP4xdKSkH5ag5JOzZYHrot
AeVrOPTsen8rrlscytdyUNrEMeuorxiUr+OgfVzi65KHIlC+nkNch9tL2yPC
UL6BQ0yzcdSNF0JQvqFDtPt+rl8bYHwjB/vwLzF+0oJQvrHDeuk12y9580P5
Jg57j1u903jMA+WbOnzj3dn4xxTGN3P4qTOpZnkOJ5Rv7lA77/IesYfMUL6F
g495/fbHejC+pcN7y1//nPS+2UP4VlD+M3sA1kVqWw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwCBfZayx7XBHK53BYlLGl
N8IKxhdwaLn21H7jEgUoX8TB+mjBSzFmGF/CYe2pxAddN+WgfBmHqyXNRs1H
ZKF8BQcuVjuns5kyUL6SQ3iW6jIVaWkoX8VB/mjb1evPJKF8NQebXddaL3ZJ
QPkaDj273t+K6xaH8rUc6nSqZud9EIXydRyWTi0W3OkA4+s5WGcVzUjYIgLl
Gzg46SVMKUoQhvINHWbuX14eqiME5Rs5cDOvrXo1WRDKN3aInLV2oaiOAJRv
4rBees32S978UL6pwzfenY1/THmgfDOHCS3MO+7HckH55g4b1+VP0YvmgPIt
HKrqfx3MXsUG5Vs6yHv4WoqtYoXyraD2M0L51g5MClq/uFf/sYfwbRzeW/76
56T3DMq3hfK/Qfl2Dsa9b787HvgJ5dtDzfsI5TvA+QB00n6w
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVwWKDgspzxjiKUz+GwIFdN
ldkDxhdwyF44O99pvwKUL+Jw673G0+nGML6EQ/O5hPPc9vJQvoxDdveMDn5W
OShfwUHhwnXzm1dkoHwlhyjtiR7nKqShfBWH0Pob4cmOUlC+msPVtw0crx9L
QPkaDqJ+aebPtotD+VoOl3Pu7DyRIgbl6zgEz5kiXWUoCuXrOcR1uL20PSIM
5Rs4/PB+ytHoIwTlGzpo+imLuOYKQvlGDv8ZAv8nlPBD+cYOurZ6Ifuf8UL5
Jg5MClq/uFfzQPmmDspe065FreCC8s3Q+OYOxr1vvzse4ITyLdD4lg5tE7Ot
quXZoXwrB3kPX0uxVaxQvrWDj3n99sd6zFC+DRrfFmreT3sI386heLW1/aZF
DFB5e4f3lr/+Oel9g8o7QPnPIPwGND6DowM389qqV5M/2gMAJ+SDRw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwUL/JcfPAaUUon8OB08DM
I9QMxhdwiJbj8YmfoADlizh8/rcrsokdxpdwWLhKTdr4rhyUL+Nw29/+5qx5
slC+gkPrbX3N6DIZKF/JQSiOT/SUmTSUr+KgH2ai/OmLJJSv5rCizjfPQxrG
13CIP9ggySUsAeVrOfRfFug+4yUO5es4LGrk2bQkUAzK13PQPi7xdclDESjf
wCE7gj0webowlG/osNTK+MTyuUJQvpGDjZFPO1+CIJRv7FC82tp+0yIBKN/E
QddWL2T/M14o39Th6Gf+4KhCHijfzOHD5ot/a0U5oXxzh43r8qfoRXNA+RYO
8h6+lmKrWKF8Swcf8/rtj/WYoXwrh/eWv/456X2zh/CtHbiZ11a9mvwRyreB
8wH2cmUH
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwaNuxmiH4siKUz+EQxxfr
slgfxhdwMLqT8u1jnwKUL+JwQypM0e2ZPJQv4dDjVHVTcZsclC/jEPZ/SUR3
oyyUr+AQoiIvZRsjA+UrOWyYlxMWoy0N5as4rNeWs3D5IAnlqzmsEzz17OUi
CShfw0FnMwubWZ84lK/lsHL+sw3asWJQvo6Dh1fPrU2RIlC+noPOh7512/uF
oXwDB8Nd0uqPSoWgfEOHGPZFs6RdBaF8IwfnkD9mrG58UL6xw+xr3D+XmXJD
+SYOZ6U+vJoiwAXlmzpMfFxc7fSdHco3c1i++7rYKRlWKN/cARK+TFC+hYO8
h6+l2CqYvKWDj3n99sd6zFC+lQOTgtYv7tV/7CF8a4f3lr/+Oek9swcA7k1j
5w==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw2G+6Skb2qiKUz+FgE3ne
wsYOxhdwaKuIuC6wVAHKF3HQvdgaU8kK40s4THs7KZv9nByUL+MQ8P6b/fMG
WShfweHg54XFsioyUL6Swxk7hxWms6WgfBWHlc/0bryIkITy1Ryeb19jaBgi
AeVrOFSVKOevdhSH8rUc0rOfOR/gFYPydRyW774udkpGFMrXc2CXYwk5ckkY
yjdw2Hu8/f6PeiEo39Ch6UlS75M1glC+kUNAjtbpr5ICUL6xwzfenY1/THmg
fBOHs1IfXk0R4ILyTR3aJmZbVcuzQ/lmDvIevpZiq1ihfHMHbua1Va8mM0L5
Fg7GvW+/Ox74aQ/hW0LlP0L5VnA+ADlwZTk=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw2HT9hbzwNUUon8PhvOnG
iwscYHwBh1UNJgYTlipA+SIOPw36DkYywPgSDvUzVhd8OScH5cs4hG/SSIrY
JAvlKzgoCtXJMffLQPlKDq7Jzq5sodJQvopDSOP/i1ecpKB8NYfzKR4+ySsl
oHwNh2n9eQWrWsWhfC2H7afFWf8kiEH5Og6PG4U0CpJFoXw9h40/+l5KOIhA
+QYO69zfB5XzCEP5hg4JhbG/T70QhPKNHGRX/7kWYw7jGzt8/rcrsoldAMo3
cfjPEPg/oYQfyjd1uLjj6pcbP7ihfDOHnzqTapbncEL55g7Ld18XOyXDCuVb
ONTOu7xH7CEzlG/pwM28turVZEYo38qBSUHrF/fqP/YQvrXDe8tf/5z0nkH5
NlD1H6F8WzR5OzgfAC1hen4=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwWPmpbcevS4pQPoeDVMvd
Z/1uML6Ag7Sf2v+NCxWgfBEH7tYFuVs4YXwJBy6NKdYcV+SgfBkHwx03anQn
yEL5Cg71flm2NytkoHwlh/df/b58U5CG8lUczkp9eDVFQArKV3PYb8Aov5pf
EsrXcOCr0Aq7N1kcytdyaOAwrvv8RAzK13H4ur1157dbolC+noPTwWA5bXkR
KN/AYeGSE6L914SgfEMHGyOfdr4EQSjfyKF4tbX9pkUCUL6xw97jVu80HvNA
+SYOF3dc/XLjBzeUb+pg3Pv2u+MBTijfzEHew9dSbBUrlG8ONY8ByreAqv9p
D+FbOnAzr616NfmjPQAGl2Nb
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw8OH6U33+hiKUz+Gw3SCQ
WdQcxhdwuPtlEuea5QpQvojDp8lPJm4ShfElHBbyJkTv/y8H5cs4iLY+vSp9
SBbKV3A4lSGlfKhJBspXcthgt8NqR4w0lK/iYHhOZQfvD0koX83hxFHb8pJd
ElC+hkPPrve34rrFoXwtB/aDynN03ohC+ToOfxazKD6/IALl6zlkR7AHJk8X
hvINHPYeb7//o14Iyjd04M0Ret1RKADlGzn4relzTd3KC+UbO0RpT/Q4V8EN
5Zs4zL7G/XOZKYxv6rBxXf4UvWgOKN/Moar+18HsVWxQvrlDYI+hNksrC5Rv
4QAJbyYo39KBSUHrF/fqP/YQvpXDe8tf/5z0vkH51g7czGurXk3+COXboPFt
0fTbQfU/swcA7w53qg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwkD7Rk37gjiKUz+FgE3ne
wsYOxhdwEJtop3NhvgKUL+Lw9x1LucYveShfwuESrzyvwjE5KF/GQbc/wUFm
jiyUr+AgNTu0bGm8DJSv5MBtmXbvjbk0lK/iIH00OJ/FSwrKV3Nwdy3JZP4j
AeVrOBwQWc2e+Eocytdy2H6Ay33+azEoX8fBZc4DoZ2dolC+nsOm9W1yEndE
oHwDh6pK7efXVGF8Q4fI+EMeURHCUL6Rw5XUb5waOwWhfGOHZcpet0wOCUD5
Jg5+a/pcU7fyQvmmDspe065FreCC8s0czkp9eDVFAMY3d/ipM6lmeQ4nlG/h
0DYx26panh3Kt3RYvvu62CkZVijfygESH0xQvrUDk4LWL+7Vf+whfBuH95a/
/jnpfYPybR24mddWvZr8Ecq3Q5O3h/Kf2QMA4IZ2Iw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVw4O1LDJ5wRRHK53BI3r2b
5acdjC/gMLF+Z+DZdQpQvoiDqXKwRbcIjC/hEHSIK8nnoRyUL+Ogv91xd9MG
WShfweH1jcURjpNkoHwlhyrGbU9nBkhD+SoOTJzNFp0aUlC+msPJq265B80l
oXwNh6veh6IeKkpA+VoOrCWy2vU7xKB8HYeTV1paS0+KQvl6Di0sJ09xTBeB
8g0ckk4o7TJuEIbyDR20ZcUk0xOFoHwjB11BjY+zLgpA+cYO2z5M0Jc6ywfl
mzjkOE3Yy7cQxjd18FvT55q6lRfKN3PgLTKyvtwE45s7nJX68GqKABeUb+EQ
2GOozdLKAuVbOoRHGa0rUvpvD+FbOXAzr616NZkRKm+NJm/jYNz79rvjgZ9Q
vi1U/Uco387hveWvf05636B8ewcmBa1f3Kv/2AMAF1Vz0g==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwWHdwxbuFVxShfA6HBt+2
s6XWML6Aw8T6nYFn1ylA+SIOATlap79KwvgSDhHKMnvtX8tB+TIOLxsn2KxZ
JwvlKzjICAaqTE2VgfKVHMKuH2CTFZGG8lUcVrg5Tt30RxLKV3OoObbuHtcn
CShfw8HS/YrDpvXiUL6WQ0DQN+n1TWJQvo7DQeUWDQYlUShfz2Hxk9Yk5zQR
KN/AQfe5dAMXC4xv6OC9+aNXoLkwlG/kwLX4R5zbUUEo39jhP0Pg/4QSfijf
xCFKe6LHuQpuKN/U4cPmi39rRTmhfDOH4tXW9psWMUD55g7czGurXk3+aA/h
Wzi8t/z1z0nvmT0Aq0Rcsw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwOHJp2oRNFxShfA4H1Tee
sdN1YHwBh56oaTfXdytA+SIOrFpX57s8kIfyJRxK929IrpggB+XLOHC1yXP8
S5CF8hUcphyzXxsOFIfwlRwWuf4+U94iBeWrODxx6ah/lygJ5as5fJrB/a/n
vTiUr+Ggs3Vx6J/dYlC+lsPy3dfFTsmIQvk6DjFJjx7rvBCG8vUcSjKW7/MX
E4LyDRx2S02Zu/O9AJRv6PD5367IJnYY38jhG+/Oxj+mPFC+sYOy17RrUSu4
oHwTh7aJ2VbV8uxQvqlDYI+hNksrC5Rv5iDv4WsptooVyjdHk7eAuhcmb4nG
t3LgZl5b9WoyI5Rv7RAeZbSuSOm/PYRv4/De8tc/J71vUL4tVP1HewDvSnFk

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVweKL/cm7LeUUon8OBRWsH
1yxLGF/AQSzM2rpokQKUL+LA3bogdwsnjC/hcKzuaoHoRzkoX8ZhRdYUc/51
slC+gsOWcw8PXqiVgfKVHPJr/FNdfaWhfBUHw3MqO3h/SEL5ag4njtqWl+yS
gPI1HNoMt8tdDxCH8rUcvm5v3fntliiUr+NQVan9/JqqCJSv51Bw7fOhREUh
KN/AYbfUlLk73wtA+YYO0hKPX0ycBOMbOTiH/DFjdeOD8o3R+CYOgm9ExD6I
wfimDtknduy7vJMbyjdz+KkzqWZ5DieUb+4g7+FrKbaKFcq3cHhv+eufkx4b
lG/pAAl/JijfyiE8ymhdkdJ/ewjfGo1v42Dc+/a744GfUL4tGt/OgZt5bdWr
yR+hfHs0eQeH4tXW9psWMUDsa3CAmw8A/o+D7Q==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVwkGzPWrr9kCKUz+FwZMtW
j5UaML6AQ0/D9VzbVgUoX8Thvsui201P5KF8CQfr/fvvWc+Wg/JlHI6EGE/6
mSQL5Ss43OgTvPZARgbKV3I47rzZrIpTGspXcUhw/mDV8E0SyldzUJRI/Hv2
rgSUr+EgsyD3echecShfy2FrTFVCeI4YlK/jsFrwnYTaZlEoX89h44++lxIO
IlC+gUNMs3HUjRdCUL6hg9CLA4dWBwlC+UYOpbsDbCx+8EH5xg5+a/pcU7fy
QvkmDoJvRMQ+iMHkTR2itCd6nKvghvLNHDauy5+iF80B5Zs7tE3MtqqWZ4fy
LdD4lmh8K4faeZf3iD1khvKtHYpXW9tvWsQA5ds4MClo/eJe/ccewrdF49s5
GPe+/e544CeUb+/Azby26tXkj1C+g8N7y1//nPSeQfgNaHwGR7h6AISnh+Y=

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw8Kh47mhxRRHK53B4Ejnh
zXwrGF/AIXhueWnDBAUoX8Qh4/BDxgs/5aF8CYd/Vo2Xn76Ug/JlHJa1Gsu9
PCYL5Ss4qObt0r62WgbKV3L41XBugVW4NJSv4rBjN9P5YnYpKF/N4f+0ncmP
HkpA+RoOqpznIvSeikP5Wg46WxeH/tktBuXrOKjfC1xYygrj6zlo97udczot
AuUbOMR1uL20PSIM5Rs6vJxW5LjWHsY3ckidu4ypeoEglG/sUKo5ZfKkTQJQ
vokDk4LWL+7VPFC+qcOJo7blJbs4oHwzh+W7r4udkmGF8s0d5D18LcVWwfgW
DoE9htosrSxQviXUvD/2EL6Vw3vLX/+c9L5B+dYO3Mxrq15N/gjl28D5ACs9
bpI=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVweB5VwSx6RRHK53Boatlh
22oG4ws4TLzvoBa0WAHKF3Hgt+9P38MH40s4SF3o97p/VQ7Kl3E4uIH3867p
slC+gsPRz/zBUYUyUL6Sw4Z5OWEx2tJQvorDY+WDxvP2SUL5ag7rBE89e7lI
AsrXcHionXqIW0ccytdymFe64paBkhiUr+Mwd4dN9OR1IlC+nsPLaUWOa+2F
oXwDB8Nd0uqPSoWgfEOHZcpet0wOCUD5Rg6f/+2KbGKH8Y0deIuMrC838UL5
Jg7y/86etvjABeWbOkxoYd5xPxbGN3PQ2czCZtbHDuWbOyzffV3slAwrlG/h
wM28turV5I/2EL4lnA8A6D1f5A==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwsPdfHel1VhHK53CYwZik
3GEF4ws4fN26trpwiQKUL+KQE7le7jkfjC/hEK9j+bf9oxyUL+PgVNQ+8cIS
WShfwWGy/smVYstloHwlh9tHfh/NjZSG8lUcDm5edIRZSwrKV3O4fFyG+Ra7
JJSv4ZCxSFy1XVQCytdyUFzQKOJ4VgzK13H4EHi5f6qZKJSv58AuxxJy5JIw
lG/gMP1hD+O9j0JQvqFD6txlTNULBKF8I4f10mu2X/Lmh/KNHWZf4/65zJQb
yjdxeG/565+THhuUb+pQO+/yHrGHzFC+mQM389qqV5MZoXxzByYFrV/cq//Y
Q/gWUP3foHxLqPqPUL4VmnprNHkbqP5n9gBgbm8c
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwuFylfzr9nCKUz+GgddtG
+qcOjC/g8LrDrGDdNAUoX8RB4LLuq49v5KF8CYcctk4Gi71yUL6MQ8lf8bOp
hbJQvoKD2dVIGRZVGShfyUH+39nTFh+koHwVh1tirCvP+UtC+WoO/F/WBb81
koDyNRyCZ/5/HCAjDuVrOajfC1xYyioG5es4tFcdqfgxRwTK13OY23C1in+d
MJRv4NDdu1R1LTOMb+hwJfUbp8ZOQSjfyEFXUOPjrIsCUL6xg66tXsj+Z7xQ
volDlPZEj3MV3FC+qcOJo7blJbs4oHwzB53NLGxmfexQvrnDe8tf/5z02KB8
C4eN6/Kn6EXD1FuiqbdyCOwx1GZpZYHyrdH4Ng7Ld18XOyXDCuXbovHtHLiZ
11a9mswI5ds7hEcZrStS+m8P4Ts4GPe+/e544Kc9AM9Ldrs=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwqJ9TsEn/siKUz+Hw5SBD
SoULjC/g8LbqI1fWCgUoX8TB+KjTNjMRGF/C4eObJyXdL+SgfBmHWNe12ozb
ZKF8BYfCK2fCudpkoHwlB772+mUCk6ShfBWHJ1OPNL/Ql4Ly1RyEskNusb2T
gPI1HKxeP25YP00cytdymNpgu1jQSQzK13Ewe/Ps7hp2UShfz+H0tq0riwqE
oXwDB0O3WTu9zgpB+YYOQi8OHFodJAjlGzlUah7/meovAOUbOyw5ubiMu4QP
yjdx8FvT55q6lRfKN3Woqv91MHsVG5Rv5gAJTyYo39zBx7x++2M9ZijfwoGb
eW3Vq8mMUL6lQ+28y3vEHsLkrRyYFLR+ca/+Yw/hWzu8t/z1z0nvGZRvA+cD
AHhJcO0=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwiNI2e+B5RRHK53DImeT+
84ozjC/g4M0gdJ57vQKUL+LwPUhMvlgKxpdwWFDfN0dCSx7Kl3GYedB16oa3
slC+gkOTTL3ghA0yUL6SQ/yPmVoSedJQvorD4YppdfPFpKB8NYdUVUNGu9MS
UL6Gg6hfmvmz7eJQvpaDa+rjzT0zxKB8HYeZffOyDpWJQvl6DjEcUg0zLEWg
fAOHpVbGJ5bPFYLyDR1cGir+GrYLQvlGDtISj19MnCQA5Rs7+K3pc03dygvl
mzjwFhlZX26C8U0dJrQw77gfywXlmznobGZhM+tjh/LNHd5b/vrnpMcG5Vug
yVs6LN99XeyUDCuUb+XAzby26tVkRijf2oFJQesX9+o/9hC+DVT+I5RvCzX/
G5Rv52Dc+/a744GfUL49mn4HVP0NDnD1APu6fOI=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwkKtS3Hn0kiKUz+FQKaTS
omAL4ws4hLamtuevU4DyRRyc72s+vSAB40s4vHog/mQrszyUL+PAdWjlway7
slC+gkO+KIvEtb0yUL6Sw6eYH/yuydJQvorDjt1M54vZpaB8NQdJhaNhj1kl
oXwNB+/lXRHcfBJQvpbDLP+f9xP+i0H5Og73Xy8vDZ8jCuXrOQQzWJzbKCgC
5Rs4GLrN2ul1VgjKN3TQFdT4OOuiAJRv5LDk5OIy7hI+KN/YYfY17p/LTLmh
fBOHE0dty0t2cUD5pmh8M4efOpNqludwQvnmDm0Ts62q5dmhfAuH95a//jnp
sUH5lg7hUUbripT+20P4Vmh8a6j6Z/YAszRnwQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVw6BV/73XnpCKUz+EQu0Uo
9KcljC/g0N33NaZgqQKUL+LAOuWQAi83jC/h4L/5qUTqOzkoX8YhoalG03O9
LJSv4PCIn//lhhIZKF/JITzJ60S8sTSUr+KgH2ai/OmLJJSv5pCqashod1oC
ytdwWHNd9sHyJeJQvpbDokaeTUsCxaB8HYfQm6ydHdWiUL6eg3VW0YyELSJQ
voHDy2lFjmvthaF8Q4dvXevEY78IQvlGDuFRRuuKlPihfGOHizuufrnxgxvK
N3GY0MK8434sF5Rv6rBxXf4UvWgOKN/MQWczC5tZHzuUb+7QNjHbqloexrdw
eG/565+THhuUb+kQ2GOozdLKAuVbORSvtrbftIgByreGqv9mD+HbOBj3vv3u
eOAnlG+LJm8H5T+D8u3hfAA8TXou
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwkKtS3Hn0kiKUz+Gw1P2o
311TGF/A4e4kg59ecxWgfBGHCx0SPgzsML6Eg++pFTGed+SgfBkHvWeqOwsm
ykL5Cg4W1UJ8D/RkoHwlB5d71f+Er0pB+SoOU95WTZK/JAnlqzmcOGpbXrJL
AsrXcMi8pqrHPVEcytdyuH18y63rxWJQvo6DX7FA9bSjIlC+nsPLaUWOa+2F
oXwDB5eGir+G7YJQvqHDMmWvWyaHBKB8IwfPletWqc7hh/KNHVY4Hj56TJIX
yjdx+KkzqWZ5DieUb+og7+FrKbaKFco3c9DZzMJm1scO5Zs7LN99XeyUDEze
wqFtYrZVtTxM3tLBuPftd8cDP+0hfCsHbua1Va8mf7QHAE9cY2s=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwsOe9OnXmZUUon8Ph2Snr
jQ7aML6Awz7Fz283TVKA8kUchGufuXVywvgSDra/XicuuyQH5cs49Ih94t4z
RxbKV3Dw/fHTKDhHBspXcmDZU3DDnE8ayldxYLiSV5j9QhLKV3Por3RcpnFS
AsrXcCjomPWxsFAcytdy4Pw3hdPaTAzK13GwziqakbBFBMrXczi9bevKogJh
KN/AoXjj+s6AKkEo39Bht9SUuTvfC0D5Rg7rpddsv+TND+UbO/it6XNN3coL
5Zs4nDhqW16yiwPKN3WonXd5j9hDZijfzIFJQesX9+o/9hC+uUN4lNG6IqX/
UL4FGt8SjW+Fpt/awbj37XfHAz+hfBu4PABtSW+1
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVweKL/cm7LeUUon8Ph406J
yAIrGF/AQe3K0uAbaxSgfBGHWzK84o+4YHwJh/jLbvb1b+WgfBkHvzV9rqlb
ZaF8BYeJHZyr3jfKQPlKDm8iVrptypCG8lUcPj9sXRh2VRLKV3Mw+p8iuX+B
BJSv4XD04OIbB5LEoXwth/3ysyXmcopB+ToOB5VbNBiURKF8PQd2OZaQI5eE
oXwDh0ezzUxvTxaC8g0dYtgXzZJ2FYTyjRx4c4RedxQKQPnGDnuPW73TeMwD
5Zs4tE3MtqqWZ4fyTR1OHLUtL9nFAeWbOVTV/zqYvYoNyjd3YFLQ+sW9+o89
hG/hwM28turV5I9QvqXDe8tf/5z0vkH5VlD+M3sA3VZnKg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVwqJ9TsEn/siKUz+Gg1dXV
yqoH4ws42K+6tvv2ZAUoX8Thg86baeuey0P5Eg4qvDx6N5fJQfkyDt6b2rpl
umWhfAUHJSadHSwVMlC+koPo+uLzZcXSUL6Kw/dki7MTXktC+WoOh5dvmWM+
SwLK13B4vWXufYNV4lC+lsPeN8F+/ovFoHwdh5l987IOlYlC+XoOTcfDY3/5
iED5Bg4vpxU5rrUXhvINHfYeb7//o14IyjdySCiM/X3qhSCUb+xQvNraftMi
ASjfxKF0d4CNxQ8+KN8UqN/qncZjHijfzKGq/tfB7FVsUL65AyR8maB8C4fa
eZf3iD1khvIt0eStHJgUtH5xr/5jD+FbO4RHGa0rUvoP5dug8W3R9Ns5cDOv
rXo1mRHKt0fjO0D9wwDhN6DxGRyh6j/aAwDO3IgJ
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw2G+6Skb2qiKUz+FwISrM
a50BjC/gMKcy6tHS2QpQvojDkXVRi/Z8l4fyJRzE5u/XnLBWDsqXcTi4gffz
rumyUL6CQ35na2tumgyUr+SQX+Of6uorDeWrONxKLZFLYZGC8tUcmnLedi+/
LgHlazhMfFxc7fRdHMrXcpjoLq5XdV0MytdxWC34TkJtsyiUr+fgdDBYTlte
BMo3cNh7vP3+j3ohKN/Q4VvXOvHYL4JQvpGDomN6Z+k/ASjf2OH1HfUW/SYY
38ShdHeAjcUPPijf1CH7xI59l3dyQ/lmDm0Ts62q5dmhfHOHjevyp+hFc0D5
Fg7yHr6WYqtYoXxLB27mtVWvJjNC+VYOTApav7hX/7GH8K0d3lv++uek980e
AEhJaJo=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVweF20evK304pQPodD4qcj
eZNsYHwBh6KgPNmJCxSgfBEHf+tlPXO/yEP5Eg6FC7eqhG6Sg/JlHPSz/Z5e
WSML5Ss4bDJePbttrgyUr+Tg7HlP5p2nNJSv4mB9cX+xS5oUlK/mUHNs3T2u
TxJQvoYDX4VW2L3J4lC+loPZyqBYr2oxKF/H4apGTuKy7aJQvp6DyaXectVd
IlC+gcNU1b+RDPOFoXxDhzfCkanfOoWgfCOH1LnLmKoXCEL5xg6Vmsd/pvoL
QPkmDqW7A2wsfvBB+aYOTApav7hX80D5Zg7y/86etvjABeWbO5w4altesosD
yrdwmPi4uNrpOzuUb+lQO+/yHrGHzFC+lYOPef32x3owvrWDce/b744HftpD
+DYO7y1//XPSewbl26Lx7dD49g7czGurXk3+aA8A2o9/Tw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQEf7MVCt+7emK3kABVwuLta2P3NdUUon8MhK+n6
dX9bGF/AwfehzNWABQpQvojDzWMhu3fxwPgSDicdXH8f/iwH5cs48KkvbHh2
UhbKV3B4wjlXzbhPBspXcvi1yyL6f7U0lK/iEDzVdfq6WikoX82hXva/cV6e
JJSv4eA2m/Pjcm0JKF/LIXjm/8cBMuJQvo7D9GULVyjJiUH5eg7Bc6ZIVxmK
QvkGDnEdbi9tjwhD+YYOP5aw1z1xFILyjRyupH7j1NgpCOUbO3iuXLdKdQ4/
lG/ioGurF7L/GS+Ub+qQfWLHvss7uaF8MwedzSxsZn3sUL65w3vLX/+c9Nig
fAsHeQ9fS7FVrFC+pQM389qqV5MZoXwrh+LV1vabFjFA+dZofBuH8CijdUVK
/+0hfFs0vh3Uvm9Qvj3U/I9QvgOqfIMDmrwjmrwjmrwTVP4ZVB7BBwCrG5e0

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwUJ734nbxGUUon8OBqZTx
zhITGF/AwWvik0O/+xWgfBGH9TNDnq45Kw/lSziwHQuVF22Xg/JlHFJlf8zc
ECkL5Ss4xAW9WnI6TgbKV3IIT/I6EW8sDeWrOOwLu/ZE7bcklK/mELBRwTNs
hwSUr+HQf1mg+4yXOJSv5ZCe/cz5AK8YlK/jEMMh1TDDUgTK13Ngl2MJOXJJ
GMo3cHgjHJn6rVMIyjd0eH1HvUW/SQDKN3JwDvljxurGB+UbOxz9zB8cVcgD
5Zs4/NSZVLM8hxPKN3WY+Li42uk7O5Rv5lBV/+tg9io2KN/cIbDHUJullQXK
t3BYvvu62CkZVijf0sHHvH77Yz1mKN/KgUlB6xf36j/2EL61Q/Fqa/tNixig
8jYOxr1vvzse+AmVt3V4b/nrn5PeN3sAR0JwWA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQEf7MVCt+7emK3kABVweB5VwSx6RRHK53C4nVhn
6GsK4ws42Kj9f5YzTQHKF3EoVPzp2/1aHsqXcDi1LCXzym05KF/Gga1i1pWQ
ybJQvoLDmg8H+pKiZaB8JYfG33uXvfopBeWrOJS1MyVx7JCE8tUcbgh+ksws
kYDyNRz+Fin6llqIQ/laDlMbbBcLOolB+ToO2v1u55xOi0D5eg7ZEeyBydOF
oXwDB0O3WTu9zgpB+YYOAjqG0uf+C0L5Rg7rpddsv+TND+UbO1zccfXLjR/c
UL6JQ1X9r4PZq9igfFOH4tXW9psWMUD5Zg7vLX/9c9J7Zg8Asi5X1A==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVw2D9txaTSi4pQPoeDatBW
/6+mML6Aw8GFh3XZ5yhA+SIO/tbLeuZ+kYfyJRxUeHn0bi6Tg/JlHBZzTt+Q
XiML5Ss4COaw7ZyjIQPlKzmcMNhd0nNWCspXcdjnL3Rv9ypJKF/N4Wr0Q8uX
/8ShfA2Hz22uEa5GML6Ww5u+c5vsL4lC+ToOfsUC1dOOikD5eg5TVf9GMswX
hvINHB7v+dugbS4E5Rs62Bj5tPMlCEL5Rg7bPkzQlzrLB+UbO+w9bvVO4zEP
lG/iMPFxcbXTd3Yo39Rh+e7rYqdkWKF8M4faeZf3iD1khvLNHYx73353PPDT
HsK3cHhv+eufk94zKN/SgZt5bdWryR/tAfKSZYc=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwSHkq5sR/QxHK53DI7POZ
u88VxhdwyPZ7xKW9XgHKF3EQ4U9qmigA40s4fPnt+4P1vhyUL+MgL/r6kMde
WShfwSHk8Tq9l4tloHwlhwObz7zOnysN5as43M+srrGokILy1Ryc33upNzVL
QvkaDqfi1n/aZy4B5Ws5RCpZLLgRJg7l6zhMX7ZwhZKcGJSv52A2+UiGp5Ao
lG/gEJP06LHOC2Eo39BBU4X9yXd3GN/I4fGevw3a5kJQvrEDN/PaqleTBaF8
E4fXd9Rb9JsEoHxTByYFrV/cq3mgfDOHnzqTapbncEL55g7yHr6WYqtYoXwL
NL6lQ/Fqa/tNixigfCsH49633x0P/LSH8K0d3lv++uek9w3Kt0GTt0WTt4O6
96M9AGZSdb0=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw4BWbGyB6UxHK53BQPhn6
3MgVxhdw+NSnfjB0rQKUL+KwWOnf/KeCML6Eg+jcXUkyl+WgfBkH3iIj68tN
slC+gkPooXMzPK1loHwlB1/rvs1bf0hB+SoOnIW+Ak8PSkL5ag7c3eaVa/dJ
QPkaDkWSudff1otD+VoOZ50jJJ/+EIXydRwUHotOXRwJ4+s5nEuM+Pj5pjCU
b+BwJODA7IZdQlC+oQPX4h9xbkcFoXwjB2mJxy8mThKA8o0dVtsoZWgc5ofy
TRycQ/6YsbrxQfmmDvL/zp62+MAF5Zs5fNh88W+tKCeUb+4w8XFxtdN3dijf
wqGq/tfB7FVsUL6lAyT8maB8KwcmBa1f3Kv/2EP41g7vLX/9c9J7Zg8AjZhq
zA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw2LNe2jnhuiKUz+Gw10Wh
aJ0tjC/g4H1SSHflHAUoX8RB4kVSuiAfjC/h0Ff/2s2AQR7Kl3F491OCQ+K0
LJSv4PBcad+1Bb4yUL6Sg2jkxUpDK2koX8Xhe7LF2QmvJaF8NYfYfp2Z9/Il
oHwNB7Wa6xcPu4tD+VoOp3+96GpbKgrl6zhEePQLPNovAuXrOWz8JDW/KkMY
yjdwaHqS1PtkjSCUb+iwTNnrlskhASjfyGG1jVKGxmF+KN/YYe9xq3caj3mg
fBOHs1IfXk0R4ILyTR1q513eI/aQGco3cwiPMlpXpPTfHsI3R+NbODApaP3i
Xv0Hyrd0eG/565+T3jco38qheLW1/aZFDFDzrNH4Nmj6bdH4dmj22aPpd3Dg
Zl5b9WryR4h8gwPcfgDfq4N3
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw+P05a/WT04pQPoeD5NmO
79s1YXwBh/1HlOUOTVGA8kUcYtOvP8j9IQ/lSzjkGUk0bNgrB+XLOEhKB3SY
dMpC+QoOXKx2TmczZaB8JQehOD7RU2bSUL6Kg36YifKnL5JQvpoD44RL/142
SkD5Gg7BM/8/DpARh/K1HEp+rVQytBKD8nUcPgRe7p9qJgrl6znMbbhaxb9O
GMo3cNh7vP3+j3ohKN/Q4VvXOvHYL4JQvpFD8Wpr+02LBKB8Y4fVNkoZGof5
oXwTB/l/Z09bfOCC8k0dZl/j/rnMlBvKN3Ooqv91MHsVG5Rv7uBjXr/9sR4z
lG/hAAlvJijf0iE8ymhdkdJ/ewjfysG49+13xwM/oXxrNHkbNHlbByYFrV/c
q//YAwBF2HTn
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwOLCv9ZfnJUUon8Ohs2T7
jru2ML6Ag1iYtXXRIgUoX8ThVPe9NRP5YHwJhx9FYfNZJeWhfBkH5Q8P9l25
IwvlKzhENmyxSdkhA+UrOVw2mDw9Y440lK/isMj195nyFikoX81h0oL7v+5n
SUL5Gg7ey7siuPkkoHwth2V/V8irzRGD8nUctKItju7zF4Xy9Rymqv6NZJgv
DOUbOFyyn8QiflcQyjd0qNQ8/jPVXwDKN3KI0p7oca6CG8o3djDuffvd8QAn
lG/isHFd/hS9aA4o39RB3sPXUmwVK5Rv5vDe8tc/Jz02KN/cQWczC5tZHzuU
b4Emb+kACX8mKN/KgZt5bdWryYxQvjWU/9EeAPIBaEU=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw+HT6zOed5xWhfA4He3Up
/z/GML6Ag+eKdbEXFyhA+SIOwrXP3Do5YXwJB9WsuWaZwvJQvoyD8ocH+67c
kYXyFRzCEie0ey+TgfKVHAqnrl/0OlgayldxWHe+MtDKXArKV3P4tDjygLyR
JJSv4aDsWxrWECsB5Ws5yB259+OSrziUr+NQOUHkqiejGJSv52ByqbdcdZcI
lG/gkHRCaZdxgzCUb+iQUBj7+9QLQSjfCI1v7BA5a+1CUR0BKN/EYb30mu2X
vPmhfFOHizuufrnxgxvKN3NgUtD6xb2aB8o3dzj6mT84qhDGt3Aw7n373fEA
J5Rv6fDe8tc/Jz02KN/KIbDHUJullQXKt3YIjzJaV6T03x7Ct4Ga/wfKt3Uo
Xm1tv2kRA1S9HZp6ezS+gwM389qqV5MZIeobHKD2P7MHACySgjY=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwmFgpenLKdUUon8NhhvhD
2c8WML6AQ1EM/9RDsxSgfBEH8RsKJVtFYHwJh9fn9ZNkH8tB+TIOZ4s+MeUv
lYXyFRz2Xy21NiiSgfKVHPJr/FNdfaWhfBWHFW6OUzf9kYTy1RwCNip4hu2Q
gPI1HObKTd03204cytdymHNe1ZOtSwzK13Eo2XlI4bCXKJSv5zC34WoV/zph
KN/AIdp9P9evDUJQvqFD05Ok3idrBKF8Iwdft2NHn9gKQPnGDuul12y/5M0P
5Zs47D1u9U7jMQ+Ub+rwU2dSzfIcTijfzGHjuvwpetEcUL65w/Ld18VOybBC
+RYO3Mxrq15NZoTyLR0Cewy1WVpZoHwrh/eWv/456X2zh/CtHYx73353PPAT
yreB8wGG3G9L
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwOMAg9ffVWUUon8PBqPvR
qzodGF/A4c7CY2nSMxWgfBGHBn6ljUFsML6EQ6R606+nPPJQvoyD8XzNBPmN
slC+gkOTTL3ghA0yUL6Sg931jXGb3KWhfBWHyuAunRP/JaF8NYfjjhu4Hh2S
gPI1HF6nbGr6tEYcytdy4FlpHrhnvhiUr+Ow4vbhqXOviUL5eg7x17fGXa4Q
gfINHJ5kaVr9bReG8g0dSjKW7/MXE4LyjRy6jVLvzE4QgPKNHcKjjNYVKfFD
+SYO33h3Nv4x5YHyTR1OHLUtL9nFAeWbObRNzLaqlmeH8s0dAnsMtVlaWaB8
CzS+pQOTgtYv7tV/7CF8Kwdu5rVVryZ/tAcANa9ioA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVw+GlQcoz3mCKUz+Fwbb/p
1G5dGF/AYen9Q59kJihA+SIODjuZev+9lYfyJRwkS2JPlJyQg/JlHJStJs/o
qJCF8hUcuv7LL/0YKwPlKzlI+uanHhKUhvJVHPTDTJQ/fZGE8tUcmnLedi+/
LgHlazg08H9viTMVh/K1HKY22C4WdBKD8nUcaqPtbbaEiEL5eg4Gsc3L964Q
gfINHJJOKO0ybhCG8g0dHs02M709WQjKN3I4eU3ly28eQSjf2GG99Jrtl7z5
oXwTB+eQP2asbnxQvqmD35o+19StvFC+mYP8v7OnLT5wQfnmDlX1vw5mr2KD
8i0cIOHNBOVbOoRHGa0rUvpvD+FboclbOxSvtrbftIgByrdBU2+LxrdzeG/5
65+T3jMo3x7OBwCQN3r8
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQEf7MVCt+7emK3kABVwcBG6E+l4WRHK53Co2vlt
7l53GF/A4VvJjPPOGxSgfBEHVbOdnNu5YHwJh+Ql917teSYH5cs4aFyfsYy5
VxbKV3DYWPj09ZpIGShfyeHxA53N1kbSUL6KQ5/1FM1GLikoX82B0Up753lO
SShfw8HiaH31vF3iUL6WA/flL4X/6sSgfB2HdbKXlbSei0D5eg4q5YyTzd4L
Q/kGDtMf9jDe+ygE5Rs6aPopi7jmCkL5Rg6Kjumdpf8EoHxjh/8Mgf8TSvih
fBMHvzV9rqlbeaF8U4drvB0ZP/1gfDOH2de4fy4z5YbyzR0mtDDvuB/LBeVb
OJw4altesosDyrd0kPfwtRRbxQrlW6HxrdH4Ng4/dSbVLM/hhPJtHarqfx3M
XsUG5duhqbd3qJ13eY/YQ2Yo38EBEt9MEH6DgwOTgtYv7tV/7CHyjg7vLX/9
c9L7BuE3oPEZnBy4mddWvZr8ESrv5GDc+/a744GfUHlnVH6DM1T/M3sAe6ib
sw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwuHDo4ZG/1xWhfA6HnXxz
A8LtYXwBB5tmf/mmDQpQvogD75XlWsESML6Ew+vz+kmyj+WgfBmHnicbpCp2
y0L5Cg6KQnVyzP0yUL6Sw6YVx5OadKShfBWH/6a5te2HJaF8NQdXDuY/XzZK
QPkaDrf/S++OLhGH8rUc2D7wX5uYIQbl6zgk+Wmu+McjCuXrOaiUM042ey8M
5Rs4/PB+ytHoIwTlGzoIvThwaHWQIJRv5FC6O8DG4gcflG/skH1ix77LO7mh
fBOHizuufrnxA8Y3dfipM6lmeQ4nlG/m8N7y1z8nPTYo3xyNb+EQ2GOozdLK
AuVbOkDCnwnKt3LgZl5b9WoyI5RvDdX/zR7Ct0Hj20LVf4Ty7dD49g7GvW+/
Ox74CeU7wOUBN4mCwA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwcA2r3153RRHK53BoWzqn
+rwVjC/gsM5zibb+fAUoX8SBY5ND98178lC+hENNyY1rbnvkoHwZhybV6Lg7
s2ShfAWHSyZRn55Pl4HylRwOxvy/l+gnDeWrODjmqlplhkpB+WoOfTOvVpd7
SEL5Gg4PfsqFNhlIQPlaDgFB36TXN4lB+ToOZm+e3V3DLgrl6znI7Sze1n5a
GMo3cIh238/1a4MQlG/oIKBjKH3uvyCUb+Sg6JjeWfpPAMo3drA8t3vBsQcw
vonDeuk12y9580P5pg4rHA8fPSbJC+WbOfzUmVSzPIcTyjd3OHHUtrxkFweU
b+Hw3vLXPyc9Nijf0mH57utip2RYoXwrh+LV1vabFjFA+dYOxr1vvzse+GkP
4dug8W2h5j2zBwBqane9
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwcPbwrLU4qwjlczj0+6xa
UaQP4ws4LJ+3nltltgKUL+LQtcr4SQIXjC/hIDOlTiiCTR7Kl3EIWPq2ZNIf
WShfweGcj6zt550yUL6Sw6OfS5gDZ0pD+SoOwXEi3VM9pKB8NYcHJ14L5opL
QvkaDnwVWmH3JotD+VoOO09HbguPFIPydRxc5jwQ2tkpCuXrORjENi/fu0IE
yjdweJKlafW3XRjKN3T41rVOPPaLIJRv5CAt8fjFxEkCUL6xw5KTi8u4S/ig
fBOHa7wdGT/9eKF8Uwf5f2dPW3zggvLNHHQ2s7CZ9bFD+eYO3Mxrq15NZoTy
LRzeW/7656T3zR7Ct4TKf7QHAJ7kYCU=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVweNj21PXsGUUon8NBdbfH
JBcTGF/AwfehzNWABQpQvohDZ2X+mxQeGF/C4ZDXyZWS++WgfBkHtS1fp5uv
kYXyFRxCDzDbNiyVgfKVHCpuBz7oKJGG8lUcCm/9EXCPl4Ly1RwqcvstSoMl
oXwNh5VZcyV0topD+VoOc86rerJ1iUH5Og5mk49keAqJQvl6Du9yj3w1/iYM
5Rs4vBGOTP3WKQTlGzrYh3+J8ZMWhPKNHLqNUu/MThCA8o0drvF2ZPz044Xy
TRz2Hrd6p/GYB8o3dThx1La8ZBcHlG/mIO/haym2ihXKN3fgZl5b9WoyI5Rv
4QAJbyYo39LBuPftd8cDP+0hfCs0vjVU/0co38aBSUHrF/fqP1C+rcN7y1//
nPSe2QMAIllzAQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw2Hdmg3vzdUUon8Nh/TfJ
jw2+ML6Aw9ziFRlmaxWgfBEHLpdjP7q5YHwJhyS/h1sPPJSD8mUcGjZNa59+
RRbKV3AIebxO7+ViGShfyeEhS9f0s5ukoXwVh+cbayq+VElB+WoOfTOvVpd7
SEL5Gg5/j8h3b7klDuVrOcxaedD561oxKF/HgWnG/N8eDaJQvp6D0NqrmR/q
RKB8A4ekE0q7jBuEoXxDh3Xu74PKeWB8I4fUucuYqhcIQvnGDpGz1i4U1RGA
8k0cwqOM1hUp8UP5pg5MClq/uFfzQPlmDhvX5U/Ri+aA8s0d3lv++uekxwbl
Wzj4mNdvf6zHDOVbOnAzr616NZkRyrdC41tDzf9jD+HbQM37Zg8A6vlwUg==

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVweNXtnSR1RhHK53C4nVhn
6GsK4ws4hDx/enLXZAUoX8ShcNc335T38lC+hMNCsY2Tkh/IQfkyDmwNIa9v
TJWF8hUcQg+dm+FpLQPlKzmIysZqBTNJQ/kqDv9CxWS7b0hC+WoOWtfWCnHM
kIDyNRz4KrTC7k0Wh/K1HC7n3Nl5IkUMytdx+M2Xbn/QVRTK13Pw8Oq5tSlS
BMo3cFi45IRo/zUhKN/QQUDHUPrcf0Eo38hBWuLxi4mTBKB8YwddW72Q/c94
oXwTh2+8Oxv/mPJA+aYOUdoTPc5VcEP5Zg5tE7OtquXZoXxzNL6FAyS8maB8
SwcmBa1f3Kv/2EP4Vg7vLX/9c9L7BuVbQ/nP7AGIAGfh
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEf7MVCt+7emK3kABVw+HT6zOed5xWhfA6Hqytn
nz9oA+MLOFh85W3uW6YA5Ys4mBn+3b9TCMaXcHh9Xj9J9rEclC/joNuf4CAz
RxbKV3Bo5eD4szZfBspXcnD2vCfzzlMayldxePX4wg95OSkoX83hjN0Tt6Cz
ElC+hsMcQXu2iz/FoXwtB8UFjSKOZ8WgfB0HhceiUxdHikL5eg5Rn26bqf4V
hvINHE5WutikqMH4hg7futaJx34RhPKNHJ7pKxnnacL4xg67pabM3fleAMo3
cfjPEPg/oYQfyjd1WHJycRl3CR+Ub+bApKD1i3s1D5Rv7nBW6sOrKQJcUL6F
g7LXtGtRK2B8S4fZ17h/LjPlhvKtHNomZltVy7ND+dYOgT2G2iytLFC+jcPy
3dfFTsmwQvm2aPJ2Dj7m9dsf6zFD+fZo8g4Oxaut7TctYoDwGxwc3lv++uek
980eIu8Idf8fCL/BEU3eCZXf4OTAzby26tXkj1B5ZzT9zg6Q9MUEtd/FITzK
aF2R0n+ovAtcPwDCt6FN
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw+MQxOyL3kiKUz+GQJZYQ
9dUWxhdwWNm4W7x0rQKUL+JgHrL/UZMcjC/hYKx+6Np9JXkoX8Zh6kYWtrcP
ZKF8BQcmBa1f3KtloHwlh6NC2S3c3tJQvorDz6gtjm9YpaB8NQcu7eZYzg8S
UL6Gw+5FcnNqpGB8LYfTmnkbZP6IQfk6DpUTRK56MsL4eg4er67v4+sWgfIN
HN7lHvlq/E0Yyjd0eLznb4O2uRCUb+Sg6JjeWfpPAMo3duDNEXrdUQjjmzis
l16z/ZI3P5Rv6nBxx9UvN35wQ/lmDieO2paX7OKA8s0dlu++LnZKhhXKt3Co
nXd5j9hDZijf0qF4tbX9pkUMUL6Vw3vLX/+c9L7ZQ/jWUP4zKN8GTd7WgZt5
bdWryR/tAVDBdOU=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAmIQDQEf7MVCt+7emK3kABVw8Kh47mhxRRHK53Bgn71l
T5UNjC/g8MS8IdNwugKUL+LAscmh++Y9eShfwuH0KrmKoyvkoHwZh9/fVrBO
S5eF8hUc2kOVJKTDZaB8JYdX0hY3F8tJQ/kqDkyczRadGlJQvpqDdKfV+jsq
klC+hgNfhVbYvcniUL6WQ+UEkauejGJQvo6DIsvdB5//iED5eg5VldrPr6nC
+AYO69zfB5XzCEP5hg7futaJx34RhPKNHHzdjh19YisA5Rs7OIf8MWN144Py
TRwu7rj65cYPbijf1OGs1IdXUwS4oHwzhxNHbctLdnFA+eZofAsH49633x0P
cEL5lg4/dSbVLM+B8a0c2iZmW1XLs0P51g7Ld18XOyXDCuXboJln66CzmYXN
rA+m3s4hPMpoXZHSf3sI396heLW1/aZFDFB5BwcmBa1f3Kv/QOQb0PgMjg7c
zGurXk3+CJV3RDPPCdW8Bieoekao+c5o8s5Q//6E6ndBs98FzXxXh/eWv/45
6T2DyqPxGdxQzWtwQ3O/O5r5aHwGDwcf8/rtj/WYoe5D4zN4ornfE819Xmj2
e6GZ742m3xstfHzQ3OeDGt4MvnA+ADPX6tY=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVweG86JaT2giKUz+GQfLbK
8bkVjC/gMNHi5amOOQpQvogD65RDCrzcML6Ew9aFBfe2c8lD+TIOu9jjWqfd
k4XyFRyYFLR+ca+WgfKVHBIuyW+bHy0N5as4LDu091jWCUkoX82hxNKqQ3ip
BJSv4fC3SNG31EIcytdy6KqLE1/zRRTK13FYOrVYcKcDjK/nEKC/QKlEQgTK
N3DYe7z9/o96ISjf0CGhMPb3qReCUL6Rg6/bsaNPbAWgfGMHvzV9rqlbeaF8
E6B+q3caj3mgfFOHCS3MO+7HckH5Zg4+5vXbH+sxQ/nmDpDwZYLyLRyKV1vb
b1rEAOVbOnAzr616NfmjPQB4j2C+
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVw4BWbGyB6UxHK53BIPlLA
22wH4ws4TNwy/RnDagUoX8Sha5XxkwQuGF/CgWXdhRvJu+SgfBkHpi2REb/n
ykL5Cg5KTDo7WCpkoHwlh46zuWKFKtJQvoqD9S6Gtbb/JKF8NYfM3RMyt96U
gPI1HFZmzZXQ2SoO5Ws56GxdHPpntxiUr+NgJsW5+OMCUShfzyGGQ6phhqUI
lG/gcLLSxSZFTRjKN3Rw2/syy+GiIJRv5FC82tp+0yIBKN/YQddWL2T/M14o
38RB/t/Z0xYfuKB8U4eq+l8Hs1exQflmDoE9htosrSxQvrlD7bzLe8QeMkP5
Fg7czGurXk3+aA8A5MtY8Q==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwiGD5eWTiWUUon8PBWk9b
vd4WxhdwKF5tbb9pkQKUL+Jw57l0+uy/8lC+hMOqT+ri7+/LQfkyDn5r+lxT
t8pC+QoO1x5GTt2TIgPlKznICOxkn+ImDeWrOLSx2yvwqUtB+WoOFQ2C08sv
SkD5Gg4rs+ZK6GwVh/K1HBbwM0n9cRWD8nUcIjz6BR7tF4Hy9RyEuMX3PNsj
DOUbOBjuklZ/VCoE5Rs6PNNXMs7TFITyjRxKdwfYWPzgg/KNHZS9pl2LWsEF
5Zs4yHv4WoqtYoXyTR2W774udkoGxjeDhg8DlG+OxrdwYFLQ+sW9+o89hG/p
YNz79rvjgZ9QvpXDe8tf/5z0vkH51mh8GzS+LZT/DMq3g/MBF+R0dw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw+Mo459DHy4pQPodDZ8n2
HXdtYXwBB2XZ50fVVypA+SIO61j5hdo4YHwJh1Wf1MXf35eD8mUcmP4t3D+v
XhbKV3BYM9Oi5a2tDJSv5FDOEG9/77MUlK/iUC/73zgvTxLKV3MQc3ycs6ZM
AsrXcCjomPWxsFAcytdy+Lg9KFjZTgzK13Ewk+Jc/HGBKJSv59B0PDz2l48I
lG/gsPd4+/0f9UJQvqFD8cb1nQFVglC+kUPkrLULRXUEoHxjB11bvZD9z3ih
fBOHb7w7G/+Y8kD5pg4b1+VP0YvmgPLNHOQ9fC3FVrFC+eYOVfW/DmavYoPy
LRxq513eI/aQGcq3dChebW2/aREDlG/lwM28turVZEYo3xqNb+PgY16//bEe
TL8tVP6jPQD4GW/U
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwaNXfzVZ/SRHK53A4bj/r
s4YVjC/gcOZHwP+NixWgfBEHHZuMn+lMML6Eg2RJ7ImSE3JQvoxD2P8lEd2N
slC+gkPWm/ryT4EyUL6Sg7zBhoWFqdJQvorDrdQSuRQWKShfzcFA4ec/6+US
UL6GQ+XGwB8aVeJQvpaD4oJGEcezYlC+jkO8mS3b3bOiUL6eg8ztCAeBiSJQ
voHDkyxNq7/twlC+ocOV1G+cGjsFoXwjB94codcdhQJQvrFD9okd+y7v5Iby
TRzOSn14NUWAC8o3ddi4Ln+KXjQHlG/mIO/haym2ihXKN3fgZl5b9WoyI5Rv
gca3dDDuffvd8cBPewD4XV7p
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwuLta2P3NdUUon8OhXXvF
oskWML6AA+MHxiCVVQpQvohDJZ/lhlYGGF/CoTLolEPbcTkoX8bBfuJuufhV
slC+gkPXf/mlH2NloHwlB9X/3RN/SkpD+SoO0zPFGRbKSEH5ag7LIl5mmNtL
QvkaDjMOzmNuD5OA8rUcHmqnHuLWEYfydRxUCi/e/CkqBuXrOfgVC1RPOyoC
5Rs4TE79MDlmuRCUb+jQ9CSp98kaQSjfyEFa4vGLiZMEoHxjB11bvZD9z3ih
fBMH+X9nT1t84ILyTR1+6kyqWZ7DCeWbOZw4altesosDyjd3COwx1GZpZYHy
LRxq513eI/aQ2QEA+rFbKA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwuCApsvz3KUUon8PhgsWr
xPmaML6AwwFu9amyXQpQvojD+pkhT9eclYfyJRxK929IrpggB+XLOJwSOpi3
ok0WyldwWLc0VvGtoAyUr+RwpupU4iJxaShfxaHPeopmI5cUlK/m4H9dN4Hz
hwSUr+GwfPWVG9/fiEP5Wg6KCxpFHM+KQfk6Dk9Zp33bPl0UytdzaDoeHvvL
RwTKN3DQ+dC3bnu/MJRv6DBz//LyUB0hKN/IoXjj+s6AKkEo39hBWuLxi4mT
BKB8Ewce4UPlBS/5oXxTByYFrV/cq3mgfDOHnzqTapbncEL55g4+5vXbH+sx
Q/kWDsa9b787HvhpD+FbOnAzr616NfmjPQA3YGPy
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEf7MVCt+7emK3kABVw8Gw3E+U4rwjlczis2xnJ
4aQP4ws4SJRc2PZungKUL+IgZrrMbyMHjC/hYK8V52bCJw/lyzh8+pr04j67
HJSv4BBh9uE933sZKF/JQYD/T9Kis9JQvorDnNe9cb09UlC+moMk/xSrBZaS
UL6Gw4OfcqFNBhJQvpbDe/s8z4es4lC+jsNZ5wjJpz9EoXw9B+3jEl+XPBSB
8g0coj7dNlP9KwzlGzqwhTJu/nBYCMo3cijJWL7PXwzGN3awPLd7wbEHAlC+
iUN4lNG6IiV+KN/U4RvvzsY/pjxQvhka39zhp86kmuU5nFC+hcPy3dfFTsmw
QvmWaHwrB+Pet98dD/y0h/Ct0fg2UPv/Q/m2DtzMa6teTWaE6rdzYFLQ+sW9
+g9U3h5NvwMqv8EBTb0jKr8Bjc/ghKYfjc/gjKYfjc/g4vDe8tc/J71vUHkE
HwC7T6n/
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwSE/2n8h4TRHK53BQlNzq
c9QUxhdwmHjfQS1osQKUL+Jw7d+09jscML6Eg8vCj6GTLstB+TIOvEVG1peb
ZKF8BQfGx3XPsj1koHwlh00rjic16UhD+SoO04Vs9697LAnlqznIex6VmzxP
AsrXcLB0v+Kwab04lK/lwLPSPHDPfDEoX8dhZcHZixl9olC+nkNfQemq6GAR
KN/AoXczp/a++0JQvqHDJftJLOJ3BaF8IwdpiccvJk4SgPKNHbZ9mKAvdZYP
yjdx+Ma7s/GPKQ+Ub+ow8XFxtdN3dijfzCE8ymhdkdJ/ewjf3IFJQesX9+o/
UL6Fw3vLX/+c9L5B+ZZQ/jN7APoQYwM=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwqDxiff/kfUUon8NhntQ7
a20HGF/AIUXm7VqDBQpQvojDGd55D2VYYHwJhwxl7cmsT+SgfBmHnicbpCp2
y0L5Cg5M8p9NvRpkoHwlh7DrB9hkRaShfBUHrv/GWW/uSUL5ag52Yqprfh2R
gPI1HNZcl32wfIk4lK/lsOzvCnm1OWJQvo7D78IF9b4ZolC+nsOFNXs7m6+J
QPkGDk+yNK3+tgtD+YYOP7yfcjT6CEH5Rg5CLw4cWh0kCOUbO/i6HTv6xFYA
yjdxYFLQ+sW9mgfKN3WY0MK8434sF5Rv5vBTZ1LN8hxOKN/cYeO6/Cl60RxQ
voWDzmYWNrM+dijf0mH57utip2RYoXwrBx/z+u2P9ZihfGs0vo1DeJTRuiKl
//YQvq2Dce/b744HftoDALnCb2A=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwiDW24dh4TRHK53C4unL2
+YM2ML6Ag6/p9INvlylA+SIOf71s1R4Jw/gSDvxyAUvtBOWhfBmHjfPnlK1h
lIPyFRwmHth7UPWZDJSv5HA690jTkXXSUL6Kw+U1z8/wZEpB+WoO98IeVh7h
loTyNRxWZs2V0NkqDuVrOdw+vuXW9WIxKF/H4SnrtG/bp4tC+XoOc3fYRE9e
JwLlGzjEJD16rPNCGMo3dIh238/1a4MQlG/k8PqOeot+kwCUb+xQujvAxuIH
H5Rv4nBxx9UvN35wQ/mmDu8tf/1z0mOD8s0cIOHJBOWbOxj3vv3ueOCnPYRv
AVX/zB4A82BmMw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw6N7yOGD3VUUon8Ph++pd
ZVfMYXwBh6clZmpCixSgfBEHVbOdnNu5YHwJh+0bqt6EXJOD8mUctnY/erlt
oSyUr+Dw+sbiCMdJMlC+ksMGux1WO2KkoXwVhw0JPubbXKWgfDWHt+c/5tga
SEL5Gg7hbF/uhJlKQPlaDn1l9U0298SgfB2HeDNbtrtnRaF8PQeTS73lqrtE
oHwDh6QTSruMG4ShfEMHAR1D6XP/BaF8IwdpiccvJk4SgPKNHV7fUW/Rb4Lx
TRy2fZigL3WWD8o3dQjI0Tr9VRImb+bAW2RkfbmJF8o3d/ipM6lmeQ4nlG/h
0DYx26panh3Kt3Soqv91MHsVG5Rv5RAeZbSuSOm/PYRv7cCkoPWLe/UfKN8G
Td4WTd7OgZt5bdWryR+hfHs0eQeH95a//jnpfYPwG2D8Z/YA3v2Djg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwSAjZUatwThHK53AQ+Mpa
q2MC4ws4vC2r75s8XQHKF3E4NGH1eaWP8lC+hIPv57M1vz7KQfkyDsofHuy7
ckcWyldwOK++b/HD5TJQvpJDfo1/qquvNJSv4nA8YMWlOjspKF/NIXtplVSZ
jiSUr+Gw1uPWsyJGCShfy2GG5e5pbw+JQfk6Dj3iFyZ9KxSF8vUcaudd3iP2
UBjKN3CYnPphcsxyISjf0CGGfdEsaVdBKN/Iwdft2NEntgJQvrFDjtOEvXwL
+aB8E4e9x63eaTzmgfJNHTauy5+iF80B5Zs5LN99XeyUDCuUb+4QHmW0rkjp
vz2Eb+FQvNraftMiBqi8pYNx79vvjgd+QuWtHLiZ11a9mvwRyrd2eG/565+T
3jMo3waNbwvnAwBsrXpb
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwWOV00EjquiKUz+EwKSbb
YZMdjC/goKFs0HtyjgKUL+Ig9HR3mDUvjC/hkLzk3qs9z+SgfBmH8E0aSRGb
ZKF8BYc2MaWrhkkyUL6Sg2jkxUpDK2koX8WBYXJ710wlKShfzaHm2Lp7XJ8k
oHwNh8VM86epWsH4Wg7v7fM8H7KKQ/k6DpkpXyv01UWhfD0H3efSDVwsIlC+
gUNk/CGPqAhhKN/QwfLc7gXHHghA+UYO4VFG64qU+KF8YwfeIiPry028UL6J
Q/aJHfsu7+SG8k0dfupMqlmewwnlmzl82Hzxb60ojG/u8N7y1z8nPTYo38KB
m3lt1avJjFC+pQMk/JmgfCs0eWuo/m/2EL4NVP4jlG/rwKSg9Yt79R8o3w7q
/v9Qvj2a+Q4OtfMu7xF7yAzhNzigqXdE5Tc4wu0HAIkHhyo=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwOJ+wOaPnjiKUz+Hw6vP3
47UGML6AQ3U6x747PQpQvojDoQmrzyt9lIfyJRw+1H2oWXxGDsqXcXBcUXXk
ULUslK/g4H3t02JJUxkoX8nB17pv89YfUlC+isP3ZIuzE15LQvlqDnWy4ks/
PZWA8jUcrl+tPdVlA+NrOajVXL942F0cytdxUCm8ePOnqBiUr+egfVzi65KH
IlC+gUPUp9tmqn+FoXxDh+7epaprmWF8I4eSjOX7/MWEoHxjh5PXVL785hGE
8k0cuo1S78xOEIDyTR14i4ysLzfxQvlmDmelPryaIsAF5Zs7vLf89c9Jjw3K
t3DgZl5b9WoyI5RvCZX/Zg/hW0H5z+wBoMxu6A==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwmH8zgoPxgiKUz+GgfDL0
uZErjC/gwPP+Uf7NwwpQvojDga9RLLrqML6Eg/V+dzVGMXkoX8Zh4VVJc+Yv
slC+goM318U5c/bJQPlKDh5FSXsvbpWG8lUcFr6P538xUQrKV3MoiKs7qOIj
CeVrOFjurL8vqicB5Ws5vIs9uD3xmBiUr+Nw8kpLa+lJUShfz+HCmr2dzddE
oHwDh5fTihzX2gtD+YYOBdc+H0pUFILyjRyKN67vDKgShPKNHZxD/pixuvFB
+SYOe49bvdN4zAPlmzpMfFxc7fSdHco3c/Axr9/+WI8Zyjd3YFLQ+sW9+o89
hG/h8N7y1z8nvWdQvqUDN/PaqleTP0L5Vmh8awfj3rffHQ/8hPJtoPq/2QMA
trdygQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQEf7MVCt+7emK3kABVw4O1LDJ5wRRHK53DIbTtl
NtcMxhdwCFeZrhQ0XQHKF3GID3VsussA40s4xISvuvh3kRyUL+OgJy2tsDpe
FspXcAiw4HmebiUD5Ss5uHcu9xI3lIbyVRwOX9z1nY1HCspXc8jcPSFz600J
KF/DQe7IvR+XfMWhfC2H95a//jnpiUH5Og7X2dqvy34SgfL1HGKSHj3WeSEM
5Rs4TH/Yw3jvoxCUb+iwL0b1oBw3jG/kcPKaypffPIJQvrHDMmWvWyaHBKB8
E4f10mu2X/Lmh/JNHfzW9LmmbuWF8s0corQnepyr4IbyzaHuY4PyLRx8zOu3
P9ZjhvItHSDhzwTlWzlwM6+tejWZEcq3dihebW2/aREDlG/jEB5ltK5I6b89
hG8LVf8RyrdzMO59+93xwE8o3x6N7wB1zzcIvwGNz+CIal6DowOTgtYv7tV/
oPJOqPY3OKG53xmV3+CM5h8XNPvR+AyuaPa7osm7QfnP7AFPgLdu
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwsJ3pV3/3vCKUz+FgN0/m
xD0DGF/AoZJ31vo3ExWgfBGHAPO5of5f5aF8CQfxv5d4XS7KQfkyDj1in7j3
zJGF8hUcfH/8NArOkYHylRyitCd6nKuQhvJVHK5c871Q5C0F5as5LN10dHHH
ZQkoX8NBlfNchN5TcShfyyGy9p1rz1cxKF/H4eKa859VckWhfD0Hifg9l/rc
RKB8A4fezZza++4LQfmGDvbhX2L8pAWhfCMHJgWtX9yreaB8Y4efOpNqludw
QvkmDm0Ts62q5dmhfFOH2nmX94g9ZIbyzRwg4ckE5ZujyVs4GPe+/e544Kc9
hG/pwM28turV5I/2ADYjY1Y=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwOLzOJOX6JUUon8Pho/Fr
XzdrGF/AYbHm7u9mMxSgfBGHtLW7/zN8k4fyJRxuT3tW/+qgHJQv4xDrulab
cZsslK/gsLHw6es1kTJQvpIDV9vhZVKTpaF8FYd5C0wjEwyloHw1h1RVQ0a7
0xJQvoYD75c5L73niEP5Wg6sJbLa9TvEoHwdB61oi6P7/EWhfD2HpBNKu4wb
hKF8AweuxT/i3I4KQvmGDvbhX2L8pGF8I4dKzeM/U/0FoHxjB11bvZD9z3ih
fBOHvcet3mk85oHyTR2UvaZdi1rBBeWbOcy+xv1zmSk3lG/uYNz79rvjAU4o
38KhbWK2VbU8O5Rv6SDv4WsptooVyrdyKF5tbb9pEQOUb+3Azby26tXkj/YA
8oVmMg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwmLpVLXHRJUUon8Oh32fV
iiJ9GF/AoX9hlYLdBAUoX8TB0eXYars38lC+hIPJYuWkjXPkoHwZB3v2qFrW
cFkoX8HhwvN9USsMZKB8JQeWWTviJl+XgvJVHL6yv1qWvlESyldz4P+yLvit
kQSUr+Gw902wn/9iMShfy+E3X7r9QVdRKF/HIerTbTPVv8JQvp7DyUoXmxQ1
GN/AwaWh4q9huyCUb+jw+o56i36TAJRv5BCQo3X6qySMb+wg+EZE7IMYH5Rv
4vCNd2fjH1MeKN/UYfY17p/LTLmhfDOHCS3MO+7HckH55g5tE7OtquXZoXwL
Bx/z+u2P9ZihfEs0vpUDN/PaqleTP9oDAITGYho=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVw+Hg4UO3mWUUon8OhLaHi
XbghjC/g4PH0vs6tGQpQvohDzHUO49dMML6Ew3m33R8m7peD8mUcJOxSJ/wv
loXyFRzWLY1VfCsoA+UrOXy8eEpqha40lK/i0MZur8CnLgXlqzlcfdvA8fqx
BJSv4WA8WXZj3UxxKF/LYc55VU+2LjEoX8ehZOchhcNeolC+nkNVpfbza6oi
UL6Bw8IlJ0T7rwlB+YYOj/f8bdA2h/GNHF7fUW/RbxKA8o0dlpxcXMZdwgfl
mzhc3HH1y40f3FC+qYNx79vvjgc4oXwzh+W7r4udkmGF8s0duJnXVr2azAjl
WziERxmtK1L6bw/hWzowKWj94l79xx4AN59j6w==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwmLTD8XPLfUUon8PBbFVg
UbYdjC/gYMKc+Vt+lgKUL+Jw3p+ne9M3eShfwiHPSKJhw145KF/GQe+Z6s6C
ibJQvoLDs+YNvd/CZaB8JYcbR97Y82tKQ/kqDpvZLx37xSEF5as5rBM89ezl
IgkoX8NhodIcmYJN4lC+lkOdTtXsvA+iUL6OQ3vVkYofc0SgfD2Hl9OKHNfa
C0P5Bg5ue19mOVwUhPINHXiED5UXvOSH8o0csk/s2Hd5JzeUb+zQNjHbqlqe
Hco3cVi++7rYKRlWKN8UjW/mAAlPJijf3MHHvH77Yz1mKN8CTd4SjW/lULza
2n7TIgYo3xqNb4PGt3V4b/nrn5PeM3sAsz5y9w==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwcBG6E+l4WRHK53CI3SIU
+tMSxhdwmCJtFrxvpgKUL+IQsz9Fto4NxpdwePHxFpP+VjkoX8bhctPt6JrZ
slC+gsPdhpSs1cEyUL6Sw5mqU4mLxKWhfBUH1tyGvH8vJaF8NQcxx8c5a8ok
oHwNh498oYc19cWhfC2HeaUrbhkoiUH5Og6b1rfJSdwRgfL1HOI63F7aHhGG
8g0cDHdJqz8qFYLyDR2EXhw4tDpIEMo3cqjUPP4z1V8Ayjd24C0ysr7cxAvl
mzh8493Z+MeUB8o3ddi4Ln+KXjQHlG/msHz3dbFTMqxQvrlDeJTRuiKl//YQ
vgUa39KBSUHrF/fqP1C+FRrf2uG95a9/TnrfoHwbNHlbNHk7NL69Azfz2qpX
kz/aAwCoVnpv
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwUL79b6baJUUon8PhUox5
zx5zGF/A4Zrls00d6xWgfBGH58pvxGolYHwJh3gdy7/tH+WgfBmHv4zF72Ou
yUL5Cg4986Mm7pwjA+UrORS4uVS2p0lD+SoOT6YeaX6hLwXlqzm4u5ZkMv+R
gPI1HBRPfmy30ITxtRxuTE2IWnNBDMrXcVApvHjzpyiMr+ewfPd1sVMyolC+
gUN71ZGKH3NEoHxDBx/z+u2P9YShfCOHmfuXl4fqCEH5xg6yq/9cizEXhPJN
HLZ9mKAvdZYPyjd1uMbbkfHTjxfKN0PjmzvMvsb9c5kpN5Rv4aCzmYXNrI8d
yrd04GZeW/VqMiOUb+XApKD1i3v1H3sI39qheLW1/aZFDFB5Gwfj3rffHQ/8
hMrbwvkA51R0og==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVwUL/JcfPAaUUon8NhvX3+
VhkDGF/AYVNvwu6XUxWgfBGH8/483Zu+yUP5Eg4f6j7ULD4jB+XLODSpRsfd
mSUL5Ss4XHnNf1xyugyUr+Sw7oHv+glt0lC+isOrxxd+yMtJQflqDg9OvBbM
FZeE8jUcyjbKTQq9Kw7lazm4pj7e3DNDDMrXcTio3KLBoCQK5es5TFX9G8kw
XxjKN3AoyVi+z19MCMo3dNgtNWXuzvcCUL6RQ+SstQtFdWB8Y4ejn/mDowp5
oHwTB/l/Z09bfOCC8k0dIOHHBOWbORSvtrbftIgByjd3YFLQ+sW9+o89AOCn
W4M=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVw0Oma9XrhKUUon8Nh1iqv
zYXaML6Aw0SP6S7tUxWgfBEHu3nrV+19Lw/lSzj0HupIZVskB+XLOJQ2mSh+
SZGF8hUcPt6M7YtIlIHylRzOVJ1KXCQuDeWrOFjvYlhr+08SyldzUJRI/Hv2
rgSUr+GwMmuuhM5WcShfy2FrTFVCeI4YlK/joMhy98HnPyJQvp7DkyxNq7/t
wlC+gcOj2WamtycLQfmGDm57X2Y5XBSE8o0c1kuv2X7Jmx/KN3bgLTKyvtzE
C+WbOPzUmVSzPIcTyjd1mPi4uNrpOzuUb+YACU8mKN/cgZt5bdWryR/tAXg+
W9s=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwcMj+JXvuoiKUz+HwTF/J
OE8TxhdwOO3n8mVJrwKUL+KgY5PxM50JxpdwsDwfZ196Sw7Kl3H4dir+39P1
slC+gsPRz/zBUYUyUL6SA5/1DYWZqtJQvooD+83zKbeZpKB8NQdZ4/ar8kkS
UL6Gw6GefsHFSuJQvpaD+r3AhaWsYlC+jsPSqcWCOx1EoXw9h7gOt5e2R4Sh
fAMHiH+FoHxDh9d31Fv0mwSgfCMH55A/ZqxufFC+sUOU9kSPcxXcUL6Jg7yH
r6XYKlYo39SBm3lt1avJjFC+mcN7y1//nPSe2UP45mh8C6j6j1C+JVweAElA
X48=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwONrL7nfkgiKUz+Fgraet
Xm8L4ws4yG2ztru0SAHKF3HwZHVQeiIE40s4lB36mLviixyUL+Owdk9g+Yrb
slC+gkNgybQFV7bJQPlKDgc2n3mdP1cayldx0PxTY/8zXwrKV3MQu2u/q2Sa
JJSv4dBYvEX/jJcElK/lwFHXL30qXhzK13Ho/HVhleRfUShfz8HszbO7a9hh
fAOHJ1maVn/bhaF8Q4eskh/bGMOFoHwjh5PXVL785hGE8o0dAnK0Tn+VFIDy
TRwE34iIfRDjg/JNHY5+5g+OKuSB8s0czkp9eDVFgAvKN3c4cdS2vGQXB5Rv
4eBjXr/9sR4zlG/pwKSg9Yt79R97CN/KITzKaF2R0n8o3xpN3sbhveWvf056
3+wBYixu4g==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwOHs9zqTkhCKUz+GwbV2E
6nctGF/A4bH5/QnMsxWgfBGHLwcaF3C8kIfyJRx0Vj22qVwvB+XLOJy2nvl9
7R5ZKF/B4fdPrTqByTJQvpLDgv/9M7sWSkP5Kg79Kv5zrPuloHw1B0aRjs//
/kpA+RoOlu5XHDatF4fytRz2vgn2818sBuXrOKwWfCehtlkUytdzaDoeHvvL
RwTKN3Aw3CWt/qhUCMo3dNgXo3pQjhvGN3LgzRF63VEoAOUbO2z7MEFf6iwf
lG/iIPhGROyDGIxv6vCNd2fjH1MeKN/MYfY17p/LTLmhfHOHs1IfXk0R4ILy
LRwmPi6udvrODuVbOuhsZmEz64PxrRzkPXwtxVaxQvnWDuFRRuuKlP7bQ/g2
DkwKWr+4V/+B8m0duJnXVr2a/NEeADJDb/0=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwEJ+uO3veMUUon8OhPXEj
v54GjC/g8Lasvm/ydAUoX8RBYVlIk+VVeShfwmHizAllItvloHwZh+LKroTL
lbJQvoJDzmqP7WpSMlC+ksP88zx8ky9JQfkqDoZOy1SXLpCE8tUc1lyJqLwd
IQHlazjMWnnQ+etaMShfy6G55fCd6QdEoXwdh2AGi3MbBUWgfD2Hl9OKHNfa
C0P5Bg4uDRV/DdsFoXxDB0XH9M7SfwJQvpHD6zvqLfpNML6xw3+GwP8JJfxQ
vomD4BsRsQ9ifFC+qUOU9kSPcxXcUL6Zg3Hv2++OBzihfHOHjevyp+hFc0D5
Fg7vLX/9c9Jjg/ItHWrnXd4j9pAZyrdyKF5tbb9pEQOUb+0QHmW0rkjpvz2E
bwPV/w3Kt3XgZl5b9WryRyjfDk3eHo3vAOU/swcAHvOA8w==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVwSE/2n8h4TRHK53CY3cXg
6GsA4ws4ZKo/+nB5kgKUL+Lgb72sZ+4XeShfwsFEesV6xyNyUL6MQ6ieyPGK
BbJQvoJDm5jSVcMkGShfycHZ857MO09pKF/FYfVrx3Q/EykoX83h01w9tx28
klC+hsPjO0GFjWwSUL6Wg0PStuuTysWgfB2H5pbDd6YfEIXy9Rw8Xl3fx9ct
AuUbOCxcckK0/5oQlG/ooOmnLOKaKwjlGzkIvhER+yDGB+UbO0RpT/Q4V8EN
5Zs4VNX/Opi9ig3KN3V4b/nrn5MejG/mAAlPJijf3MG49+13xwM/7QGvEFeP

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwEHSNvp18URHK53D4vnpX
2RVzGF/A4avyqzN6kxSgfBGHSx+miZWwwPgSDorPl2ucOCUH5cs47AhexLy/
WxbKV3B44Vn5XcNLBspXcuCzvqEwU1UayldxELtrv6tkmiSUr+ZQkviCaVea
BJSv4ZDytHhLp7U4lK/loFJ48eZPUTEoX8dhnexlJa3nIlC+nsO5xIiPn28K
Q/kGDoZus3Z6nRWC8g0dXBoq/hq2C0L5Rg7LlL1umRwSgPKNHSo1j/9M9Yfx
TRxWOB4+ekySF8o3dTgr9eHVFAEuKN/Mwce8fvtjPWYo39wBEr5MUL6Fw3vL
X/+c9L7ZQ/iWDkwKWr+4V/+B8q0cuJnXVr2azAhVb40mb4Mmb4smbweV/2gP
AJXKdiE=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwmHBcarPeVUUon8PBM/z5
Ty5LGF/A4e2h7Ez+ZQpQvohDkNHfG9uFYXwJB524LXV738tB+TIOIgGxh8Uf
yUL5Cg7q7Jq/k/bLQPlKDvzfdnl8yJaG8lUcpmeKMyyUkYLy1Rwyd0/I3HpT
AsrXcLB6/bhh/TRxKF/L4b3lr39OemJQvo7DhTV7O5uviUD5eg7ZEeyBydOF
oXwDh30xqgfluIWgfEMHaYnHLyZOEoDyjRy2fZigL3WWD8o3RuObOHzj3dn4
x5QHyjd1OCv14dUUAS4o38xBZzMLm1kfO5Rv7vBTZ1LN8hxOKN8CTb2lw8Z1
+VP0ojmgfCs0/dZQ/7FB+TYOkPhigvJtHXzM67c/1mOG8u3Q5O0dildb229a
xADlO0DN+2YPAClSe5M=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVw4P4qp7vivCKUz+HwpT72
XrIFjC/goJkqsOboSgUoX8QhYN+T6EQlGF/C4Ux458QODnkoX8ZhZXCYm859
WShfwcHDTfjUliUyUL6Sw4Z5OWEx2tJQvoqD4TmVHbw/JKF8NQd2rW09Ylsk
oHwNh4VKc2QKNolD+VoOc86rerJ1iUH5Og4rC85ezOgThfL1HAL0FyiVSIhA
+QYOPub12x/rCUP5hg7czGurXk0WhPKNHCo1j/9M9ReA8o0dnEP+mLG68UH5
Jg7feHc2/jHlgfJNHTauy5+iF80B5Zs5QMKTCco3h9rHDOVbOLy3/PXPSe+b
PQAQflhQ
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw0DD4mOJ8WhHK53Dolpou
KqsD4ws4bJvTaC7crwDlizh80Hkzbd1zeShfwkHFstJj9ho5KF/G4aXUK069
SlkoX8EhOdl9d5a4DJSv5PBJ8gBr6UYpKF/F4bex8TrxTEkoX81Bb+am97F/
xKF8DQe2D/zXJmaIQflaDvci+tp7votA+ToOJytdbFLUhKF8PYeSjOX7/MWE
oHwDB6EXBw6tDhKE8g0deIQPlRe85IfyjRz2Hrd6p/GYB8o3dljhePjoMUle
KN/EQdlr2rWoFVxQvqmDce/b744HOKF8M4flu6+LnZJhhfLNHWrnXd4j9pAZ
yrdwgIQ3E5Rv6cCkoPWLe/UfewjfyoGbeW3Vq8kfoXxrh/eWv/456X2D8m3Q
5G3R5O3gfACyGHgN
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVweLF1SqTjcUUon8Ph93Kt
GnVDGF/Agae5eb3hEgUoX8RB92JrTCUrjC/hsH1D1ZuQa3JQvozDS6lXnHqV
slC+gkPooXMzPK1loHwlh/As1WUq0tJQvoqDXLGL0pWPklC+mkPBzDz/Ewck
oHwNh4VKc2QKNolD+VoOZx4v/uugJQbl6zjM7JuXdahMFMrXc6idd3mP2ENh
KN/AAeJfISjf0GG31JS5O98LQPlGDuFRRuuKlPihfGOHJScXl3GX8EH5Jg7Z
J3bsu7yTG8o3ddi4Ln+KXjQHlG8GtY8Zyjd3MO59+93xwE97CN/C4b3lr39O
et+gfEso/5k9ABbMZdc=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw2D9txaTSi4pQPocD49Ef
R0vMYXwBB81UgTVHVypA+SIOpQ0X3f+Lw/gSDmzZFX+uC8tD+TIOC6U77vvd
lIXyFRx8f/w0Cs6RgfKVHB4/0NlsbSQN5as4bN/capW4TRLKV3PYY/neoWii
BJSv4dBmuF3ueoA4lK/lcGNqQtSaC2JQvo5Dyc5DCoe9RKF8PYepqn8jGeYL
Q/kGDj+8n3I0+ghB+YYOio7pnaX/BKB8I4fwKKN1RUr8UL6xQ/aJHfsu7+SG
8k0clL2mXYtawQXlmzpMfFxc7fSdHco3c6iq/3UwexUblG/usHz3dbFTMqxQ
vgWavKWDj3n99sd6zFC+lYNx79vvjgd+2kP41g7vLX/9c9L7BuXbODApaP3i
Xv0Hyrd14GZeW/Vq8kco3w6q/pk9AAJue5E=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwkGSI9Gy/qAjlczgEzdwj
v8oGxhdwuNuekjNlrQKUL+JwKXCHD7M4jC/h8OStY8pWEXkoX8bhS1Pgkfms
clC+gsOsoLk7km/KQPlKDpfWLQjfvkoayldxWPqo/gtXvRSUr+aw/8n6/Q9N
JaF8DYflq6/c+P5GHMrXckja9+DTvy1iUL6Ow2rBdxJqm0WhfD2HpuPhsb98
RKB8A4elVsYnls8VgvINHWyMfNr5EgShfCMHz5XrVqnO4YfyjR10bfVC9j/j
hfJNHK7xdmT89IPxTR2Me99+dzzACeWbOehsZmEz62OH8s0dmBS0fnGv/mMP
4VtA1f+0BwD/aWDD
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwiDW24dh4TRHK53DgU570
cYkTjC/gsFsp1GbnRgUoX8Qhx2m2QqsYjC/hcPBgwmV2GXkoX8Zh3YIlpp1v
ZKF8BYd3Dp/evtokA+UrOXz6kdd/coM0lK/i8Kp/p5v1cSkoX83hVVOzmvA6
SShfw+H59jWGhiESUL6Ww6GefsHFSuJQvo5DnU7V7LwPolC+nkP89a1xlytE
oHwDh+BrnT2XZIWhfEOH4o3rOwOqBKF8I4fi1db2mxYJQPnGDs4hf8xY3fig
fBOHCS3MO+7HckH5pg4fNl/8WyvKCeWbOUDCkwnKN3dgUtD6xb36jz2Eb+Hw
3vLXPye9b1C+pQM389qqV5M/2gMAV4xkQw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwYNc3+PbsmCKUz+Fw4mf4
ysvaML6Aw/JL4ucXdylA+SIOHnzP/Ga8kYfyJRwylLUnsz6Rg/JlHH7O/r5S
eaUslK/gcPPVz+2TemSgfCWHLf4MSSpTpKF8FQftcy84/fykoHw1B0ObxQq/
fCWhfA2HTQyLGroFJKB8LYdZKw86f10rBuXrODxuFNIoSBaF8vUc4jrcXtoe
EYbyDRx6N3Nq77svBOUbOuyLUT0oxw3jGzn4uh07+sRWAMo3dtC11QvZ/4wX
yjdxMO59+93xACeUb+rQNjHbqlqeHco3cwjsMdRmaWWB8s0dIOHLBOVbOBSv
trbftIgByrd0CI8yWlek9N8ewreCmv8Tyrd2eG/565+T3jd7AFfIaUo=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwEJ+25sSt64pQPoeDUCXb
qgo3GF/AYfGyP3u0VihA+SIOvFeWawVLwPgSDqpZc80yheWhfBkHt6W3Ur++
loXyFRwOxi5d4LhKBspXcjAWT1JbUyYN5as4SB8NzmfxkoLy1RyePzsq8EVJ
EsrXcCj9pb7+5ClxKF/LwWxlUKxXtRiUr+Owq0DnezCTKJSv5xCgv0CpREIE
yjdw+Na1Tjz2iyCUb+igK6jxcdZFASjfyOHzv12RTewwvrHDkpOLy7hL+KB8
E4eLO65+ufGDG8o3dZD38LUUW8UK5Zs5+JjXb3+sxwzlmzsE9hhqs7SyQPkW
DkwKWr+4V/+xh/AtHcKjjNYVKf23BwAHIV1O
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQEf7MVCt+7emK3kABVwMOXSXstxXRHK53B49qLA
7IkxjC/gYL/q2u7bkxWgfBGHN3MaOj7/lYfyJRzeC1d/1NgnB+XLOLA1hLy+
MVUWyldwyO9sbc1Nk4HylRzCrh9gkxWRhvJVHG58WLB4b7EklK/m8Exp8dfU
ORJQvobDyalrAl9riEP5Wg6HPT7PU9wjCuXrOPgVC1RPOyoC5es5/Ews/tu4
VRjKN3CIdt/P9WuDEJRv6CC7+s+1GHNBKN/IoXR3gI3FDz4o39hhQgvzjvux
XFC+iYPOZhY2sz52KN/UARJ+TFC+mYNx79vvjgd+2gMAyAZZ0A==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwyLz2uGzrWUUon8PBYuu/
TBY3GF/AIUreOP31cgUoX8Qhx2m2QqsYjC/h0PChxOUEmzyUL+PwpcZv/5dN
slC+gsNV7rWsso0yUL6Sg+r/7ok/JaWhfBWHIze8Zjk/lYTy1RwUXm7eeuO+
BJSv4SB8WFFXfL44lK/lIDjBj8HRSAzK13FoOztdMkJHFMrXc0ifylTCaywC
5Rs4dPcuVV3LLAzlGzpYntu94NgDASjfyOHzv12RTewwvrHDeuk12y9580P5
Jg5+a/pcU7fyQvmmDspe065FreCC8s0clu++LnZKhhXKN3eonXd5j9hDZijf
wsHHvH77Yz0Y39KBSUHrF/fqP/YQvpWDce/b744HftoDAPFTZDc=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwUF3QwCh8RxHK53C4KPTC
pMQRxhdw0K2c8yVtpQKUL+JguEB2jhMzjC/hEJT6y8rsixyUL+Og/OHBvit3
ZKF8BQetx4cON1bJQPlKDuoNSplhLtJQvorDf67WpHnyUlC+mgN3t3nl2n0S
UL6GQ4/VvzTncnEoX8thlsJW/mfPRaF8HYcIj36BR/tFoHw9h6mqfyMZ5gtD
+QYOC5ecEO2/JgTlGzqkzl3GVL1AEMo3cihebW2/aZEAlG/scI23I+OnHy+U
b+Jw4qhteckuDijf1GHjuvwpetEwvpmDce/b744HOKF8c4e2idlW1fLsUL6F
AyS8maB8SwcmBa1f3Kv/2EP4Vg7vLX/9c9L7BuVbO4RHGa0rUvoP5ds4cDOv
rXo1+aM9AJn0a8o=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQEf7MVCt+7emK3kABVweH1SmunDVUUon8OhXFb0
eIUrjC/gwCOxfc3e1QpQvojDkrT/xsnCML6EQ1nTprU9X+WgfBmH2YY+Tjtu
yEL5Cg6S7vOrA2fJQPlKDmK3VjV5N0pD+SoOElIb1ZsfSEL5ag7/p+1MfvRQ
AsrXcDjkvULrYow4lK/lwPaB/9rEDDEoX8dh0/o2OYk7IlC+nsMsv8Zfj7lg
fAOHde7vg8p5hKF8Q4eZ+5eXh+oIQflGDm57X2Y5XBSE8o0dLM/tXnDsgQCU
b+Kw2kYpQ+MwP5Rv6iD4RkTsgxgflG/mcI23I+OnHy+Ub+7ApKD1i3s1D5Rv
4WDc+/a74wFOKN/SYeLj4mqn7+xQvpVD7bzLe8QeMkP51g4+5vXbH+vB+DZo
fFuH8CijdUVK/+0hfDuo+T+hfHuH95a//jnpfYPyHaDu+QPhNzigqXdEVd/g
6MDNvLbq1WRGqH1ODpD0wgThNzhB5T/aAwBg35Xc
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwuLta2P3NdUUon8PhhTZv
Q7otjC/gUHA4cJ3AdAUoX8RhgoX8LV9WGF/C4R3flBUem+WgfBmHHrFP3Hvm
yEL5Cg6pzl6mCvNloHwlB89LYjdLW6ShfBWH1a8d0/1MpKB8NQd315JM5j8S
UL6GA/+B4KVMEjC+loPigkYRx7NiUL6OQ+hN1s6OalEoX89B97l0AxeLCJRv
4HB629aVRQXCUL6hw5GAA7MbdglB+UYO37rWicd+EYTyjR2WKXvdMjkkAOWb
OHQbpd6ZnQDjmzowKWj94l7NA+WbOZyV+vBqigAXlG/u8N7y1z8nPTYo38KB
m3lt1avJH+0BmH5YaQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwmKb1er/fdUUon8OhXFb0
eIUrjC/gsG3DkyUqGxSgfBGHIKO/N7YLw/gSDsrf/4mrvZGD8mUcQpums0zc
LAvlKzi8P3dkm2igDJSv5LDNuijlur00lK/icOSG1yznp5JQvprDh80X/9aK
wvgaDreVsxYdV5OA8rUcPvKFHtbUF4fydRzSs585H+AVg/L1HATaC1PuLxKB
8g0cnmt+qjQMEIbyDR3c9r7McrgoCOUbOXz+tyuyiV0Ayjd2yD6xY9/lndxQ
vonDxMfF1U7f2aF8U4f3lr/+OemxQflmDj7m9dsf6zFD+eYOxr1vvzse+GkP
4Vs4MClo/eJe/QfKt3TgZl5b9WryR3sAjOlm6g==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwWPr5Fte1C4pQPodDoXJV
3yojGF/A4cyPgP8bFytA+SIO7Ie/ZAkwwfgSDiUyljVnXslB+TIODZumtU+/
IgvlKzgcydL6snWGDJSv5MCzRn2Ndr40lK/iYL2LYa3tP0koX83h6tsGjteP
JaB8DYc2w+1y1wPEoXwth91PN8ncXyYG5es4MM2Y/9ujQRTK13MwiG1evneF
CJRv4PBc81OlYYAwlG/o8K1rnXjsF0Eo38iheLW1/aZFAlC+sUN4lNG6IiV+
KN/EwW9Nn2vqVl4o3xSNb+awcV3+FL1oDijf3KFtYrZVtTw7lG+Bxrd0COwx
1GZpZYHyraD2M0D51g7GvW+/Ox74aQ/h26DxbR3eW/7656T3Dcq3c+BmXlv1
avJHKN8eKv/MHgBien1E
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwKBI/lshzWRHK53CQu3JY
67UTjC/gwPiBMUhllQKUL+JgW7pE+K4sjC/hcJ9rb8VnRnkoX8ZhWaux3Mtj
slC+goOrwvoji0/IQPlKDr6rpOdc2CIN5as4TGhh3nE/VgrKV3P4t0rWPFpS
EsrXcMhYJK7aLioB5Ws5uKY+3twzQwzK13HQirY4us9fFMrXc9j4o++lhIMI
lG/gcCTgwOyGXUJQvqFDQmHs71MvBKF8IwdpiccvJk4SgPKNHUp3B9hY/OCD
8k0clL2mXYtawQXlmzqcOGpbXrKLA8o3cwjsMdRmaWWB8s0dmBS0fnGv/mMP
4Vs4hEcZrStS+g/lWzpwM6+tejWZEareysG49+13xwM/ofLWDu8tf/1z0ntm
DwDPgGhH
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwiJy17JDIWUUon8NBgfHi
FSVLGF/AYVHbrP15yxSgfBEHu+Vz3qXxwfgSDqJzdyXJXJaD8mUcXJg9GL5N
loXyFRwKr5wJ52qTgfKVHBJ9nUL5LaWhfBWHs1IfXk0RkILy1Rw+zdVz28Er
CeVrOPw9It+95ZY4lK/lEMMQLBYwUQzK13FgmjH/t0eDKJSv5xB/fWvc5QoR
KN/Awce8fvtjPWEo39AB4n8hKN/IwaWh4q9huyCUb+xQqjll8qRNAlC+iUOO
04S9fAv5oHxThyjtiR7nKrihfDOHD5sv/q0V5YTyzR2W774udkqGFcq3gNrH
BOVbOhSvtrbftIgByrdy4GZeW/VqMiOUb42m3gZNva0Dk4LWL+7Vf+wB/5Bs
EA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwuHDo4ZG/1xWhfA4HFq0d
XLMsYXwBB6N97PIXlyhA+SIOx/4XrbkvAuNLOByJZTT9pS4P5cs47PtVvY7h
niyUr+DQMz9q4s45MlC+kkOU9kSPcxXSUL6Kw8HNi44wa0lB+WoO/jIJO0xk
JaF8DYdPM7j/9bwXh/K1HE5r5m2Q+SMG5es4zFLYyv/suSiUr+ewTvayktZz
ESjfwKHpeHjsLx8Y39DhjXBk6rdOISjfyCF17jKm6gWCUL6xw+s76i36TQJQ
vomDr9uxo09sYXxTB+eQP2asbnxQvpkDk4LWL+7VPFC+ucNPnUk1y3M4oXwL
B53NLGxmfexQvqXDe8tf/5z02KB8Kwd5D19LsVWsUL61Q+28y3vEHjJD+TYO
4VFG64qU/ttD+LZQ+/5A+XYO3Mxrq15N/gjl20PN/wblO6DyG2D8Z/YAH1yC
2g==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwiNI2e+B5RRHK53BQSq30
EXOE8QUcenf7HmdZpQDliziIGcWEfJCC8SUcfq/e+/nfTzkoX8aB69DKg1l3
ZaF8BYfrlm9OPbguA+UrOTxk6Zp+dpM0lK/ioLlm4qNdRVJQvpqD83sv9aZm
SShfw+Gcexz3VxkJKF/LYemdh5ev/hCD8nUc4s1s2e6eFYXy9Ryss4pmJGwR
gfINHF5OK3Jcay8M5Rs6lGQs3+cvJgTlGznoCmp8nHVRAMo3dvj8b1dkEzuM
b+KwwvHw0WOSvFC+qUP2iR37Lu/khvLNHGZf4/65zBTGN3dom5htVS3PDuVb
ONTOu7xH7CEzlG/pEB5ltK5I6b89hG/l8N7y1z8nvW9QvrUDk4LWL+7Vf6B8
G4fi1db2mxYxQPXbOnAzr616NfkjVN4Oqv8ZlG+PxneAqwcAzU6E0w==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQEf7MVCt+7emK3kABVwcMj+JXvuoiKUz+HAePTH
0RJzGF/AYfFuEf/suQpQvojDBE8DR3U2GF/CgZ9ha8jCfXJQvozD7+3/Gxnj
ZaF8BYeu//JLP8bKQPlKDv+FmuZo+EhD+SoOZ8yec4XelYTy1RzOp3j4JK+U
gPI1HCzdrzhsWi8O5Ws5WKltuLGmVwzK13FgmjH/t0eDKJSv5yC09mrmhzoR
KN/AwdX2Sc35X0JQvqHD4z1/G7TNYXwjh9S5y5iqFwhC+cYO2z5M0Jc6ywfl
mziERxmtK1Lih/JNHa7xdmT89OOF8s3Q+OYOxr1vvzse4ITyLRxOHLUtL9nF
AeVbOgT2GGqztLJA+VZQ8//bQ/jWDsWrre03LWKAyttAzfsJlbdFk7dD02+P
xndw4GZeW/Vq8kcIv8HB4b3lr39Oet+g8o4OTApav7hX/4HKO0LVM0LNd0K1
v8EJzXxnNP3OqPYxuKDa1+CCJu+Kpt8VzXw3NHk3NHl31PBocIe7FwDJscCJ

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwmPV6ZdPPC4pQPoeD8w83
1u8GML6Aw5zKqEdLZytA+SIOZU5Wfo9+y0P5Eg661v0sP3fIQfkyDos5p29I
r5GF8hUcVjgnifa6y0D5Sg6SvvmphwSloXwVh0U6wSJBjFJQvpqDu2tJJvMf
CShfw+G9gZXvpi/iUL6WQwP/95Y4Uxhfx2Fqg+1iQScxKF/PwWXOA6GdnaJQ
voHDrx/Oi8p1RKB8Q4d17u+DynmEoXwjh0v2k1jE7wpC+cYOxaut7TctEoDy
TRzCo4zWFSnxQ/mmDkc/8wdHFfJA+WYO8v/Onrb4wAXlmztsXJc/RS+aA8q3
QONbOrRNzLaqlmeH8q0cuJnXVr2azAjlWzswKWj94l79xx7Ct4HKf4TybR3e
W/7656T3DMq3Q5O3h8sDAAiyddo=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwSLFZ7aFzRhHK53C4Z5tU
d9MGxhdwCFeZrhQ0XQHKF3GI2si02Pu2PJQv4XDg6Nqvr3bKQfkyDpuSxed4
t8tC+QoOj84f3b8kSwbKV3I4KpTdwu0tDeWrOGyuYz1aqy0F5as5uLuWZDL/
kYDyNRwSIsN+Ts8Wh/K1HAQn+DE4GolB+ToO2sclvi55KALl6znUzru8R+yh
MJRv4JBV8mMbY7gQlG/o8ExfyThPUxDKN3IIyNE6/VVSAMo3dnAO+WPG6sYH
5Zs4XNxx9cuNH9xQvqmD/L+zpy0+cEH5Zg4THxdXO31nh/LNHarqfx3MXsUG
5Vs4yHv4WoqtYoXyLR0g4c8E5VtB3csM5Vs7BPYYarO0sjgAABzoZmQ=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwaH4fzv3zmCKUz+HAz2XO
/1MPxhdwaDHijtjdowDlizh80Hkzbd1zeShfwuH0KrmKoyvkoHwZh4OvT1wN
rZOF8hUcLjzfF7XCQAbKV3KQ9M1PPSQoDeWrOLzc7zl71k9JKF/NwXN3vvhn
Rhhfw6Fzqjur/AVxKF/L4VjPofKy/WJQvo7DxTXnP6vkikL5eg7VVyt5GRJE
oHwDh0ezzUxvTxaC8g0dUucuY6peIAjlGzmsl16z/ZI3P5Rv7MCkoPWLezUP
lG/icI23I+OnHy+Ub+owoYV5x/1YLijfzEH+39nTFh9gfHM0voXDWakPr6YI
wPiWDoE9htosrSxQvpVDeJTRuiKl//YQvrXDe8tf/5z0vkH5NlD+M3sATxJw
Tg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwsHJ9vGXVRUUon8Nhq7Gz
6ht9GF/AYc79uBv+kxSgfBGHnskLvRY8k4fyJRxkNH48FX8hB+XLOKzdE1i+
4rYslK/g4Lwl/tyx9TJQvpKDrNOMhFJXaShfxaGN3V6BT10KyldzUJRI/Hv2
rgSUr+FwyHuF1sUYcShfy2HfLiGOD1PEoHwdB4sse6NecVEoX88hmMHi3EZB
ESjfwKG7d6nqWmZhKN/QIaEw9vepF4JQvpFDDPuiWdKuML6xw+s76i36TQJQ
vomD58p1q1Tn8EP5pg5R2hM9zlVwQ/lmDhNamHfcj+WC8s0d5D18LcVWsUL5
Fg4THxdXO31nh/It0eStHN5b/vrnpMcG5Vs7LN99XeyUDEzexqF4tbX9pkUM
UL6tg3Hv2++OB37aQ/h2UP3P7AEwPXGY
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw4DZW9L91SxHK53CIyxfQ
+WgD4ws4tFx7ar9xiQKUL+JgetHdzlERxpdwOBPeObGDQx7Kl3GYkPTivuMu
WShfwYGnedq0tZUyUL6SQ8Il+W3zo6WhfBWHzeyXjv3ikILy1RxSVQ0Z7U5L
QPkaDqW/1NefPCUO5Ws5XM65s/NEihiUr+Pwu3BBvW+GKJSv51B9tZKXIUEE
yjdw2FxQ/DmqQhjKN3RgC2Xc/OGwEJRv5LBM2euWySEBKN/YYe9xq3caj3mg
fBMHZa9p16JWcEH5pg46m1nYzPrYoXwzB3kPX0uxVaxQvrmDj3n99sd6zFC+
hUPxamv7TYsYoHxLByYFrV/cq//YQ/hWDuFRRuuKlP5D+dYOxr1vvzse+Anl
2zi8t/z1z0nvmT0AaSlq7w==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwmPV6ZdPPC4pQPoeD6hvP
2Ok6ML6Aw+s76i36TQpQvohDUX3yzU0H5aF8CYfSOet4J3XIQfkyDtP1dJY/
9ZCF8hUcdPwXf07nkYHylRxEZWO1gpmkoXwVh5jznpx7b0tC+WoONruutV7s
koDyNRws3a84bFovDuVrORzrOVRetl8MytdxqI22t9kSIgrl6znoPpdu4GIR
gfINHKLd93P92iAE5Rs6XEn9xqmxUxDKN4L6TwDKN3bY9mGCvtRZPijfxEH+
39nTFh+4oHxTB+Pet98dD3BC+WYO8h6+lmKrWKF8c4faeZf3iD1khvIt0PiW
Du8tf/1z0vtmD+FbwfkALBhnIQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVw+Hg4UO3mWUUon8NB4Ctr
rY4JjC/gUPVv2rTAJQpQvohD66f6u5eUYXwJh08K0/74S8lD+TIO4Zs0kiI2
yUL5Cg7vHD69fbVJBspXchBdX3y+rFgayldxmLfANDLBUArKV3OoObbuHtcn
CShfw2Gu3NR9s+3EoXwtB52ti0P/7BaD8nUcVhacvZjRJwrl6zkk396zZ/kb
ESjfwMHpYLCctjyMb+jgpJcwpShBGMo3cni852+DtrkQlG/soOiY3ln6TwDK
N3GInLV2oagOjG/qIPhGROyDGB+Ub+ag7DXtWtQKLijf3CFKe6LHuQpuKN/C
YeLj4mqn7+xQviWaeisHeQ9fS7FVrFC+tUPxamv7TYsYoHwbBx/z+u2P9Zih
fFuH95a//jnpPbOH8O3Q+PYOxr1vvzse+AnlO6DKNzg4cDOvrXo1+SNU3hGV
3+CIZp4TnA8Ax3iUlw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwsHJ9vGXVRUUon8PhyO8V
X3XMYXwBh01LFWaoz1GA8kUcpvkdjWwUh/ElHGSm1AlFsMlD+TIODNVfzssc
lYXyFRwenT+6f0mWDJSv5GAsnqS2pkwayldxaGO3V+BTl4Ly1Rw8d+eLf2aU
hPI1HK5GP7R8+U8cytdy6Curb7K5Jwbl6zjU6VTNzvsgCuXrOVhnFc1I2CIC
5Rs4RMYf8oiKEIbyDR0EdAylz/0XhPKNHCzP7V5w7IEAlG/sEDlr7UJRHRjf
xOEab0fGTz9eKN/UQdlr2rWoFVxQvpmD/L+zpy0+wPjmDmelPryaIgDjWzj8
1JlUszyHE8q3dJD38LUUW8UK5Vs5vLf89c9Jjw3Kt3aAxA8TlG/jULza2n7T
IgYo39aBm3lt1avJjFC+HRrf3iE8ymhdkdJ/ewjfwYFJQesX9+o/EH6DA1T9
R3sAqmt8+w==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQEf7MVCt+7emK3kABVwSHmqmrr7jCKUz+Fg2Jd/
i1UdxhdwuHHA79inbgUoX8Th5cd5td5v5aF8CQep0KY/Jo/koHwZh40e+Uaz
VstC+QoO+6+WWhsUyUD5Sg7/hZrmaPhIQ/kqDjGJCese+EhB+WoOfTOvVpd7
SEL5Gg5bJZ/d/3JfHMrXcugrq2+yuScG5es4TJTNfDPrsSiUr+fwZzGL4vML
IlC+gYOHV8+tTZEwvqHDG+HI1G+dQlC+kYOmn7KIa64glG/s8J8h8H9CCT+U
b+LgHPLHjNWND8o3deAtMrK+3MQL5Zs5GPe+/e54gBPKN3c4K/Xh1RQBLijf
wuG95a9/TnpsUL6lQ1X9r4PZq2B8K4fAHkNtllYWKN/agZt5bdWryYxQvo0D
k4LWL+7Vf+whfFuH4tXW9psWMUDl7RzCo4zWFSn9h8rbo8k7QN33EyLf4AB1
zzOoekeofR+h8o5o5jmh2t/gBFcPADFmlL4=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJw10Vsow3EUB/C/reRac9kst+ZvLcSwuc3G/7sRJeUSLUpJFuUW8zIlHjyI
FLm8KCTygAm5pcwLEpKSFOWBRisZiabcd/6/Ov36nO+p83CialpKTQKGYeS/
9fe7n5OTlK9tLzewoAaiJx6uzMdRZC/kpN6tccm8RdApvu2NYzJyMC727i89
GN5SnOZtO4dskeRwlDgmXZa+CLIMmpfDpGJDOJlF70mTpFUeRpbjJNTpGBGF
khW4rBtpsS5KyTHQ5J9jZSmEHIcF7cx+wYOEHI+to4p1YwVvJWZHzQFbEJOT
UJw4xbZLg8nJOLTk6moVQWQV2uvndookgWQ13vqsIVWvAeQU2BNZdXMs71RY
Yg9cpiIROQ39KtP1eDXvdCRkKctsdn9yBgSyuA/feT+yBoM9ws2bKh9yJpyr
Z5+dYm+yFk+ajy+D0pOsg/teAnIWzPNabmWaIWfDV7jY4Rj2IHMoTO/auFUK
yYCxUmVtY7+5f3aD5p/dZvS0741yPdQDj+/6XRflBsrt3A9PNZAP
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVweKL/cm7LeUUon8Ph8KuQ
mQL2ML6Aw0SLl6c65ihA+SIOMftTZOvYYHwJB2aXgKKkQ3JQvozDLaPcfaFB
slC+gsPuH9u+iunKQPlKDnKO/7Z4fZOC8lUcytqZkjh2SEL5ag6dfy5f2+gs
AeVrOJzWzNsg80cMytdyeMo67dv26aJQvo5DVaX282uqIlC+nkPvZk7tffeF
oHwDhyup3zg1dgpC+YYOr++ot+g3CUD5Rg68RUbWl5t4oXxjhw+bL/6tFeWE
8k0c2iZmW1XLs0P5pg7vLX/9c9Jjg/LN0PjmDoE9htosrSxQvoWDvIevpdgq
VijfEqr+mz2Eb4XGt4bzAVPla/s=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwWGZZ8rH9siKUz+Ggcoc9
y9oYxhdwUL6v++fDEgUoX8Rh6m2LU99YYHwJh9fn9ZNkH8tB+TIO+5zmsm3e
LwvlKzi8f8JusPWgDJSv5CCzb+aTtihpKF/FwTFX1SozVArKV3PIuurKOldQ
EsrXcNjEsKihW0ACytdyeBd7cHviMTEoX8dhZt+8rENlolC+nsOvH86LynVE
oHwDh6VWxieWzxWC8g0ddktNmbvzvQCUb+SwXnrN9kve/FC+scPe41bvNB7z
QPkmDhvX5U/Ri+aA8k0d3lv++uekxwblmzlAwpMJyjd34GZeW/VqMiOUb+HA
pKD1i3v1H3sI3xIq/xHKt4Ka98weABj7aHU=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwMPrpleBzUhHK53CYKSKy
bIIGjC/g0Nr5SPB9hwKUL+JgxeE52fC1PJQv4dA+168kdLcclC/jEHG/3mtf
iyyUr+AwZ23Dw3OuMlC+ksP+XZP7pwhIQ/kqDsa9b787HpCE8tUcnN+tnJqb
IgHlazio1Vy/eNhdHMrXcphzXtWTrUsMytdxSPLTXPGPRxTK13N4rvmp0jBA
GMo3cPixhL3uiaMQlG/oILv6z7UYc0Eo38iBR/hQecFLfijf2GHvcat3Go95
oHwTB/l/Z09bfOCC8k0dJj4urnb6zg7lmzmclfrwaooATN7cYfnu62KnZFih
fAsHbua1Va8mM0L5lg7hUUbripT+20P4Vg5MClq/uFf/gfKtoeo/Qvk2aHxb
h/eWv/456X2zBwA303RY
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwSAjZUatwThHK53A4bj/r
s4YVjC/gwLHeNN93ngKUL+LAqnV1vssDeShfwiFP5y2r50w5KF/GQcIudcL/
YlkoX8FBannw9K8ZMlC+koPNgaUJafzSUL6Kg26778qVpyWhfDUHVw7mP182
SkD5Gg5bJZ/d/3JfHMrXcoisfefa81UMytdx+Lq9dee3W6JQvp5D29npkhE6
ML6Bw8YffS8lHESgfEMHnQ9967b3C0P5Rg7asmKS6YlCUL6xQ/Fqa/tNiwSg
fBMH3iIj68tNvFC+qcPsa9w/l5lyQ/lmDm0Ts62q5dmhfHMHSPgyQfkWaHxL
B+Pet98dD/y0h/CtHLiZ11a9mvwRyrd2eG/565+T3jMo3wbK/wbl2zowKWj9
4l79B8q3Q5O3RzPfAVV9gwOa+Y6o9jc4wuUBeT+Q/w==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwOD6r8caJw4pQPofDKpF/
q1IUYXwBh8NXszxv1ClA+SIOChf9ZcNOykP5Eg55RhING/bKQfkyDtOXX3e3
mSUL5Ss48F67+pYrWQbKV3LYv2ty/xQBaShfxYGz0Ffg6UFJKF/Noc/4NeOt
QAkoX8NhrtzUfbPtxKF8LYeV859t0I4Vg/J1HJJv79mz/I0IlK/nEJP06LHO
C2Eo38Chu3ep6lpmGN/Q4ZL9JBbxu4JQvpGDffiXGD9pGN/YYbWNUobGYX4o
38Th6Gf+4KhCHijf1KFtYrZVtTw7lG/m4GNev/2xHjOUb+5QvNraftMiBijf
wsG49+13xwM/7SF8SzS+lQMkPpig6q3R9Nugqbd1eG/565+T3jco3w7Kfwbl
26PxHRy4mddWvZr80R4AZVmDhQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQEf7MVCt+7emK3kABVwaGud4GVxSRHK53AImrlH
fpUNjC/g4H/uQdCx2QpQvoiD9dGCl2LMML6EQ8WEDeqez+SgfBmHez9Ya1ed
k4XyFRxab+trRpfJQPlKDrGpKx/bFUhD+SoOwVNdp6+rlYLy1RwuH5dhvsUu
CeVrOFRuDPyhUSUO5Ws5xJvZst09Kwrl6zho97udczotAuXrOTzJ0rT62y4M
5Rs49G7m1N53XwjKN3SQXf3nWoy5IJRv5PCfIfB/Qgk/lG/scHHH1S83fnBD
+SYOP3Um1SzP4YTyTR3OSn14NUWAC8o3c1i++7rYKRlWKN/cwce8fvtjPWYo
38IhPMpoXZHSf3sI3xKNb4XGt3bgZl5b9WoyI1S/DZq8LVT+I5Rvh8a3R1Pv
4PDe8tc/J71vEH6DgwOTgtYv7tV/oPKOqPobHKHqn0HlnVD5DU6o5jE4o5nv
7GDc+/a744GfUHkXNHk0PoMrmvkIPgAPtron
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQEf7MVCt+7emK3kABVwmPV6ZdPPC4pQPodDv8+q
FUX6ML6Aw9L7hz7JTFCA8kUcTvieKDV/Kg/lSziwfp9qaPBBDsqXcXjZOMFm
zTpZKF/Bod4vy/ZmhQyUr+Qw+xr3z2Wm0lC+isORG16znJ9KQvlqDpm7J2Ru
vSkB5Ws4CB9W1BWfLw7lazks+7tCXm2OGJSv4/C4UUijIFkUytdzmLvDJnry
OhEo38CBXY4l5MglYSjf0CHafT/Xrw1CUL6Rg9vel1kOFwWhfGOH4tXW9psW
CUD5Jg6rbZQyNA7zQ/mmDqW7A2wsfvBB+WYOTApav7hX80D55g4TWph33I/l
gvItHDauy5+iF80B5Vs6yHv4WoqtYoXyrRzeW/7656THBuVbOyzffV3slAxM
3sYhsMdQm6WVBcq3dfAxr9/+WI8ZyrdzqKr/dTB7FUy/PZr5DqjyDQ5o5jk6
cDOvrXo1mREq7+hQO+/yHrGHMPOdoOHBAJV3gqr/aA8ARk2NSA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw2PXkdZ/KBUUon8Nhp0dA
eZoOjC/gwL7zU4vdFAUoX8Rh/6ULF6M4YHwJB9M9J779eyEH5cs4HDP1lJgz
UxbKV3DgvLOlf9EEGShfyaHjbK5YoYo0lK/isMLNceqmP5JQvppDnaz40k9P
JaB8DYe/R+S7t9wSh/K1HIzE5yfGtIlB+ToOFln2Rr3iolC+noOHV8+tTZEi
UL6Bg5NewpSiBGEo39BBW1ZMMj1RCMo3ctgtNWXuzvcCUL6xg+fKdatU5/BD
+SYO/xkC/yeUwPimDtd4OzJ++vFC+WYOe49bvdN4zAPlmzt82Hzxb60oJ5Rv
4eBjXr/9sR4zlG+JxrdC41uj8W0cIPHFBOXbovHtHN5b/vrnpPfMHgCpHXTB

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwOM9X8lDyvCKUz+GQ23bK
bK4ZjC/gMPG+g1rQYgUoX8TBQMWhyYYfxpdwuPkl3nE6tzyUL+NwtaTZqPmI
LJSv4MCmH2qScVIGyldyWM5UcLJ2vjSUr+IQ9dzHXbZZCspXc4hLW9jI1iAJ
5Ws4bFyXP0UvWgLK13Kwev24Yf00cShfxyGGIVgsYKIYlK/n8LhRSKMgWRTK
N3ConXd5j9hDYSjf0KG7d6nqWmYY38jBbe/LLIeLglC+sUNAjtbpr5ICUL6J
w7YPE/SlzvJB+aYOyl7TrkWt4ILyzRxOHLUtL9nFAeWbO3Azr616NZkRyrdw
CI8yWlek9N8ewrd0MO59+93xwE8o38rhveWvf05636B8a6j+j1C+DVT+mT0A
4sBsCw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdyVkowwEcB/A1tzUmzNwzZ+tvzdznviSNJJTzUclZWPMicjx5EEU8SKSU
DVvkmhAlSpJGpEhDOR9QypG7/f4vvvXr2+f3DSiryy/ncjgcye/9tSWPSmHB
/PJMjQT0wLTudGlnL4Bsj+/OcGOEgrUATFU9RzUkJrthrNCcO2L2J4uQti9X
X0/7kX2g+fTYLW/wJYshv48T37x4kyXo2jl3Mq97kYPQ3j1wUjHlSQ6BnXSh
SzgnIoch93lu25juQZYi9CxvtNFGSGZQrOoRXKy5kWWo6Odq+JGs5ciObV28
lLmSI5CxelsNkwtZgXCXsKdBk4AciZJB/ag7wzoKmTrDRPCQMzkafLUi8aCD
T47BEb+z8i2HdSy0qRubW56s42AyHj4fv/LI8QjMGjgq1TqSE/DG9DaP1zqQ
E8HMWtvGdNuRk/A4a/pscWf3ZLQMH6wIz63IKf+sRFGpwqCWfCstBrhi6Ttv
8sPiNoBnpW+663uiPRUP8e9fabIr5Q/8FYgI
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwaJRx37/yqiKUz+Gwue+P
g7sTjC/gwPiBMUhllQKUL+Ig9HR3mDUvjC/h4Jb4Y5/XezkoX8ZBtPXpVelD
slC+gsOfuVtd3h+QgfKVHF7uaSrYt0Yayldx2FS1dK7tZCkoX81h++ZWq8Rt
klC+hgPjhEv/XjZKQPlaDnPlpu6bbScO5es4NJTaf7FSE4Py9RzM3jy7u4Zd
FMo3cPB4dX0fX7cIlG/okB3BHpg8XRjKN3JwtX1Sc/6XEJRv7MDNvLbq1WRB
KN/EYduHCfpSZ/mgfFOHvcet3mk85oHyzRwu7rj65cYPbijf3MG49+13xwOc
UL4FGt8SjW/lUFX/62D2KjYo39ohPMpoXZHSf3sI38aheLW1/aZFDFB5W6j7
PtoDABn7eDk=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwUBaw3zLhkiKUz+GwQH/e
OitLGF/AwcbznuW6eQpQvogD65RDCrzcML6EQ7yO5d/2j3JQvozDpSmb5jw/
IAvlKzgcydL6snWGDJSv5NBxNlesUEUayldxYM1tyPv3UhLKV3Mw+p8iuX+B
BJSv4VC5MfCHRpU4lK/lEHqTtbOjWhTK13F4l3vkq/E3YShfz2Hv8fb7P+qF
oHwDBxsjn3a+BEEo39CheLW1/aZFAlC+kcNqG6UMjcP8UL6xg9+aPtfUrbxQ
volD9okd+y7v5IbyTR2UvaZdi1rBBeWbOXzYfPFvrSgnlG/uUDvv8h6xh8xQ
voVDeJTRuiKl//YQviXUfgaovJWDce/b744HfkLlrdH4Ng7czGurXk3+COXb
osnbOby3/PXPSe8blG+PJu8A1w8Ac9+FyQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQDQEf7MVCt+7emK3kABVwmBjHqnb/jCKUz+GQsiNg
0241GF/A4U/pw6ea3QpQvohDZfF9Gbnz8lC+hEPiwwffo6bJQfkyDlufsMRL
TZeF8hUcwhIntHsvk4HylRxOzXm5fFapNJSv4iDp/ltKxUoKyldzWFHnm+ch
LQnlazg0Fm/RP+MlAeVrOczjmb5N5IoYlK/jcPrXi662paJQvp6Dx6vr+/i6
RaB8A4eNn6TmV2UIQ/mGDtqyYpLpiUJQvpGDjZFPO1+CIJRv7PCfIfB/Qgk/
lG/isMLx8NFjkrxQvqmDste0a1EruKB8MzS+ucPEx8XVTt/ZoXwLB3kPX0ux
VaxQvqVDYI+hNksrC5Rv5cDNvLbq1WRGKN/aoXi1tf2mRQxQvo2Dj3n99sd6
zFC+rcPy3dfFTsnAzLND49s7QOKXCcp3cHhv+eufk943ezC3AY3P4IhqX4Mj
mrwT1H0fofrR+AzOcD4AvQKVYw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwUEnh/JF4RhHK53CYwZik
3GEF4ws4tFVEXBdYqgDlizjUFRhp9HHD+BIOZ607jT69lYPyZRxCm6azTNws
C+UrOLy7J72nrkMGyldyCOk4dKbERhrKV3FYpBMsEsQoBeWrOfRXOi7TOCkB
5Ws4rMyaK6GzVRzK13LYt0uI48MUMShfx6Ht7HTJCB1RKF/P4V3uka/G34Sh
fAMHw13S6o9KhaB8QwfLc7sXHHsgAOUbOby+o96i3wTjGztUah7/meoP45s4
lO4OsLH4wQflmzpc3HH1y40f3FC+mcNPnUk1y3M4oXxzh43r8qfoRXNA+RYO
xaut7TctYoDyLR2YFLR+ca/+Yw8AN4BgIQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwCNu5dkr2BUUon8PhyO8V
X3XMYXwBh+2Hp6nrzlOA8kUcfn+7VS3AC+NLOJwJ75zYwSEP5cs4/GUsfh9z
TRbKV3CYbLIk/vQRGShfyeHUPqtdR45IQ/kqDgvfx/O/mCgF5as5/N55gZ+t
UhLK13A4n+Lhk7xSAsrXchCzUijiqRWH8nUclDZxzDrqKwbl6zmYTT6S4Skk
CuUbOKxzfx9UziMM5Rs6COgYSp/7LwjlGznoCmp8nHVRAMo3dvBcuW6V6hx+
KN/EIcdpwl6+hXxQvqkDb5GR9eUmXijfzMG49+13xwOcUL65w/Ld18VOybBC
+RYOtfMu7xF7yAzlWzowKWj94l79xx7Ct4Lq/wnlWztwM6+tejX5I5Rv4/De
8tc/J71n9gAA1m8P
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwyPyz/0foOUUon8Nh7e/S
bZr6ML6AwzX7uA+ikxWgfBGHmP0psnVsML6EgymPiGHgKTkoX8aB/0NX/+ZJ
slC+gkNc0Kslp+NkoHwlh8QpIds8lKWhfBUHhit5hdkvJKF8NQfL8pDHbL8k
oHwNB4uj9dXzdolD+VoOW2OqEsJzxKB8HYc/i1kUn18QgfL1HGKajaNuvBCC
8g0c3Pa+zHK4KAjlGzoE5Gid/iopAOUbOYRHGa0rUuKH8o0d9h63eqfxmAfK
N3GI0p7oca6CG8o3daiq/3UwexUblG/mUDvv8h6xh8xQvjnUvP/2EL6FQ/Fq
a/tNixig8pYO3Mxrq15N/giVt3J4b/nrn5PeMyjfGs4HAMIJa9M=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVw+MQxOyL3kiKUz+Egu/rP
tRhzGF/AgT997/G61QpQvohD9VmGM6ZcML6Ew/8bJvqzt8lB+TIO2a9T1Vnb
ZKF8BQfF7AWT01pkoHwlB9dkZ1e2UGkoX8Whf2K0UPMFSShfzWGP5XuHookS
UL6Gw9s2zlWtHeJQvpbDztOR28IjxaB8HYeZffOyDpWJQvl6DrXzLu8ReygM
5Rs4vBGOTP3WKQTlGzpYntu94NgDASjfyCE8ymhdkRI/lG/scPQzf3BUIQ+U
b+KQfWLHvss7uaF8Uwfj3rffHQ9wQvlmDjqbWdjM+tihfHOH5buvi52SYYXy
LaDuYYbyLdH4Vg6Q+GCC8q0dildb229axADl2zj4mNdvf6wHU2+LxreDuv+/
PYRvD3XfTyjfwYGbeW3Vq8kf7QHGHH2w
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQDQEf7MVCt+7emK3kABVwWPmpbcevS4pQPoeDwFfW
Wh0TGF/A4eDCw7rscxSgfBGH6TedKto/yUP5Eg6ic3clyVyWg/JlHHii6wsO
rpSF8hUcvv5KmaVZIwPlKznICOxkn+ImDeWrOCyTZe27HCYF5as5iJy9c/Lf
SwkoX8Ph9n/p3dEl4lC+lsOZx4v/OmiJQfk6DmZvnt1dwy4K5es56D6XbuBi
EYHyDRyCr3X2XJIVhvINHRIKY3+feiEI5Rs5SEs8fjFxkgCUb+yw2kYpQ+Mw
P5Rv4lCpefxnqj9M3tShdHeAjcUPPijfzOHoZ/7gqEIeKN/c4cRR2/KSXRxQ
voXDT51JNctzOKF8S4f3lr/+OemxQflWDpD4YILyrR18zOu3P9ZjhvJtHKrq
fx3MXgVTb4vGt3OonXd5j9hDmHp7h+W7r4udkmGF8h1QzW9A4zM4OjApaP3i
Xv3HHiKPxmdwQpN3cihebW2/aREDVL8z1D/foPJofAYXNHkXNPNdHYx73353
PPATKo/GZ3BDk3eDmvcMKu+OZj4an8HDgZt5bdWryR+h8h5o8p5o/vNEVc/g
hWpfgxeafm+4egAhFuwU
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwWGZZ8rH9siKUz+Ewb3Xo
xAWGML6Aw/4jynKHpihA+SIOPZMXei14Jg/lSzjcnvas/tVBOShfxqG7KVe4
bp8slK/goPX40OHGKhkoX8lhm3VRynV7aShfxYH95vmU20xSUL6aw/kUD5/k
lRJQvoZDVYly/mpHcShfy6FygshVT0YxKF/H4c9iFsXnF0SgfD2H09u2riwq
EIbyDRz2Hm+//6NeCMo3dJBd/edajLkglG/kEB5ltK5IiR/KN3ZYcnJxGXcJ
H5Rv4hClPdHjXAU3lG/qMPFxcbXTd3Yo38xB3sPXUmwVK5Rv7lA77/IesYfM
UL6Fw3vLX/+c9L7ZQ/iWaHwrB27mtVWvJn+E8q3R5G2g/GdQvq2Dce/b744H
fkL5dmh8ezT9Dg5MClq/uFf/gfAbHNDMc0S1vwHBBwBi6Jc7
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw2KLqfPnPWUUon8Nh3urQ
iQsMYXwBh9z7K17NmKEA5Ys43HkunT77rzyUL+HwTzBbyP60HJQv43D35FPf
652yUL6CA6eUZHyTpgyUr+TQaNr51VRLGspXcZizWCri1DFJKF/NYY/le4ei
iRJQvobD2zbOVa0d4lC+lkPjS8X9jzzFoHwdB+usohkJW0SgfD2H6Q97GO99
FILyDRwe7/nboG0O4xs68OYIve4oFIDyjdD4xg7rpddsv+TND+WbOGSf2LHv
8k5uKN/UYeLj4mqn7+xQvplDVf2vg9mr2KB8cwedzSxsZn0weQuHwB5DbZZW
Fijf0qF23uU9Yg+ZoXwrh+LV1vabFjFA+dYO4VFG64qU/ttD+DYO7y1//XPS
e2YPABusb8o=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwMGYoVA66qAjlczh83CkR
WWAF4ws4PDa/P4F5tgKUL+JQyWe5oZUBxpdwWLhKTdr4rhyUL+Pw7VT8v6fr
ZaF8BYcnnHPVjPtkoHwlh9jUlY/tCqShfBWHlUfvJtpGSEH5ag77n6zf/9BU
EsrXcHjwUy60yUACytdymGG5e9rbQ2JQvo7Db750+4OuolC+ngO7HEvIkUvC
UL6Bw1Ir4xPL5wpB+YYOsqv/XIsxF4TyjRwCcrROf5UUgPKNHfzW9LmmbuWF
8k0cZl/j/rnMlBvKN3X4sPni31pRTijfzGH57utip2RYoXxzB0j4MkH5Fg61
8y7vEXvIDOVbOviY129/rAfjWzm8t/z1z0nvmz2Eb43Gt3HgZl5b9WryRyjf
1oFJQesX9+o/UL6dg3Hv2++OB35C+fYOxaut7TctYoCa7wBXDwDBFICG
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQEf7MVCt+7emK3kABVw6N7yOGD3VUUon8OBiceU
e7kLjC/g8PZQdib/MgUoX8ShozR57lMeGF/CwffUihjPO3JQvozD1zMnN1ZO
k4XyFRyM/U+yGZTLQPlKDqf2/5t4Vl4ayldxSDm8zbCHVwrKV3MomJnnf+KA
BJSv4XDIe4XWxRhxKF/LoeTXSiVDKzEoX8cheM4U6SpDUShfz6H6aiUvQ4II
lG/gsL1gWaSeqDCUb+hQcO3zoURFISjfyKFUc8rkSZsEoHxjhxynCXv5FvJB
+SYOgm9ExD6IwfimDkc/8wdHFfJA+WYOyl7TrkWt4ILyzR02rsufohfNAeVb
OEx8XFzt9J0dyrdE41s5BPYYarO0skD51g7Ld18XOyXDCuXboMnbOlTV/zqY
vYoNyrdDk7d3qJ13eY/YQ2Yo3wFVvsHBoW1itlW1PMx+R4cPmy/+rRXlhMo7
ornfyUHew9dSbBXUPQ1OaO5zRrWvwdkBkr6YoPIuDsWrre03LWKAyrs4+JjX
b3+sB3OfK2p4NLiime+GJu+G5l93NP+5o9nvgWa/h4Nx79vvjgd+2kPkPR24
mddWvZr8EcJvQPABv3zDsQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwqOO3m7f4rCKUz+GQueT5
STFrGF/AQbnOcaHWXAUoX8ShzMnK79FveShfwmGh2MZJyQ/koHwZh9bFcg0B
SbJQvoLDAdbTmuvtZaB8JYdEX6dQfktpKF/FYfqRs0tDdktC+WoOnX8uX9vo
LAHlazgc4DPfe0hIHMrXcnBR5dO5LygG5es4RH26bab6VxjK13PgWvwjzu2o
IJRv4HDymsqX3zwwvqHDf4bA/wkl/FC+kcM33p2Nf0x5oHxjB2WvadeiVnBB
+SYO2Sd27Lu8kxvKN0WTN3OY+Li42uk7O5Rv7iDv4WsptooVyrdwYFLQ+sW9
+o89hG/pwM28turV5I9QvpWDce/b744HfkL51mjyNmjytmjydg7vLX/9c9L7
BuXbo8k7QOWfQfgNDnB5AKzMhvU=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVwiPZQtLG9rgjlczjMk3pn
re0A4ws48J0uPiq7UQHKF3HYVHEwfZcMjC/hsOqTuvj7+3JQvozDaeuZ39fu
kYXyFRx8bOtL16yQgfKVHPp+/F8hVycN5as4eFvXeIokSUH5ag779siFML+R
gPI1HBYqzZEp2CQO5Ws57O6ZsLx6oxiUr+OwWvCdhNpmUShfz0H3uXQDF4sI
lG/gsPd4+/0f9UJQvqHD6zvqLfpNAlC+kYPfmj7X1K28UL6xw8UdV7/c+MEN
5Zs4/NSZVLM8hxPKN3XwMa/f/liPGco3czDuffvd8cBPewjf3IGbeW3Vq8kf
7QEMZlwC
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwWCLOr2l2ShHK53A4smWr
x0oNGF/AYYNJcqj2NAUoX8ThbcbuC9dfyUP5Eg7yi7h9b2+Ug/JlHErcTomt
DZaF8hUcnunyWWyUk4HylRzOawXf5torBeWrOLyZ/Th55xZJKF/NYU9x5G+z
bRJQvoZD5cbAHxpV4lC+lsO+XUIcH6aIQfk6Dr8LF9T7ZohC+XoOMRxSDTMs
RaB8AwfvzR+9As2FoXxDh0ezzUxvTxaC8o0cUucuY6peIAjlGzv8Zwj8n1DC
D+WbOOja6oXsf8YL5Zs6TGhh3nE/lgvKN3Nom5htVS3PDuWbO0x8XFzt9B3G
t3ConXd5j9hDZijf0oGbeW3Vq8mMUL6VQ3iU0boipf/2EL61A5OC1i/u1X+g
fBuH95a//jnpfYPybaH8Z/YAtmtxLw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwsLwdnsx8RRHK53DISrp+
3d8WxhdwiJ0hJMy9QgHKF3H4dztz3jNeGF/C4c62Z6qaEvJQvozDudAG4V0/
ZaF8BQeJtcF1OqdkoHwlh7Ke0vkeM6ShfBWHU4znrdQDpaB8NQdGK+2d5zkl
oXwNh5VZcyV0topD+VoOu59ukrm/TAzK13Go06manfdBFMrXczCIbV6+d4UI
lG/goKnC/uS7uzCUb+hwyX4Si/hdQSjfyOH1HfUW/SYBKN/YYcnJxWXcJXxQ
vomDste0a1EruKB8U4cTR23LS3ZxQPlmaHxzB0j4MkH5Fg7Fq63tNy1igPIt
HbiZ11a9mvzRHsK3cnhv+eufk94zewBUrWOj
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwUA6tTf90QxHK53BInpru
wWIB4ws4rGowMZiwVAHKF3H42eG6Zi07jC/h8M+q8fLTl3JQvoyDRrK4Zc4T
WShfwaHkvZSx5gEZKF/J4VPMD37XZGkoX8UhOE6ke6qHFJSv5uBi/t40Sk8S
ytdwOBW3/tM+cwkoX8vhtGbeBpk/YlC+jsPvwgX1vhmiUL6eQ2CPoTZLqwiU
b+DQ3btUdS2zMJRv6JBQGPv71AtBKN/IIcdpwl6+hXxQvrGDce/b744HOKF8
Ewd5D19LsVWsUL6pg495/fbHesxQvpkDJDyZoHxzNHkLB27mtVWvJjNC+ZYO
xaut7TctYoDyrRzeW/7656T3zR4Au1lg2A==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwiJy17JDIWUUon8PhkqfI
rysmML6Ag0T+/Qm3+hWgfBEHFT7bk5Hf5KF8CYewpYcz4m/LQfkyDqeEDuat
aJOF8hUcLjL8d/5bIwPlKzn0/fi/Qq5OGspXcZi3wDQywVAKyldzKJiZ53/i
gASUr+HwYzt3uMwJcShfyyGj+l7aIiYYX8fhzOPFfx20xKB8PQfrrKIZCVtE
oHwDh+eanyoNA4ShfEMHAR1D6XP/BaF8IwfeHKHXHYUCUL6xw2obpQyNw/xQ
vomDc8gfM1Y3Pijf1GFCC/OO+7FcUL6Zg85mFjazPnYo39xh+e7rYqdkWKF8
Cwd5D19LsVUwvqUDJPyZoHwrB27mtVWvJjNC+dYO7y1//XPS+2YP4dtA5T9C
+bZQ+WdQvh0a3x5Nv4ODce/b744HfkL4DQ5w8wAenIPD
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7MVCt+7emK3kABVwMEx55Xf8rCKUz+Egu/rP
tRhzGF/AYVadSMH/mQpQvoiDw06m3n9v5aF8CYeFye8bt26Rg/JlHJyWXFsx
sUMWyldw+JLrxFXgKAPlKzmwaK8w5LgvBeWrODT2TbudvkYSyldzcH63cmpu
igSUr+GwPoSF5eM7MShfy0FpE8eso74wvo7DasF3EmqbRaF8PQfrrKIZCVtE
oHwDh18/nBeV68D4hg4vpxU5rrUXhvKNHCDhIQTlGztwLf4R53ZUEMo3cfB1
O3b0ia0AlG/q4LemzzV1Ky+Ub+aw97jVO43HPFC+uYP8v7OnLT5wQfkWaHxL
B53NLGxmfexQvpVD8Wpr+02LGKB8a4fwKKN1RUr/7SF8GwcmBa1f3Kv/QPm2
Du8tf/1z0vsG5dtB+c+gfHs0vgOq+gY0PoOjAzfz2qpXkz9C5R3R9DuhyTs5
GPe+/e544CdU3hlVfYMzqnoGFzgfAHPnqzI=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwcPwSEeV3TxHK53C4/ecg
t54XjC/gsN9P8vny9QpQvoiDjPwRo/ViML6EwzO9bdN05OShfBmHtYf1jvIK
y0H5Cg7HnVZFK7yUgfKVHD50ZDw6eFQayldx2KTYrHFrrhSUr+bwaXHkAXkj
SShfw6Fn1/tbcd3iUL6Ww8ftQcHKdmJQvo6D2eQjGZ5ColC+nsO73CNfjb8J
Q/kGDpsLij9HVcD4hg6GbrN2ep0VgvKNHHQFNT7OuigA5Rs7LDm5uIy7hA/K
N3HIPrFj3+Wd3FC+qYNx79vvjgc4oXwzNL65w4mjtuUluzigfAuHqvpfB7NX
sUH5lg5MClq/uFf/sYfwrRzeW/7656T3Dcq3RuPbOHAzr616NfkjlG8L5wMA
A1p4Cw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwuLzQu5rjjCKUz+GwhGOm
yltdGF/AQWudnpR4uwKUL+JwaMLq80of5aF8CYdLBxPebT0tB+XLOPyc/X2l
8kpZKF/B4XFUmUuIhAyUr+RQr/v/jSeHNJSv4qCzdIG4Vo8klK/m4L28K4Kb
TwLK13CwUttwY02vGJSv5eAy54HQzk5RKF/HYfGT1iTnNBEoX89h+sMexnsf
haB8A4cf3k85Gn1gfEOHZ/pKxnmaglC+kUPp7gAbix98UL6xw9HP/MFRhTxQ
vomDce/b744HOKF8U4faeZf3iD1khvLNHLiZ11a9mswI5Zs7FK+2tt+0iAHK
t4DKf7SH8C0d3lv++uek9wzKt0LjW6Opt4HLAwAeZnBi
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwOHs9zqTkhCKUz+FwRav4
RLMxjC/g8IDT4vWJqQpQvoiDuRnr7slMML6Ew3qH2L6q+3JQvozD5abb0TWz
ZaF8BYfnSvuuLfCVgfKVHHTzl9Wd1ZOG8lUctm9utUrcJgnlqznMODiPuT1M
AsrXcFgfwsLy8Z0YlK/lsF9+tsRcThhfx+E6W/t12U8iUL6eg86HvnXb+4Wh
fAOHmGbjqBsvhKB8Q4eT11S+/OYRhPKNHJxD/pixuvFB+cYOOU4T9vIthPFN
HHiLjKwvN/FC+aYOe49bvdN4zAPlmzlEaU/0OFfBDeWbO2xclz9FL5oDyrdw
qKr/dTB7FRuUb+kACX8mKN/Kwce8fvtjPWYo39ohPMpoXZHSf3sA/uBn+w==

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwcPnZxhByWxHK53DIY71+
6bwDjC/gsG3DkyUqGxSgfBGHPKVOmThOGF/Coa/+tZsBgzyUL+Ow71f1OoZ7
slC+ggN30nmv2GsyUL6Sg0zyY7vLu6WhfBWHvetPLj27UArKV3MQu2u/q2Sa
JJSv4fDg1w6GtfUSUL6Ww+dfx47euSUG5es4/Cv6rsp5VBTK13NQZLn74PMf
ESjfwOHXD+dF5TowvqFDd+9S1bXMwlC+kcMb4cjUb51CUL6xg66gxsdZFwWg
fBOHJScXl3GX8EH5pg7XeDsyfvrxQvlmDsa9b787HuCE8s0dThy1LS/ZxQHl
WzhEaU/0OFfBDeVbOmxclz9FLxomb+Ug7+FrKbaKFcq3dqidd3mP2ENmKN/G
4b3lr39OemxQvq3D8t3XxU7JwNTbORSvtrbftIgByreHqv9mD+E7QPnP7AH7
vYLp
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVweCAeVH/usiKUz+EQ99mu
/qUjjC/gIP2C47b9agUoX8TB+KjTNjMRGF/CwWirYpYFuzyUL+OgabxmhsR+
WShfwSG/s7U1N00GyldyOCqU3cLtLQ3lqzgszTdUVnOXgvLVHD4tjjwgbyQJ
5Ws4ONyvixZ0k4DytRzkOrJWfhEVh/J1HKY22C4WdBKD8vUcrrO1X5f9JALl
Gzj8TCz+27hVGMo3dNCWFZNMTxSC8o0cdAU1Ps66KADlGzt4rly3SnUOP5Rv
4hClPdHjXAU3lG/qYNz79rvjAU4o38yhqv7XwexVbFC+uYOPef32x3rMUL6F
Q3iU0boipf/2EL6lAzfz2qpXkz9C+VYOTApav7hX/4HyrdHkbRzeW/7656T3
Dcq3RePbQfnP7AFn73KH
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVweG86JaT2giKUz+GQueT5
STFrGF/AYf8RZblDUxSgfBGHi8e1XLm/y0P5Eg6XeOV5FY7JQfkyDrf97W/O
micL5Ss47L9aam1QJAPlKzkk+jqF8ltKQ/kqDjHnPTn33paE8tUc6mTFl356
KgHlaziIiptqn20Sh/K1HFbOf7ZBO1YMytdxMLnUW666SwTK13M4vW3ryqIC
YSjfwCGm2TjqxgshKN/QIXXuMqbqBYJQvpEDb47Q645CASjf2MFz5bpVqnP4
oXwThxWOh48ek+SF8k0djHvffnc8wAnlmzm0Tcy2qpZnh/LNHSDhywTlW0DV
/7SH8C0duJnXVr2a/BHKt3J4b/nrn5PeMyjfGs4HAOMoarA=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVw2D9txaTSi4pQPofDpRjz
nj3mML6Aw5sVLtJFixWgfBEH9+vbJ9znhPElHBr5NNRSmOShfBmHBVOY614e
loXyFRwOqF6uvD9ZBspXcmj2fxS9t1wayldxOFwxrW6+mBSUr+ZgoPDzn/Vy
CShfw+Hg4aVM1yLFoXwtB+7LXwr/1YlB+ToOWtEWR/f5i0L5eg5xHW4vbY8I
Q/kGDpNTP0yOWS4E5Rs6aPopi7jmCkL5Rg7LlL1umRwSgPKNHbZ9mKAvdZYP
yjdx4C0ysr7cxAvlmzpkn9ix7/JObijfzOHD5ot/a0U5oXxzB3kPX0uxVaxQ
voVD8Wpr+02LGBwAIGhcvw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwsPdfHel1VhHK53Dg3lFU
X6gG4ws4aFtYLeFoU4DyRRze/jFZMv2MPJQv4RATvuri30VyUL6MQ/VPRY/I
YlkoX8Gh67/80o+xMlC+ksN61rOeL1iloXwVB/a73Rs3v5OE8tUc9hRH/jbb
JgHlaziIWSkU8dSKQ/laDo0vFfc/8hSD8nUcFFnuPvj8RwTK13OoqtR+fk0V
xjdw2F6wLFJPVBjKN3Rwaaj4a9guCOUbOZRqTpk8aZMAlG/sEB5ltK5IiR/K
N3GYfY375zJTbijfFI1v5vBh88W/taKcUL65w4QW5h33Y7mgfAuHjevyp+hF
c0D5lg6Q8GeC8q0cfMzrtz/WY4byrdH4NlD3/LeH8G0d3lv++uek9wzKt4Pz
AZ5EdeM=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw2GK2N3PPRUUon8Nh7e/S
bZr6ML6Ag3iMLt+lhQpQvojD53+7IpvYYXwJh8batmtnL8hB+TIODq8croUu
koXyFRx4X5h+Zy2WgfKVHNw7l3uJG0pD+SoO+8KuPVH7LQnlqzlMepuhUWcN
42s4xHvvcdhzSBzK13KYvmzhCiU5MShfx0HmdoSDwEQRKF/P4Wdi8d/GrcJQ
voGD7Oo/12LMBaF8QwddW72Q/c94oXwjB781fa6pW2F8Y4fsEzv2Xd7JDeWb
OERpT/Q4VwHjmzooe027FrWCC8o3Q+ObO0x8XFzt9J0dyrdwqKr/dTB7FRuU
b+mwcV3+FL1oDijfyuG95a9/TnoweWuHwB5DbZZWFijfBk2/rcPy3dfFTsmw
Qvl2DpD4ZILy7dH4Dg7Fq63tNy1igPAbHByYFLR+ca/+Yw8AFyqBHw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw8OIXPP78giKUz+GwzWQ7
4xZjGF/AwePpfZ1bMxSgfBEHwQtfaz1YYHwJB36GrSEL98lB+TIO8dmChkKT
ZKF8BYeLDP+d/9bIQPlKDr8azi2wCpeG8lUcJN1/S6lYSUH5ag7xuRvnz7gq
AeVrOPRY/UtzLheH8rUcSn6tVDK0EoPydRzuRfS193wXgfL1HHQ+9K3b3i8M
5Rs4FFz7fChRUQjKN3TwdTt29ImtAJRv5LDtwwR9qbN8UL6xw8UdV7/c+MEN
5Zs4fNh88W+tKCeUb4rGN3OQ9/C1FFvFCuWbO4RHGa0rUvpvD+FbOHAzr616
NZkRKm/pYNz79rvjgZ9QeSuH95a//jnpPYPyraH8b/YALE1utw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwSHmqmrr7jCKUz+Eg8JW1
VscExhdwuM5h94lvvgKUL+Jw9yNDI58wjC/hEJ9+ekrIdzkoX8ZBfmJs2Laj
slC+goOdtN9F43UyUL6SQ00sC8/hLmkoX8Vh3gLTyARDKShfzWHFql0dXIqS
UL6Gw+M7QYWNbBJQvpbDQ+3UQ9w64lC+jkOdTtXsvA+iUL6eg0WWvVGvOIxv
4DDLr/HXYy4RKN/QYeGSE6L914SgfCOH1LnLmKoXCEL5xg724V9i/KRhfBOH
bqPUO7MTBKB8U4ejn/mDowp5oHwzh7NSH15NEeCC8s0dJj4urnb6zg7lWzgs
331d7JQMK5Rv6eBjXr/9sR4zlG/l8N7y1z8nvWf2AMIBYJY=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwcA2r3153RRHK53Boqk5g
/GwE4ws45N5f8WrGDAUoX8Th+EkrzqVv5aF8CQdTHhHDwFNyUL6Mw+mO55ef
L5eF8hUc2sSUrhomyUD5Sg42B5YmpPFLQ/kqDl/ZXy1L3ygJ5as5lCS+YNqV
JgHlazikPC3e0mktDuVrOcxS2Mr/7LkolK/jYHKpt1x1lwiUr+fwJEvT6m+7
MJRv4BDtvp/r1wYhKN/QYZmy1y2TQwJQvpGDr9uxo09sYXxjhxWOh48ek+SF
8k0cvvHubPxjygPlmzowKWj94l4N45s5TGhh3nE/lgvKN3dom5htVS3PDuVb
OBSvtrbftIgByrd04GZeW/Vq8kd7AOwIYMQ=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwqPLJ5JK7rAjlczjwbtV5
a+QG4ws4cKw3zfedpwDlizisY+UXauOA8SUcXp/XT5J9LAflyzjc4+Q20t0i
C+UrOBzJ0vqydYYMlK/ksMwk6NrvfmkoX8UhOE6ke6qHFJSv5rBvj1wI8xsJ
KF/D4ZD3Cq2LMeJQvpbD7eNbbl0vFoPydRyss4pmJGwRgfL1HHQ+9K3b3i8M
5Rs47D3efv9HvRCUb+hQkrF8n78YjG/kEDlr7UJRHQEo39ghSnuix7kKbijf
xMG49+13xwOcUL6pQ9vEbKtqeXYo38xh+e7rYqdkWKF8cwdI+DJB+RZQ/T/t
IXxLh/eWv/456T2zBwAQcWCz
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQDQEf7MVCt+7emK3kABVw6N7yOGD3VUUon8PBJvK8
hY0djC/gwHXraH7rbAUoX8RBvfXhrJCH8lC+hIPwjZ5v9TvkoHwZh3O/k269
7JOF8hUcTveXStYnyED5Sg581jcUZqpKQ/kqDpXBXTon/ktC+WoOihKJf8/e
lYDyNRwqNwb+0KgSh/K1HOaVrrhloCQG5es4rJO9rKT1XATK13NIn8pUwmsM
4xs4HAk4MLthlxCUb+hQvHF9Z0CVIJRv5GAf/iXGTxrGN3ZY4Xj46DFJXijf
xEH+39nTFh+4oHxTh586k2qW53BC+WYOHzZf/FsrCuObOyh7TbsWtQKm3gJN
vaXDWakPr6YIwOStHCY+Lq52+s4O5Vs7vLf89c9Jjw3Kt3GonXd5j9hDZijf
1iE8ymhdkdJ/ewjfzoFJQesX9+o/UL69Q/Fqa/tNixig6h0cuJnXVr2a/BEi
34DGZ3CE2vcMKu+IJu/kYNz79rvjgZ9QeTQ+gzNcPwC7jZ/J
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwqLxwN1bspCKUz+GwL3gN
9wY9GF/AYVadSMH/mQpQvojDzw7XNWvZYXwJB53M8K8nD8tB+TIOTarRcXdm
yUL5Cg6n+0sl6xNkoHwlB27LtHtvzKWhfBWHV48v/JCXk4Ly1Rx0G2/GcX+R
gPI1HPRmbnof+0ccytdyONZzqLxsvxiUr+Mw65TQrgXrRKF8PYcD2k5v1xSJ
QPkGDrXzLu8ReygM5Rs6TH/Yw3jvoxCUb+TwYwl73RNHGN/YwT78S4yftCCU
b+KgK6jxcdZFASjf1MFz5bpVqnP4oXwzh/Aoo3VFSjC+ucM33p2Nf0x5oHwL
h9nXuH8uM+WG8i0dqup/HcxexQblWzm0Tcy2qpZnh/KtHXzM67c/1mOG8m0c
uJnXVr2azAjl20L5H+0BxHxy+w==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwmH8zgoPxgiKUz+Hw9rGx
61RTGF/AYdtDW3mfaQpQvoiD6WrJD6+fykP5Eg6LM99HpS+Vg/JlHCQW/D2a
2CoL5Ss4NFc1FtuHyUD5Sg6b0sXUVnFJQ/kqDux3uzduficJ5as5WJaHPGb7
JQHlazhk8v0IyV0uDuVrOew8HbktPFIMytdxOKjcosGgJArl6zlUVWo/v6Yq
AuUbOLCFMm7+cFgIyjd0uJL6jVNjpyCUb+RQqXn8Z6q/AJRv7OAc8seM1Y0P
yjdxyD6xY9/lndxQvqmDzmYWNrM+dijfzCGwx1CbpZUFyjd3kPfwtRRbxQrl
Wzj4mNdvf6zHDOVbOhSvtrbftIgByrdy4GZeW/VqMiOUb+3ApKD1i3v1H3sI
38bhveWvf05636B8WzgfAAIkbIw=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwEHstpz/tviKUz+Gw+Ouz
hU/sYXwBh7eHsjP5lylA+SIOz3+c0LHhg/ElHF7JTHbad0cOypdxeH6+/unn
a7JQvoLD0c/8wVGFMlC+ksOWdc0d4k7SUL6KQ2vnPFsZRSkoX82hKedt9/Lr
ElC+hgNfhVbYvcniUL6Wg9nKoFivajEoX8fh4przn1VyRaF8PQeVcsbJZu+F
oXwDh5hm46gbL4SgfEOHK6nfODV2CkL5Rg4nr6l8+c0D4xs78AgfKi94yQ/l
mzjwFhlZX27ihfJNHSa0MO+4H8sF5Zs5bFyXP0UvmgPKN3eoqv91MHsVG5Rv
4cDNvLbq1WRGKN/Swbj37XfHAz/tAXk4ZDA=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwiPnCf+/AOUUon8OhUkil
RcEWxhdw8H0oczVggQKUL+Ig/PflvTlSML6Eg67YErF7YvJQvowDm8G3ozUv
ZKF8BYfz6vsWP1wuA+UrORiLJ6mtKZOG8lUcYrj3RcwWloLy1RyePzsq8EVJ
EsrXcLA4Wl89b5c4lK/lYCQ+PzGmTQzK13FYvvu62CkZUShfzyEm6dFjnRfC
UL6BQ3YEe2DydBjf0GGplfGJ5XOFoHwjB5eGir+G7YJQvrHDMmWvWyaHBKB8
E4clJxeXcZfwQfmmDrxFRtaXm3ihfDOH2de4fy4z5YbyzR2Me99+dzzACeVb
OLy3/PXPSY8Nyrd0kPfwtRRbxQrlWzlA4oMJyreG6v9pD+HbQPU/g/JtHbiZ
11a9mvzRHgCzF3BI
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVw8Itj/3jvtiKUz+GwIFdN
ldkDxhdwUE1d/St6owKUL+JgeIRzaoIsjC/hwC8XsNROUB7Kl3HI3tZ6b+oX
WShfweGMZqDIs1syUL6SA+P7yX/+x0tD+SoOjrmqVpmhUlC+msM9aZb7XN8k
oHwNh+Ip62o5D4hD+VoO2Xq/7186KQbl6zh0/rqwSvKvKJSv57Cy4OzFjD4Y
38Ch6Xh47C8fESjf0EHnQ9+67f3CUL6RQ0yzcdSNF0JQvrFDQmHs71MvBKF8
E4fijes7A6pgfFOHZ/pKxnmaML6Zw+d/uyKb2AWgfHMHwTciYh/E+KB8C4ej
n/mDowp5oHxLh43r8qfoRXNA+VYOVfW/DmavYoPyrR2W774udkqGFcq3cQjs
MdRmaWWB8m0dwqOM1hUp/beH8O0cIPHJBJW3dyhebW2/aREDlO+Aym9wcGBS
0PrFvfoPVL8jKr/B0YGbeW3Vq8kf7QFgFIej
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwaLxsN6vtqiKUz+GQueT5
STFrGF/A4cyPgP8bFytA+SIOs3SSrk76Iw/lSzh8UD3H7nBdDsqXcQjVEzle
sUAWyldwcN+hU7C2XQbKV3LwvCR2s7RFGspXcdhUtXSu7WQpKF/NoW/m1epy
D0koX8NhE8Oihm4BCShfy6HNcLvc9QBxKF/Hgf2g8hydN6JQvp5D8Jwp0lWG
ML6BQ9Sn22aqf4WhfEMHH/P67Y/1YHwjB7e9L7McLgpC+cYOn//timxiF4Dy
TRwE34iIfRDjg/JNHc5KfXg1RYALyjdzeG/565+THhuUb+6wfPd1sVMyrFC+
BVT+mz2EbwnlP7MHADXoZLk=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwMD8kELLjpCKUz+Gguttj
kosJjC/gcPBzgoraRAUoX8ShkmPOVKs/8lC+hENyacuFlnVyUL6MA88fqW1v
02ShfAWH/OamhkPCMlC+ksOcwishJk+loHwVB7G79rtKpklC+WoOJZZWHcJL
JaB8DQdL9ysOm9aLQ/laDlZqG26s6RWD8nUckvw0V/zjEYXy9RycDgbLacuL
QPkGDmyhjJs/HBaC8g0deHOEXncUCkD5Rg6eK9etUp3DD+UbO0xoYd5xP5YL
yjdxeG/565+THhuUb+og7+FrKbaKFco3c/Axr9/+WI8Zyjd3KF5tbb9pEQOU
b+HApKD1i3v1H3sI39KBm3lt1avJH+0BciBbjA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQEf7MVCt+7emK3kABVw0N4exrrvhiKUz+Hw5SBD
SoULjC/gIP2C47b9agUoX8TBk9VB6YkQjC/h8EpmstO+O3JQvozD5abb0TWz
ZaF8BQep2aFlS+NloHwlB6E4PtFTZtJQvooDE2ezRaeGFJSv5qDwcvPWG/cl
oHwNh6dM28smPRKH8rUcFvAzSf1xFYPydRxc5jwQ2tkpCuXrOQQzWJzbKCgC
5Rs4sIUybv5wWAjKN3SQXf3nWoy5IJRv5JDjNGEv30I+KN/Y4RpvR8ZPP14o
38Th4o6rX2784IbyTR02rsufohfNAeWbOehsZmEz62OH8s0dAnsMtVlaWaB8
C4eJj4urnb7D5C0d2iZmW1XLw/hWDlX1vw5mr2KD8q0dfMzrtz/WY4bybRwg
8cUE5ds6hEcZrStS+m8P4ds5FK+2tt+0iAEqb4+m38Ghdt7lPWIPofwGBzR5
R1TzGxzR3O+EJu/kIO/haym2ihUq74xqf4Ozg3Hv2++OB35C3eeCpt/FgZt5
bdWryYxQ/a6o6htcHd5b/vrnpPcNqt8Nqv6jPQCRBKhP
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVwSAjZUatwThHK53DYUX6V
Q9oFxhdwWNVgYjBhqQKUL+JwxKWCRUQGxpdwKDv0MXfFFzkoX8Yh2S3748H7
slC+gsM7h09vX22SgfKVHL7IXZ5yq0cayldxOMV43ko9UArKV3OoyO23KA2W
hPI1HD6oH5djzZSA8rUctko+u//lvjiUr+PwLvbg9sRjYlC+nkOdTtXsvA+i
UL6BQ/LtPXuWvxGB8g0dfv1wXlSuA+MbOfRu5tTed18Iyjd22BejelCOG8Y3
cZBd/edajLkglG/qYB/+JcZPGsY3c/j8b1dkE7sAlG/u8I13Z+MfUx4o38Lh
xFHb8pJdHFC+pQMk/JmgfCuH95a//jnpfbOH8K0dmBS0fnGv/gPl2zj4mNdv
f6zHDFVv61C82tp+0yIGKN/OgZt5bdWryYxQvr1D7bzLe8QewtQ7OFTV/zqY
vYoNwm9wcJD38LUUW8UKlXdEdU+Do4Nx79vvjgd+Qu13gpr/0R4A3UCSEQ==

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwsJ3pV3/3vCKUz+HwvTMz
3FUJxhdwEJLYKNzVoQDlizjceC+XV3hDHsqXcFDh5dG7uUwOypdxaF0s1xCQ
JAvlKzhM6L/gK/JVGspXclj28luL/20pKF/FgfnKwut2rZJQvpqDmOPjnDVl
ElC+hsMh7xVaF2PEoXwtB8EJfgyORmJQvo6D2Ztnd9ewi0L5eg6/fjgvKtcR
gfINHDRV2J98dxeG8g0dfixhr3viKATlGzmUak6ZPGmTAJRv7NBtlHpndgKM
b+KQ4zRhL99CPijf1IG3yMj6chMvlG/mkH1ix77LO7mhfHOHizuufrnxA8a3
cPiw+eLfWlFOKN/Soar+18HsVWxQvpVD7bzLe8QeMkP51g6Q+GGC8m0cuJnX
Vr2azAjl2zqERxmtK1L6bw/h2zm8t/z1z0nvG5RvD1X/0R4AsBR7jg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwyDziovjgsiKUz+Fg8Py6
k6sjjC/gsG9i+bOmVQpQvoiD0NPdYda8ML6Eg033oTmiN+WgfBkHhr7ZQtOn
yEL5Cg7Pmjf0fguXgfKVHOp1/7/x5JCG8lUczpg95wq9KwnlqzlwOp145Zct
AeVrOGydtcyxj18cytdyOOzxeZ7iHlEoX8eh6Xh47C8fEShfz2Hv8fb7P+qF
oHwDB0XH9M7SfwJQvqHDkpOLy7hL+KB8I4fZ17h/LjPlhvKNHZbvvi52SoYV
yjdxeG/565+THhuUb+pQVf/rYPYqGN/MQWczC5tZHzuUb+4g7+FrKbYKpt/C
gZt5bdWryYxQvqUDk4LWL+7Vf+whfCs0vrVDeJTRuiKl/1C+DVT/RyjfFuqe
Z1C+HVweALU+diM=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw+Nmd83/GRUUon8PhdmKd
oa8pjC/gUCbJcixwoQKUL+LA9/NH60o2GF/CwUR6xXrHI3JQvozDFM6Wi0t7
ZaF8BYcVzkmive4yUL6Sw9+06PLln6SgfBWHBawHgo5XSUL5ag59xq8ZbwVK
QPkaDpFKFgtuhIlD+VoOzS2H70w/IArl6zgIrb2a+aFOBMrXc3DSS5hSlCAM
5Rs4zNy/vDxURwjKN3SQXf3nWoy5IJRv5BCQo3X6q6QAlG/scHHH1S83fnBD
+SYOHzZf/FsrygnlmzpsXJc/RS+aA8o3c/ipM6lmeQ5M3twhsMdQm6WVBcq3
cChebW2/aREDlG/pYNz79rvjgZ/2EL6Vw3vLX/+c9L5B+dZwPgD9ZW3R
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwcBG6E+l4WRHK53B4aHfM
VtodxhdweLTv8IXzSxWgfBGHOs4FqZyMML6Ew6WDCe+2npaD8mUcQrepH7G8
JAvlKziEPF6n93KxDJSv5MB+Rb00pUgayldxCDPepFmVLAXlqzlId1qtv6Mi
CeVrOEx8XFzt9F0cytdy2LdLiOPDFDEoX8dB4bHo1MWRolC+nkP11UpehgQR
KN/AIemE0i7jBmEo39Ch4NrnQ4mKQlC+kcMyZa9bJocEoHxjh/8Mgf8TSvih
fBOHJScXl3GX8EH5pg5R2hM9zlVwQ/lmDm0Ts62q5dmhfHOHjevyp+hFc0D5
FlD3w+QtHXQ2s7CZ9cH4Vg7yHr6WYqtYoXxrh+LV1vabFjFA+TYOxr1vvzse
+GkP4dui8e3Q+PYO3Mxrq15N/gjlO6DyGxwc3lv++uek9wwq74jKb0DwAeRU
jPQ=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwOLG2xbrthCKUz+Ewa5XX
5kJtGF/AYZ7h5pid/QpQvohDbtjFDzF35KF8CYdl1/KVHk+Rg/JlHF7nTzJR
dZGF8hUcvl0+4V/5TxrKV3LQrZBcW7VLCspXcTC0Wazwy1cSyldzaPl/J4iN
UwLK13BgLZHVrt8hBuVrOch7+FqKrRKF8nUcNq1vk5O4IwLl6znI7Sze1n5a
GMo3cOjdzKm9774QlG/oIKBjKH3uvyCUb+QgLfH4xcRJAlC+scO2DxP0pc7y
QfkmDkwKWr+4V/NA+aYO8v/Onrb4wAXlmzlMfFxc7fSdHco3d6iq/3UwexUb
lG/hwM28turVZEYo39KheLW1/aZFDFC+lUN4lNG6IqX/9hC+NdS+P1C+DZq8
LZp5dmjm2aOpd3B4b/nrn5PeNwi/wcHBuPftd8cDP+0BhYOBeg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwmFgpenLKdUUon8MhoIon
/6EdjC/gsGnSwTnvNylA+SIOxkedtpmJwPgSDpM51/0QZJSH8mUcTlvP/L52
jyyUr+Dw9f6jMvFYGShfyeFH3PrUCx7SUL6Kw7rzlYFW5lJQvpoDo0jH539/
JaB8DQdVznMRek/FoXwthxmWu6e9PSQG5es4/C5cUO+bIQrl6zls/NH3UsJB
BMo3cHiSpWn1t10Yyjd00PRTFnHNFYTyjRy6jVLvzE4QgPKNHXRt9UL2P+OF
8k0cjn7mD44q5IHyTR02rsufohfNAeWbOfiY129/rMcM5Zs7hEcZrStS+m8P
4Vs4GPe+/e544Kc9AKtlXmM=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwsOe9OnXmZUUon8NB9Y1n
7HQdGF/AISFK9klOtwKUL+LAfvhLlgATjC/h8Pq8fpLsYzkoX8bBb02fa+pW
WShfweHdPek9dR0yUL6SQ8qPJ3MmLJKG8lUcPt713jatUgrKV3OY9DZDo85a
EsrXcNgq+ez+l/viUL6Ww5zzqp5sXWJQvo6Ddr/bOafTIlC+noPczuJt7aeF
oXwDB4h/haB8Q4fdUlPm7nwvAOUbOeja6oXsf8YL5Rs7XNxx9cuNH9xQvomD
vIevpdgqVijf1CGwx1CbpZUFyjdz8DGv3/5YjxnKN0fjW0DtZ4LyLR3eW/76
56T3zR4Ag+RipA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEf7MVCt+7emK3kABVwCBfZayx7XBHK53Aw6n70
qk4HxhdwULX4L/x4lgKUL+Jw57l0+uy/8lC+hIPUhX6v+1floHwZh9Mdzy8/
Xy4L5Ss4POGcq2bcJwPlKznIOs1IKHWVhvJVHLI3VhQkf5aE8tUc4nM3zp9x
VQLK13D48C217sFCcShfy+H28S23rheLQfk6Dvci+tp7votA+XoOUZ9um6n+
FYbyDRx+eD/laPQRgvINHbgW/4hzOyoI5Rs5rLZRytA4zA/lGztc4+3I+OnH
C+WbODApaP3iXs0D5Zs6nJX68GqKABeUb+Zw4qhteckuDijf3KGq/tfB7FVs
UL4FGt/S4b3lr39OejC+lcPy3dfFTsmwQvnWaHwbh/Aoo3VFSv/tIXxbqHv+
QPl2aPL2DsWrre03LWKA6ndAlW9wQJN3RJN3dDDuffvd8cBPqHlODtzMa6te
Tf4IlXeCuv8ZVN4ZVX2DM1T+G1TeBU2/C1w/AGUAr1w=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVw0H2atPn1LUUon8NBNWir
/1dTGF/A4SHXyaqPCxSgfBGHCUFuSyd9lofyJRzqZ6wu+HJODsqXcdBPnJ9q
Wy4L5Ss43POZv6nfQQbKV3JYbbXxzuMXUlC+ikOPovXhn3skoXw1h6act93L
r0tA+RoOT5m2l016JA7laznEMASLBUwUg/J1HPyKBaqnHRWB8vUcnPQSphQl
CEP5Bg7R7vu5fm0QgvINHfYeb7//ox7GN3IQenHg0OogQSjf2GG1jVKGxmF+
KN/EYcnJxWXcJXxQvqkDk4LWL+7VPFC+mcPGdflT9KI5oHxzh7aJ2VbV8uxQ
vgUa39IhsMdQm6WVBcq3cpD38LUUW8UK5Vs7LN99XeyUDIxv4+BjXr/9sR4z
lG/rwM28turVZEYo387hveWvf0563+whfHso/5k9AN30eBM=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwyPyz/0foOUUon8OhULmq
b5URjC/gEK4yXSlougKUL+LQtcr4SQIXjC/hcKFC+u/KH3JQvoxDslv2x4P3
ZaF8BYfz6vsWP1wuA+UrOTR/2/8sskkayldxaKx8W64oLQXlqzk8U1r8NXWO
BJSv4RBsyMFwM1gcytdy6KqLE1/zRRTK13GI8OgXeLRfBMrXc+grKF0VHQzj
GzgcCTgwu2GXEJRv6FC82tp+0yIBKN/IoXR3gI3FDz4o39ghSnuix7kKbijf
xMG49+13xwOcUL6pQ9vEbKtqeXYo38zhveWvf056bFC+uUPtvMt7xB4yQ/kW
DtzMa6teTWaE8i3R+FYO4VFG64qU/ttD+NZQ+35C+TZQ9R+hfFs0vh3U/mf2
AIsmeWU=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwYN76wcPhqiKUz+HA35ex
s8QExhdweGx+fwLzbAUoX8ThZ4frmrXsML6EQ4SyzF7713JQvozDoVmKj49e
lYXyFRxEbn2sqjgjA+UrOazfqKLGXysN5as4lO6Vr1pvIQXlqzksi3iZYW4v
CeVrOFyNfmj58p84lK/lcFozb4PMHzEoX8fh5JWW1tKTolC+nkP89a1xlytE
oHwDh9Pbtq4sKhCG8g0dskp+bGMMF4LyjRye6SsZ52kKQvnGDp4r161SncMP
5Zs4MClo/eJezQPlmzr81JlUszyHE8o3c6iq/3UwexUblG/uIO/haym2ihXK
t3ConXd5j9hDZijfEo1v5WDc+/a744Gf9gBmKWcs
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBwBWIQDQEf7MVCt+7emK3kABVwiJy17JDIWUUon8Mh6rPJ
QQcrGF/AYeXOd3d55ilA+SIOzwWbVs9ngfElHA55nVwpuV8Oypdx0O1PcJCZ
IwvlKzh8/ZUyS7NGBspXcgjYrqVo7iwN5as4rDtfGWhlLgXlqzn8TauqSD0v
AeVrOFi9ftywfpo4lK/lwLPSPHDPfDEoX8fhKeu0b9uni0L5eg5Ca69mfqgT
gfINHJ5rfqo0DBCG8g0d2EIZN384LATlGzlcsp/EIn5XEMo3drA8t3vBsQcC
UL6Jw+d/uyKb2GF8U4fwKKN1RUr8UL6Zw97jVu80HvNA+eYOP3Um1SzP4YTy
LRx0NrOwmfWxQ/mWDu8tf/1z0mOD8q0cNq7Ln6IXzQHlW6Opt3E4K/Xh1RQB
LijfFk3eziGwx1CbpZUFyrd38DGv3/5YjxnKd3CAxDcThN+AxmdwRFXf4OhQ
vNraftMiBqi8k0PtvMt7xB7C5J0cqup/HcxeBXO/s4O8h6+l2CpWqLyzQ9vE
bKtqeZj7XBwmPi6udvoO5Te4oKpncEUNjwZXh+W7r4udkoHJu6Ga1+CGah6D
u8OJo7blJbug4dfgjhY+Hmju80CT90QNvwZPNPu9UPkNXmjh640aHg3eaPHr
gxq/DT5o5vuihb+vAzfz2qpXkxmh8n5o4e+Hpt8fzf3+aO4LQI1PhwAH4963
3x0P/LSHqA+A2vcRwj+AxmcIRFXvEAj13zN7ALYgD1c=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwmHlyNlPdKUUon8Oh2fW5
aoEhjC/g8IDT4vWJqQpQvojDAUOr20tYYXwJh0u88rwKx+SgfBmHDQJzuS2m
ykL5Cg6Wn04aBDjJQPlKDi9zxCzyn0lB+SoO1rsY1tr+k4Ty1Rz27ZELYX4j
AeVrOFRuDPyhUSUO5Ws5mK0MivWqFoPydRxOXmlpLT0pCuXrOcjcjnAQmCgC
5Rs4aKqwP/nuLgzlGzpoy4pJpicKQflGDoqO6Z2l/wSgfGOHJScXl3GX8EH5
Jg5MClq/uFfzQPmmDsa9b787HuCE8s3Q+OYOOptZ2Mz62KF8C4f3lr/+Oemx
QfmWDvIevpZiq1ihfCsHbua1Va8mMzoAAJMKW9o=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwqPLJ5JK7rAjlczjs5Jsb
EG4P4ws4TLpaKFS9UQHKF3Fo61Ju5ZWF8SUcOmUvMT/6JQflyzgwbYmM+D1X
FspXcPh4M7YvIlEGyldyEI28WGloJQ3lqziclfrwaoqAFJSv5qB1ba0QxwwJ
KF/DgffLnJfec8ShfC0H19THm3tmiEH5Og6ZKV8r9NVFoXw9B3Y5lpAjl4Sh
fAOHH0vY6544CkH5hg6lmlMmT9okAOUbORSvtrbftAjGN3aInLV2oagOjG/i
4Bzyx4zVjQ/KN3U4+pk/OKqQB8o3c5h9jfvnMlNuKN/c4cRR2/KSXRxQvoXD
T51JNctzOKF8SzS+lcPEx8XVTt/ZoXxrBx/z+u2P9ZihfBsHSHwxQfm2DkwK
Wr+4V/+xh/DtHN5b/vrnpPfNHgCE03ER
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVw8OTwCom8pgjlczic8LI6
U+gA4ws47JtY/qxplQKUL+LA5XLsRzcXjC/hsO3DBH2ps3JQvoyD96a2bplu
WShfwcHy00mDACcZKF/JoZwh3v7eZykoX8WBs9BX4OlBSShfzWGd4KlnLxdJ
QPkaDtP68wpWtYpD+VoOZiuDYr2qxaB8HYckP80V/3hEoXw9h76C0lXRwSJQ
voGDq+2TmvO/hKB8Q4fUucuYqhcIQvlGDqttlDI0DvND+cYOOU4T9vIt5IPy
TRy+8e5s/GPKA+WbOmSf2LHv8k5uKN/MoW1itlW1PDuUb+6wfPd1sVMyrFC+
hQM389qqV5M/2gMAgDlbrA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw8LASXqt9XhHK53C45r1U
5owxjC/gkNN7rmfnDAUoX8Th3+3Mec94YXwJhw+q59gdrstB+TIOx0w9JebM
lIXyFRx4mqdNW1spA+UrOWjv6WSdmy4N5as4nGq8e4zbVgrKV3NYUeeb5yEt
CeVrOEx8XFzt9F0cytdyMBKfnxjTJgbl6zj85ku3P+gqCuXrObRXHan4MUcE
yjdwSDqhtMu4QRjKN3QwdJu10+usEJRv5GBj5NPOlyAI5Rs7vL6j3qLfJADl
mzhs+zBBX+osH5Rv6iD4RkTsgxiMb+ag7DXtWtQKLijf3OHEUdvykl0cUL6F
g7yHr6XYKlYo39Khqv7XwexVbFC+lUPtvMt7xB4yQ/nWaOptHAJ7DLVZWlmg
fFuH5buvi52SgcnbOby3/PXPSQ9mnj2avINDeJTRuiKl//ZgboODg3Hv2++O
B37aAwB46Hw0
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwWMPPJJ17RRHK53BI/HQk
b5INjC/goNPxMcVrhQKUL+Ig8SIpXZAPxpdwkLrQ73X/qhyUL+Mg9nP5+d8z
ZKF8BYe4oFdLTsfJQPlKDmIvohgUlKShfBWHxsq35YrSUlC+msODE68Fc8Ul
oXwNB1XOcxF6T8WhfC2HjOp7aYuYYHwdh+nLFq5QkhOD8vUcNv7oeynhIALl
Gzj88H7K0egjBOUbOjzTVzLO0xSE8o0cImetXSiqIwDlGztc4+3I+OnHC+Wb
OMj/O3va4gMXlG/qMKGFecf9WBjfzOGnzqSa5TmcUL65w3vLX/+c9NigfAsH
bua1Va8mM0L5lg7Fq63tNy1igPKtoOq/2QMAYvtjHg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwUBaw3zLhkiKUz+HA3FHW
o2cN4ws4xGxbfXDuTAUoX8RhssyJuUeZYXwJB29D47daN+SgfBmHsP9LIrob
ZaF8BQeRE5VhdX4yUL6Sw8eLp6RW6EpD+SoODFfyCrNfSEL5ag6MEy79e9ko
AeVrOPidCziyPEMcytdyuKqRk7hsuyiUr+MgtPZq5oc6EShfz8F780evQHNh
KN/A4Zm+knGepiCUb+iw2kYpQ+MwP5Rv5MBbZGR9uYkXyjd2uMbbkfHTD8Y3
cbi44+qXGz+4oXxThwktzDvux3JB+WYOG9flT9GL5oDyzR0mPi6udvrODuVb
OLy3/PXPSY8Nyrd0CI8yWlek9N8ewrdyKF5tbb9pEQNU3tqBSUHrF/fqP1B5
Gwfj3rffHQ/8hPJtHbiZ11a9mvwRyreDmv8MyreH8wEl6nzJ
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVwmK1slNd9ThHK53BQSTf1
UzWD8QUcildb229apADlizgs3FoktEcAxpdwMPKrNt91UQ7Kl3HIVT+1V7Za
FspXcDAvKbyTbyQD5Ss5uNyr/id8VQrKV3FYdmjvsawTklC+msPh5VvmmM+S
gPI1HNoMt8tdDxCH8rUcfhcuqPfNEIXydRwC9BcolUiIQPl6DlklP7YxhgtB
+QYOkbPWLhTVEYDyDR1KdwfYWPzgg/KNHHiLjKwvN/FC+cYORz/zB0cV8kD5
Jg5npT68miLABeWbOrRNzLaqlmeH8s0cuJnXVr2azAjlmzu8t/z1z0nvmz0A
9aNVUA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwuKj2/N2604pQPodDbtsp
s7lmML6AQ0jbac9n6xWgfBGHvCrtE54KML6EwwS5+E/X38lB+TIOu9jjWqfd
k4XyFRyct8SfO7ZeBspXcmB8P/nP/3hpKF/F4XjAikt1dlJQvprDJsfOpp//
JaB8DQdVznMRek/FoXwth8a5F+IlC8SgfB2H33zp9gddRaF8PYeNP/peSjiI
QPkGDq62T2rO/xKC8g0dDHdJqz8qhfGNHJ7pKxnnaQpC+cYO66XXbL/kzQ/l
mzjsPW71TuMxD5Rv6qDsNe1a1AouKN/M4b3lr39OemxQvrkDJHyZoHwLh+LV
1vabFjFA+ZZQ9d/sIXwrKP+ZPQDo/mrX
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwmF3eyvrxjCKUz+Gwbmck
h5M+jC/gMNHi5amOOQpQvohDfLrkpJMf5KF8CYcls4WUmxbJQfkyDl0qLWk8
RbJQvoKDRbUQ3wM9GShfyeFvWnT58k9SUL6KQ6jNrRSVW5JQvprDDB+VII5e
CShfw+FQT7/gYiVxKF/LYVEjz6YlgWJQvo7D78IF9b4ZolC+nkMwg8W5jYIi
UL6Bg+EuafVHpUJQvqFDDPuiWdKuglC+kUN4lNG6IiV+KN/Y4afOpJrlOZxQ
vonDxMfF1U7f2aF8U4fAHkNtllYWKN/MgZt5bdWryYxQvrnDe8tf/5z0vtlD
+BZofEsH49633x0P/ITyrRyYFLR+ca/+A+Vbo/Ft0NTbQu37aA8AvgRu0A==

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw6N7yOGD3VUUon8MhKfsc
X6ILjC/gENqa2p6/TgHKF3HIiVwv95wPxpdwSDHgXvfomxyUL+PAUP3lvMxR
WShfwSG/s7U1N00GyldyOKA1/5KnqDSUr+LA9d846809SShfzUG4wPtgXq0E
lK/hcPDwUqZrkeJQvpbDvNIVtwyUxKB8HYcIj36BR/tFoHw9h6hPt81U/wpD
+QYOGz9Jza/KgPENHfYeb7//o14IyjdycGmo+GvYLgjlGzustlHK0DjMD+Wb
OHzj3dn4x5QHyjd1yD6xY9/lndxQvpnDiaO25SW7OKB8c4flu6+LnZJhhfIt
HLiZ11a9mswI5Vs6hEcZrStS+m8P4Vs5GPe+/e544CeUbw1V/9EeAOHDbKs=

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw+HT6zOed5xWhfA4Hz79+
7UGWML6Aw8qd7+7yzFOA8kUcYq5zGL9mgvElHA55nVwpuV8Oypdx4C0ysr7c
JAvlKzhMspp4pnmmDJSv5JBf45/q6isN5as4rDtfGWhlLgXlqznoNt6M4/4i
AeVrOOxeJDenRgrG13L4yBd6WFNfHMrXcbBS23BjTa8YlK/nYPbm2d017KJQ
voFDVaX282uqIlC+ocP2gmWReqLCUL6RQ9OTpN4nawShfGMHHuFD5QUv+aF8
E4ccpwl7+RbyQfmmDh82X/xbK8oJ5Zs5LN99XeyUDCuUb+5g3Pv2u+OBn/YQ
voXDe8tf/5z0nkH5lg7czGurXk3+COVbofGtoeq/Qfk2cP0Ascpzlg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7MVCt+7emK3kABVweG86JaT2giKUz+Gw0b7n
l7cFjC/g8FNiTYvDLAUoX8Th7zuWco1f8lC+hEMjn4ZaChOML+NQYZHIuPaR
LJSv4OC8Jf7csfUyUL6Sg+3Wc7zLlklD+SoOFUaHH5THSEH5ag7MVxZet2uV
hPI1HNhlUp7a9ktA+VoOwocVdcXni0P5Og5ddXHia76IQvl6DutkLytpPReB
8g0coj7dNlP9KwzlGzoYus3a6XVWCMo3ctgXo3pQjhvGN3Z4IxyZ+q0Txjdx
sDHyaedLEITyTR14c4RedxQKQPlmDs4hf8xY3figfHOH2de4fy4z5YbyLRzO
Sn14NUWAC8q3dPiw+eLfWlFOKN/KYfnu62KnZFihfGuH8CijdUVK/+0hfBsH
JgWtX9yr/0D5tmh8OzS+vQMkfpmg5jmgmtfg4FBV/+tg9io2qLwjqvoGRwcf
8/rtj/WYofJODtzMa6teTWaEyjuh2efs8N7y1z8nvW9Q853R5F2g+j/aAwAV
7Jl6
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwKBI/lshzWRHK53CYaPxE
RdAKxhdwuLjnz7rOFQpQvoiDbYVyi5UQjC/hoJo11yxTWB7Kl3EQOczmzr1T
FspXcDjU6tB7PU8GyldycO9c7iVuKA3lqzi8enzhh7ycFJSv5pDw8/nPXmFJ
KF/DoeTW4hOCN8ShfC2HNdZLjnm9EIPydRyUNnHMOuoL4+s5/OZLtz/oKgrl
GzjI7Sze1n5aGMo3dOjuXaq6lhnGN3KIYV80S9pVEMo3dug2Sr0zO0EAyjdx
2PZhgr7UWT4o39Thp86kmuU5nFC+mUNV/a+D2avYoHxzh9p5l/eIPWSG8i0c
ildb229axADlWzqERxmtK1L6bw/hWzm8t/z1z0nvGZRvDeV/g/Jt4PIA4XJu
UA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwqDuU/b3/lCKUz+Hwc82q
HlMdGF/AYaLFy1MdcxSgfBGHQxNWn1f6KA/lSzh8SJ0lYrZKDsqXcXh+U72J
p1YWyldwMLsaKcOiKgPlKznwWd9QmKkqDeWrOMSc9+Tce1sSyldzeKa0+Gvq
HAkoX8Ohx+pfmnO5OJSv5TDnvKonW5cYlK/jUDlB5KonI4yv56DwWHTq4khR
KN/AISbp0WOdF8JQvqHDD++nHI0+QlC+kYPlud0Ljj0QgPKNHXKcJuzlW8gH
5Zs4MClo/eJezQPlmzp82Hzxb60oJ5Rv5qCzmYXNrI8dyjd3WL77utgpGVYo
38IBEt5MUL6lAzfz2qpXkxmhfCsH49633x0P/LSH8K0d3lv++uek98weAALJ
aUs=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwmHlyNlPdKUUon8Mh86Lr
6R4TGF/AgX3npxa7KQpQvojD//6oH3nH5KF8CQcDB7/3E8vkoHwZhwc9t3Qc
vGShfAWHSeslHDMUZaB8JYcN83LCYrSloXwVh0U6wSJBjFJQvppDRYPg9PKL
ElC+hkNBx6yPhYXiUL6WQ3r2M+cDvGJQvo5D8u09e5a/EYHy9Rxikh491nkh
DOUbOED8KwTlGzo801cyztMUhPKNHLqNUu/MThCA8o0dcpwm7OVbyAflmzhM
aGHecT+WC8o3dbi44+qXGz+4oXwzh43r8qfoRXNA+eYOtfMu7xF7yAzlWzj4
mNdvf6wH41s6vLf89c9J75s9hG/lwM28turV5I9QvjVU/pk9AMkYbFY=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw2PR21sX7FxWhfA6HmIf9
Rl3aML6Aw8HPCSpqExWgfBEHi7MKds5/5aF8CQcujSnWHFfkoHwZh+AUmy7p
E7JQvoLDZP2TK8WWy0D5Sg59P/6vkKuThvJVHARYH3fxR0tB+WoOSTs2WB66
LQHlazgkRIb9nJ4tDuVrOcw5r+rJ1iUG5es4HPb4PE9xjyiUr+cQf31r3OUK
ESjfwOFJlqbV33ZhKN/QYamV8Ynlc4WgfCOHpidJvU/WCEL5xg7dRql3ZicI
QPkmDuFRRuuKlPihfFOHJScXl3GX8EH5Zg7XeDsyfvrxQvnmDhNamHfcj+WC
8i0czkp9eDVFAMa3dKiq/3UwexUblG/lUDvv8h6xh8xQvrUDk4LWL+7Vf+wh
fBuH95a//jnpPYPybdH4dg7czGurXk3+aA8ADz14gQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwWGZZ8rH9siKUz+GgU5qV
LKgP4ws4aBtE/uidpwDlizi03mTTS+OF8SUcFq5Skza+Kwflyzg4vHK4FrpI
FspXcDj6mT84qlAGyldyKJy6ftHrYGkoX8XheMCKS3V2UlC+msMfxk/pO6Ik
oXwNhwc/5UKbDCSgfC2HyNp3rj1fxaB8HYeJsplvZj0WhfL1HK6ztV+X/SQC
5Rs4nEuM+Pj5pjCUb+iQOncZU/UCQSjfyCFy1tqFojoCUL6xw7YPE/SlzvJB
+SYO4VFG64qU+KF8U4fS3QE2Fj9g8mYOTApav7hX80D55g7GvW+/Ox7ghPIt
HD5svvi3VhTGt3SQ9/C1FFvFCuVbOby3/PXPSY8Nyrd2mPi4uNrpOzuUb+Pg
Y16//bEeM5Rvi8a3g9r30x7Ct4e65489AND+eIA=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwuPQ7pHPzFUUon8OhaMvt
iHo9GF/AgWO9ab7vPAUoX8SBjaPf8SMzjC/hELb0cEb8bTkoX8bh5+zvK5VX
ykL5Cg7uO3QK1rbLQPlKDjL7Zj5pi5KG8lUcGivflitKS0H5ag539rRb/Xwu
AeVrOFgcra+et0scytdycEjadn1SuRiUr+OQmfK1Ql9dFMrXc6iq1H5+TVUE
yjdweJKlafW3XRjKN3QouPb5UKKiEJRv5FC8cX1nQJUglG/sULza2n7TIgEo
38ShdHeAjcUPPijf1EHXVi9k/zNeKN/M4RpvR8ZPPxjfHE29BZp6S4e2idlW
1fLsUL6Vg7yHr6XYKlYo39qhqv7XwexVbFC+jcPy3dfFTsnA5G3R1Nuhyds7
MClo/eJe/cceANrEddw=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwiPnCf+/AOUUon8PhyOEe
8WNaML6Aw71X79XsuxSgfBGHCUFuSyd9lofyJRx+mod8f31CDsqXcRD7ufz8
7xmyUL6CQ+ttfc3oMhkoX8lh6equvk/60lC+ikNj5dtyRWkpKF/NgVGk4/O/
vxJQvobD3yPy3VtuiUP5Wg6zVh50/rpWDMrXcfjNl25/0FUUytdziOGQaphh
KQLlGzhMVf0byTBfGMo3dNh7vP3+j3ohKN/I4Zm+knGepiCUb+zAI3yovOAl
P5Rv4rDtwwR9qbN8UL6pwzfenY1/THmgfDMHZa9p16JWcEH55g4b1+VP0Yvm
gPItHN5b/vrnpMcG5Vs6GPe+/e544Kc9hG/lwM28turV5I9QvjVU/Td7AGD+
cLM=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAGIQDQEf7MVCt+7emK3kABVwUH/G8enBDUUon8NhwqQd
p+I9YHwBB1ELrqk+mxWgfBGH4tyw2cekYHwJh/+f3rZ1C8lD+TIOIofZ3Ll3
ykL5Cg5HsrS+bJ0hA+UrOfRlSfqLJ0pD+SoOKYe3GfbwSkH5ag4HTy+ySWiT
gPI1HNZcl32wfIk4lK/lcDnnzs4TKWJQvo7DyoKzFzP6RKF8PYcWlpOnOKaL
QPkGDjof+tZt7xeG8g0dJqd+mByzXAjKN3I4eU3ly28eQSjf2OHzv12RTewC
UL6Jw2obpQyNw/xQvqlD9okd+y7v5IbyzRwmPi6udvrODuWbO3zYfPFvrSgn
lG+Bxrd0eG/565+THhuUb+WwfPd1sVMyrFC+tUPtvMt7xB4yQ/k2aHxbh8Ae
Q22WVhYo3w5N3t7Bx7x++2M9GN/BARLfTBB+g4ODvIevpdgqmH2ODlX1vw5m
r4K6p8HR4cRR2/KSXRxQeScHnc0sbGZ9UP81OKHZ74zKb3BGc48LqnsaXND8
64qm3xVN3g3NfjeHs1IfXk0R4ILKu6OGf4M7qnoGD4eN6/Kn6EVD/dPg4fBT
Z1LN8hxYfHiihkeDJ5r/vBy4mddWvZrMCJX3cgiPMlpXpPTfHiLv7cCkoPWL
e/UfCL/BGxq/36DyPlD+M3sAEZvdqw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwOCb5O6D5liKUz+GQ8aHe
v9MBxhdweL3CSPrTQgUoX8SBZ0rLk4Zf8lC+hMOLj7eY9LfKQfkyDvqJ81Nt
y2WhfAWH9+eObBMNlIHylRwOxvy/l+gnDeWrOLSx2yvwqUtB+WoO7q4lmcx/
JKB8DYcP31LrHiwUh/K1HEp+rVQytBKD8nUcFB6LTl0cKQrl6znEX98ad7lC
BMo3cPDe/NEr0FwYyjd02BejelCOWwjKN3LQFdT4OOuiAJRv7LDtwwR9qbN8
UL6JwzXejoyffrxQvqlDlPZEj3MV3FC+GRrf3OGnzqSa5TmcUL6Fw4fNF//W
isL4lg4TWph33I/lgvKtHOT/nT1t8QHGt3bIPrFj3+WdMPNsHDauy5+iF80B
5ds61M67vEfsITOUb4fGt3d4b/nrn5PeN3sI38HBuPftd8cDPyH8Bgeo/DOo
vCMqvwHBBwDnLJI/
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwmD/x3sroS4pQPoeDVsey
p7ONYXwBh+scdp/45itA+SIO7qaH104QhPElHETn7kqSuSwH5cs4hOqJHK9Y
IAvlKziInKgMq/OTgfKVHB6d5U5u+C4F5as4WO9iWGv7TxLKV3PQurZWiGOG
BJSv4SAqbqp9tkkcytdyeLTwSqiAlBiUr+MQPGeKdJWhKJSv57C5oPhzVIUw
lG/gsPd4+/0f9UJQvqFD05Ok3idrBKF8I4fi1db2mxYJQPnGDjzCh8oLXvJD
+SYOKxwPHz0myQvlmzooe027FrWCC8o3c9i4Ln+KXjQHlG/uUFX/62D2KjYo
38Khdt7lPWIPmaF8SzS+FRrf2iE8ymhdkdJ/ewjfxsG49+13xwM/7QHmkW59

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwUFkQbW5xUxHK53B4cHh2
T4sPjC/g8LLK0HreagUoX8TBtkK5xUoIxpdwkA3/YvfwvByUL+PgwuzB8G2y
LJSv4LCx8OnrNZEyUL6SQ4GbS2V7mjSUr+JwK7VELoVFCspXc1gW8TLD3F4S
ytdw2MSwqKFbQALK13KQ68ha+UVUHMrXcZgom/lm1mNRKF/PQbvf7ZzTaREo
38AhMv6QR1SEMJRv6CC7+s+1GHNBKN/IYbWNUobGYX4o39gh+8SOfZd3ckP5
Jg4fNl/8WyvKCeWbOhj3vv3ueADGN3PQ2czCZtbHDuWbO5w4altesosDyrdw
eG/565+THhuUb+ngY16//bEeM5Rv5VA77/IesYcwvjXU/J/2EL4NVP83KN8W
yn9mDwDP73Jo
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwEFlZ5uR/XhHK53CIlFi5
YZE2jC/gYHQn5dvHPgUoX8TBilvAO48ZxpdwCO99UvDrgByUL+NQ2mSi+CVF
FspXcHgcVeYSIiED5Ss5THxekNL4UArKV3FwZO++K7BZEspXc+gJ5fK4tF4C
ytdweL1l7n2DVeJQvpZD49wL8ZIFYlC+jkPwnCnSVYaiUL6ewyy/xl+PuUSg
fAOHS/aTWMTvCkL5hg4x7ItmSbvC+EYO3Uapd2YnCED5xg5LTi4u4y7hg/JN
HGZf4/65zJQbyjd1qKr/dTB7FRuUb+YACU8mKN/cgZt5bdWryYxQvgWU/9Ee
AIXWWlg=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw2Nj9d5HaFUUon8Mh+dBO
j6XWML6Aw+LdIv7ZcxWgfBGHMFW9nz2MML6Ew4e6DzWLz8hB+TIOZ4s+MeUv
lYXyFRwYH9c9y/aQgfKVHGrV4nbf5JaG8lUcQm1upajckoTy1RyM/qdI7l8g
AeVrOIhZKRTx1IpD+VoORuLzE2PaxKB8HYd8xt9tq6xFoXw9hwPaTm/XFIlA
+QYO5aKzGfqXCUP5hg6Gu6TVH5UKQflGDrulpszd+V4Ayjd2EHwjIvZBjA/K
N3FgUtD6xb2aB8o3dYjSnuhxroIbyjdz0NnMwmbWxw7lmzu0Tcy2qpaH8S0c
fMzrtz/WY4byLR0Cewy1WVpZoHwrNL411L4/9hC+jcN7y1//nPSe2QMAAYRj
qg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwOGHv8erELUUon8Nh8ddn
C5/Yw/gCDmpXlgbfWKMA5Ys4HHGpYBGRgfElHE64/WfZpSwP5cs4/F98z05L
RA7KV3BYZJ0yf/kTGShfyWHhhusGVVekoXwVh0+SB1hLN0pB+WoOnnzOO4Im
SkL5Gg7sWtt6xLZIQPlaDhx1/dKn4sWhfB0Hs5VBsV7VYlC+nsMsha38z56L
QvkGDtr9buecTotA+YYOT7I0rf62C0P5Rg4xzcZRN14IQfnGDtzMa6teTRaE
8k0cImetXSiqIwDlmzrkOE3Yy7eQD8o3c9h73OqdxmMeKN/cQdlr2rWoFVxQ
voXDT51JNctzOKF8Swd5D19LsVWsUL6Vg495/fbHesxQvrWDce/b744HftpD
+DYOTApav7hX/4HybdHk7aDu/WgPACfGdJQ=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwWG7EUz//miKUz+GwzWQ7
4xZjGF/Agc99+ZreaQpQvojDA1txlhXX5KF8CYf/ubGlK7bKQfkyDpu/1Myp
qJKF8hUcDrU69F7Pk4HylRzCk7xOxBtLQ/kqDgyT27tmKklB+WoOxx03cD06
JAHlazisuS77YPkScShfy8Ehadv1SeViUL6Og7PO1fPMraJQvp5DX0Hpquhg
ESjfwEFThf3Jd3dhKN/QIdp9P9evDUJQvpFDwbXPhxIVYXxjh1LNKZMnbRKA
8k0cdAU1Ps66COObOiw5ubiMu4QPyjdz+Ma7s/GPKQ+Ub+7wYfPFv7WinFC+
hUNgj6E2SysLlG/p4GNev/2xHjOUb+Xw3vLXPye9b/YQvrWDce/b744HftoD
AFdVanE=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwmHBcarPeVUUon8Nhcs93
0WO2ML6AQ8PJ9g0GSxWgfBEHniktTxp+yUP5Eg78DFtDFu6Tg/JlHBInlpop
58lC+QoOX3KduAocZaB8JYepvpdt5H9LQfkqDo+VDxrP2ycJ5as5ZO6ekLn1
pgSUr+Egd+Tej0u+4lC+lsObvnOb7C+JQvk6DtVXK3kZEkSgfD2Hde7vg8p5
hKF8A4emJ0m9T9YIQvmGDuul12y/5M0P5Rs5fOPd2fjHlAfKN3b4qTOpZnkO
J5Rv4gAJLyYo39SBm3lt1avJjFC+GRrfHI1v4eBjXr/9sR4zlG/pULza2n7T
IgYo3wqq/qM9hG/t8N7y1z8nvW9Qvg2U/8weAP32cCk=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwOHs9zqTkhCKUz+FgpLQw
TcQExhdwuM5h94lvvgKUL+LAe2W5VrAEjC/h8OW37w/W+3JQvoyDbn+Cg8wc
WShfweGA6uXK+5NloHwlh23WRSnX7aWhfBUH49633x0PSEL5ag7HHTdwPTok
AeVrOFgcra+et0scytdyONZzqLxsvxiUr+PgrHP1PHOrKJSv57BO9rKS1nMR
KN/AITL+kEdUhDCUb+iQVfJjG2O4EJRv5KDomN5Z+k8Ayjd2yHGasJdvIR+U
b+KQfWLHvss7uaF8U4dvvDsb/5jyQPlmDvL/zp62+MAF5Zs7nDhqW16yiwPK
t3B4b/nrn5MeG5Rv6cDNvLbq1WRGKN8Kyv9oDwDBi2ZX
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQEf7MVCt+7emK3kABVweNXtnSR1RhHK53D4Ipq5
UFUZxhdwqGvi/vh+mgKUL+Jw/KQV59K38lC+hMM9t/yfQelyUL6Mg/Cn088D
ZGWhfAWHXDdB4S0npaF8JYeo5z7uss1SUL6Kw40PCxbvLZaE8tUcPqgfl2PN
lIDyNRzaDLfLXQ8Qh/K1HDp/XVgl+VcUytdxkLkd4SAwUQTK13PIjmAPTJ4u
DOUbOPiY129/rAfjGzoUb1zfGVAlCOUbOfi6HTv6xFYAyjd2+M8Q+D+hhB/K
N3FYcnJxGXcJH5Rv6rDC8fDRY5K8UL6Zw97jVu80HvNA+eZofAsH+X9nT1t8
4ILyLR2yT+zYd3knN5Rv5aDsNe1a1AqYvLXDh80X/9aKckL5Nmh8W4eN6/Kn
6EVzQPl2aHx7h8AeQ22WVhYo38FBZzMLm1kfO4Tf4ODQNjHbqloeymdwdGBS
0PrFvfqPPUTeERpezFB5J4fi1db2mxYxQPU7OXAzr616NZkRKu+Mym9wdgiP
MlpXpPQfYh6DCyq/wcXBuPftd8cDP6Hyrmj2u6Lax+CGZr6bw3vLX/+c9J5B
9buj8hvcoeo/2gMARqW80w==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwuGy9I/TFFUUon8NhXXLb
/ivWML6AA5ffjhaBBQpQvojDaQv52RsZYHwJh7KcXInkk3JQvowD05bIiN9z
ZaF8BYe/P7TeXOqXgfKVHBgDPnOaT5OG8lUcnm+sqfhSJQXlqznUHFt3j+uT
BJSv4XBAZDV74itxKF/LYYbl7mlvD4lB+ToOp3+96GpbKgrl6znEX98ad7lC
BMo3cFjn/j6onEcYyjd0SJ27jKl6gSCUb+Tw+d+uyCZ2ASjf2OEb787GP6Y8
UL6Jw4mjtuUluzigfFOHtonZVtXy7FC+mYO8h6+l2CpWKN/cgZt5bdWryYxQ
voXDe8tf/5z0ntlD+JZQ/jco3wouDwDrRmru
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwUBaw3zLhkiKUz+Ggsztz
T4wjjC/gYFnK+NBmowKUL+KQcOcon7ksjC/hMGfmSZYpKvJQvoyDrq1eyP5n
slC+gsPppyuT/66TgfKVHCpuBz7oKJGG8lUcrlzzvVDkLQXlqzksi3iZYW4v
CeVrOCxmmj9N1UoCytdy2CkTmXtCVRzK13Go06manfdBFMrXc7DOKpqRsEUE
yjdwOJcY8fHzTWEo39AhMv6QR1QEjG/kcCTgwOyGXUJQvrFDqeaUyZM2CUD5
Jg6rbZQyNA7zQ/mmDiscDx89JskL5Zs5nDhqW16yiwPKN3fwMa/f/liPGcq3
cAiPMlpXpPTfHsK3dOBmXlv1avJHKN/K4b3lr39Oes+gfGs4HwDzC2qF
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwOLCv9ZfnJUUon8NB/NlC
YVZTGF/AYdcVPr3amQpQvojDlHCZ2o3v5KF8CQfW71MNDT7IQfkyDprGa2ZI
7JeF8hUcxO5tn/+xSwbKV3Lgs76hMFNVGspXcbj17+zrp+ckoXw1hxJLqw7h
pRJQvoYDR12/9Kl4cShfy+HRwiuhAlJiUL6Ow72Ivvae7yJQvp5D0gmlXcYN
wlC+gUNWyY9tjOFCUL6hwzN9JeM8TUEo38iBR/hQecFLfijf2ME55I8Zqxsf
lG/icFbqw6spAlxQvqlD28Rsq2p5dijfzIGbeW3Vq8mMUL65g495/fbHesxQ
vgVU/qM9ADV8Wc0=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwmLpVLXHRJUUon8PBgVsh
4Y05jC/gYGL1XyK8RwHKF3EIEj3L8PS1PJQv4ZB44Ff0ziNyUL6Mw4sY4V9z
tslC+QoOEm5rvddNkYHylRxUsppC9ZKkoXwVh/9crUnz5KWgfDWHq28bOF4/
loDyNRxKf6mvP3lKHMrXcmjgMK77/EQMytdxaG45fGf6AVEoX8+hvepIxY85
IlC+gUNk/CGPqAhhKN/Q4fGevw3a5kJQvpHDbqkpc3e+F4DyjR0E34iIfRDj
g/JNHOT/nT1t8YELyjd1mPi4uNrpOzuUb4bGN3fwMa/f/liPGcq3cHhv+euf
k94zewBhMWFv
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVwUL/JcfPAaUUon8PBxjZN
ldsYxhdwOJ7IL7JolgKUL+Jgt3zOuzQ+GF/C4c0bm8at1+WgfBmHBX9+JSb2
yEL5Cg68166+5UqWgfKVHITi+ERPmUlD+SoOrkfzqiepSkH5ag77DRjlV/NL
QvkaDtev1p7qspGA8rUc5mx/1y3LKQ7l6zhUThC56skoBuXrOUR49As82i8C
5Rs4aKqwP/nuLgzlGzpcsp/EIn5XEMo3crAP/xLjJw3jGzvslpoyd+d7ASjf
xGHJycVl3CV8UL6pwzfenY1/THmgfDOHiY+Lq52+s0P55g5V9b8OZq9ig/It
HHQ2s7CZ9cHkLdHkrRzaJmZbVcvD5K0daudd3iP2kBnKt3FYvvu62CkZVijf
1uG95a9/Tnow/XZo8vYOxaut7TctYoDyHVD5DQ4O3Mxrq15N/mgPkXeEmvfM
HgCuLIJz
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEf7MVCt+7emK3kABVwOLzOJOX6JUUon8Ph+eXA
p55GML6Ag/oHJolbDQpQvoiDo8ux1XZv5KF8CQdml4CipENyUL6MwxODa0/E
F8pC+QoO12LPaGjlykD5Sg7Onvdk3nlKQ/kqDk2rngpMDpKC8tUcPs3Vc9vB
Kwnlazh0TnVnlb8gDuVrOex9E+znv1gMytdxyO+tlBSeLArl6zksftKa5Jwm
AuUbOETGH/KIihCG8g0dtGXFJNMThaB8I4dSzSmTJ20SgPKNHXiED5UXvOSH
8k0cwqOM1hUpwfimDtd4OzJ++vFC+WYOHzZf/Fsrygnlm6PxLRyW774udkqG
Fcq3dICEPxOUb+VQvNraftMiBijf2sG49+13xwM/7SF8G4f3lr/+Oel9g/Jt
HbiZ11a9mvwRyrdD49uj8R1Q9Tc4oJnviMpvcHRgUtD6xb36D1TeCer//1B5
ND6DM5p+ZzT3ukD5z6DyLnD3AQCYUqsj
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwUBLiEPa4oAjlczjEFgge
rLaA8QUcNt11/1WwQAHKF3FYbH334m5eGF/CgfX7VEODD3JQvozDPqe5bJv3
y0L5Cg4Sa4PrdE7JQPlKDqLri8+XFUtD+SoOjrmqVpmhUlC+msNvY+N14pmS
UL6Gw1XvQ1EPFSWgfC2H9/Z5ng9ZxaF8HYfKCSJXPRnFoHw9B4XHolMXR4pC
+QYOU1X/RjLMF4byDR1KMpbv8xcTgvKNHJ7pKxnnaQpC+cYOn//timxiF4Dy
TRz81vS5pm7lhfJNHSa0MO+4H8sF5Zs5nDhqW16yiwPKN3cIjzJaV6T03x7C
t3BgUtD6xb36D5Rv6WDc+/a744GfUL4VGt8aTb2NAzfz2qpXkz9C+bYO7y1/
/XPSe2YPAAvYbxk=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVweLF1SqTjcUUon8Nh8hUP
uzMqML6AQ9+D9bnr+xSgfBGHSwcLXnK9l4fyJRysi/Pqiw7KQfkyDvdWCa3p
cpeF8hUctMUvnmH9Jg3lKzn0nH7I9+CAFJSv4tA/MVqo+YIklK/mICmdnTE9
VwLK13DYfoDLff5rMShfy8FFlU/nviCMr+NwULlFg0FJFMrXcwjQX6BUIiEC
5Rs4bC4o/hxVIQzlGzpcsp/EIn5XEMo3cvB1O3b0ia0AlG/sULo7wMbiBx+U
b+KwwvHw0WOSvFC+qUNV/a+D2avYoHwzh+W7r4udkmGF8s0dfMzrtz/WY4by
LRy4mddWvZrMCOVbOhSvtrbftIgByrdyCI8yWlek9N8ewrd2YFLQ+sW9+g+U
bwPV/9EeANwuap8=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwWG7EUz//miKUz+Gwue+P
g7sTjC/gsFsp1GbnRgUoX8RhhvO9iHBxGF/CIUJZZq/9azkoX8YhtGk6y8TN
slC+gsPXXymzNGtkoHwlh4LIo1cPqElD+SoOoTa3UlRuSUL5ag4iZ++c/PdS
AsrXcOix+pfmXC4O5Ws51OlUzc77IArl6zhcZ2u/LvtJBMrXcygXnc3Qv0wY
yjdwMHSbtdPrrBCUb+iQVfJjG2M4jG/ksEzZ65bJIQEo39hB11YvZP8zXijf
xMG49+13xwOcUL6pw8THxdVO39mhfDOHwB5DbZZWFijf3AESvkxQvoUDN/Pa
qleTGaF8S4fwKKN1RUr/7SF8KwcmBa1f3Kv/QPnWDu8tf/1z0vsG5dvA+QA5
nW0m
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwmLRio6rLOUUon8PhlM2N
TdP1YHwBB0HW/xMaZylA+SIO4TH3X11hg/ElHFRK306vfCIH5cs4NGya1j79
iiyUr+DgqrD+yOITMlC+kkNZT+l8jxnSUL6Kw9J8Q2U1dykoX81hRZ1vnoe0
JJSv4XBEpLxS4ZM4lK/lMMNy97S3h8SgfB0HrWiLo/v8RaF8PQe5ncXb2k8L
Q/kGDoa7pNUflQpB+YYOJRnL9/mLwfhGDpbndi849kAAyjd2WC+9Zvslb34o
38TBOeSPGasbH5Rv6pB9Yse+yzu5oXwzhxNHbctLdnFA+eYOtfMu7xF7yAzl
WzhAwpsJyrd04GZeW/VqMiOUbwXlf7QHAGHZZlQ=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwEFlZ5uR/XhHK53CQ6Xq1
9ZARjC/gwHXraH7rbAUoX8ThjuG0OS5f5KF8CYcqyzvfXi+Rg/JlHLL3/+Bx
bpCF8hUc7jakZK0OloHylRyObzlxslJWGspXcRC7a7+rZJoklK/m0Pnn8rWN
zhJQvobDyalrAl9riEP5Wg4uqnw69wXFoHwdh3zG322rrEWhfD2HqE+3zVT/
CkP5Bg6aKuxPvrvD+IYOM/cvLw/VEYLyjRxi2BfNknYVhPKNHXiED5UXvOSH
8k0cVjgePnpMkhfKN3VQ9pp2LWoFF5Rv5tA2MduqWp4dyjd3gIQvE5Rv4RAe
ZbSuSOm/PQAOp1yJ
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVweHhNzybwviKUz+GQ3TW3
ebYPjC/gcH5lquTx9QpQvohD4td/+TwiML6EQ4SyzF7713JQvoyDbn+Cg8wc
WShfwUExe8HktBYZKF/J4UzVqcRF4tJQvorDxAf3nCUfSUL5ag79lY7LNE5K
QPkaDpUbA39oVIlD+VoO20+Ls/5JEIPydRwyU75W6KuLQvl6Dqe3bV1ZVCAM
5Rs47D3efv9HvRCUb+iwL0b1oBw3jG/kYHlu94JjDwSgfGOHHKcJe/kW8kH5
JkD9Vu80HvNA+aYOxr1vvzse4ITyzRzaJmZbVcuzQ/nmaHwLh9p5l/eIPWSG
8i0dwqOM1hUp/beH8K2g5v2E8q0d3lv++uek98weADribDU=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwWK5VxLvlkiKUz+HAPnvL
niobGF/AYW7xigyztQpQvoiDmFFMyAcpGF/CYVL2v0pWJXkoX8ZhityCtKc3
ZaF8BYcFfy26LVploHwlh9azVhvmtktD+SoO5+5uDr7bKQXlqzmo9l9x+1ko
CeVrODzfvsbQMEQCytdykOvIWvlFVBzK13HoqosTX/NFFMrXc9hqn/ajJkcE
yjdw6O5dqrqWWRjKN3T44f2Uo9FHCMo3ckidu4ypeoEglG/sIC3x+MXESQJQ
vomD58p1q1Tn8EP5pg68RUbWl5t4oXwzh4s7rn658YMbyjd3qKr/dTB7FRuU
b+FQvNraftMiBijf0sG49+13xwM/7SF8K4f3lr/+Oel9g/KtHbiZ11a9mvzR
HgAC121T
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQEf7MVCt+7emK3kABVwOFTjcUTtpiKUz+Fg8Py6
k6sjjC/goFs550vaSgUoX8Rh88rFGrsFYXwJh6gDl6JdmeWhfBmHD+u+thZd
kIXyFRzCEie0ey+TgfKVHPp5X81UCJOG8lUclj6q/8JVLwXlqzlMepuhUWct
CeVrOJxzj+P+KiMB5Ws5qNVcv3jYXRzK13FwUeXTuS8oBuXrOSTf3rNn+RsR
KN/AQedD37rt/cJQvqFDwbXPhxIVhaB8IwddQY2Psy4KQPnGDjlOE/byLeSD
8k0c9h63eqfxmAfKN3Vom5htVS3PDuWbOWxclz9FL5oDyjd3OHHUtrxkF4xv
gca3dIjSnuhxroIbyrdyOCv14dUUAS4o39rhw+aLf2tFOaF8G4faeZf3iD1k
hvJtHZgUtH5xr/5jD+HbOXAzr616NfkjlG/vEB5ltK5I6T+U7+CwfPd1sVMy
rBD9DQ4OOptZ2Mz6YO53dAjsMdRmaWWByjs6VNX/Opi9ig0q74Rqf4OTAyT9
MEHlnVHd0+Ds8N7y1z8nvW9Q+11Q3dPggibvCnc/ADP0qYM=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQEf7MVCt+7emK3kABVwmK1slNd9ThHK53AoVK7q
W2UE4ws4xE6MV5vRrwDliziotz6cFfJQHsqXcFjd+6Gopl8OypdxKPkrfja1
UBbKV3BYePiuhLaNDJSv5HD+5aP321ikoXwVB/ab51NuM0lB+WoOjBMu/XvZ
KAHlazhM688rWNUqDuVrOTxaeCVUQEoMytdxCJ4zRbrKUBTK13NIn8pUwmss
AuUbOLycVuS41l4Yyjd0SJ27jKl6gSCUb+TQbZR6Z3aCAJRv7OAc8seM1Y0P
yjdxuLjj6pcbP7ihfFM0vpnDNd6OjJ9+vFC+ucPEx8XVTt/ZoXwLB27mtVWv
JjNC+ZYOTApav7hX/7GH8K0cjHvffnc88BPKt0aTt0Hj2zqERxmtK1L6D+Xb
ocnbo/EdHIpXW9tvWsQAsb/BAU2/I6r6Bkeoez9C5Z0c3lv++uek9wwqD+N/
g8o7o8k7w/UDALPyoP4=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7MVCt+7emK3kABVwePGk0CXmriKUz+Egcd8i
0cgFxhdwYPzAGKSySgHKF3EQM13mt5EDxpdw6Kt/7WbAIA/lyzhM3cjC9vaB
LJSv4BBYMm3BlW0yUL6Sg+29GYdXLZeG8lUcPt713jatUgrKV3NQ7b/i9rNQ
EsrXcFD2LQ1riJWA8rUc2iZmW1XLi0P5Og6Ncy/ESxaIQfl6Dr/50u0PuopC
+QYOLSwnT3FMF4HyDR2EuMX3PNsjDOUbOeyLUT0oxy0E5Rs7FG9c3xlQJQjl
mzjo2uqF7H/GC+WbOmSf2LHv8k5uKN/Mwbj37XfHA5xQvrnDT51JNctzYHwL
h/eWv/456bFB+ZZofCsHH/P67Y/1mKF8awdu5rVVryYzQvk2DkwKWr+4V/+x
h/Bt0fh2DpD4ZIKqt0eTd4Da9w3Cb3CAmv8RKu8Idf9PqLwjmn4nVPUNTqjm
MTijqm9whso/g8q7wPkAWKihfQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVwMC/fZmV0QxHK53B4zet+
46QdjC/gwHXraH7rbAUoX8ShcNc335T38lC+hMOGJ4JMXxfLQfkyDgwmtTyP
y2WhfAWHC8/3Ra0wkIHylRzk/509bfFBCspXcZj44J6z5CNJKF/NYU9x5G+z
bRJQvoZDkWTu9bf14lC+loPgBD8GRyMxKF/HYenUYsGdDqJQvp7DAW2nt2uK
RKB8A4fu3qWqa5mFoXxDhxj2RbOkXQWhfCMH3hyh1x2FAlC+sUOO04S9fAv5
oHwTByYFrV/cq3mgfFOo+7mgfDOHqvpfB7NXsUH55g7Ld18XOyXDCuVbOEDC
mwnKt0STt3II7DHUZmllgfKtHYx73353PPDTHsK3ceBmXlv1avJHKN/W4b3l
r39Oet+gfDs09fYO4VFG64qU/kP5Dqj8Bgc09Y5Q857ZAwDVPIlZ
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7MVCt+7emK3kABVwuLzQu5rjjCKUz+Fw4F7G
Qj89GF/AwUbt/7OcaQpQvohD790pblNvyUP5Eg5Vlne+vV4iB+XLOGik3Zlv
YSAL5Ss4vApQvXRBTQbKV3KoOVCnek5CGspXcQi1uZWicksSyldz0Lq2Vohj
hgSUr+FwY2pC1JoLYlC+lkM+4++2VdaiUL6Ow7vcI1+NvwlD+XoOl+wnsYjf
FYTyDRxKdwfYWPzgg/INHZxD/pixusH4Rg7feHc2/jHlgfKNHSa0MO+4H8sF
5Zs46GxmYTPrY4fyTR2q6n8dzF7FBuWbOch7+FqKrWKF8s0dIOHLBOVbOHAz
r616NZkRyrd0CI8yWlek9N8ewrdCk7d2KF5tbb9pEQOUb4PGt0Uz3w5N3t7h
veWvf05636DmO0DN/wjhNzigyTs6GPe+/e544CdU3hFVPYMTqvoGJ1T1DM5o
8mh8Bhco/5k9AHRopnc=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw8LASXqt9XhHK53Bg8OMu
aLOH8QUc6pq4P76fpgDlizh0Hcrp33VdHsqXcNCNlbo8aYEclC/j0KXSksZT
JAvlKzhwSknGN2nKQPlKDvJJjb+n2kpD+SoOuUEztytISEH5ag77DRjlV/NL
QvkaDm/bOFe1dohD+VoOnP+mcFqbiUH5Og7axyW+LnkoAuXrOaiUM042ey8M
5Rs4COgYSp/7LwjlGzrwCB8qL3jJD+UbOSw5ubiMu4QPyjd2uMbbkfHTjxfK
N3HIPrFj3+Wd3FC+qUPbxGyranl2KN/MQd7D11JsFSuUb+5QvNraftMiBijf
wiE8ymhdkdJ/ewjf0oFJQesX9+o/UL4VmnprB+Pet98dD/y0BwA6yGBK
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw+PBlXiv3VUUon8NBctMq
pcWOML6Ag9Sitaf75ytA+SIOrBN9DwX/l4fyJRwOHF379dVOOShfxmHGdvdY
3wOyUL6Cg5hFA3ObpQyUr+QgFMcnespMGspXcbiVWiKXwiIF5as5bLv+2UTo
uASUr+EgKm6qfbZJHMrXclg5/9kG7VgxKF/HYenUYsGdDqJQvp6DSjnjZLP3
wlC+gUPvZk7tffeFoHxDh+KN6zsDqgShfCOHbqPUO7MTBKB8YwfeIiPry028
UL6JwzfenY1/THmgfFMHnc0sbGZ97FC+mYO8h6+l2CpWKN/coXi1tf2mRQxQ
voWDce/b744HftpD+JYO3Mxrq15N/gjlWzm8t/z1z0nvGZRvDeV/g/Jt0Pi2
cP0AicJw9w==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwkGSI9Gy/qAjlczhstO/5
5W0B4ws49Cxcfr9isgKUL+Kg+0dm3hNGGF/CgfX7VEODD3JQvoyD1zWZ060r
ZKF8BYfsczqcRRNloHwlB5416mu086WhfBWH78kWZye8loTy1RxeRpyteFch
AeVrOHzkCz2sqS8O5Ws57JefLTGXUwzK13GwziqakbBFBMrXc/iZWPy3casw
lG/gkFXyYxtjuBCUb+gg9OLAodVBglC+kUPkrLULRXUEoHxjB781fa6pW3mh
fBM0vqlD9okd+y7v5IbyzRzOSn14NUWAC8o3d3hv+eufkx4blG/hsHz3dbFT
MqxQvqVDVf2vg9mrYPJWDrXzLu8Re8gM5Vs7GPe+/e544Kc9hG/jwM28turV
5I9Qvi0a3w7OBwBRDHj6
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVwUA6tTf90QxHK53B43KfA
c8kRxhdwkPZT+79xoQKUL+Jw57l0+uy/8lC+hIO3ofFbrRtyUL6Mg9c1mdOt
K2ShfAUHqeXB079myED5Sg7rWc96vmCVhvJVHDKuyW3YvFQSyldz4D6gYK9f
LQHlazjwfpnz0nuOOJSv5eCQtO36pHIxKF/HQSva4ug+f1EoX8/hgLbT2zVF
IlC+gYPuc+kGLhYY39DhSMCB2Q27hKB8I4dvXevEY78IQvnGDpWax3+m+gtA
+SYORz/zB0cV8kD5pg4njtqWl+zigPLNHHQ2s7CZ9bFD+eYObROzrarlYXwL
h43r8qfoRcPUWzos331d7JQMK5Rv5cCkoPWLe/Ufewjf2uG95a9/TnrfoHwb
B27mtVWvJn+E8m2h8s+gfDs0eXsH49633x0P/ITyHVDVNzigqXdE5Teg8Rmc
4PoBY/KTEQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQEf7MVCt+7emK3kABVw+JB3rHnlGUUon8OBqZTx
zhITGF/AQSzM2rpokQKUL+JwoUPCh4EdxpdwUCl9O73yiRyUL+MwY7t7rO8B
WShfweHoZ/7gqEIZKF/J4Ufc+tQLHtJQvooDw+T2rplKUlC+mgO71rYesS0S
UL6Gw4KpHBzHL4lD+VoOigsaRRzPikH5Og6PG4U0CpJFoXw9Bw+vnlubIkWg
fAOH7t6lqmuZhaF8Q4do9/1cvzYIQflGDgmFsb9PvRCE8o0dNP2URVxzYXwT
h91SU+bufC8A5Zs68AgfKi94yQ/lmzmU7g6wsfjBB+WbO6xwPHz0mCQvlG/h
EKU90eNcBTeUb+nwYfPFv7WinFC+FRrf2mHjuvwpetEcUL4NGt/WQd7D11Js
FSuUb+fw3vLXPyc9NijfHk3ewaGq/tfB7FVQ+QYHh7aJ2VbV8uxQeUeHE0dt
y0t2Qc1vcEQzz8lh+e7rYqdkoOY1ODkE9hhqs7SyQOWdUfkNaHwGFzR5F4fi
1db2mxYxQOVdHSDpkQkq7wq1/5s9RN4Nyn8G4Te4OXAzr616NfkjVN4dTd4d
Td7Dwbj37XfHAz+h8h5w8wGNBL9Z
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwUBaw3zLhkiKUz+EQKbFy
wyJtGF/AQf0Dk8StBgUoX8Thy4HGBRwv5KF8CYfMuA0653bLQfkyDmwNIa9v
TJWF8hUcvt5/VCYeKwPlKznIOs1IKHWVhvJVHNhvnk+5zSQF5as5GCj8/Ge9
XALK13CQO3LvxyVfcShfy0Fwgh+Do5EYlK/j0F51pOLHHBEoX89BiFt8z7M9
wlC+gUPTk6TeJ2sEoXxDh2XKXrdMDglA+UYOvDlCrzsKYXxjh/8Mgf8TSvih
fBMHXVu9kP3PeKF8U4cJLcw77sdyQflmDhMfF1c7fWeH8s0ddDazsJn1wfgW
DrXzLu8Re8gM5Vs6hEcZrStS+m8P4Vs5GPe+/e544CeUbw3nAwBxQWm7
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwaPtpuODpNUUon8MhtkDw
YLUFjC/gUBTDP/XQLAUoX8Sh8mzf2d+sML6Eg1Ro0x+TR3JQvoyD05JrKyZ2
yEL5Cg7XYs9oaOXKQPlKDv28r2YqhElD+SoOwXEi3VM9pKB8NYdLJ24YrdaQ
hPI1HNxmc35cri0B5Ws5rLFecszrhRiUr+NwVSMncdl2UShfz0H3uXQDF4sI
lG/g4GNev/2xnjCUb+hwyX4Si/hdQSjfCI1v7BA5a+1CUR0BKN/EwXPlulWq
c/ihfFOHvcet3mk85oHyzdD45g5npT68miLABeVbOAT2GGqztLJA+ZYOxaut
7TctYoDyrRyMe99+dzzw0x7Ct0bj2zi8t/z1z0nvG5RvC+U/swcAkjxzdw==

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVw2LDyzs7T5xWhfA6HU7Kc
8+9pwfgCDgcXHtZln6MA5Ys4XDv6/AYjA4wv4TCZc90PQUZ5KF/Gwadpe0Pi
a1koX8HhZSTfFIfDMlC+koPMvAM3ey5KQ/kqDgvfx/O/mCgF5as5SHdarb+j
Ignlazjozdz0PvaPOJSv5bBy/rMN2rFiUL6OQ4/4hUnfCkWhfD2HqE+3zVT/
CkP5Bg4/lrDXPXEUgvINHYReHDi0OkgQyjdyeKavZJynCeMbO6yXXrP9kjc/
lG/ioGurF7L/GS+Ub+pwVurDqykCXFC+mYO8h6+l2CpWKN/cIbDHUJullQXK
t3DgZl5b9WoyI5RvCeV/tAcANophWQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwEDqwRejIXUUon8Ph8Kqk
cINIGF/AIXum9WHVgwpQvohDp7hdR68wjC/hUO7Rf34aizyUL+Og/OHBvit3
ZKF8BYd396T31HXIQPlKDjFpJ2JfxElD+SoO685XBlqZS0H5ag61K6eaR9tK
QvkaDreVsxYdV5OA8rUcbkxNiFpzQQzK13H4Xbig3jdDFMrXc4j6dNtM9a8w
lG/goKnC/uS7O4xv6PBGODL1W6cQlG/ksEzZ65bJIQEo39jBc+W6Vapz+KF8
EwcmBa1f3Kt5oHxTB53NLGxmfexQvhka39whsMdQm6WVBcq3cICENxOUb4nG
t3KonXd5j9hDZijf2oGbeW3Vq8mMUL6NQ3iU0boipf/2EL4tVP4jlG/n8N7y
1z8nvW9Qvj0a3wGuHgDB53rX
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwcPnZxhByWxHK53DY/CD/
8GUnGF/A4ebHY2a6yxWgfBGHDw/Mo/qFYHwJh6fr5S9I/JWD8mUcXjZOsFmz
ThbKV3B45/Dp7atNMlC+ksPDE6Ie76ukoXwVB0n331IqVlJQvprD5eMyzLfY
JaF8DYcDIqvZE1+JQ/laDkn7Hnz6t0UMytdxsMiyN+oVF4Xy9RyqKrWfX1MV
gfINHFxtn9Sc/yUE5Rs6ND1J6n2yRhDKN3JYpux1y+SQAJRv7LBees32S978
UL6Jw97jVu80HvNA+aYO2Sd27Lu8kxvKN3M4K/Xh1RQBLijf3GH2Ne6fy0xh
8hZo8pYO8v/Onrb4AONbOUDigwnKt3Yw7n373fHAT3sI38bhveWvf0563+wB
lV53Iw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw6Pm3d7v2dUUon8Nhcs93
0WO2ML6Aw9uqj1xZKxSgfBEH9+vbJ9znhPElHFIMuNc9+iYH5cs46D1T3Vkw
URbKV3B4vmfn/ORQGShfycH28Gmb45nSUL6Kg6T7bykVKykoX82BS7s5lvOD
BJSv4WDpfsVh03pxKF/LYc72d92ynDC+joPN14P3euJEoXw9h+qrlbwMCSJQ
voGD9+aPXoHmwlC+oUNCYezvUy8EoXwjh8//dkU2sQtA+cZofBMHXVu9kP3P
eKF8U4dvvDsb/5jyQPlmDhvX5U/Ri+aA8s0duJnXVr2azAjlWzhAwpsJyrd0
CI8yWlek9N8ewrdyMO59+93xwE8o39qBSUHrF/fqP1C+jcN7y1//nPSeQfm2
cD4AAFZ1Xg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwiNI2e+B5RRHK53D4mGfH
9t8Kxhdw2HWFT692pgKUL+KwdSGviQ0TjC/hEKEss9f+tRyUL+MwN3yD+8kt
slC+goOk+/zqwFkyUL6SQ1lP6XyPGdJQvoqD9rkXnH5+UlC+moOL+XvTKD1J
KF/D4fGdoMJGNgkoX8vhtGbeBpk/YlC+jkPlBJGrnowwvp7D8t3XxU7JiEL5
Bg6z/Bp/PeYSgfINHfYeb7//o14Iyjdy4Fr8I87tqCCUb+zwTF/JOE8Txjdx
kF3951qMOYxv6vD5367IJnYBKN/MYYXj4aPHJHmhfHOHCS3MO+7HckH5Fg7G
vW+/Ox7ghPItHeQ9fC3FVrFC+VYOxaut7TctYoDyrdH4Ng5MClq/uFf/sYfw
bR24mddWvZr8Ecq3c3hv+eufk943ewAQIXGr
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwUL79b6baJUUon8PhotAL
kxJHGF/A4SHXyaqPCxSgfBEHwwWyc5yYYXwJBxPpFesdj8hB+TIOQrHc4fpN
slC+ggNPpsxCfmkZKF/JQf7f2dMWH6SgfBWH833fep3mSkL5ag7nUzx8kldK
QPkaDhx1/dKn4sWhfC0Hna2LQ//sFoPydRxKdh5SOOwlCuXrOQhxi+95tkcY
yjdw6N3Mqb3vvhCUb+jg0lDx17BdEMo3cug2Sr0zO0EAyjd28Fy5bpXqHH4o
38QhSnuix7kKbijf1OGnzqSa5TmcUL6ZQ2CPoTZLKwuUb+5QvNraftMiBijf
Ao1v6RAeZbSuSOm/PYRvhca3djDuffvd8cBPewCEtmUJ
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQEf7MVCt+7emK3kABVwWK+deLXovCKUz+GQeMiV
L84axhdw4PLb0SKwQAHKF3HgWtl6dgcjjC/hcGpZSuaV23JQvowDT3R9wcGV
slC+gsOaDwf6kqJloHwlh5oDdarnJKShfBWHPuspmo1cUlC+msOktxkaddaS
UL6GQ3jaih+/mCWgfC2Hj3yhhzX1xaF8HQf2g8pzdN6IQvl6DpvWt8lJ3BGB
8g0c2OVYQo5cEobyDR2OBByY3bBLCMo3crAx8mnnSxCE8o0dhF4cOLQ6CMY3
cfB1O3b0ia0AlG/qsOTk4jLuEj4o38zBb02fa+pWXijf3CFKe6LHuQpuKN/C
4afOpJrlOZxQvqXDxMfF1U7f2aF8K4e2idlW1fIwvjWavI2DzmYWNrM+GN/W
4b3lr39OemxQvp1DVf2vg9mrYHx7NHkHh8AeQ22WVhYIv8EBTd7RoXbe5T1i
D5mh8o4O8h6+lmKrWKHyTg7Ld18XOyUD5Tc4oapncHaApCcmqLyzQ/Fqa/tN
ixig8i4OTApav7hX/7GHyLs4cDOvrXo1+SOEz+AKdc83qDyM/wwq74aqvsEN
Lg8AEl2xvg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw+KiVcOT6KUUon8Ph2n7T
qd26ML6AQ8jzpyd3TVaA8kUcXn6cV+v9Vh7Kl3BQfL5c48QpOShfxuGl1CtO
vUpZKF/BwUzaP53HVgbKV3KYrrvk0q5/UlC+ioNx79vvjgckoXw1hz2W7x2K
JkpA+RoOBR2zPhYWikP5Wg7q9wIXlrKKQfk6Dtr9buecTotA+XoO2RHsgcnT
haF8A4d9MaoH5biFoHxDh8hZaxeK6ghA+UYO/xkC/yeU8EP5xg7ZJ3bsu7yT
G8o3cZD/d/a0xQcuKN/UYfY17p/LTGHyZmjy5g4njtqWl+zigPItHDauy5+i
Fw3jWzq0Tcy2qpZnh/KtHGrnXd4j9pDZAQBBoWgt
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwOLCv9ZfnJUUon8OBn8uc
/6cejC/gMKcy6tHS2QpQvojDYuu7F3fzwvgSDmvjV9zLOi8H5cs46Ip9XDy9
TBbKV3A43V8qWZ8gA+UrObDsKbhhzicN5as4rNeWs3D5IAnlqzmUWFp1CC+V
gPI1HGQW5D4P2SsO5Ws53JiaELXmghiUr+PwlHXat+3TRaF8PQehtVczP9SJ
QPkGDt29S1XXMgtD+YYOLg0Vfw3bBaF8Iwf78C8xftIwvrHDf4bA/wkl/FC+
icPsa9w/l5lyQ/mmDjqbWdjM+tihfDOH8CijdUVK/+0hfHM0vgUa39KBSUHr
F/fqP1C+lcN7y1//nPSeQfnWcD4AHsVpPA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVw2G+6Skb2qiKUz+FweWbX
sShdGF/A4bk//z3mqQpQvohDfKhj010GGF/CQfH5co0Tp+SgfBkHpyXXVkzs
kIXyFRy+/kqZpVkjA+UrOXycs5ezzl8ayldx2JDgY77NVQrKV3PY5NjZ9PO/
BJSv4dCz6/2tuG5xKF/L4dHCK6ECUmJQvo6DQWzz8r0rRKB8PQe5ncXb2k8L
Q/kGDo/3/G3QNheC8g0dildb229aJADlGzn8Zwj8n1DCD+UbO3zj3dn4x5QH
yjdxOHHUtrxkFweUb+rwU2dSzfIcTijfzGHi4+Jqp+/sUL45mnoLh6r6Xwez
V7FB+ZYOy3dfFzslwwrlWzkE9hhqs7SyQPnWaOptHCDxxQTl26Lx7RyYFLR+
ca/+Yw/h2zu8t/z1z0nvmT0AywB9SA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw4BWbGyB6UxHK53DQ1T95
/oUnjC/gUL/tqq7GdgUoX8Th8L9ARQ4tGF/CYb9GxMuHkvJQvoxD8lzpDzJv
ZaF8BYfIhi02KTtkoHwlB9H1xefLiqWhfBUHhsntXTOVpKB8NYdLJ24YrdaQ
hPI1HOQX9zap+0pA+VoOc+Wm7pttJw7l6zjMUtjK/+y5KJSv5xA8Z4p0lSGM
b+AQ1+H20vaIMJRv6LBwyQnR/mtCUL6RQ9OTpN4nawShfGMHX7djR5/YCkD5
Jg7XeDsyfvrxQvmmDspe065FreCC8s0c2iZmW1XLs0P55g7Ld18XOyXDCuVb
OBSvtrbftIgByrdE41s5GPe+/e544Kc9hG/t8N7y1z8nvWdQvg2U/80eAJ+/
bgA=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwuCApsvz3KUUon8Mhji/W
ZbE+jC/g8HDutMTkVQpQvojDGd55D2VYYHwJhwmBS4XrrshB+TIO+tsddzdt
kIXyFRy23Nw2pz1EBspXcrjGUZfsLyMN5as4rNeWs3D5IAnlqzmInL1z8t9L
CShfwyHee4/DnkPiUL6Wg+AEPwZHIzEoX8dh0/o2OYk7IlC+nkNk/CGPqAhh
KN/AoSRj+T5/MSEo39DB8tzuBcceCED5Rg6f/+2KbGKH8Y0dVjgePnpMkhfK
N3H4xruz8Y8pD5Rv6nDiqG15yS4OKN/MIbDHUJullQXKN3dgUtD6xb36jz2E
b+Hw3vLXPye9Z1C+JRrfCo1v7cDNvLbq1eSPUL4NGt8Wrh4AdNd02A==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwOM9X8lDyvCKUz+FQ8n5N
d681jC/gcNAreD/vJAUoX8ThzIz9PgUf5KF8CYfsjkNhIcvloHwZh8bCNXuX
lshC+QoODUx3XvG7yED5Sg7vv/p9+aYgDeWrOBieU9nB+0MSyldzqJMVX/rp
qQSUr+GwfPWVG9/fiEP5Wg5yHVkrv4jC+DoO918vLw2fIwrl6zn0FZSuig4W
gfINHI4EHJjdsEsIyjd04GZeW/VqsiCUb+TguXLdKtU5/FC+scO2DxP0pc7y
QfkmDqttlDI0DsPkTR2u8XZk/PTjhfLNHJS9pl2LWsEF5Zs7vLf89c9Jjw3K
t3BYvvu62CkZVijf0uHEUdvykl0cUL4VmnprqPsYoXwbB+Pet98dD/y0h/Bt
oeqfQfl2cD4A06x9TQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVwePtlgkDeWUUon8NBUXKr
z1FTGF/AYdNd918FCxSgfBGHpm6HOxbCML6EQ/476yvPWeWhfBkHkYDYw+KP
ZKF8BQc7ab+LxutkoHwlhwI3l8r2NGkoX8Vhn81t88vZUlC+mkPWVVfWuYKS
UL6GwxxBe7aLP8WhfC0HnpXmgXvmi0H5Og5mb57dXcMuCuXrOczya/z1mEsE
yjdwMHSbtdPrrBCUb+ig6acs4porCOUbOTzTVzLO04TxjR3+MwT+Tyjhh/JN
HK7xdmT89OOF8k0dJrQw77gfywXlmzn81JlUszyHE8o3d5D38LUUW8UK5Vs4
BPYYarO0skD5lg6Q8GeC8q0cildb229axADlWzsY97797njgpz2Eb+PApKD1
i3v1HyjfFk3eDo1v7/De8tc/J71nUL4DlP8Nwm9wQFPv6MDNvLbq1eSPUHk0
PoMTnA8AGomPFw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw2KLqfPnPWUUon8OhTX2f
w20LGF/AIff+ilczZihA+SIO8emSk05+kIfyJRz4GbaGLNwnB+XLOPz+toJ1
WroslK/gUN2oMfGVqgyUr+QQL3DxOcN7KShfxeH0Jcv/O5MloXw1h5Jbi08I
3hCH8jUcZq086Px1rRiUr+WgUnjx5k9RGF/HQfu4xNclD0WgfD2HpBNKu4wb
hKF8A4eEwtjfp14IQvmGDoJvRMQ+iPFB+UYO2Sd27Lu8kxvKN3b4sPni31pR
TijfxOG95a9/TnpsUL6pAyT8mKB8MwcmBa1f3Kv/2EP45mh8C6j+Z1C+JRrf
Csr/BuVbo/Ft4OoBFzt5lg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVweGx7dgXfOUUon8PhT/fH
Xzx2ML6Awy33dY/uzVSA8kUcCv718r7+Iw/lSzjY3Z4ixnBLDsqXcQi81SBV
tFYWyldweHdPek9dhwyUr+Rge/i0zfFMaShfxUH6aHA+i5cUlK/mcNxxA9ej
QxJQvoaDzILc5yF7xaF8LYfbx7fcul4sBuXrOGhFWxzd5y8K5es5LH7SmuSc
JgLlGzhMVf0byTBfGMo3dNh7vP3+j3ohKN/IYZmy1y2TQwJQvrHDtg8T9KXO
8kH5Jg6zr3H/XGbKDeWbOrRNzLaqlmeH8s0cIOHJBOWbOzApaP3iXv3HHsK3
cDDuffvd8cBPKN8SjW+Fxrd2eG/565+T3jco38aBm3lt1avJH6F8W6j8M3sA
9HB8Og==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVwqOO3m7f4rCKUz+HwPvTS
d391GF/AYcc1j1WmPQpQvoiDasgcxXOP5aF8CYcXH28x6W+Vg/JlHDSuz1jG
3CsL5Ss42Nb63PXvlIHylRwY30/+8z9eGspXcVh3vjLQylwKyldzcHctyWT+
IwHlaziIWSkU8dSKQ/laDlMbbBcLOolB+ToOCo9Fpy6OFIXy9RziOtxe2h4R
hvINHAR0DKXP/ReE8g0d7MO/xPhJw/hGDqttlDI0DvND+cYOOU4T9vIt5IPy
TRx0bfVC9j/jhfJNHa7xdmT89IPxzRy2fZigL3UWpt7cYe9xq3caj3mgfAsH
3iIj68tNMPWWaHwrh+wTO/Zd3skN5Vs7nDhqW16yiwPKt3E4K/Xh1RQBLijf
1uGnzqSa5TmcUL6dg85mFjazPnYo396heLW1/aZFDFC+gwMkvpkg/AYHByYF
rV/cq//YQ+QdHYx73353PPATwm9wdOBmXlv1avJHqLyTw3vLX/+c9J7ZAwBD
zonc
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQEf7MVCt+7emK3kABVw+Mo459DHy4pQPoeD7acV
2n/sYXwBB81UgTVHVypA+SIO+y9duBjFAeNLOGQoa09mfSIH5cs4MG2JjPg9
VxbKV3AocfSVbyuVgfKVHI4KZbdwe0tD+SoO+8KuPVH7LQnlqzlwd5tXrt0n
AeVrOFRuDPyhUSUO5Ws5XM65s/NEihiUr+Ng8/XgvZ44UShfz+FnYvHfxq3C
UL6BQ0yzcdSNF0JQvqFD6txlTNULBKF8IwfeHKHXHYUCUL6xg3PIHzNWNz4o
38Rh9jXun8tMuaF8U4dvvDsb/5jyQPlmDlHaEz3OVcDkzR10NrOwmfWxQ/kW
Dst3Xxc7JcMK5Vs6cDOvrXo1mRHKt0LjWzuERxmtK1L6bw/h2zgwKWj94l79
B8q3dTDuffvd8cBPKN/OoXi1tf2mRQxQ/fZo6h1QzWtA4zM4oqpvcIS65yNU
3snhveWvf056z6DyCD4ApiiTVA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw4L1yL6vmmiKUz+HAo3RD
R8MexhdwWOCUevvjYgUoX8Sha5XxkwQuGF/CoUurZ4/OGTkoX8aBoW+20PQp
slC+gsMjfv6XG0pkoHwlh8Kp6xe9DpaG8lUcnkw90vxCXwrKV3NQlcmIXhQo
CeVrOMgat1+VT5KA8rUc1oewsHx8Jwbl6zic/vWiq22pKJSv5xDMYHFuo6AI
lG/gEO2+n+vXBiEo39BB6MWBQ6uDBKF8IwdpiccvJk4SgPKNHY5+5g+OKuSB
8k0cLu64+uXGD24o39Rh73GrdxqPYfJmDhNamHfcj+WC8s0dJj4urnb6zg7l
Wzj4mNdvf6zHDOVbovGtHMKjjNYVKf23h/CtHbiZ11a9mvwRyrdB49ui8e0c
3lv++uek98weAK8zeJI=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVwEJ+25sSt64pQPoeDx9ds
6TInGF/AQUNwT3vAUgUoX8ThuWDT6vksML6Ew7YPE/SlzspB+TIOEr2Zero5
slC+gsNvVm2pmfIyUL6Sw7z3OitFvkpB+SoOZ8yec4XelYTy1Rz+T9uZ/Oih
BJSv4WD1+nHD+mniUL6WQ+PcC/GSBWJQvo7DOtnLSlrPRaB8PYdfP5wXlevA
+AYO0x/2MN77KATlGzoI6BhKn/svCOUbOby+o96i3yQA5Rs7MClo/eJezQPl
mzhsXJc/RS+aA8o3deBmXlv1ajIjlG/m8N7y1z8nvW/2EL65g3Hv2++OB37a
AwA9MFrf
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQEf7MVCt+7emK3kABVwmPPS7abULUUon8PhjMx3
galBML6Aw+kvSu0PtitA+SIObmWxW++IwvgSDv6bn0qkvpOD8mUcHF45XAtd
JAvlKzhIzQ4tWxovA+UrObyStri5WE4ayldx4PpvnPXmniSUr+YgXOB9MK9W
AsrXcNgpE5l7QlUcytdyWHH78NS510ShfB2HvoLSVdHBIlC+nsPJShebFDVh
KN/A4VvXOvHYL4JQvqEDj/Ch8oKX/FC+kUOU9kSPcxXcUL6xw0+dSTXLczih
fBOH95a//jnpsUH5pg7Fq63tNy1igPLNHMKjjNYVKf23BwCKCVYy
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwYLd4UPXknCKUz+GwUPrR
MxdzGF/AoSgoT3biAgUoX8QhclG12HRpGF/CQWxZs8Hvv3JQvozD5abb0TWz
ZaF8BYf9V0utDYpkoHwlhyrGbU9nBkhD+SoOjrmqVpmhUlC+mkNFg+D08osS
UL6GQ/GUdbWcB8ShfC2HsGWzjcJ5YHwdh5Xzn23QjhWD8vUc4s1s2e6eFYXy
DRycDgbLacuLQPmGDhD/C0H5Rg67pabM3fleAMo3dhB8IyL2QYwPyjdx8FvT
55q6lRfKN3WQ/3f2tMUHLijfzOGs1IdXUwRgfHOH95a//jnpsUH5FlD7mKB8
S6j8M3sAdRxfTQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVweKL/cm7LeUUon8NhR3/m
shgTGF/A4fUKI+lPCxWgfBGHf7cz5z3jhfElHHQdnBonPpaD8mUc5EVfH/LY
KwvlKzhciZSRL18pA+UrObSetdowt10ayldxcMxVtcoMlYLy1RxufFiweG+x
JJSv4XDOPY77q4wElK/l0DYx26paXhzK13HoqosTX/NFFMrXczB78+zuGnYY
38DhXGLEx883haF8Q4fu3qWqa5lhfCOHx3v+NmibC0H5xg66ghofZ10UgPJN
HJxD/pixuvFB+aYO13g7Mn768UL5Zg46m1nYzPrYoXxzqPtgfAuHiY+Lq52+
w/iWDvIevpZiq1ihfCsHH/P67Y/1mKF8awcmBa1f3Kv/2EP4Ng7czGurXk3+
aA8ATAFqRA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwcMj+JXvuoiKUz+Hg/vOi
2ltXGF/Awd20LvLDfAUoXwTIP7x2giCML+Fw80u843RueShfxiF8it/Rruuy
UL6Cg9bjQ4cbq2SgfCWHgzH/7yX6SUP5Kg7/QsVku29IQvlqDrLG7VflkySg
fA2HlKfFWzqtxaF8LYeSXyuVDK3EoHwdh76C0lXRwSJQvp7DD++nHI0+QlC+
gQM389qqV5MFoXxDh2XKXrdMDglA+UYOATlap79KwvjGDkc/8wdHFfJA+SYO
yl7TrkWt4ILyTR02rsufohfNAeWbOch7+FqKrWKF8s0dfMzrtz/WY4byLRze
W/7656T3zR7Ct4Tyn9kDAE4RYMc=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwmOGm+7LwliKUz+HwdHun
noUtjC/gcHHPn3WdKxSgfBEHHls1fn4eGF/Cwbo4r77ooByUL+NwfLESa3mz
LJSv4NB6W18zukwGyldyCNiupWjuLA3lqzhky+SbzLCWgvLVHCzLQx6z/ZKA
8jUcFkzl4Dh+SRzK13JY1MizaUmgGJSv47BpfZucxB0RKF/PQYhbfM+zPcJQ
voHDjyXsdU8chaB8QweXhoq/hu2CUL6Rw2obpQyNw/xQvrFDeJTRuiIlGN/E
4RpvR8ZPP14o39ShbWK2VbU8O5Rv5lA77/IesYfMUL65g3Hv2++OB37aQ/gW
aHxLh/eWv/456X2D8q3Q5K0dmBS0fnGv/gPl20DVP7MHAFkibGQ=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwSE/2n8h4TRHK53D43VY9
Ybc+jC/gUMk7a/2biQpQvohDHeeCVE5GGF/CQfzvJV6Xi3JQvozD5S9pO7r7
ZaF8BYevdvuF17nJQPlKDvECF58zvJeC8lUcJKQ2qjc/kITy1Ry4u80r1+6T
gPI1HIQPK+qKzxeH8rUcGl8q7n/kKQbl6zhkpnyt0FcXhfL1HKaq/o1kmC8M
5Rs4eG/+6BVoDuMbOnAt/hHndlQQyjdyUHRM7yz9JwDlGzvwCB8qL3jJD+Wb
OIRHGa0rUoLxTR2u8XZk/PTjhfLNHC7uuPrlxg9uKN/cYeLj4mqn7+xQvoVD
28Rsq2p5GN8STd7KoXbe5T1iD5mhfGsHJgWtX9yr/9hD+DYO7y1//XPS+wbl
2zpwM6+tejX5oz0AOU5wbQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwUFkQbW5xUxHK53C4+Y29
ytADxhdwuH1Bfd6MHQpQvoiD41Jhg/s6ML6Eg/QJ51PFkvJQvozDTdnXEfm/
ZaF8BYe3RX+n82yTgfKVHCpuBz7oKJGG8lUcXj2+8ENeTgrKV3PQbbwZx/1F
AsrXcGj5fyeIjRPG13L4yBd6WFNfHMrXcSj5tVLJ0EoMytdzuM7Wfl32kwiU
b+Awt+FqFf86YSjf0OGS/SQW8buCUL6RQ+SstQtFdQSgfGOH0t0BNhY/+KB8
EwfeIiPry028UL6pQ/aJHfsu7+SG8s0c3lv++uekxwblmzvIe/haiq1ihfIt
HHzM67c/1mOG8i0dildb229axADlW0H1f7OH8K2h/Gf2ACAtaTM=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVw0Oma9XrhKUUon8Ph6fZO
PQtbGF/A4XCHyLz3SxWgfBGHHgHdDVxcML6EA+v3qYYGH+SgfBmH83oBRzyX
y0L5Cg7zUkQdD3XLQPlKDumyvUUXYqWhfBUH/TAT5U9fJKF8NQdFicS/Z+9K
QPkaDqJ+aebPtotD+VoO+3YJcXyYIgbl6zhoRVsc3ecvCuXrOZxLjPj4+aYw
lG/gAPGvEJRv6KDppyzimisI5Rs58AgfKi94yQ/lGztkn9ix7/JObijfxOGn
zqSa5TmcUL6pw4fNF//WisL4Zg618y7vEXvIDOWbOyzffV3slAwrlG/h4GNe
v/2xHkze0oGbeW3Vq8kf7QG6aGDd
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw2PXkdZ/KBUUon8Ph8KuQ
mQL2ML6AQ1LDBLuNCxSgfBGH54JNq+ezwPgSDgePPG44dU0OypdxkFjw92hi
qyyUr+DgvkOnYG27DJSv5FDg5lLZniYN5as45AbN3K4gIQXlqzn8n7Yz+dFD
CShfw+HHdu5wmRPiUL6WA9sH/msTM8SgfB2H/N5KSeHJolC+nkMMh1TDDEsR
KN/AwXvzR69Ac2Eo39Ahde4ypuoFglC+kQOP8KHygpf8UL6xw5KTi8u4S/ig
fBOHa7wdGT/9eKF8U4fZ17h/LjPlhvLNHNomZltVy7ND+eYO3Mxrq15NZoTy
LdD4lg7vLX/9c9L7Zg/hW0H5z+wBNCJlQg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwmF1xLSj0tCKUz+Fwzsgp
Nl4Dxhdw2NSbsPvlVAUoX8SBZ0rLk4Zf8lC+hEPw0XVhtw7JQfkyDkz/Fu6f
Vy8L5Ss4KDHp7GCpkIHylRwOtUlHhURIQ/kqDtky+SYzrKWgfDWHkg+Ge4Uc
JaF8DYf/WckdJ56LQ/laDqwlstr1O8SgfB2HD4GX+6eaiUL5eg7BDBbnNgqK
QPkGDtsLlkXqiQpD+YYOhruk1R+VCkH5Rg7dRql3ZicIQPnGDktOLi7jLuGD
8k0cZl/j/rnMlBvKN3X4sPni31pRTijfzKF23uU9Yg+ZoXxzh+LV1vabFjFA
+RYOkPBmgvIt0fhWaHxrB27mtVWvJjNC+TZo5tk6MClo/eJe/ccewrdzeG/5
65+T3jco3x6N7+Bg3Pv2u+OBnxB+gwNU/hlU3hHVvAZHqP0f7QFs2Itl
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwcPwSEeV3TxHK53BIPOTK
F2cN4ws4WHzlbe5bpgDliziImS7z28gB40s4qGbNNcsUlofyZRw0ksUtc57I
QvkKDqEHmG0blspA+UoOX+QuT7nVIw3lqzgEcDH23k+RgvLVHBbMtFRrj5GE
8jUcrl+tPdVlIwHlazncPr7l1vViMShfx8FMinPxxwWiUL6eg0Fs8/K9K0Sg
fAOHuQ1Xq/jXCUP5hg6R8Yc8oiJgfCOH4o3rOwOqBKF8Y4fXd9Rb9JsEoHwT
h73Hrd5pPOaB8k0dlL2mXYtawQXlmznobGZhM+tjh/LNHd5b/vrnpMcG5Vs4
QMKbCcq3dAjsMdRmaWWB8q0cjHvffnc88NMewrd2YFLQ+sW9+g+Ub4Mmb+sQ
HmW0rkjpP5RvhyZvD7X/G5Tv4MDNvLbq1eSPEH4Dgg8AJY2BbQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwaLg95478bUUon8Phnm1S
3U0bGF/AwYGl+JjgEgUoX8Qh8eu/fB4RGF/CoVP2EvOjX3JQvoyD69vcTf6H
ZaF8BQfnLfHnjq2XgfKVHFJ+PJkzYZE0lK/ioLlm4qNdRVJQvpqDztIF4lo9
klC+hsPz7WsMDUMkoHwth/UhLCwf34lB+ToOE2Uz38x6LArl6zkYxDYv37tC
BMo3cGg6Hh77ywfGN3RwtX1Sc/6XEJRv5MDNvLbq1WRBKN/YYcnJxWXcJXxQ
vonDN96djX9MeaB8Uwfj3rffHQ9wQvlmDieO2paX7OKA8s0dlu++LnZKhhXK
t3CAhDcTlG/pULza2n7TIgYo3wqNb+3ApKD1i3v1H3sI3waNb4vGt4O6/6M9
AIbtd8k=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQEf7MVCt+7emK3kABVwOJ+wOaPnjiKUz+Hw5SBD
SoULjC/g4PH0vs6tGQpQvoiDX7rp/t//5KF8CYd7rP95/6+Tg/JlHJStJs/o
qJCF8hUclsn+46/JloHylRyucdQl+8tIQ/kqDtyiV0v2T5GE8tUcHvzawbC2
XgLK13DQ2czCZtYnDuVrOayc/2yDdqwYlK/jkOSnueIfjyiUr+fwM7H4b+NW
YSjfwMFwl7T6o1IhKN/Q4eQ1lS+/eQShfCOHUs0pkydtEoDyjR381vS5pm7l
hfJNHL7x7mz8Y8oD5Zs6KHtNuxa1ggvKN3M4cdS2vGQXB5RvDnUvO5Rv4VA7
7/IesYfMUL6lAyT8maB8K4fi1db2mxYxQPnWaPI2Dsa9b787HvhpD+HbovHt
0Pj2DkwKWr+4V/+B8h1QzWtwcAiPMlpXpPQfKu+Ian+DI5q8kwM389qqV5M/
QvgNTmjudYbKM0L1O6PJu6C6p8EFzb2uDu8tf/1z0vsGlXdFtY/BDSr/DCqP
xmdwh/MBLJTAjA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwyLz2uGzrWUUon8NBgfHi
FSVLGF/AYUZD0vGoNQpQvoiDl+59m3QZGF/C4aSD6+/Dn+WgfBkH0danV6UP
yUL5Cg5crHZOZzNloHwlh/AkrxPxxtJQvopDG7u9Ap+6FJSv5iCUHXKL7Z0E
lK/hoLOZhc2sTxzK13JoKLX/YqUmBuXrOCT5aa74xyMK5es5yO0s3tZ+WhjK
N3B4NNvM9PZkISjf0IFr8Y84t6OCUL6RQ/Fqa/tNiwSgfGMH3iIj68tNvFC+
iYP8v7OnLT5wQfmmDj91JtUsz+GE8s0c2iZmW1XLs0P55g618y7vEXvIDOVb
OPiY129/rAfjW0LtY4DyrRyMe99+dzzw0x7Ct3Z4b/nrn5PeMyjfBo1v68DN
vLbq1eSPUL4dVP4blG+PJu8A1w8AiKR94g==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwaJRx37/yqiKUz+GwLrlt
/xVrGF/AoeRVeuaiVQpQvojDBE8DR3U2GF/C4Z9gtpD9aTkoX8Zh672bTzYV
yUL5Cg4HPy8sllWRgfKVHFT/d0/8KSkN5as4JDh/sGr4Jgnlqzk8+LWDYW29
BJSv4TBXbuq+2XbiUL6Ww6OFV0IFpMSgfB2Hi2vOf1bJFYXy9RwC9BcolUiI
QPkGDoZus3Z6nRWC8g0dZFf/uRZjLgjlGzlUah7/meovAOUbOziH/DFjdeOD
8k0clpxcXMZdAuObOvzUmVSzPIcTyjdzeG/565+THhuUb+7Azby26tVkRijf
Asr/aA/hW0LVP4PyreB8AJOhaBE=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwSK24NOHQNUUon8Ph+eXA
p55GML6Aw9MSMzWhRQpQvoiDwGXdVx/fyEP5Eg6LM99HpS+Vg/JlHHKZaycF
2spC+QoOMZ9eCX3/Jg3lKznkFz05n7tECspXcdBZukBcq0cSyldzWOtx61kR
owSUr+Ewa+VB569rxaB8LYf7r5eXhs8RhfJ1HOR2Fm9rPy0M5es5eG/+6BVo
DuMbOMzcv7w8VEcIyjd0KF5tbb9pkQCUb+Sw2kYpQ+MwP5Rv7FC6O8DG4gcf
lG/icHHH1S83fnBD+aYOOptZ2Mz62KF8M4eq+l8Hs1exQfnmDtzMa6teTWaE
8i2g9jFA+ZYOkPBngvKtHN5b/vrnpPfMHgCZVGlQ
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw+FYnYahyShHK53BYb5+/
VcYAxhdwuLPwWJr0TAUoX8SB4bdN2AVWGF/C4cK37wsMnstB+TIOUzeysL19
IAvlKzj8LPTMcNkqA+UrOZT1lM73mCEN5as4LJNl7bscJgXlqzkoSiT+PXtX
AsrXcPifldxx4rk4lK/lsLtnwvLqjWJQvo7DVY2cxGXbRaF8PQeZ2xEOAhNF
oHwDB00V9iff3YWhfEOHaPf9XL82CEH5Rg5XUr9xauwUhPKNHQJytE5/lRSA
8k0cBN+IiH0Q44PyTR381vS5pm7lhfLNHKK0J3qcq+CG8s0dNq7Ln6IXzQHl
Wzi0Tcy2qpZnh/It0fhWDj7m9dsf6zFD+dYO4VFG64qU/ttD+DYO7y1//XPS
e2YPAJtgamQ=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwUA6tTf90QxHK53AQf7ZQ
mNUUxhdwYN/5qcVuigKUL+Jw8biWK/d3eShfwuH1ef0k2cdyUL6Mg/52x91N
G2ShfAWHptCwZdH+MlC+kkPY9QNssiLSUL6KQ2Vwl86J/5JQvprD4eVb5pjP
koDyNRwyqu+lLWISh/K1HFQKL978KSoG5es4mE0+kuEpJArl6znMbbhaxb9O
GMo3cCi49vlQoqIQlG/oYHlu94JjDwSgfCMHwTciYh/E+KB8Y4co7Yke5yq4
oXwTB+Pet98dD3BC+aZofDOHE0dty0t2cUD55g4+5vXbH+sxQ/kWDkwKWr+4
V/+xh/AtHcKjjNYVKf2H8q0cuJnXVr2a/BHKt0bj2zi8t/z1z0nvmT0A8o1u
LA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwyDziovjgsiKUz+HgU1l4
yMkBxhdwOLjwsC77HAUoX8Thr5et2iNhGF/CIXCNy0bpn3JQvozDvytTJtyc
LwvlKzi0cnD8WZsvA+UrOUj65qceEpSG8lUc9oVde6L2WxLKV3OwE1Nd8+uI
BJSv4SDql2b+bLs4lK/loLN1ceif3WJQvo5D6E3Wzo5qUShfz2Hxk9Yk5zQR
KN/AIdp9P9evDUJQvqHDM30l4zxNQSjfyGG1jVKGxmF+KN/Y4RvvzsY/pjxQ
vomDste0a1EruKB8U4cTR23LS3ZxQPlmDjqbWdjM+tihfHM0voVD28Rsq2p5
GN/SYfnu62KnZFihfCsHJgWtX9yr/9hD+NYO3Mxrq15N/gjl2zi8t/z1z0nv
G5RviyZvh8a3h/MBN8V2sw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwuFylfzr9nCKUz+GwYKWH
h7IxjC/gsK1bOHDlCgUoX8RhHSu/UBsHjC/hYHk+zr70lhyUL+Nwx4yH8+4u
WShfwaFNTOmqYZIMlK/kUKElUrw1UBrKV3Fo7ZxnK6MoBeWrOXwXshRTkJeE
8jUcMhaJq7aLSkD5Wg7zeKZvE7kiBuXrODS3HL4z/YAolK/nINBemHJ/kQiU
b+CwuaD4c1SFMJRv6HDJfhKL+F1BKN/IIcdpwl6+hXxQvrHD3uNW7zQe80D5
Jg5npT68miLABeWbOizffV3slAwrlG/mUDvv8h6xh8xQvrkDN/PaqleTGaF8
C4fwKKN1RUr/7SF8S4f3lr/+Oel9g/Kt0OStofo/Qvk2UPXP7AGBBmmP
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwMHwwZ27ncUUon8NBpOXa
5h5zGF/AwaDaT+buagUoX8ThyVbD5FfSML6EQ8mc3ozpEvJQvoxDUpXByruf
ZKF8BQfVvF3a11bLQPlKDiyd/VmrOqShfBWH3KCZ2xUkpKB8NQeFl5u33rgv
AeVrOFi6X3HYtF4cytdyqKr/dTB7lRiUr+OwfPd1sVMyolC+nkP11UpehgQR
KN/AYXNB8eeoCmEo39CBLZRx84fDQlC+kUOp5pTJkzYJQPnGDr5ux44+sYXx
TRycQ/6YsbrxQfmmDvL/zp62+MAF5Zs56GxmYTPrY4fyzR3aJmZbVcvD+BZo
fEs09VYO8h6+lmKrWKF8a4fwKKN1RUr/7SF8GzS+rQM389qqV5M/Qvl2Du8t
f/1z0ntmDwAMtXDU
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwuGy9I/TFFUUon8NhdheD
o68BjC/gIDCrim9ZswKUL+IgYWZae+qyPJQv4ZDjNGEv30I5KF/G4flN9Sae
WlkoX8FBanZo2dJ4GShfyYFlT8ENcz5pKF/F4eDmRUeYtaSgfDWH+NyN82dc
lYDyNRw46vqlT8WLQ/laDg2l9l+s1MSgfB0Hm68H7/XEiUL5eg4xHFINMyxF
oHwDh5OVLjYpasJQvqGDffiXGD9pQSjfyOE/Q+D/hBJ+KN/Y4RvvzsY/pjxQ
vomDce/b744HOKF8U4eJj4urnb6zQ/lmDtzMa6teTWaE8s2h/I/2EL4FGt/S
4b3lr39Oes/sAbS8Xq8=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwEFlZ5uR/XhHK53CYIf5Q
9rMFjC/gwO0VXXlungKUL+LwJ7+cteajPJQv4VBz4mVFwlQ5KF/GIZe5dlKg
rSyUr+DQ8zN19m9dGShfyUF48sJdK59LQfkqDi12ibr8KyWhfDWHD+rH5Vgz
JaB8DYdIJYsFN8LEoXwth666OPE1X0ShfB2HFpaTpzimi0D5eg5TVf9GMswX
hvINHLgW/4hzOyoI5Rs6rJdes/2SNz+Ub+Rwjbcj46cfL5Rv7BClPdHjXAU3
lG/ikH1ix77LO2F8Uwf5f2dPW3zggvLNHNomZltVy7ND+eYOEx8XVzt9h/Et
HKrqfx3MXsUG5Vs6LN99XeyUDCuUb4Umb40mb+NQvNraftMiBijf1uG95a9/
TnrP7CF8Oyj/G5Rv72Dc+/a744GfUL4DqnyDgwOTgtYv7tV/oPKODtzMa6te
Tf4IlXeEmw8ArSeQLw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwOLCv9ZfnJUUon8MheWq6
B4sFjC/gcGfhsTTpmQpQvohD2H7J1vKf8lC+hIM8h8LszKtyUL6Mw4I/vxIT
e2ShfAWHiwz/nf/WyED5Sg79vK9mKoRJQ/kqDvF5QlbfdaSgfDUHec+jcpPn
SUD5Gg7T+vMKVrWKQ/laDo1zL8RLFohB+ToO1llFMxK2iED5eg7bC5ZF6okK
Q/kGDgXXPh9KVBSC8g0dAnK0Tn+VFIDyjRz81vS5pm7lhfKNHfYet3qn8ZgH
yjdxWHJycRl3CR+Ub4qm3syBSUHrF/dqmHpzh6Of+YOjCmF8C4eN6/Kn6EVz
QPmWDm0Ts62q5dmhfCuH4tXW9psWMUD51g7czGurXk3+aA/h2zi8t/z1z0nv
GZRviyZvB5X/BuXbO4RHGa0rUvoP5Tugmt/gADcPAEa3gX8=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw0N4exrrvhiKUz+GgfDL0
uZErjC/g0PTZlk98rQKUL+IQZPT3xnZhGF/CwS3xxz6v93JQvoxDaNN0lomb
ZaF8BYdDq/nUD/vIQPlKDr7WfZu3/pCC8lUc7gSXid2dKQnlqzncVs5adFxN
AsrXcGiceyFeskAMytdyqI22t9kSIgrl6zhstU/7UZMjAuXrOZzetnVlUYEw
lG/gYOg2a6fXWSEo39Dhkv0kFvG7glC+kYPs6j/XYsxhfGOH9dJrtl/y5ofy
TRz81vS5pm7lhfJNHZgUtH5xr+aB8s0cJrQw77gfywXlmztU1f86mL2KDcq3
cNDZzMJm1scO5Vs6vLf89c9JDyZv5RDYY6jN0soC5Vs71M67vEfsITOUb+PA
zby26tVkRijfFmr/H3sAH5FssA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVweMtntsX0jiKUz+Eg0nJt
c485jC/gsKrBxGDCUgUoX8RB1Wwn53YuGF/C4Y2Nxr3PV+SgfBkH0danV6UP
yUL5Cg6hB5htG5bKQPlKDmcPKLB97JOG8lUcQutvhCc7SkH5ag6fFkcekDeS
hPI1HE7Frf+0z1wCytdymHNe1ZOtSwzK13G4F9HX3vNdBMrXc/iZWPy3casw
lG/gcCTgwOyGXUJQvqGDS0PFX8N2QSjfyEFa4vGLiZMEoHxjh/Aoo3VFSvxQ
volDjtOEvXwL+aB8U4eLO65+ufGDG8o3czgr9eHVFAEuKN/cYfnu62KnZFih
fAsHeQ9fS7FVML6lAyT8maB8K6h9/+0hfGsHbua1Va8mf4TybeB8ANPSbk4=

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwEPr79OGZq4pQPofDxqxn
mi8NYXwBB/fJWox/OhWgfBGHlHuvtk18Kg/lSzhc4pXnVTgmB+XLOGTv/8Hj
3CAL5Ss4/CvPOGYRIAPlKzlsWdfcIe4kDeWrOHD9N856c08SyldzEMoOucX2
TgLK13BYMJWD4/glcShfy+Ghduohbh0YX8dB4bHo1MWRolC+nkNch9tL2yPC
UL6Bw8IlJ0T7rwlB+YYOV1K/cWrsFITyjRykJR6/mDhJAMo3duARPlRe8JIf
yjdxiNKe6HGughvKN3WYfY375zJTGN/Mwbj37XfHA5xQvrlD28Rsq2p5dijf
woGbeW3Vq8mMUL6lA5OC1i/u1X/sIXwrqP6fUL41VP1HewAyU2oc
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwKBI/lshzWRHK53D4OGWu
qIkFjC/gcOZHwP+NixWgfBGHyEXVYtOlYXwJh6YN097nfJKD8mUcuptyhev2
yUL5Cg48zdOmra2UgfKVHB561n17+18Kyldx+BcqJtt9QxLKV3MQOXvn5L+X
ElC+hsPrlE1Nn9aIQ/laDjMsd097e0gMytdxSM9+5nyAF8bXc2g7O10yQkcU
yjdw2PijD2iaCJRv6HAk4MDshl1CUL6Rw5XUb5waOwWhfGOHbR8m6Eud5YPy
TRwu7rj65cYPbijf1MG49+13xwOcUL6Zw1mpD6+mCHBB+eYOVfW/DmavYoPy
LRy4mddWvZrMCOVbQvX/tIfwrRzCo4zWFSn9twcAFr5vOQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwmNx1baXnTUUon8NBIGPN
4lceML6AQ43Vu0XdcxWgfBEHrpWtZ3cwwvgSDhozWIxmvpGD8mUcTnc8v/x8
uSyUr+CgcSqp7XaxDJSv5MBtmXbvjbk0lK/iwDC5vWumkhSUr+ZwL+xh5RFu
SShfw2Hi4+Jqp+/iUL6WQwxDsFjARDEoX8fhXkRfe893EShfz2Fuw9Uq/nXC
UL6Bw97j7fd/1AtB+YYOlud2Lzj2QADKN3IIjzJaV6TED+UbOxz9zB8cVcgD
5Zs4bFyXP0UvmgPKN0Xjmzm8t/z1z0mPDco3dwjsMdRmaWWB8i0cildb229a
xADlWzpwM6+tejX5oz2Eb4XGt0bj26DxbaH2fYPy7aD8Z1C+PRrfAc4HAMbA
hKs=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwmBjHqnb/jCKUz+Gwcv4t
/r9mML6AQ07vuZ6dMxSgfBGHxZwHn728Lw/lSzj8CMmdN7tWDsqXcTgSYjzp
Z5IslK/g0FzVWGwfJgPlKznk1/inuvpKQ/kqDrlBM7crSEhB+WoOQtkht9je
SUD5Gg5uszk/LteG8bUclv1dIa82RwzK13FYvvu62CkZUShfz6HpeHjsLx8R
KN/AYXvBskg9UWEo39AhoTD296kXglC+kcMyZa9bJocEoHxjh9LdATYWP/ig
fBOHa7wdGT/9eKF8U4eLO65+ufGDG8o3czhx1La8ZBcHlG/uIO/haym2ihXK
t3ConXd5j9hDZijf0iE8ymhdkdJ/ewjfyuG95a9/TnrP7AHEtme2
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw8Itj/3jvtiKUz+Fwwsvq
TKEDjC/gYON5z3LdPAUoX8RB92JrTCUrjC/hUCJjWXPmlRyUL+PAVjHrSshk
WShfwWHLuYcHL9TKQPlKDr92WUT/r5aG8lUcQutvhCc7SkH5ag6S/FOsFlhK
QvkaDk+ZtpdNeiQO5Ws57H0T7Oe/WAzK13HYVaDzPZhJFMrXcxDiFt/zbI8w
lG/goC0rJpmeKATlGzpo+imLuOYKQvlGDrw5Qq87CgWgfGMHz5XrVqnO4Yfy
TRxWOB4+ekySF8o3dZh9jfvnMlNuKN/M4cRR2/KSXRxQvrlDYI+hNksrC5Rv
4eBjXr/9sR4zlG/pULza2n7TIgYo38rBuPftd8cDP+0Btxlgqg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQEf7MVCt+7emK3kABVw+H+s58PX44pQPodD47xt
f9P0YHwBh6X3D32SmaAA5Ys4WAozmai8kofyJRziHKfqLFstB+XLODQWrtm7
tEQWyldw+Ma7s/GPqQyUr+QQdv0Am6yINJSv4tDGbq/Apy4F5as53NnTbvXz
uQSUr+FgGeY2v5Mbxtdy+Pzr2NE7t8SgfB2H33zp9gddRaF8PQedD33rtvcL
Q/kGDguXnBDtvyYE5Rs6nLym8uU3jyCUb+SwXnrN9kve/FC+scPe41bvNB7z
QPkmDhNamHfcj+WC8k0dsk/s2Hd5JzeUb+bwYfPFv7WinFC+ucPGdflT9KI5
oHwLB3kPX0uxVaxQvqVD8Wpr+02LGKB8Kwfj3rffHQ/8tIfwrR2YFLR+ca/+
A+XbOLy3/PXPSe8blG+LxrdD49s7cDOvrXo1+SOU7wCVfwbhN6DxGRxR1Tc4
opnnhCbvhOZeZzR5ZzTzXdDsR+MzuKLa1+CK5n831PBqcIPbBwDZO8kf
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwuKj2/N2604pQPofDl/rY
e8kWML6Aw50X96cKLlSA8kUcfE61hOiKw/gSDq8eiD/ZyiwP5cs4sP5Zrun0
WBbKV3DIF2WRuLZXBspXcnAtnPrmXqU0lK/ioGfnem9FuhSUr+bwU2dSzfIc
SShfw2Gr5LP7X+6LQ/laDsd6DpWX7ReD8nUcvm5v3fntliiUr+ewaX2bnMQd
ESjfwOG55qdKwwBhKN/Q4WSli02KGoxv5DBz//LyUB0hKN/YgTdH6HVHoQCU
b+KwXnrN9kve/FC+qYPgGxGxD2J8UL6ZA2+RkfXlJl4o39zhG+/Oxj+mPFC+
hcPsa9w/l5lyQ/mWDh82X/xbK8oJ5Vs5yHv4WoqtYoXyrR2YFLR+ca/+Yw/h
2ziERxmtK1L6D+XbOkDijwmq3g5N3h6N7+Dw3vLXPye9ZxB+A4IPAOj4hS4=

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVw2M6hcy/wqiKUz+Gwue+P
g7sTjC/goBDJP4dvswKUL+Lwu6Vi+mZZGF/CISj1l5XZFzkoX8bBrijA0Wq+
LJSv4LA4X15kSZ0MlK/ksO6B7/oJbdJQvorDDyO2464uUlC+moP+f8PNr5kl
oXwNB1G/NPNn28WhfC0HxQWNIo5nxaB8HQebrwfv9cSJQvl6DtVXK3kZEkSg
fAOHpBNKu4wbhKF8Qwe3vS+zHC4KQvlGDr5ux44+sRWA8o0d9h63eqfxmAfK
N3E4K/Xh1RQBLijf1KGq/tfB7FVsUL6ZAzfz2qpXkxmhfHOH95a//jnpfbMH
AAYsWKk=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwUL+b+oTprCKUz+Fwx1Yy
RUUTxhdweMBp8frEVAUoX8Thy4HGBRwv5KF8CYc2mepYtXlyUL6MQ5dKSxpP
kSyUr+DQwHTnFb+LDJSv5LBhXk5YjLY0lK/iEMO9L2K2sBSUr+ZQMDPP/8QB
CShfw4Gjrl/6VLw4lK/l0FBq/8VKTQzK13HQPi7xdclDEShfz0FuZ/G29tPC
UL6Bw8IlJ0T7rwlB+YYOP7yfcjT6wPhGDq/vqLfoNwlA+cYOgm9ExD6I8UH5
Jg5HP/MHRxXyQPmmDnuPW73TeAzjmzmclfrwaooAF5Rv7mDc+/a74wFOKN/C
YeLj4mqn7+xQvqXDxnX5U/SiOaB8K4eq+l8Hs1exQfnWDst3Xxc7JcMK5ds4
cDOvrXo1mRHKt3WAxB8TlG/nULza2n7TIgYo3x5q/097CN/B4b3lr39Oes/s
ATy1fLE=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwyPyz/0foOUUon8PBrOF8
u6AujC/gIHyP59OV6QpQvoiD7sXWmEpWGF/CwW6Ga0jTATkoX8bhctPt6JrZ
slC+gsOctQ0Pz7nKQPlKDhI7jv44tFsKyldxON/3rddpriSUr+agdW2tEMcM
CShfwyF3SRJ7W544lK/l4DLngdDOTlEoX8fBILZ5+d4VIlC+nkPwtc6eS7LC
UL6Bg4COofS5/4JQvqGD58p1q1Tn8EP5Rg68RUbWl5t4oXxjByYFrV/cq3mg
fBOHs1IfXk0R4ILyTR2yT+zYd3knN5Rv5mDc+/a74wFOKN/cQd7D11JsFSuU
b+HgY16//bEeM5Rvica3gtr3xx7Ct0bj2ziERxmtK1L6bw8Ao25rcg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwSE/2n8h4TRHK53AQf7ZQ
mNUUxhdwWLnz3V2eeQpQvogD18rWszsYYXwJhw+q59gdrstB+TIOPNH1BQdX
ykL5Cg5z9ByuXIyQgfKVHM6/fPR+G4s0lK/isLmO9WitthSUr+ag23gzjvuL
BJSv4WBxtL563i5xKF/Lgfvyl8J/dWJQvo7D78IF9b4ZolC+nkPT8fDYXz4i
UL6BQ9IJpV3GDcJQvqHD4z1/G7TNhaB8IzS+scMzfSXjPE1BKN/EYZmy1y2T
QwJQvqnDf4bA/wkl/FC+mUOU9kSPcxXcUL65w0+dSTXLczihfAuHjevyp+hF
c0D5lg6Q8GeC8q0caudd3iP2kBnKt0aTt3Ew7n373fHAT3sAVz1uDw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwEDqwRejIXUUon8NBTImL
ycATxhdw8Jm2/0zfOgUoX8Th0odpYiUsML6Eg7eh8VutG3JQvoyD08Pp+6Ln
ykL5Cg5z9ByuXIyQgfKVHI4KZbdwe0tD+SoOZ6U+vJoiIAXlqzl8mqvntoNX
EsrXcCjbKDcp9K44lK/lYCQ+PzGmTQzK13G4/3p5afgcUShfz6H6aiUvQ4II
lG/gsM79fVA5jzCUb+jwrWudeOwXQSjfyEHoxYFDq4NgfGMHX7djR5/YCkD5
Jg68RUbWl5t4oXxThxWOh48ek4TxzRxmX+P+ucyUG8o3d9i4Ln+KXjQHlG/h
sHz3dbFTMqxQviUa38rBx7x++2M9Zijf2qF23uU9Yg9hfBsHeQ9fS7FVMPW2
aOrtHJgUtH5xr/5jD+HbO7y3/PXPSe8blO8A5T+D8BsQfAB81YAZ
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBGIQDQEf7MVCt+7emK3kABVweCsmIR51ShHK53C46mwV
v0cXxhdw4LOeW9w5UQHKF3E4ftKKc+lbeShfwuGOXovL7pVyUL6Mg8NiU8uN
tbJQvoJDU2jYsmh/GShfyeH8y0fvt7FIQ/kqDtOPnF0aslsSyldzOPuxrU6l
SALK13A4wGe+95CQOJSv5VCnUzU774MolK/jsNU+7UdNjgiUr+fwM7H4b+NW
YSjfwOFkpYtNihqMb+hQkrF8n7+YEJRv5BA5a+1CUR0BKN/Yodso9c7sBBjf
xOHzv12RTewwvqnD3uNW7zQe80D5Zg7KXtOuRa3ggvLNHSY+Lq52+s4O5Vs4
yHv4WoqtYoXyLR3eW/7656THBuVbOQT2GGqztLJA+dYOPub12x/rMUP5Ng7L
d18XOyUD02/rAIk/JijfzqF23uU9Yg9h6u3R1Dug2tfg4MCkoPWLe/Ufe4i8
o4Nx79vvjgd+QvgNjg7czGurXk1mhOp3QuU3OKH5xxnV/Q3ODsWrre03LWKA
yrug8hvQ+AyuqO5vcEWz380hPMpoXZHSf6j73NDk3VHDo8EdzX8eqPwGND6D
J5r5nmjme6GZ74Xmfm80/3lDw/sb1HwfVH6DDzy8ASJD4po=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw0Oma9XrhKUUon8Phm4f5
nVtGML6AQ07vuZ6dMxSgfBEHR5djq+3eyEP5Eg73WP/z/l8nB+XLOPAWGVlf
bpKF8hUcnjVv6P0WLgPlKzmwzNoRN/m6FJSv4uCzw8FVc4YklK/mwH1AwV6/
WgLK13DYfoDLff5rMShfy8HsU5SG931RKF/HofpqJS9DggiUr+ew8ZPU/KoM
YSjfwGFfjOpBOW4hKN/QwaWh4q9huyCUb+Sw7cMEfamzfFC+sYNzyB8zVjcY
38SBSUHrF/dqHijf1OEb787GP6YwvpnDT51JNctzOKF8c4cTR23LS3ZxQPkW
DoE9htosrSxQvqUDN/PaqleTGaF8Kwfj3rffHQ/8tIfwraHyH6F8G4f3lr/+
Oek9g/Jt0eTt4HwAFZh0+Q==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVw4Pvywn3VCUUon8PhU2X+
wQg1GF/Awe79jSePJyhA+SIOLz/Oq/V+Kw/lSzgc9dS73twrB+XLOJQ2mSh+
SZGF8hUcgoM2ivl8lIbylRyctc7G3l0nBeWrOFTk9luUBktC+WoO/AeClzJJ
SED5Gg5thtvlrgeIQ/laDnPOq3qydYlB+ToOPeIXJn0rFIXy9RwMYpuX710h
AuUbODjpJUwpShCG8g0dot33c/3aIATlGzkI6BhKn/svCOUbO0TOWrtQVEcA
yjdxEHwjIvZBjA/KN3VgUtD6xb2aB8o3c5jQwrzjfiwXlG/uoOw17VrUChjf
wuHEUdvykl0cUL4lGt/KoW1itlW1PDuUb+3Azby26tVkRijfBmrfH3sI3xYq
/xHKt0Pj2zsY97797njgJ5TvANcPAOjseeA=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwiDN8sVblmiKUz+EQUMWT
/9AOxhdweFpipia0SAHKF3GQKba/JMgP40s4XPj2fYHBczkoX8YhtGk6y8TN
slC+gsP+q6XWBkUyUL6SQ0jHoTMlNtJQvoqD4TmVHbw/JKF8NQf9/4abXzPD
+BoOC6ZycBy/JA7lazns2yXE8WGKGJSv43D614uutqWiUL6eQ1yH20vbI8JQ
voGDk17ClKIEGN/QwXCXtPqjUiEo38iBm3lt1avJglC+sUPkrLULRXUEoHwT
h9LdATYWP/igfFOHHKcJe/kWwvhmDkc/8wdHFfJA+eYOy3dfFzslwwrlWzjU
zru8R+whM5Rv6cCkoPWLe/UfewjfCmr/R3sA+UhimQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwWOV00EjquiKUz+EQly+g
89EGxhdwOJ7IL7JolgKUL+LgsJOp999beShfwiGHrZPBYq8clC/jENNxV0R4
jyyUr+Cg9fjQ4cYqGShfyWH2Ne6fy0yloXwVh3XnKwOtzKWgfDUHLu3mWM4P
ElC+hoPezE3vY/+IQ/laDu/t8zwfssL4Og4z++ZlHSoThfL1HDy8em5tihSB
8g0cFi45Idp/TQjKN3S4ZD+JRfyuIJRv5BA5a+1CUR0BKN/YgUlB6xf3ah4o
38RB/t/Z0xYfuKB8Uwdlr2nXolbA+GYOG9flT9GL5oDyzR0Cewy1WVpZoHwL
Bx/z+u2P9ZihfEuH8CijdUVK/+0hfCuH95a//jnpfbMHAKKKYTE=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwyLz2uGzrWUUon8PhhlGG
vLsnjC/g0Lvb9zjLKgUoX8RBfM3U6xP5YXwJh776124GDPJQvowDm8G3ozUv
ZKF8BQfT1eK6kRtloHwlh2uTmTddCJKG8lUcUg5vM+zhlYLy1Ry4tJtjOT9I
QPkaDiW3Fp8QvCEO5Ws5zDmv6snWJQbl6zi4zHkgtLNTFMrXc5DbWbyt/bQw
lG/gMP1hD+O9j0JQvqFD6txlTNULBKF8I4fi1db2mxYJQPnGDs4hf8xY3fig
fBOHb7w7G/+Y8kD5pg4b1+VP0YvmgPLNHHQ2s7CZ9bFD+eYOgT2G2iytLFC+
BdR8Bijf0iE8ymhdkdJ/ewjfyuG95a9/TnrfoHxrB27mtVWvJn+0BwDiKWVJ

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwSE/2n8h4TRHK53D4aPza
180axhdw8D5tYya0WAHKF3FYrPRv/lNBGF/C4c72Q1GvbslB+TIOx0w9JebM
lIXyFRz653LtdE2XgfKVHJau7ur7pC8N5as4rH7tmO5nIgXlqzncC3tYeYRb
EsrXcFhzXfbB8iXiUL6Wg87WxaF/dotB+ToOJTsPKRz2EoXy9Rxq513eI/ZQ
GMo3cJj+sIfx3kchKN/Q4Zm+knGepiCUb+QQHmW0rkiJH8o3dri44+qXGz+4
oXwTh7NSH15NEeCC8k0dJj4urnb6zg7lm0HtY4byzaHm/beH8C0cuJnXVr2a
zAiVt3R4b/nrn5PeN3sARj5mKQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwcA2r3153RRHK53DY66JQ
tM4WxhdwSJF5u9ZggQKUL+IwwUL+li8rjC/h8OmOaezn9XJQvowDW8WsKyGT
ZaF8BQez0HUc54NkoHwlh1q1uN03uaWhfBWHW6klciksUlC+msMZuyduQWcl
oHwNhx/bucNlTohD+VoObB/4r03MEIPydRwiPPoFHu0XgfL1HJ5rfqo0DBCG
8g0cejdzau+7LwTlGzpo+imLuOYKQvlGDtISj19MnCQA5Rs7dBul3pmdAOOb
OBz9zB8cVcgD5Zs6RGlP9DhXwQ3lmzmclfrwaooAF5Rv7lBV/+tg9io2KN8C
jW/p0DYx26panh3Kt3II7DHUZmllgfKtHd5b/vrnpPfMHsK3ceBmXlv1avJH
ewD+7mj9
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVw+JB3rHnlGUUon8NhQd67
+cY2ML6Ag27lnC9pKxWgfBGHxK//8nlEYHwJh/x31lees8pD+TIOPk3bGxJf
y0L5Cg7n1fctfrhcBspXcjg15+XyWaXSUL6KA8Pk9q6ZSlJQvprD0k1HF3dc
loDyNRz8zgUcWZ4hDuVrOcw6JbRrwTpRKF/HYfGT1iTnNBEoX8+hdt7lPWIP
haF8A4fpD3sY730UgvINHTT9lEVccwWhfCOHUs0pkydtEoDyjR2WnFxcxl3C
B+WbOKxwPHz0mCQvlG/qsHFd/hS9aA4o38zhveWvf056bFC+ORrfwkHew9dS
bBUrlG/psHz3dbFTMjC+FdS9zFC+tUNgj6E2SysLlG+DJm/rwM28turVZEYo
3w6Nb+8QHmW0rkjpvz2E7+Bg3Pv2u+OBn/YAicmAiA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwiPnCf+/AOUUon8PhSeSE
N/OtYHwBB+9uK7OgRQpQvojDzw7XNWvZYXwJhzdvbBq3XpeD8mUcqthbD+hd
lYXyFRwW58uLLKmTgfKVHPi/7fL4kC0N5as4VAZ36Zz4Lwnlqzlwd5tXrt0n
AeVrOBR0zPpYWCgO5Ws5zDmv6snWJQbl6zisFnwnobZZFMrXcwhmsDi3UVAE
yjdwKLj2+VCiohCUb+jwTF/JOE9TEMo3ctj2YYK+1Fk+KN/YIfvEjn2Xd3JD
+SYOs69x/1xmCuObOlTV/zqYvYoNyjdz8DGv3/5YjxnKN3fgZl5b9WoyI5Rv
4QAJbyYo39KheLW1/aZFDFC+FZp6awcmBa1f3Kv/2EP4Ng7GvW+/Ox74CeXb
ovHtHN5b/vrnpPcNyreHmvcRyneAyj+D8Bsc4PIAjdyGvA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw+HT6zOed5xWhfA4HkSmz
X+8xgfEFHLxPCumunKMA5Ys41HEuSOVkhPElHESvfTBd+UgOypdxsP/UZOJ5
RhbKV3DQZ71wWaFLBspXclj3wHf9hDZpKF/F4YcR23FXFykoX82hokFwevlF
CShfw+Hg4aVM1yLFoXwth666OPE1X0ShfB2HTevb5CTuiED5eg6nt21dWVQg
DOUbOOyLUT0oxy0E5Rs6lGpOmTxpkwCUb+RQujvAxuIHH5Rv7OAc8seM1Q3G
N3H4qTOpZnkOJ5Rv6iDv4WsptooVyjdzYFLQ+sW9+o89hG/uwM28turV5I9Q
voXDe8tf/5z0vkH5lmh8Kyj/mT0AAx9nUg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVw+Nmd83/GRUUon8NBZMrs
13tMYHwBh+f+/PeYpypA+SIOLrsORup9kofyJRzKcnIlkk/KQfkyDqF6Iscr
FshC+QoOz5o39H4Ll4HylRwY30/+8z9eGspXcbiv5PJ4l78UlK/m8PzZUYEv
SpJQvoZDvPcehz2HxKF8LYfLOXd2nkgRg/J1HJbvvi52SkYUytdzCNBfoFQi
IQLlGzjEdbi9tD0iDOUbOrjaPqk5/0sIyjdySCiM/X3qhSCUb+ygK6jxcdZF
ASjfxCHHacJevoV8UL6pwwrHw0ePSfJC+WYO2Sd27Lu8kxvKN3eoqv91MHsV
G5Rv4SDv4WsptooVyrd0gIQ/E5Rv5RAeZbSuSOm/PYRv7eBjXr/9sR4zVN4G
jW/rUDvv8h6xhzC+ncN7y1//nPS+QfXbO3Azr616NfkjlO8A5wMAy6uCkA==

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVweNXtnSR1RhHK53DwDH/+
k8sSxhdwSA/c+2X1XAUoX8Sh4F8v7+s/8lC+hMM3Pc6ZXQvloHwZh9ImE8Uv
KbJQvoLD3pR7k81MZKB8JYepvpdt5H9LQfkqDnLFLkpXPkpC+WoOc2tl0pZO
loDyNRzUaq5fPOwuDuVrOZh9itLwvi8K5es4mFzqLVfdJQLl6zlkR7AHJk8X
hvINHAx3Sas/KhWC8g0d7MO/xPhJC0L5Rg6rbZQyNA7zQ/nGDtd4OzJ++vFC
+SYORz/zB0cV8kD5pg5R2hM9zlVwQ/lmDh82X/xbK8oJ5Zs7cDOvrXo1mRHK
t3BgUtD6xb36jz2Eb+lg3Pv2u+OBn1C+FZq8NZq8DRrf1uG95a9/TnrPoHw7
NL49lP8NyneAywMAW3eC6Q==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw8P+9k2/9OUUon8PhlCzn
/HtaML6Ag/A9nk9XpitA+SIOl6+36a34Kg/lSzjIhn+xe3heDsqXcXh+U72J
p1YWyldwuPYwcuqeFBkoX8lBMtuTacIbKShfxWHzpDq9CbMloXw1h5LEF0y7
0iSgfA2HsGWzjcJ5xKF8LYc3fec22V8ShfJ1HLT73c45nRaB8vUcJOL3XOpz
g/ENHNhCGTd/OCwE5Rs6/FjCXvfEEcY3clB0TO8s/ScA5Rs7LFP2umVyCMY3
cdj2YYK+1Fk+KN/U4RvvzsY/pjxQvpmDce/b744HOKF8cwedzSxsZn3sUL6F
g7yHr6XYKlYo39IhPMpoXZHSf3sI38rhveWvf056z+wBKP9lUg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwuHDo4ZG/1xWhfA6Hp9s7
9SxsYXwBh0v7yjMfrlKA8kUcFiv9m/9UEMaXcPA9tSLG844clC/joGm8ZobE
flkoX8Eh+5wOZ9FEGShfyUHWaUZCqas0lK/iwMTZbNGpIQXlqznck2a5z/VN
AsrXcGDN5zbOPSoO5Ws57H66Seb+MjEoX8dh+e7rYqdkRKF8PYeqSu3n11RF
oHwDh4Jrnw8lKgpB+YYOsqv/XIsxF4TyjRy6jVLvzE4QgPKNHbZ9mKAvdZYP
yjdxiNKe6HGughvKN3WY0MK8434sF5Rv5tA2MduqWp4dyjd3eG/565+THhuU
bwF1HyuUb4nGt3KAxAcTlG/tIO/haym2CiZvgyZvi8a3g9r3zR4A059zXA==

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw8Kh47mhxRRHK53BI3r2b
5acdjC/g8FKpKP3ABgUoX8Rhq94LRgM5GF/CoelEtF7kKzkoX8ah58kGqYrd
slC+gkMMT5rpgjUyUL6SQ7P/o+i95dJQvoqD9NHgfBYvKShfzcFfJmGHiawk
lK/hEJ624scvZgkoX8uhbWK2VbW8OJSv49D568Iqyb+iUL6eg3VW0YyELSJQ
voHD9Ic9jPc+CkH5hg4lGcv3+YvB+EYOvm7Hjj6xFYDyjR0iZ61dKKoD45s4
lO4OsLH4wQflmzowKWj94l7NA+WbOfzUmVSzPIcTyjd3mPi4uNrpOzuUb+Gg
s5mFzawPxrd0gIQ/E5RvBTXvjz2Eb+3w3vLXPye9Z/YAkqplSg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw+Hg4UO3mWUUon8MhkFF2
VbYxjC/gsPJf5LuLixWgfBEH1imHFHi5YXwJhxcfbzHpb5WD8mUcFnNO35Be
IwvlKzh8yXXiKnCUgfKVHOa911kp8lUKyldxiDnvybn3tiSUr+ZQMDPP/8QB
CShfw8F4suzGupniUL6Ww87TkdvCI8WgfB2HexF97T3fRaB8PYfaeZf3iD0U
hvINHCanfpgcs1wIyjd0ENAxlD73XxDKN3JYpux1y+SQAJRv7PD5367IJnYY
38SBSUHrF/dqHijf1OHijqtfbvzghvLNHIx73353PMAJ5Zs7fNh88W+tKIxv
4eBjXr/9sR4zlG/pULza2n7TIgYo38ohPMpoXZHSf3sI39qBm3lt1avJH6F8
G4f3lr/+Oek9swcAO2JxfQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwsHMRPrX9uiKUz+Hw7EWB
2RNjGF/AgZ2Ph+XcMgUoX8RhaZf1/87f8lC+hENl0CmHtuNyUL6MQ9j/JRHd
jbJQvoLD6f5SyfoEGShfyWHLuuYOcSdpKF/F4cgNr1nOTyWhfDWHw8u3zDGf
JQHlazgEG3Iw3AwWh/K1HNgPKs/ReSMK5es4/PrhvKhcRwTK13OIdt/P9WuD
EJRv4HDJfhKL+F1BKN/QoVRzyuRJmwSgfCOHHKcJe/kW8kH5xg5npT68miLA
BeWbOCzffV3slAwrlG/qUFX/62D2KjYo38yhdt7lPWIPmaF8c4fAHkNtllYW
KN/CITzKaF2R0n97CN/S4b3lr39Oet/sARRGYZQ=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw8P92fr7TbUUon8Nhrk/l
8ll2ML6Ag8LT9FcHVylA+SIOiZ+XCZmIwvgSDg95vvjm/JOD8mUcuvt2n996
SBbKV3CIC3q15HScDJSv5HBAa/4lT1FpKF/FoUfR+vDPPZJQvppDwEYFz7Ad
ElC+hkNBx6yPhYXiUL6Ww9QG28WCTmJQvo7Ddbb267KfRKB8PYd3uUe+Gn8T
hvINHGbuX14eqiME5Rs6XLKfxCJ+VxDKN3KQlnj8YuIkASjf2IFJQesX92oe
KN/E4cRR2/KSXRxQvqnDe8tf/5z02KB8MwdIeDJB+eZofAsHH/P67Y/1mKF8
S4fi1db2mxYxQPlWUPOe2UP41g7czGurXk3+aA8AXDxsRg==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBwAWIQDQEf7MVCt+7emK3kABVwaNuxmiH4siKUz+FgpLQw
TcQExhdwMNrHLn9xiQKUL+Kgf+fnvGcCML6EQ4mMZc2ZV3JQvozD7lxb6UUX
ZaF8BYeXkXxTHA7LQPlKDhsbJF/czpKG8lUcDm5edIRZSwrKV3Pg0m6O5fwg
AeVrOPR9T/DIvSoO5Ws5sJbIatfvEIPydRzOOkdIPv0hCuXrObRXHan4MUcE
yjdwiIw/5BEVIQzlGzosXHJCtP+aEJRv5HDymsqX3zyCUL6xQ0CO1umvkgJQ
vonD53+7IpvYYXxTByYFrV/cq3mgfDOHs1IfXk0R4ILyzR02rsufohfNAeVb
OHzYfPFvrSgnlG/p0DYx26panh3Kt3KY+Li42uk7jG+Npt8GTd4WzTw7B53N
LGxmfTB5ezT1Dg4/dSbVLM+Bqm9wcJjQwrzjfizMvY4Oy3dfFzslwwqVd3Qo
Xm1tv2kRA1TeySE8ymhdkdJ/e4i8E9T/fyB8Bmc0eWcHH/P67Y/1mKH6XRxq
513eI/YQym9wQbWPwRXVvgZXVPMY3NDMd0NznzuafndU+xg8HAJ7DLVZWlmg
8h4O3Mxrq15NZoTKe6LyGzzR9HuhxlcDGp/BGzX8G7wd3lv++uekxwaV90Gz
H43P4Itmvy+avJ8DJL8yQeX90OT90cLHH2r/N2j4BaDKOwQ4GPe+/e544CdU
PRr/QACa/kC4PABO5A8I
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw2GK2N3PPRUUon8PhS33s
vWQLGF/AgZ2Ph+XcMgUoX8TBSPvlRwMxGF/CIf6ym339WzkoX8bhZeMEmzXr
ZKF8BYdlsv/4a7JloHwlh/9CTXM0fKShfBWHf6Fist03JKF8NQfubvPKtfsk
oHwNh0gliwU3wsShfC0HpU0cs476ikH5Og42Xw/e64kThfL1HPoKSldFB4tA
+QYO73KPfDX+JgzlGzpMTv0wOWa5EJRv5CAt8fjFxEkCUL6xw5KTi8u4S/ig
fBOHo5/5g6MKeaB8U4cTR23LS3ZxQPlmDhMfF1c7fWeH8s0dPmy++LdWlBPK
t3CQ9/C1FFvFCuVbOgT2GGqztLJA+VYO4VFG64qU/ttD+NYO7y1//XPSewbl
28D5AEkwbZM=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwYN76wcPhqiKUz+GQPDXd
g8UCxhdwmHM/7ob/JAUoX8RB6OnuMGteGF/CYe2pxAddN+WgfBmHfU5z2Tbv
l4XyFRyeLGM8GlotA+UrOSROCdnmoSwN5as43Jh2w17zqCSUr+YgKZ2dMT1X
AsrXcBCzUijiqRWH8rUczjpHSD79IQrl6zgE9hhqs7SKQPl6Dt6bP3oFmgtD
+QYOP7yfcjT6CEH5hg7czGurXk0WhPKNHCzP7V5w7IEAlG/ssF56zfZL3vxQ
vonD3uNW7zQe80D5pg4njtqWl+zigPLNHOQ9fC3FVrFC+eYOPub12x/rMUP5
Fg6Q8GaC8i3R5K0cildb229axADlWzsY97797njgpz2EbwN170co3xbOBwA+
d247
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwmPPS7abULUUon8MhdpFt
4Y8QGF/AwXLjYXbWowpQvoiDhXQVn7AVjC/hYKx+6Np9JXkoX8aB2/9dmO83
WShfwWGWmGZm60IZKF/JIeGS/Lb50dJQvorDq8cXfsjLSUH5ag77DRjlV/NL
QvkaDp1T3VnlL4hD+VoOe98E+/kvFoPydRzazk6XjNARhfL1HFTKGSebvReG
8g0cjgQcmN2wSwjKN3QoyVi+z18MxjdysDy3e8GxBwJQvrEDj/Ch8oKX/FC+
iYNzyB8zVjc+KN/U4ehn/uCoQh4o3wyNb+5g3Pv2u+MBTijfwmHjuvwpetEc
UL6lw3vLX/+c9NigfCsHnc0sbGZ97FC+tUNV/a+D2atg8jYOPub12x/rMUP5
tg7hUUbripT+20P4dlD7ftoDADl7cDc=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwqJy81Jb7oiKUz+Ewuee7
6DFbGF/AIcHa3Z1rrgKUL+Lg8u9Vrz4HjC/hwKUxxZrjihyUL+Mwffl1d5tZ
slC+gkPWm/ryT4EyUL6Sw/mXj95vY5GG8lUcehStD//cIwnlqzkIF3gfzKuV
gPI1HA4eXsp0LVIcytdysFLbcGNNrxiUr+NQG21vsyVEFMrXc9B9Lt3AxSIC
5Rs4sIUybv5wWAjKN3SInLV2oaiOAJRv5PCNd2fjH1MeKN/YQWczC5tZHzuU
b+LAzby26tVkRijf1IFJQesX9+o/9hC+mUN4lNG6IqX/UL65g3Hv2++OB35C
+RYO7y1//XPS+wblW6LxrdD41mh8Gyj/mT0AzPdwMA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwmH8zgoPxgiKUz+GgdWCC
6lkzGF/AgdsruvLcPAUoX8ShrsBIo48bxpdwmCAX/+n6OzkoX8ahYdO09ulX
ZKF8BQcuVjuns5kyUL6Sw8+Xf3+7PJCC8lUcjHvffnc8IAnlqzkodTuEXZ8q
AeVrOJycuibwtYY4lK/lMEthK/+z56JQvo7Ddbb267KfRKB8PYfaeZf3iD0U
hvINHHo3c2rvuy8E5Rs6uDRU/DVsF4TyjRy6jVLvzE4QgPKNHXiLjKwvN/FC
+SYOF3dc/XLjBzeUb+pwVurDqykCXFC+GdT9nFC+ucNPnUk1y3NgfAuHtonZ
VtXy7FC+pcPy3dfFTsmwQvlWDj7m9dsf6zFD+dYO4VFG64qU/ttD+DYO7y1/
/XPS+wbl20L5z+wBXU117Q==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwSAjZUatwThHK53Boqk5g
/GwE4ws4uJvWRX6YrwDlizh8eGAe1S8E40s4dMpeYn70Sw7Kl3G4Y8bDeXeX
LJSv4KDPeuGyQpcMlK/kEJu68rFdgTSUr+Kgfe4Fp5+fFJSv5uB/XTeB84cE
lK/hYPX6ccP6aeJQvpbDmceL/zpoiUH5Og4X1uztbL4mAuXrOWiqsD/57i4M
5Rs4FG9c3xlQJQjlGzrwCB8qL3jJD+UbORz9zB8cVcgD5Rs7yP87e9riAxeU
b+Jw4qhteckuDijf1OG95a9/TnpsUL6ZQ+28y3vEHjJD+eYO4VFG64qU/ttD
+BYOPub12x/rweQtHSDhzwTlWzkY97797njgJ1S9NdT8Z/YAs4xsgQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwONrL7nfkgiKUz+HAbLNX
b6sZjC/gwL7zU4vdFAUoX8TB0eXYars38lC+hEPbTkfZWdVyUL6Mw4GPRwqi
JWShfAUH0aLN8y7vkIbylRyUvaZdi1ohBeWrONz4sGDx3mJJKF/NYcbBeczt
YRJQvoZDA4dx3ecnYlC+lkPoTdbOjmpRKF/HYat92o+aHBEoX89hcuqHyTHL
haB8AwdNP2UR11xBKN/QwfLc7gXHHghA+UYOpZpTJk/aBOMbO1zj7cj46ccL
5Zs4fOPd2fjHlAfKN3WY+Li42uk7O5Rv5vDe8tc/Jz02KN/cgZt5bdWryYxQ
voUDk4LWL+7Vf+whfEuo/Ed7ALgcYoc=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwEOUr9PlwWxHK53B4oc3b
kG4L4ws4MDz83vlntQKUL+LA3bogdwsnjC/hULCh4MqEs3JQvoxDl0pLGk+R
LJSv4HCnY8MrMQEZKF/JYf55Hr7Jl6SgfBUHnx0OrpozJKF8NQfFkx/bLTQl
oHwNhxtTE6LWXBCD8rUcOn9dWCX5VxTK13EwiG1evneFCJSv5xDX4fbS9ogw
lG/gsL1gWaSeKIxv6CD04sCh1UGCUL6RQ3iU0boiJX4o39hhycnFZdwlfFC+
icPRz/zBUYU8UL6pwzfenY1/TGF8M4cTR23LS3ZxQPnmDlX1vw5mr2KD8i0c
Nq7Ln6IXDZO3dAjsMdRmaWWB8q2g9v+3h/CtHbiZ11a9mszoAACKHGac
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwsOe9OnXmZUUon8Nhu0Eg
s6g5jC/gwLHeNN93ngKUL+Jw32XR7aYn8lC+hEObTHWs2jw5KF/GISOE4YJ3
qSyUr+Dwm1Vbaqa8DJSv5CD/7+xpiw9SUL6Kg3Hv2++OByShfDWHD+rH5Vgz
JaB8DYceq39pzuXiUL6WA89K88A988WgfB0HZ52r55lbRaF8PQeTS73lqrtE
oHwDh+BrnT2XZIWhfEMHw13S6o9KhaB8I4emJ0m9T9YIQvnGDoqO6Z2l/wSg
fBMHXVu9kP3PeKF8U4clJxeXcZfwQflmDlHaEz3OVXBD+eYOHzZf/Fsrygnl
WzjUzru8R+whM5Rv6QAJfyYo38ohPMpoXZHSf3sI39qBm3lt1avJjFB5G2j4
/LQHAGGgaiY=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQEf7MVCt+7emK3kABVwOHUi2/XdSUUon8PhwL2M
hX56ML6Ag/dJId2VcxSgfBGHP/nlrDUf5aF8CQdTHhHDwFNyUL6MwzuZmx4S
BbJQvoJDh/k3AV9tGShfyeH9V78v3xSkoXwVh/+mubXthyWhfDWHgpl5/icO
SED5Gg4PtVMPceuIQ/laDl11ceJrvohC+ToOSX6aK/7xwPh6DlNV/0YyzBeG
8g0cot33c/3aIATlGzrslpoyd+d7ASjfyCFy1tqFojowvrFDlPZEj3MV3FC+
icOHzRf/1opyQvmmDvIevpZiq1ihfDMHJgWtX9yr/9gDAN/7U2g=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwcPnZxhByWxHK53Dg2L9o
caQ3jC/gUBN7IqlluwKUL+IwP8t2p74ujC/h8KMobD6rpDyUL+Pw+FPmu11f
ZaF8BYcoJq9FjbtloHwlhxULF6c3t0pD+SoOfY8Kt8iKSkH5ag7Pnx0V+KIk
CeVrONxWzlp0XE0CytdyCJ75/3GAjDiUr+Ng9ilKw/u+KJSv5+Dx6vo+vm4R
KN/AwdX2Sc35X0JQvqFD6txlTNULBKF8I4eT11S+/OaB8Y0d/jME/k8o4Yfy
TRz81vS5pm7lhfJNHSa0MO+4H8sF5Zs5yHv4WoqtYoXyzR2YFLR+ca/+Yw/h
WzgY97797njgJ5Rv6cDNvLbq1eSP9gBkFGNP
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwMEx55Xf8rCKUz+Gw1P2o
311TGF/AoSgoT3biAgUoX8RBuPaZWycnjC/hkGLAve7RNzkoX8Yh+8uPlV8W
yUL5Cg68L0y/sxbLQPlKDn0//q+Qq5OG8lUcNiT4mG9zlYLy1Ry8PohtbEmV
hPI1HG4rZy06riYB5Ws57H0T7Oe/WAzK13Fw1rl6nrlVFMrXc/j1w3lRuY4I
lG/goKnC/uS7uzCUb+hwJODA7IZdQlC+kUPBtc+HEhVhfGOH3VJT5u58LwDl
mzhEaU/0OFfBDeWbOpw4altesosDyjdzCOwx1GZpZYHyzR2KV1vbb1rEAOVb
OHAzr616NfmjPQBUgV3g
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw+KitcX/zKUUon8Ph+eXA
p55GML6Aw+EOkXnvlypA+SIOr2SXrtRmh/ElHL789v3Bel8OypdxOFv0iSl/
qSyUr+AQ99mzLnCRDJSv5NCXJekvnigN5as4FN76I+AeLwXlqzlwaTfHcn6Q
gPI1HEqMj9mWnhWH8rUceFaaB+6ZLwbl6zisLDh7MaNPFMrXc/iZWPy3casw
lG/gAPGvEJRv6HDymsqX3zyCUL6Rw3rpNdsvefND+cYO13g7Mn768UL5Jg6z
r3H/XGbKDeWbOpw4altesosDyjdz4GZeW/VqMiOUb+7ApKD1i3v1H3sI38Lh
veWvf05636B8S6j6j1C+FZwPABfBaWg=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw8OIXPP78giKUz+Ewo+Vx
XJYljC/g4LliXezFBQpQvojDLJ2kq5P+yEP5Eg6y4V/sHp6Xg/JlHPg/dPVv
niQL5Ss4tN7W14wuk4HylRzUG5Qyw1ykoXwVh/tKLo93+UtB+WoOyyJeZpjb
S0L5Gg78X9YFvzWSgPK1HFxTH2/umSEG5es4XFxz/rNKriiUr+cgtPZq5oc6
ESjfwOFkpYtNipowlG/okDp3GVP1AkEo38ihUvP4z1R/ASjf2CE8ymhdkRI/
lG/icHHH1S83fnBD+aYOxr1vvzse4ITyzRwCewy1WVpZoHxzByYFrV/cq//Y
Q/gWDu8tf/1z0nsG5Vs6cDOvrXo1+SOUb4XGt0ZTbwPnAwD9VHIP
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwqPLJ5JK7rAjlczgsWOnh
oWwM4ws4cHtFV56bpwDlizjEpl9/kPtDHsqXcJgu/jMvd4MclC/j0KXSksZT
JAvlKzis++pRp80vA+UrOdTwsIYG7ZOC8lUcfl7OZ3cpl4Ty1Rwe/JQLbTKQ
gPI1HCJr37n2fBWD8rUc5D18LcVWiUL5Og4xHFINMyxFoHw9h6ySH9sYw4Wg
fAMHl4aKv4btglC+ocMyZa9bJocEoHwjhxynCXv5FvJB+cYO13g7Mn768UL5
Jg4fNl/8WyvKCeWbOizffV3slAwrlG/mULza2n7TIgYo39yBm3lt1avJH+0h
fAsH49633x0P/ITyLdH4Vg7vLX/9c9L7BuVbo+m3QePbovHtoPqf2QMAsfN2
aw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwiOK9zFZ6VRHK53AoVK7q
W2UE4ws48AdeuzpzsgKUL+Ig+KHyfN8FeShfwkHiQPO32GVyUL6Mw9miT0z5
S2WhfAWHg7FLFziukoHylRwOxvy/l+gnDeWrOPRZT9Fs5JKC8tUcuLSbYzk/
SED5Gg6VGwN/aFSJQ/laDgv4maT+uIpB+ToOv/nS7Q+6ikL5eg59BaWrooNF
oHwDh8j4Qx5REcJQvqGD4S5p9UelQlC+kUPq3GVM1QsEoXxjh1LNKZMnbRKA
8k0cwqOM1hUp8UP5pg5MClq/uFfzQPlmDlX1vw5mr2KD8s0daudd3iP2kBnK
t3AoXm1tv2kRA5RvCTXvvz2Eb4Umb+3w3vLXPye9b1B5Gwfj3rffHQ/8hPJt
HbiZ11a9mvzRHgC29m8N
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwCFTPLjM8rQjlczhw1P64
t9ESxhdwuM5h94lvvgKUL+JQebbv7G9WGF/CIbVtWXbRSzkoX8aB1/CQf/0p
WShfwSGwZNqCK9tkoHwlh9azVhvmtktD+SoO0keD81m8pKB8NYesq66scwUl
oXwNh/9ZyR0nnotD+VoOS+88vHz1hxiUr+OQ31spKTxZFMrXc9i0vk1O4o4I
lG/gcC4x4uPnm8JQvqFDtPt+rl8bhKB8Iwdu5rVVryYLQvnGDsWrre03LRKA
8k0ctn2YoC91lg/KN3Uo3R1gY/EDxjdzuLjj6pcbP7ihfHMH+X9nT1t84ILy
LRw+bL74t1aUE8q3dNi4Ln+KXjQHlG/l0DYx26panh3Kt3aQ9/C1FFvFCuXb
OOhsZmEz64PJ20Ldywjl2zkY97797njgpz2Ebw+V/wjlOzi8t/z1z0nvG4Tf
gMZncITyn0HlEXwADoCRWQ==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwcA2r3153RRHK53BQYLx4
RckSxhdwOL8yVfL4egUoX8TB+b7m0wsSML6EQ/476yvPWeWhfBmHnicbpCp2
y0L5Cg5XImXky1fKQPlKDnzt9csEJklD+SoOPaIGKgV6UlC+mkN87sb5M65K
QPkaDsaTZTfWzRSH8rUckvY9+PRvixiUr+PQI35h0rdCUShfz6GvoHRVdLAI
lG/gEBl/yCMqQhjKN3Rw2/syy+GiIJRv5CC7+s+1GHMY39hhvfSa7Ze8+aF8
E4dvvDsb/5jyQPmmDsa9b787HuCE8s0c5D18LcVWsUL55g7Fq63tNy1igPIt
HN5b/vrnpPfMHgDRx12b
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwOCb5O6D5liKUz+Hwccpc
URMLGF/AoXi1tf2mRQpQvohDU7fDHQthGF/Coaxp09qer3JQvoyDloP/nNXL
ZKF8BYcSR1/5tlIZKF/Jwe76xrhN7tJQvorDuvOVgVbmUlC+msOlEzeMVmtI
QvkaDvwHgpcySUhA+VoOpzXzNsj8EYPydRze9J3bZH9JFMrXc6i+WsnLkCAC
5Rs4sIUybv5wWAjKN3SwMfJp50sQhPKNHF7fUW/RbxKA8o0dtn2YoC91lg/K
N3GI0p7oca6CG8o3dThx1La8ZBcHlG+Gxjd3aJuYbVUtzw7lWzgE9hhqs7Sy
QPmWDj7m9dsf6zFD+VYO8h6+lmKrWKF8a4fwKKN1RUr/7SF8G4f3lr/+Oel9
swcA95hnag==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw+HT6zOed5xWhfA4HjWLP
UG8bGF/A4fUKI+lPCxWgfBGHJ1sNk19Jw/gSDkfnMFY8lpGH8mUcUp53W9Sz
yEH5Cg6MB0rvpd+RgfKVHBb875/ZtVAayldx2PLj70fZxVJQvprDPMeLXX5e
klC+hsOxkokV+R4SUL6Ww/YDXO7zX4tB+ToOdTpVs/M+iEL5eg7x17fGXa4Q
gfINHLYXLIvUExWG8g0d3Pa+zHK4KAjlGzmUak6ZPGmTAJRv7PCNd2fjH1Me
KN/EgUlB6xf3ahjf1OGnzqSa5TmcUL6Zg85mFjazPnYo39xB3sPXUmwVK5Rv
4VA77/IesYfMUL4lGt/K4b3lr39Oet/sIXxrKP8ZlG8D5wMAjzZx6A==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw+NyjrRJwQhHK53D4FPHJ
2UwPxhdwOOgVvJ93kgKUL+JgxeE52fC1PJQv4fDi4y0m/a1yUL6MQ3FlV8Ll
SlkoX8Hh+Z6d85NDZaB8JQehOD7RU2bSUL6Kw8+oLY5vWKWgfDUHoeyQW2zv
JKB8DYc112UfLF8iDuVrOezbJcTxYYoYlK/j8JR12rft00WhfD2HpuPhsb98
RKB8Awcf8/rtj/WEoXxDB8Nd0uqPSoWgfCOHhMLY36deCEL5xg66ghofZ10U
gPJNHJacXFzGXcIH5Zs6+K3pc03dygvlmzkc/cwfHFXIA+WbO2Sf2LHv8k5u
KN/CYUIL8477sVxQvqWDzmYWNrM+dijfyoGbeW3Vq8mMUL61Q3iU0boipf/2
EL4NVP6jPQCyv2vN
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw2KLqfPnPWUUon8NhaXCr
P68ZjC/gMOd+3A3/SQpQvojDDOd7EeHiML6EQ4oB97pH3+SgfBmH8Cl+R7uu
y0L5Cg6BJdMWXNkmA+UrOWxZ19wh7iQN5as43EotkUthkYLy1RxcOZj/fNko
AeVrOJSaq6VuTRWH8rUcFjXybFoSKAbl6zgs331d7JSMKJSv5xDDIdUww1IE
yjdw8DGv3/5YTxjKN3RInbuMqXqBIJRv5LBM2euWySEBKN/Y4T9D4P+EEn4o
38Qhx2nCXr6FfFC+qcNZqQ+vpghwQflmDj91JtUsz+GE8s0dAnsMtVlaWaB8
CwcmBa1f3Kv/2EP4lg7hUUbripT+Q/lWDsa9b787HvhpDwAJFGHy
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwCJM8Le5/SxHK53D4cpAh
pcIFxhdwWNQ2a3/eMgUoX8ThtIX87I0MML6Ew5LZQspNi+SgfBmHkr/iZ1ML
ZaF8BQep2aFlS+NloHwlh08xP/hdk6WhfBUHPTvXeyvSpaB8NYcFMy3V2mMk
oXwNh3C2L3fCTCWgfC2HOedVPdm6xKB8HYeJsplvZj0WhfL1HC6s2dvZfE0E
yjdweJd75KvxN2Eo39DhSMCB2Q27hKB8I4eEwtjfp14IQvnGDkIvDhxaHQTj
mzhUah7/meovAOWbOpTuDrCx+MEH5Zs5yP87e9riAxeUb+7QNjHbqlqeHcq3
cOBmXlv1ajIjlG/pEB5ltK5I6b89hG/lYNz79rvjgZ9QvrUDk4LWL+7Vf6B8
G4f3lr/+Oel9swcA2xpv5Q==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVw+H+s58PX44pQPoeDTmlW
sqA+jC/gcM0+7oPoZAUoX8SBgaX89sFz8lC+hMO1+PMhhzbLQfkyDh8Otvxl
jZSF8hUcFBXemPQYykD5Sg7qC9bc2GYnDeWrOBwPWHGpzk4Kyldz0P9vuPk1
sySUr+HA+2XOS+854lC+loNr6uPNPTPEoHwdhx7xC5O+FYpC+XoOAu2FKfcX
iUD5Bg5C3OJ7nu0RhvINHX4sYa974igE5Rs56ApqfJx1UQDKN3bY9mGCvtRZ
PijfxIFJQesX92oeKN/UYfY17p/LTLmhfDOHCS3MO+7HckH55g4fNl/8WyvK
CeVbOBj3vv3ueADGt3TQ2czCZtbHDuVbOVTV/zqYvYoNyrd2eG/565+THoxv
4wCJLyYo39ZB3sPXUmwVK5Rv58DNvLbq1WRGKN/eITzKaF2R0n97AN0eeKI=

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVw0DD4mOJ8WhHK53B49fn7
8VoDGF/AIXhueWnDBAUoX8Sh4F8v7+s/8lC+hMM/wWwh+9NyUL6Mw47gRcz7
u2WhfAWHJ8sYj4ZWy0D5Sg7xP2ZqSeRJQ/kqDnVPVnqKqUhB+WoOFbn9FqXB
klC+hgP/l3XBb40koHwtB9YSWe36HWJQvo5DbbS9zZYQUShfz8Hj1fV9fN0i
UL6BQ2T8IY+oCGEo39CBa/GPOLejglC+kUPkrLULRXUEoHxjB781fa6pW3mh
fBMH+X9nT1t84ILyTdH4Zg5V9b8OZq9ig/LN0fgWDu8tf/1z0oPxLR0Cewy1
WVpZoHwrB27mtVWvJjNC+dZQ9d/sIXwbqPxHKN8WTd4OjW8P5T+D8h1Q9Tc4
oMk7Ohj3vv3ueOAnVN4RLg8Ar3iSZA==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwWMPPJJ17RRHK53CIyxfQ
+WgD4ws43Hlxf6rgQgUoX8ThlezSldrsML6Ew9EVkyaGX5CD8mUcesQ+ce+Z
IwvlKziUOPrKt5XKQPlKDgHbtRTNnaWhfBUH3XbflStPS0L5ag5G/1Mk9y+Q
gPI1HAo6Zn0sLBSH8rUcZq086Px1rRiUr+Ow4vbhqXOviUL5eg5Ca69mfqgT
gfINHLIj2AOTpwtD+YYOb4QjU791CkH5Rg6afsoirrmCUL6xg+W53QuOPRCA
8k0cVjgePnpMkhfKN3WQ/3f2tMUHLijfzKGq/tfB7FVsUL65g495/fbHesxQ
voVD7bzLe8QewviWDuFRRuuKlP7bQ/hWDsa9b787HvgJ5Vuj8W0cmBS0fnGv
/mMPAG1gcAI=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwUBLiEPa4oAjlczjMWx06
cYEhjC/g8GiN0u+U2QpQvoiDxVkFO+e/8lC+hMOUuUG/DI7KQfkyDuf1Ao54
LpeF8hUcPGO2XGmPkoHylRx+xK1PveAhDeWrOPRZT9Fs5JKC8tUcCmbm+Z84
IAHlaziUmqulbk0Vh/K1HPbLz5aYyykG5es4WGcVzUjYIgLl6zkEM1ic2ygI
4xs4RLvv5/q1QQjKN3SYuX95eagOjG/koOiY3ln6TwDKN3bwdTt29IktjG/i
8J8h8H9CCT+Ub+qwwvHw0WOSvFC+mUP2iR37Lu/khvLNHS7uuPrlxg8Y38Lh
veWvf056bFC+pcOJo7blJbs4oHwrB53NLGxmfexQvrVD8Wpr+02LGKB8Gwdu
5rVVryYzQvm2UP5HewjfDs4HABo6c48=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwUEnh/JF4RhHK53DYmPVM
86UhjC/gULza2n7TIgUoX8Thee4exom8ML6EQ1DqLyuzL3JQvoyD8XzNBPmN
slC+goOhZiqj/GwZKF/JYZt1Ucp1e2koX8Vh+w+DiI/2UlC+mkPSjg2Wh25L
QPkaDq9TNjV9WiMO5Ws5JO178OnfFjEoX8dhlsJW/mfPRaF8PQeZ2xEOAhNF
oHwDh80FxZ+jKoShfEMHw13S6o9KhaB8I4emJ0m9T9YIQvnGDuFRRuuKlPih
fBMHvzV9rqlbeaF8U4cJLcw77sdyQflmDm0Ts62q5dmhfHOHwB5DbZZWFijf
wqF23uU9Yg+ZoXxLBx/z+u2P9WB8KwcmBa1f3Kv/2EP41lD7/0P5Nmh8Wwfj
3rffHQ/8hPLtHN5b/vrnpPcMyreH8wEoaHnj
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwmF3eyvrxjCKUz+Eg0/Vq
6yEjGF/AYU5l1KOlsxWgfBGHM7zzHsqwwPgSDm/e2DRuvS4H5cs4HNI8scFi
uyyUr+Dw9VfKLM0aGShfycG1cOqbe5XSUL6Kw4QW5h33Y6WgfDUHRivtnec5
JaF8DYetks/uf7kvDuVrOayxXnLM64UYlK/joPBYdOriSFEoX88hsMdQm6VV
BMo3cCgXnc3Qv0wYyjd0mP6wh/HeRyEo38hB6MWBQ6uDBKF8Y4fXd9Rb9JsE
oHwTB+eQP2asbnxQvqnDxR1Xv9z4wQ3lm6HxzR2u8XZk/PTjhfItHOT/nT1t
8YELyrd0MO59+93xACeUb+Uw8XFxtdN3dijf2kFnMwubWR+MbwP1DwuUb+vw
3vLXPye9b/YQvh3UvJ9Qvr0Dk4LWL+7Vf6B8B6j6Z/YAppeFGw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw4O1LDJ5wRRHK53DI+/k0
dZIRjC/gIDbRTufCfAUoX8Rh5RnmeZaf5aF8CYdoZX9l4Q45KF/GIS1moqVd
hiyUr+AgmMO2c46GDJSv5HCNoy7ZX0YayldxuPXv7Oun5yShfDWHpB0bLA/d
loDyNRwqNwb+0KgSh/K1HKzUNtxY0ysG5es4aEVbHN3nLwrl6zkIrb2a+aFO
BMo3cEg6obTLuEEYyjd0YAtl3PzhsBCUb+SQOncZU/UCQSjf2MHy3O4Fxx4I
QPkmDp//7YpsYofxTR0E34iIfRDjg/LNHLJP7Nh3eSc3lG/ucOKobXnJLg4o
38IBEt5MUL6lg3Hv2++OB37aQ/hWDu8tf/1z0ntmDwB+nmc1
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwsHMRPrX9uiKUz+Hg9P3e
gzx7GF/Awdd0+sG3yxSgfBGH57l7GCfywvgSDrMsTxXt3yMH5cs47AhexLy/
WxbKV3D4kuvEVeAoA+UrOdTr/n/jySEN5as4rNeWs3D5IAnlqznE526cP+Oq
BJSv4ZAQGfZzerY4lK/lsDWmKiE8RwzK13HIZ/zdtspaFMrXc5iq+jeSYb4w
lG/g8EY4MvVbpxCUb+jAmyP0uqNQAMo3ctj2YYK+1Fk+KN/YwW9Nn2vqVl4o
38Rh9jXun8tMuaF8U4f3lr/+OemxQflmDpDwZILyzR2KV1vbb1rEAOVbOBj3
vv3ueOCnPQBVy13j
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwaLxsN6vtqiKUz+GwzWQ7
4xZjGF/AIdCpyeXMXAUoX8ThjuG0OS5f5KF8CQepC/1e96/KQfkyDkmmr8J/
1clC+QoOigpvTHoMZaB8JYd63f9vPDmkoXwVh83sl4794pCC8tUcXNc/aJu4
RwLK13DwOxdwZHmGOJSv5aC0iWPWUV8xKF/H4cKavZ3N10SgfD0HJ72EKUUJ
wlC+gYNLQ8Vfw3ZBKN/QYbWNUobGYX4o38hhhePho8ckeaF8Ywfj3rffHQ9w
QvkmDieO2paX7OKA8k0d3lv++uekxwblmzn4mNdvf6zHDOWbo/EtHGrnXd4j
9hDGt3SAhD8TlG8FNe+bPYRvjca3gbrnJ5Rv68DNvLbq1eSP9gBdfnaN
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVw2PXkdZ/KBUUon8PhmvdS
mTPGML6AA5/78jW90xSgfBGHmOscxq+ZYHwJhzvbD0W9uiUH5cs4JN96cqTx
oCyUr+DwzuHT21ebZKB8JYfY1JWP7QqkoXwVhzZ2ewU+dSkoX81hRZ1vnoe0
JJSv4XBAZDV74itxKF/Loa+svsnmnhiUr+Pgosqnc18QxtdzMLnUW666SwTK
N3BY5/4+qJxHGMo3dLAx8mnnSxCE8o0cPv/bFdnELgDlGzsc/cwfHFXIA+Wb
OGSf2LHv8k5uKN/UYeO6/Cl60RxQvpnD8t3XxU7JsEL55g4+5vXbH+sxQ/kW
DpDwZoLyLR24mddWvZr80R4ALdJggw==
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwiPitsM35hiKUz+Hwp/vj
Lx47GF/AYZ/+mZrM9QpQvojDZJkTc48yw/gSDk6XDIqeb5CD8mUcvDe1dct0
y0L5Cg4bC5++XhMpA+UrOcS+ynn0XkgayldxYL95PuU2kxSUr+aw34BRfjW/
JJSv4VA8ZV0t5wFxKF/LYQE/k9QfVzEoX8fB5uvBez1xolC+nkNM0qPHOi+E
oXwDB0O3WTu9zgpB+YYO9uFfYvykBaF8I4dtHyboS53lg/KNHS7uuPrlxg9u
KN/EoW1itlW1PDuUb+pQO+/yHrGHzFC+mUPxamv7TYsYoHxzB0j4MkH5Fmh8
SzT9Vg6BPYbaLK0sUL61A5OC1i/u1X/sIXwbh/eWv/456X2D8m3hfAArgHRP

       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVw2CIiUmF7XhHK53D4uFMi
ssAKxhdw+NSnfjB0rQKUL+LAWmMVvlocxpdwiJ2h1rv8jxyUL+PA/97c5vpj
WShfweHTJbvJocdkoHwlh7Ke0vkeM6ShfBUHa57/r2oWSEH5ag6nL1n+35ks
CeVrOHA6nXjlly0B5Ws55C5JYm/LE4fydRy4L38p/FcnBuXrOSg8Fp26OFIU
yjdwSJ/KVMJrLALlGzpoqrA/+e4uDOUbOVyyn8QiflcQyjd2eH1HvUW/SQDK
N3HgET5UXvCSH8o3dbjG25Hx048XyjdzuLjj6pcbP7ihfHOH7BM79l3eCeNb
OGxclz9FL5oDyrd0qKr/dTB7FRuUb+XAzby26tVkRijf2qF4tbX9pkUMUL6N
g3Hv2++OB37aQ/i2UPUfoXw7NL49Gt/B4b3lr39Oes/sAQwOgMo=
       "]]}, 
     {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwmD/x3sroS4pQPofD5J7v
osdsYXwBB81UgTVHVypA+SIOHx6YR/ULwfgSDs+6HEtDeeWhfBmH0G3qRywv
yUL5Cg4+tvWla1bIQPlKDraHT9scz5SG8lUcguNEuqd6SEH5ag7fhSzFFOQl
oXwNhyLJ3Otv68WhfC2H28e33LpeLAbl6zgs331d7JSMKJSv5xCT9Oixzgth
KN/AwXCXtPqjUiEo39Dhkv0kFvG7glC+kcN/hsD/CSX8UL6xw5KTi8u4S/ig
fBOHo5/5g6MKeaB8Uwdlr2nXolZwQflmDsa9b787HuCE8s0dJj4urnb6zg7l
WzhAwpsJyrd0YFLQ+sW9+o89hG/l8N7y1z8nvWf2ADQeZeA=
       
       "]]}}, {}}, {{{}, {}, 
     {Hue[0.67, 0.6, 0.6], Thickness[0.005], LineBox[CompressedData["
1:eJxd1ntUVOUaBnCUCeGoRSi3I8hAcEIgj0BCCsqDgIKaXJwRGG57BjaieEFT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       "]]}, 
     {Hue[0.9060679774997897, 0.6, 0.6], Thickness[0.005], 
      LineBox[CompressedData["
1:eJxd1XtQVHUUB/Ad00h5CMhLVgIWZVjiuQboAvGFeMp7H7C7LI8ejBpUgpLo
5HQlB0WdQhErlATBqDBIigQZ8iYBPpIJHckcG51wFMYmlkcKyiObzu+Pe3dm
Z+ez5569v/s7Z3/H/fV3VfmLJBLJ7mfv/z7/f5kiHLTtXWcKZKAv8Fy7KR43
3MkvYHohwLgvkNkah+7AU9XgRrZDeKnHHqUtsxMKZ/sUZktcyatgl5bd4/in
C9kNmuEWv9GGVWQZPnx0/r6+TEpeDdn2kcbfFM5kT5i+G5zbZb+S7IW5n10P
fH/LkewNheOJ14zlDmQfXHkysr/8lD3ZD7UdYVlVLXbkAJyZcD6xc9MKciDq
Gy/afzxkS1Ygryj76eURG/JaxHaPvoVB5pexfqCrru+uNTkIk/Pn9GVmzMH4
wVTp73zVihwi8jqkFXpf+Wclu349Gi81vGe+jcWVsPnLzsHkwBwqcpjI4bAs
VoReL7Mkv4LBjhtTN6fNyREouNjx4/VOZsDw0qH4gVIyB/ROLlcbiiwoHolM
g6KlWLac4pEojKrstqpn94vCgiR9IW8bi0dBX/NNvb0Pe55X0Rwm2+TVw+Ii
S6JhseLC9i2jLB4t2r8YWBbaPtxXROZiRPsdixL5karDbSweC5fm2SFjCKtP
HOQpHnYxb5O5OEidhkcOHWb58cL95+Lha+M1XjPI4gnYIe+fyU9l8QQcUOTf
PpbH4huE6+E2IOGrlq/XHGfPl4iU0x/F5LdTPbhE+Ib7ac7fZ/VJEtaHS4Lr
/NUr60zLKJ6MR5adu2eDqB6cyJIULHLzfmLezOIpODZkPvNFEKtvKjw2HB0y
fEm/x6WK+iFNWG+kYcbn8PtNhUvp+jT6v5H5NFF/pQvrjXRRPdKF+8Wno8v5
SG3nGNs/lbB/oBLttwpbm0Mj2k6yfBWSY/t674WzfLUwDjUuDa2eemrB6q0W
Xs+rRf2pQav09Nlriez+GlE/a4Tr4TWi/tEKDS3cIzdWlMyz9WthNDtZI42h
9fBa2I7wF5pVrD8zEM2VzgXuJSMD9/1la9+Rs/VnICJzypgiZfkZwvVIMoX9
h0zh/nKZovxMWPsESgcW2P11qMo3VRmb6LyDDpd2RIe96UnnIadDUsgHZ4f9
yLwOBTqz9Dc+YeelHtVr5vSSE2TooR6qOHjNheXrIV9tdu9xHMvXw/eBlFu2
mJ2/Bsw2LHZ/8CsZBpzb4vNYvYjOa86AU9VbbTpB5g34yWOPl0TGzvMsBDsv
bRivI+OZJwxeiXdYfha4kogppSfNAz4Lk0/6em/fYvPBiHErbY/cn+YHjHBQ
uhVb7CJzRigfDnOtR8m8EROfms8fHGPzJhtjAcrktimWn41R3dXSv0udKD8b
rgm9L1Z9TuazsbmrcnP772RJDtoiK8pmFsjIQd0SXtW/k+Ybl4Nfgh8s0/5B
5nMwrXi+PyaazcNczGft3yj/loxcVCdfD3N9SuZyYRV60+2zNTRP+VxcPj7a
VFPC5mseWu4mt1aWk93yUKHrNtYOSPEvr6Ubmw==
       "]]}, 
     {Hue[0.1421359549995791, 0.6, 0.6], Thickness[0.005], 
      LineBox[CompressedData["
1:eJxdl3lcjWkbx48GaTGydGTthGylQVSi8SvT0Yb2tJ9OnbbTNlGR8BSGeaXG
vs2QMYMiXtJYCkdkl1eRDKNDyDqyvFkmGZ+P6/rjPOfz6Y9v1/O7v/f13Pe5
z/NYKFN9VXoSiUSvw+c/CX9aJksDyiv2qweB/gHzqbGDq69ZEHdB1a2o8ONy
ZhN4rTtxqWCvjLgXdngd/HixD7MZVqnb53YaZE7cH1LjS1tv/D2AWAbXIeru
OQf7Ew/Cs6ye9vt29SMeggPZv//itLov8VDMbhlzrIdzH+Lh2HByy1dLA82I
R8IBg/XwSkpsDYP2NQYT7ZhtMK52RZbl0V7Eo3E/cYTjx6U9icfAaoC0T1xU
D+KxCNP/dVM/1+7EtjDuWZWV9rgb8Tgkufx07OttXxOPR/Xrbn4h3xsT22GX
86nqM326EtvjvfWqnJ1JBsQO+GGl2nGeuT7xBJi7TZsgLelE7IhZuydOPvCr
hHgi9GQjPxjtbpv8hSchKGTs3vRBn4idRPVvYbvi+VtnzXviyTD6qjT7yeoO
NB7wZb31vrAAkd9ZVBexxAU++WOsOi7pSHUXUX4KXkz40O5i05nqU2Bd1rGz
XQH3+51u/4KIJa6ivKuoLkf2wg8n1SVcl4v8U7Gz4ob0Qn9iQcQSN5HfTXc8
ibvueII7VjbNmufylv0euuspeODq4etvGt4ZUd0T9V2Xxb+fTusveIr2ixcy
KrwnObwjFrzQ2vVIbtt43j/TdPeTMA0hVivdaubw+NN1rxemi/bbDHR/1kva
IuXxZyB4U+k2U2sTqntjin+bXSc51eGNUU42/ice8ny9MX1PgauqnFjjjU8S
n0+K2bz/feBevLfE8mdi+GBCTUXRGS2NL4hY44OH3wyyTRnB3ydf7Bjs8ee4
KqrDF/3Mmh6tXMV5XwzY3VYfZk/Xa0R1iR+Wj1Xd3qzgvB+e3h62+Js8zovq
Gj9Mk5+pvu/EeX+8bj8anKfPeX+R3x8ZI9asXnWA8/4w3P4uQl7N8w/ANVWr
wfAjxAjAO88HXXK96PwQArDxxM6sAGtizef6b/oL7jvz+RKoe94gEGGLbEMa
HnE+EGPkm454XOZ8IA6l7Qi2MeXzKgjbfjtnWljP+SBYtxTsPVRIdSEIF/8o
L05PI9YEITiyyi1kJudn4rS3ZrNwlPMzcezs0sZ3C9kvYs1MNFV+FKzsef7B
uv0iGC42ijXpCvYHY/3d/A53XnI+WHTehsDLfuGhJhtihKAmaubL1zc5H4K4
tXqzu9rSea0JQZjyXpP1I86HwiyysrZATnWEYv6WukrpXc6H4vG6dOfSydx/
qOj+hWFFmYHV8Uaef5ho/mHYO/WFb5Yx58N0+5GE664XwtE84tXcMd6cD8f5
ud9NihnK+XAMPDLrj6UX2R+hy4jQ7U+IEPUfgb+TT//ftpXzkciea9Vcb8n9
R+qOJ0Sih1HvyoeV7I9EWdqs1yFzOK/QnZ9MIVoPhe79UChE+0uh22+RAp5l
Lz187NmnQMQy+WOn08RaBfQHdvQ/Xcv+KN31kkXp9gdRXREFP4lDzf7u1K8Q
hVHN/QTDjsRFURgdvmjnsV18v6LovDclfxQan+7MCPqZWKJEcdrlq/EFxDIl
zl9bvCTjPDGUaE9/a2lQTaxQoqibXt82V3qeEJSoS7p95FwMcZESZ/KrsjJP
EGuUsC7fHtBWQaxV0u9Nb/JHQ+j2dnHEeGJZNG596lcROpsY0Sjv87DxTSOx
IhoTjixsNLWh5x0hGtc9q0LuWhAXReNCxL5Xx+2JNdHYrrd1naUjsTYa5ttX
5A2bxs9LMZgQKN/6oxGxLAY3rs+/8J9JxIiBfLPBy51WxApRXYjBA71Dmavu
0fyKYlCc+IuZdTmxJgaFdSbLL3kQa2OwrjAlrWQJ969CvmN77JQs7l8FqaMs
3Xg+96/C8x8MSpYs4/5V6HnKYlTvrcSCCnP3+7wbns1+FVpaVQu029ivgqbX
bv2oJ+xXocD2aYc/fbj/WEidm5L2ZHL/sdDvH/PAqZD7j0V+gKFb7T7uX8RC
LEbWl/bosoHvfywMrRaFG7Tw/RexNhbfSi33fDjN/jjcrlzq+L6Z/XHw3i9z
DzzM/jiEF1pvvJPK/jjMEbqvz7rK/jiMyr0ZYfSG/XGwMIv6ePkv9sfhrPN/
De9VsT9Odz6SeOwqObrM0IKep2XxaC8ZYB/ahxjxOH9dnnzSnlgRjxOjO5jv
7kYsxEP2uKy8oZH98bgS4+YVXcz+eN1+tfH4/UD19mV17E/A/OK19qFO7E9A
7bmGsbuHsz8BxQ9tGh7NZH8CFu2p6hkQwf4EJLbllZ/OJS5KgN2H5BPH9hFr
ErBxU/b4N1uItQl4H3LQ+Vknfp9IxIXcv84YORHLEvHJcIlyizkxEpFX8sBk
tS+xIhHHJ92yr1MTC4loTJiX4zCHuOjzeB2uOA7zIdYkwm+t6/q984m1icgs
KCvKzmC/GnPGntJmhbFfjYCFDUHRzuwX1RVq6BkscvhxOPvVuNy35ckaE/ar
kXHMPHufA/vVqC7Xf1aqYL9atx9JEjwn5rj3UrI/CcVq0/ZdxexPgtMBl0c/
lbI/CedGV8zOv8x+Ub0oCTnGnQJ8j7NfdL02CT1Xbzta3Mz+ZHS02jWmSyP7
k5FtfGp7azX7k3GrLm140in2J+PF1FytXz37k3HOIWO5yf/Yn4yzU8rssg3o
/VGTjIHO7Qc9WtkvyktScMOpc6ZfG/tTkKNZYFljRnmkINq79HBrCftTUCWv
PFBTw/4UJGlXzhhaxX5RXpMCzcitte6mxNoU3HVf0Pr8E/tTEWlytVnygv2p
SM2ZoXKdxv5UmCtz/1nrRKxIxZyRvWaV+xALqbDtrRy6J5O4KBXutdKbGYvZ
n4od43zr/ylkfyqGJOYF2Cj5/ToNrt+vfXZnLrFJGjLzM7a6bSCWpcE+4Erp
+ap++BemT0qd
       "]]}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  Epilog->InsetBox[
    FormBox[
     StyleBox[
     "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
     TraditionalForm], 
    Scaled[{0.05, 0.95}]],
  Frame->{True, True, False, False},
  FrameLabel->{{
     FormBox["\"Number of individuals\"", TraditionalForm], None}, {
     FormBox["\"\"", TraditionalForm], None}},
  FrameTicks->{{{{0., 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  FrameTicksStyle->{
   FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
  GridLines->{None, None},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->NCache[{{0, 150}, {
      Log[2], 
      Log[10000]}}, {{0, 150}, {0.6931471805599453, 9.210340371976184}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, {{0., 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.756330500791314*^9, 3.7563305417492847`*^9}, 
   3.756330584148004*^9, 3.756336994957234*^9, 3.756384469116396*^9, {
   3.756390535145423*^9, 3.756390538934165*^9}, {3.756390577953017*^9, 
   3.756390594261531*^9}, {3.756390655254073*^9, 3.756390684915965*^9}, 
   3.756390736068143*^9, 3.7563909561355543`*^9, 3.756491840043756*^9, 
   3.7564919033769617`*^9, {3.756492206079246*^9, 3.756492252221015*^9}, {
   3.764202586457931*^9, 3.7642026067603273`*^9}, 3.764202682890997*^9, 
   3.764249913585663*^9, {3.764249993809445*^9, 3.764250020551547*^9}, 
   3.7715434219882793`*^9, 3.771543692487176*^9, 3.7822514437082577`*^9, {
   3.7849005666583*^9, 3.784900579194004*^9}, 3.784903245292321*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mutation dynamics (panel B)", "Subsubsection",
 CellChangeTimes->{{3.751644693247404*^9, 3.7516446957673063`*^9}, 
   3.751646095632869*^9, {3.7849032211636877`*^9, 3.784903223660363*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"n0", "=", "\"\<10000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "\"\<4\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", "\"\<0.010000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "\"\<0.01000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "\"\<0.50\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", "\"\<-0.30\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mutmax", "=", "\"\<2\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rep", "=", "\"\<675\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"genmax", "=", "150"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nmax", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ymax", "=", 
    SuperscriptBox["10", "4"]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{
   "datadir", "<>", "\"\<alleles_N\>\"", "<>", "n0", "<>", "\"\<_n\>\"", "<>",
     "n", "<>", "\"\<_U\>\"", "<>", "U", "<>", "\"\<_Es\>\"", "<>", "Es", 
    "<>", "\"\<_mmax\>\"", "<>", "mmax", "<>", "\"\<_mwt\>\"", "<>", "mwt", 
    "<>", "\"\<_mutmax\>\"", "<>", "mutmax", "<>", "\"\<_rep\>\"", "<>", 
    "rep", "<>", "\"\<.csv\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alleles", "=", 
    RowBox[{"Transpose", "[", 
     RowBox[{"PadRight", "[", "%", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{
   "datadir", "<>", "\"\<kmuts_N\>\"", "<>", "n0", "<>", "\"\<_n\>\"", "<>", 
    "n", "<>", "\"\<_U\>\"", "<>", "U", "<>", "\"\<_Es\>\"", "<>", "Es", 
    "<>", "\"\<_mmax\>\"", "<>", "mmax", "<>", "\"\<_mwt\>\"", "<>", "mwt", 
    "<>", "\"\<_mutmax\>\"", "<>", "mutmax", "<>", "\"\<_rep\>\"", "<>", 
    "rep", "<>", "\"\<.csv\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"allmuts", "=", 
    RowBox[{"Transpose", "[", 
     RowBox[{"PadRight", "[", "%", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rescuemuts", "=", 
    RowBox[{"Ordering", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"alleles", "[", 
        RowBox[{"[", 
         RowBox[{"2", ";;"}], "]"}], "]"}], "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"-", "1"}]}], "]"}], "]"}], ",", 
      RowBox[{"-", "2"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fig2b", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListLogPlot", "[", 
      RowBox[{
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"alleles", "[", 
          RowBox[{"[", 
           RowBox[{"2", ";;"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"rescuemuts", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"rescuemuts", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "}"}]}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Black", ",", 
          RowBox[{"Thickness", "[", "0.002", "]"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "genmax"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Generation\>\"", ",", "\"\<Number of copies of allele\>\""}], 
         "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<B\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"alleles", "[", 
         RowBox[{"[", 
          RowBox[{"2", ";;"}], "]"}], "]"}], "[", 
        RowBox[{"[", "rescuemuts", "]"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{
            RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
            RowBox[{"defaultcolors", "[", 
             RowBox[{"[", "2", "]"}], "]"}], ",", 
            RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}], ",", 
          RowBox[{"Directive", "[", 
           RowBox[{
            RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
            RowBox[{"defaultcolors", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], "}"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ListLogPlot", "[", 
      RowBox[{
       RowBox[{"allmuts", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Gray", ",", 
          RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}]}]}], "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "n0", ",", "n", ",", "U", ",", "Es", ",", "mmax", ",", "mwt", ",", "r", ",",
    "mutmax", ",", "rep", ",", "genmax", ",", "nmax", ",", "ymax"}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.74267566307705*^9, 3.742675738028081*^9}, {
   3.742675793382869*^9, 3.7426757941699123`*^9}, {3.7426758242657747`*^9, 
   3.7426758650463943`*^9}, {3.7426786610125723`*^9, 3.742678707278528*^9}, {
   3.742678865359585*^9, 3.7426788708994293`*^9}, {3.7431786248700647`*^9, 
   3.74317867251116*^9}, {3.743178774984033*^9, 3.743178793853217*^9}, {
   3.7431788660578403`*^9, 3.743178966613968*^9}, {3.743179006583357*^9, 
   3.743179036592964*^9}, {3.743179072719985*^9, 3.743179135126026*^9}, {
   3.743179179293623*^9, 3.743179217109619*^9}, {3.7431792852033854`*^9, 
   3.7431793547671432`*^9}, {3.7431795886138687`*^9, 3.743179665943205*^9}, {
   3.7431796963860826`*^9, 3.743179703976123*^9}, {3.743180184364689*^9, 
   3.743180184726823*^9}, {3.7432776211771593`*^9, 3.743277700536654*^9}, {
   3.7432777376714373`*^9, 3.743277919986001*^9}, 3.743278353152574*^9, {
   3.743278802125987*^9, 3.743278805400436*^9}, {3.743279048593625*^9, 
   3.743279076393252*^9}, {3.743279166224839*^9, 3.743279168335823*^9}, {
   3.7432792160679407`*^9, 3.743279240129554*^9}, {3.7432795039697323`*^9, 
   3.743279517934054*^9}, {3.743279693387833*^9, 3.7432797386881723`*^9}, {
   3.7438764370845757`*^9, 3.7438764425864573`*^9}, {3.743876481903409*^9, 
   3.743876520919177*^9}, 3.743876570192697*^9, {3.74387660075054*^9, 
   3.7438766008485327`*^9}, {3.743876634210388*^9, 3.7438767564934883`*^9}, {
   3.743876792932558*^9, 3.743876860830018*^9}, {3.743876897126893*^9, 
   3.743876900159235*^9}, {3.743876940413685*^9, 3.743877121718658*^9}, {
   3.7438771591939993`*^9, 3.743877232237978*^9}, 3.7438773082588673`*^9, {
   3.743877547277384*^9, 3.743877581979311*^9}, {3.7510320460797*^9, 
   3.7510320550121317`*^9}, {3.751559153848452*^9, 3.751559165390586*^9}, {
   3.751559218454067*^9, 3.751559236146096*^9}, 3.751644701386467*^9, 
   3.751644892512967*^9, {3.751645475830846*^9, 3.751645504983404*^9}, {
   3.75639074905398*^9, 3.756390749866386*^9}, {3.756390787404292*^9, 
   3.756390834637045*^9}, {3.7563909770961313`*^9, 3.7563910383208933`*^9}, {
   3.756391080443749*^9, 3.7563910821087923`*^9}, {3.756491500205241*^9, 
   3.7564917308287497`*^9}, 3.764202603898903*^9, {3.764202705100109*^9, 
   3.764202735459268*^9}, {3.764249930841949*^9, 3.764249954594822*^9}, {
   3.764250025682835*^9, 3.764250025887844*^9}, 3.769183523278316*^9, {
   3.769259416841812*^9, 3.769259423406817*^9}, {3.769259456564904*^9, 
   3.76925969361941*^9}, {3.769259785186446*^9, 3.76925982361383*^9}, {
   3.769259856278158*^9, 3.769259885292897*^9}, {3.769260031793565*^9, 
   3.769260057200686*^9}, {3.771164192448515*^9, 3.77116425309562*^9}, {
   3.771543713323512*^9, 3.771543734252017*^9}, {3.784900586094571*^9, 
   3.784900590994008*^9}, 3.784903238669899*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.6931471805599453}, {5., 
       1.0986122886681098`}, {6., 1.0986122886681098`}, {7., 
       0.6931471805599453}, {8., 1.0986122886681098`}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 1.0986122886681098`}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.6931471805599453}, {5., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 1.0986122886681098`}, {5., 
       1.3862943611198906`}, {6., 0.6931471805599453}, {7., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 0.6931471805599453}, {
       5., 0.}, {6., 1.0986122886681098`}, {7., 0.6931471805599453}, {8., 
       0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}, {5., 0.}, {6., 0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 1.0986122886681098`}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 1.6094379124341003`}, {4., 
       1.6094379124341003`}, {5., 2.0794415416798357`}, {6., 
       1.791759469228055}, {7., 1.0986122886681098`}, {8., 
       0.6931471805599453}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.6931471805599453}, {5., 
       0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 1.0986122886681098`}, {4., 0.}, {5., 
       0.6931471805599453}, {6., 0.}, {7., 0.}, {8., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 0.}, {5., 
       0.6931471805599453}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 0.6931471805599453}, {
       5., 0.6931471805599453}, {6., 0.}, {7., 0.6931471805599453}, {8., 
       0.}, {9., 0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}, {5., 0.}, {6., 0.}, {7., 
       0.6931471805599453}, {8., 0.6931471805599453}, {9., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 1.791759469228055}, {5., 
       1.0986122886681098`}, {6., 1.0986122886681098`}, {7., 0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 0.}, {5., 
       0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}, {5., 0.6931471805599453}, {6., 
       0.6931471805599453}, {7., 1.0986122886681098`}, {8., 0.}, {9., 
       0.6931471805599453}, {10., 1.0986122886681098`}, {11., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 
       1.0986122886681098`}, {5., 1.3862943611198906`}, {6., 
       0.6931471805599453}, {7., 0.6931471805599453}, {8., 
       0.6931471805599453}, {9., 1.0986122886681098`}, {10., 
       1.791759469228055}, {11., 1.6094379124341003`}, {12., 
       1.6094379124341003`}, {13., 0.6931471805599453}, {14., 
       1.0986122886681098`}, {15., 1.0986122886681098`}, {16., 
       0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.6931471805599453}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 1.0986122886681098`}, {4., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 1.0986122886681098`}, {4., 0.}, {5., 0.}, {6., 
       1.0986122886681098`}, {7., 1.3862943611198906`}, {8., 
       1.791759469228055}, {9., 1.0986122886681098`}, {10., 
       1.3862943611198906`}, {11., 1.3862943611198906`}, {12., 
       2.0794415416798357`}, {13., 1.9459101490553132`}, {14., 
       1.3862943611198906`}, {15., 1.6094379124341003`}, {16., 
       1.0986122886681098`}, {17., 1.3862943611198906`}, {18., 
       0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 
       0.}}]}, {}, {}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 0.6931471805599453}, {
       5., 0.}}]}, {}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}, {5., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 
       1.0986122886681098`}, {5., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 
       0.6931471805599453}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 0.6931471805599453}, {
       6., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{3., 0.}, {4., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{3., 0.}, {4., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.6931471805599453}, {6., 0.}, {7., 
       0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}, {6., 0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{3., 0.}, {4., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}, {6., 0.6931471805599453}, {7., 
       0.}, {8., 0.}, {9., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{3., 0.}, {4., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{3., 0.}, {4., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[CompressedData["
1:eJxdlHlMHHUUx0d6YLkKFBDYVm6yi0ALCJQF5LvIfbPLsuyyHFFJ24Da0pIe
io7E1KLVcFalh7SNUksLBtO0gOhYstDDEilxrabGGhroEQUKlkI5rOn7/TEz
yWbzyXc+83vz3st4vfKmusyC47h3nvz+/396PQtOdNljImp+KT54LO4pOxE/
JHbFzvbouK4THHnrJeyJjMh3z48GryD2luS+0BlCOyq9l+l5/rBecXbfvcZn
KJej+tjIdy5/MT8Abb2/ulxZv4o4EPvry5VveVgSB0vyTVTvauIQeKRkRrmc
ZnkoJr8dXqx2XkMchsNm67mvwq2JX8Q198l7TfZWxOG4ZIrdvauH9SkCYR//
PasSmB+J8ksXvh/pZv5mmG0PbJ3LsiWOQt+g8h/5qA2xEqdU/aYBN5ZHS+6P
gW1laPRIDeNYif+S5Lw4CQOGF+pThvYQ84Bpeq3GsIP5Kur/WspVqIiv67M7
bkd5PJa53OXSXSyPh77l7HHnQHvKX0Z7jPdWeT/LJcwlwGbdxd3b77I8AdNL
PfoaS+YnwrbC8f6BHcR8IqKGelsHbrE8CVWKpsaGLpYnYUP7gtkY6UB5MhRZ
Pk6JrxPzyZC5jt6pb2B+CnIqAq7+68b8FAQ5yKdahlmeir2KwbmybJan4qPQ
spuHS1meJq6HT0Pq1x2n/Y6w90tH1plPEsvO0Xz4dATFBuf9MMbmlYHhC7/M
3HjE+p8Bj6VrVzdPsn3KxEPb7vcWwmkevIS5LFh4Bsxbt7M8S7Kf2fBJO2Q2
nKLn8dni87gc8byRg7nAhrfbKmhf+Rzx/gs5kn3LFc8buZJ55Ir7JeSi173p
aPcE659avD9QS/qtpu8B89XITBow3Y5lvkacQ4PLZt+ZxzZs3hrx/YJGsp95
6JSdOX89nZ2fJ9nnPHE9Qp5kf7RihhZeqi21VUusfi2MlidaZIlUj6CF4x3h
Yrua7Wc+Evg9iyEfECMfYxu9w95QsPrzEaebMWbJmJ8vrofTifcPOnF/eZ3E
18E+MEQ2tMzOL0Bj2WSjsc2R/AJc3psQ85r/OvIL6PtMLBSgvMAy99VPiTk9
mv0W9dwXxNBDY649eH0D8/VQ+Frenk1mvh5B4zLeaqUT+QYsnFzpNf4zMQzo
2R44q7FwJt+AL5t3OnSDWDDgR5/35Zw3MVeICPc1J6daifGEHxjk6X8yvxB8
VdyM0t+F/EJMzw+Ybv5OzBkxZaftV2x8jnwjXJSelTbVxLwRyvujfOchYsGI
B59ZLx2cIOaKMLFJmdk1w/wieKSanm885kp+Ebb11m079xuxUIQuVW3N3DIx
V4zWVYJ6cJ8b+cX4KWLcSvsHMV+MR6GrBxMT3MkvxlLhh1sU3xBzJWjOHInx
eEyMEthF3/D83E9GfgmuHLnb1lJFLJSg41ZmZ91+Yq4UtQV9xqNDMvwHEIcN
CA==
       "]]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}, {6., 0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.6931471805599453}, {6., 0.}, {7., 
       0.6931471805599453}, {8., 0.}, {9., 0.6931471805599453}, {10., 
       0.6931471805599453}, {11., 0.6931471805599453}, {12., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 1.0986122886681098`}, {6., 
       0.6931471805599453}, {7., 0.6931471805599453}, {8., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.}}]}, {}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{3., 0.}, {4., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 1.0986122886681098`}, {6., 
       0.6931471805599453}, {7., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 1.0986122886681098`}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{3., 0.}, {4., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 0.6931471805599453}, {
       6., 1.0986122886681098`}, {7., 1.0986122886681098`}, {8., 
       1.3862943611198906`}, {9., 0.6931471805599453}, {10., 
       0.6931471805599453}, {11., 0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{4., 0.}, {5., 0.6931471805599453}, {6., 0.6931471805599453}, {
       7., 1.0986122886681098`}, {8., 1.0986122886681098`}, {9., 
       1.0986122886681098`}, {10., 0.6931471805599453}, {11., 
       1.3862943611198906`}, {12., 1.3862943611198906`}, {13., 
       0.6931471805599453}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{4., 0.}, {5., 0.}}]}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{4., 0.}, {5., 0.}}]}, {}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{4., 0.}, {5., 1.0986122886681098`}, {6., 
       1.6094379124341003`}, {7., 0.6931471805599453}, {8., 
       1.3862943611198906`}, {9., 0.}, {10., 0.6931471805599453}, {11., 
       0.6931471805599453}, {12., 0.6931471805599453}, {13., 0.}, {14., 
       0.6931471805599453}, {15., 0.6931471805599453}, {16., 
       0.6931471805599453}, {17., 1.0986122886681098`}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{4., 0.}, {5., 0.6931471805599453}, {6., 0.}, {7., 
       0.}}]}, {}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{4., 0.}, {5., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.}, {7., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{4., 0.}, {5., 0.6931471805599453}, {6., 
       0.}}]}, {}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{4., 0.}, {5., 0.6931471805599453}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{4., 0.}, {5., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.6931471805599453}, {7., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{4., 0.}, {5., 1.0986122886681098`}, {6., 
       0.6931471805599453}, {7., 0.6931471805599453}, {8., 
       1.6094379124341003`}, {9., 1.3862943611198906`}, {10., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{5., 0.}, {6., 1.0986122886681098`}, {7., 
       1.0986122886681098`}, {8., 0.6931471805599453}, {9., 
       1.0986122886681098`}, {10., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{5., 0.}, {6., 0.}}]}, {}, {}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{5., 0.}, {6., 1.3862943611198906`}, {7., 
       2.1972245773362196`}, {8., 0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{5., 0.}, {6., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{5., 0.}, {6., 1.0986122886681098`}, {7., 0.}, {8., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{5., 0.}, {6., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{5., 0.}, {6., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 1.0986122886681098`}, {8., 
       0.6931471805599453}, {9., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 1.3862943611198906`}, {8., 
       1.3862943611198906`}, {9., 0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{5., 0.}, {6., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{5., 0.}, {6., 
       0.6931471805599453}}]}, {}, {}, {}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{5., 0.}, {6., 0.6931471805599453}, {7., 0.6931471805599453}, {
       8., 0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{5., 0.}, {6., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{5., 0.}, {6., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{5., 0.}, {6., 0.6931471805599453}, {7., 0.}, {8., 
       0.6931471805599453}, {9., 0.6931471805599453}, {10., 
       0.6931471805599453}, {11., 0.6931471805599453}, {12., 0.}, {13., 
       0.}}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{6., 0.}, {7., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{6., 0.}, {7., 0.}, {8., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{6., 0.}, {7., 0.6931471805599453}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{6., 0.}, {7., 0.}, {8., 0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{6., 0.}, {7., 1.0986122886681098`}, {8., 
       1.3862943611198906`}, {9., 1.791759469228055}, {10., 
       2.0794415416798357`}, {11., 2.1972245773362196`}, {12., 
       1.0986122886681098`}, {13., 0.6931471805599453}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{6., 0.}, {7., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{6., 0.}, {7., 0.}, {8., 0.6931471805599453}, {9., 
       1.0986122886681098`}, {10., 1.0986122886681098`}, {11., 
       0.}}]}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{6., 0.}, {7., 0.6931471805599453}, {8., 0.}, {9., 
       1.0986122886681098`}, {10., 0.6931471805599453}, {11., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{6., 0.}, {7., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{6., 0.}, {7., 0.}, {8., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{6., 0.}, {7., 1.0986122886681098`}, {8., 
       0.6931471805599453}, {9., 1.0986122886681098`}, {10., 
       0.6931471805599453}, {11., 0.6931471805599453}, {12., 
       0.6931471805599453}, {13., 1.3862943611198906`}, {14., 
       1.3862943611198906`}, {15., 1.0986122886681098`}, {16., 
       0.6931471805599453}, {17., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{6., 0.}, {7., 1.0986122886681098`}, {8., 0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{6., 0.}, {7., 0.}}]}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{6., 0.}, {7., 0.6931471805599453}, {8., 
       1.0986122886681098`}, {9., 1.3862943611198906`}, {10., 
       1.0986122886681098`}, {11., 1.3862943611198906`}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{6., 0.}, {7., 0.}, {8., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{7., 0.}, {8., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{7., 0.}, {8., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{7., 0.}, {8., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{7., 0.}, {8., 0.}, {9., 1.0986122886681098`}, {10., 
       0.6931471805599453}, {11., 0.6931471805599453}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{7., 0.}, {8., 0.}, {9., 0.6931471805599453}, {10., 
       0.}}]}, {}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{7., 0.}, {8., 0.}, {9., 0.}, {10., 0.}}]}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{7., 0.}, {8., 0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{7., 0.}, {8., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{8., 0.}, {9., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{8., 0.}, {9., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{8., 0.}, {9., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{8., 0.}, {9., 0.6931471805599453}, {10., 
       1.0986122886681098`}, {11., 1.3862943611198906`}, {12., 
       0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{8., 0.}, {9., 0.}, {10., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{8., 0.}, {9., 0.6931471805599453}, {10., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{8., 0.}, {9., 0.}, {10., 0.}, {11., 0.}, {12., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{8., 0.}, {9., 0.}, {10., 0.}, {11., 0.}, {12., 
       0.6931471805599453}, {13., 0.6931471805599453}, {14., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{8., 0.}, {9., 0.}, {10., 0.}, {11., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{9., 0.}, {10., 1.0986122886681098`}, {11., 
       1.6094379124341003`}, {12., 0.}, {13., 0.}, {14., 
       0.6931471805599453}, {15., 0.6931471805599453}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{9., 0.}, {10., 0.6931471805599453}, {11., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{9., 0.}, {10., 0.}, {11., 0.}}]}, {}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{10., 0.}, {11., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{10., 0.}, {11., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{10., 0.}, {11., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{10., 0.}, {11., 0.6931471805599453}, {12., 0.}, {13., 
       0.6931471805599453}, {14., 0.6931471805599453}, {15., 0.}, {16., 0.}, {
       17., 0.6931471805599453}, {18., 0.}, {19., 0.}}]}, {}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQDQEaDgwoQMvhveWvf056z+whfB00vh4a38CBm3lt
1avJH6F8Q6j8NyjfCE3eGE3eBI1v6mDc+/a744GfUL4Zmrw5mnst0PiWaPZZ
oclbo/Ft0Pi2aP6zg8sDAGUjQNE=
       "]]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{12., 0.}, {13., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{13., 0.}, {14., 0.6931471805599453}, {15., 0.}, {16., 
       0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{13., 0.}, {14., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{14., 0.}, {15., 0.6931471805599453}, {16., 0.}, {17., 
       0.6931471805599453}, {18., 1.0986122886681098`}, {19., 
       0.6931471805599453}, {20., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{15., 0.}, {16., 0.6931471805599453}, {17., 0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{20., 0.}, {21., 0.}, {22., 0.6931471805599453}, {23., 
       1.0986122886681098`}, {24., 0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{26., 0.}, {27., 0.6931471805599453}, {28., 
       0.6931471805599453}, {29., 0.6931471805599453}, {30., 
       1.0986122886681098`}, {31., 0.6931471805599453}, {32., 
       1.0986122886681098`}, {33., 1.0986122886681098`}, {34., 0.}, {35., 
       0.}, {36., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{30., 0.}, {31., 0.}, {32., 0.6931471805599453}, {33., 
       1.0986122886681098`}, {34., 1.0986122886681098`}, {35., 0.}, {36., 
       1.0986122886681098`}, {37., 1.791759469228055}, {38., 
       1.9459101490553132`}, {39., 1.0986122886681098`}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{36., 0.}, {37., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{36., 0.}, {37., 0.}, {38., 0.}, {39., 1.0986122886681098`}, {
       40., 1.0986122886681098`}, {41., 1.6094379124341003`}, {42., 
       1.791759469228055}, {43., 2.0794415416798357`}, {44., 
       1.0986122886681098`}, {45., 1.0986122886681098`}, {46., 
       0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{37., 0.}, {38., 0.6931471805599453}, {39., 0.}, {40., 0.}, {
       41., 0.}, {42., 0.}, {43., 0.6931471805599453}, {44., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{38., 0.}, {39., 0.}, {40., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{41., 0.}, {42., 0.}, {43., 0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{45., 0.}, {46., 0.}}]}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{50., 0.}, {51., 0.}, {52., 1.3862943611198906`}, {53., 
       0.6931471805599453}, {54., 0.6931471805599453}, {55., 0.}, {56., 
       0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{52., 0.}, {53., 0.}, {54., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{53., 0.}, {54., 0.}, {55., 0.6931471805599453}, {56., 0.}, {
       57., 0.6931471805599453}, {58., 1.6094379124341003`}, {59., 
       1.0986122886681098`}, {60., 1.0986122886681098`}, {61., 
       2.302585092994046}, {62., 2.0794415416798357`}, {63., 
       2.3978952727983707`}, {64., 2.302585092994046}, {65., 
       1.0986122886681098`}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{62., 0.}, {63., 0.}, {64., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{68., 0.}, {69., 0.}, {70., 0.}, {71., 
       0.6931471805599453}}]}, {}, {}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{71., 0.}, {72., 0.}, {73., 0.6931471805599453}, {74., 
       0.6931471805599453}, {75., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{76., 0.}, {77., 0.}, {78., 0.6931471805599453}, {79., 
       0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], LineBox[{{81., 0.}, {82., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQYNIQ4MyOBAiMN7y1//nPS+2UMEQh24mddWvZr8
EcJ3CHVgUtD6xb36D4TfgMY/EOogFrp198ZsJqi5YQ7Fq63tNy1igPAdwhzC
o4zWFSn9h+oPczDuffvd8cBPqH40eYZwVPMd0PgN4ajqD6DJM0Sg+schAtW+
hghU9x1A4zNEQv3PCHV/JKr/GiId2iZmW1XLs0P1R0LN54Tqj3KY+Li42uk7
VN4hyqGq/tfB7FVsUP1RDvIevpZiq1ih+qMcAnsMtVlaWaD6ox1q513eI/aQ
Gao/GtV9DdGo6g+gyTPEoLk/BhoeMPtjHGZf4/65zJQbqj8GGn48UP2xDt94
dzb+MYXyHWIdBN+IiH0Q44Pqj0VVfyDW4eKOq19u/ICaxxCHpj/OYYXj4aPH
JHmh+uMcrvF2ZPz0g/IPxKHZH++w5OTiMu4SqH0O8Q6rbZQyNA7zQ/XHO/xn
CPyfUALlH4h3CMjROv1VUgCqP8GhVHPK5EmbBBwAMMjKUg==
       "]]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{84., 0.}, {85., 0.6931471805599453}, {86., 
       1.3862943611198906`}, {87., 0.}, {88., 0.}, {89., 
       1.0986122886681098`}, {90., 1.3862943611198906`}, {91., 
       1.0986122886681098`}, {92., 1.6094379124341003`}, {93., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{87., 0.}, {88., 0.6931471805599453}, {89., 
       0.6931471805599453}, {90., 0.}, {91., 0.}, {92., 0.6931471805599453}, {
       93., 0.}, {94., 0.6931471805599453}, {95., 0.}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{92., 0.}, {93., 0.}, {94., 0.6931471805599453}}]}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{108., 0.}, {109., 0.}}]}, {}, 
     {GrayLevel[0], Thickness[0.002], 
      LineBox[{{115., 0.}, {116., 0.}}]}}, {}}, {{{}, {}, 
     {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[0.005], Dashing[
      Medium], LineBox[CompressedData["
1:eJxd0mtIU3EYx/GTtzIts8vUFphCYSlChja18jcrsjB0Zzd3l8gXuagw0XLG
TmH5Il1NX5klQeDK0rCw5iX9p92j3lgaGJktsjeWZXgZohl7Bq0Dh8Pn8P8+
PBxOzMFjfIEfx3G7F+6/T8+VA+7fS8jBj1T3XGbi1wzPi1xfw+tJj4X/zHKx
tXpsSspmqJfBb/1md8itWeplUGuTWopi56mXQaRs62w1+3n2YDLIqrbEB5wL
oL14ODoHRS/XBXoMHuft5jRL9GKPBR521wlL5hSZ8cjeZn3gSvSnXu5ryBGd
dSBV1ETzBDntH0S9HKcb+rtEI95e4XseCt99BAXKrO5H5iZvr0DCvYCgFBvt
wynpewRTr8RMQk254whZUOJShb9z2LCUeiXqB0JmGpNDqFfR9wulXoXoudev
JON0XlDB/NzZ3d9O55nKdz6n9p0HNR4+S/se56J5gho3pH1PnkYto14NcaTr
m71mBfV5eFswGRzXHk59HgqLp+8vUq+kPm9hXuXwtJXM8vA4l9ULHWROg9qC
8Vq9gwwN6nocpcoEb6/xnc80+FyfkjxU6+21uCq8KwtrWUW9FmWn4kcHNqym
Xkv/C5lpweIzx24XkTkdJIUZSdURa6jXoc7WUNhbQhZ06MuaaIjpIjMdUm7y
hv0WEfV62EqsZ7d/JEOP3qqL4ddjI6jXo+1yo9QWRmZ6aGIl196ryJwBQ/Pi
Tl0xGQZUzH/gg4IjqTcg5sXPSskmMjPgk9vJNVvJnBF7lvjP/m4lw4ieL3d6
RpKjqDdi3/JdTt5OZkakd3DNO+bInAnDhy3lkpNrqTehPDRQyXeTBRPso8cP
nRkhMxNKf0mz5eli6vOxc7DVeHcveX0+rmw8OvHmghh/AGdYKXA=
       "]]}, 
     {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[0.005], 
      LineBox[CompressedData["
1:eJxdlHtMlXUYx9/wQnITEAg4GnfGIUCBADlAfCHucIBzDpdzDofLKqYOKkWZ
aDHfWFMpa1yt8BLqChOFRnMKRL3JDngJFrLImi0bDkSXgJAIcsnm8/vjfd/t
7Oyz7/t5f8/7PM9etzfeVRebcBx34Nnv///n14vgRJc1JsMXlmMDxqKfsx3x
Y2JH7G6NiO44zZG3UcKuSAs7cGk0YBWxuyT3RK4+qK3MfYWe5w3zVRf2369/
gXIfVJ4c/t7hb+b7oqX7N4frG9cQ++FgbYniPRdT4gBJvoXqXUscCJckZbjD
OZYHYeq7oaVK+3XEwTg2Yj7/dYg58asYcJ6632BtRhyCq8aovXu6WJ9CEfzJ
P3MxAvPDUHL18g/DnczfihHLw9vn0y2Jw9HTr3joM2pBrMDZmF5jnxPLIyT3
R8KyLChiuIpxlMR/TXJetIQB/Su1SYMVxDxgnFmv0e9ifgz1fz3lMSiNremx
OmVFeSxWONVK0R6Wx0LXdOGUvZ815a+jNdJ9u08vyyXMxcFiw5W9OydYHoeZ
5S5dlSnz42FZavvg8C5iPh7hg93NfXdYnoByeUN9XQfLE7CpdXHEEGZDeSLk
6R528W8T84mQOY7eq61jfhIyS31v/OvE/CT42/hMNw2xPBn75P3zxRksT8bH
QcW3jxWxPEVcD5+C5G/aznkdZ++XivTzn8YXX6T58KnwjwrI+nGMzSsNQ5d/
nb31hPU/DS7LAze2TrF9UuKxZecHiyE0D17CXDpMXH0XzFtZni7Zzwx4pBwd
0Z+l5/EZ4vO4TPG8kYl5v7r3W0ppX/lM8f4LmZJ9U4nnDZVkHipxvwQVup0b
TnROsv6pxfsDtaTfavoeMF8NZUKf8W4U8zXiHBpcG/GcfWrB5q0R3y9oJPuZ
hXbZ+Us3U9n5WZJ9zhLXI2RJ9idbzMiGW8y26vJlVn82DKanm2TxVI+QDdt7
wpVWNdvPHMTxFUuBh4iRg7HN7sHvyFn9OYjOnTWky5ifI66HyxXvH3LF/eVz
JX4urP0CZYMr7Hwt6oun6g0ttuRrcW1fXORb3hvI19L3mVjQokRrqnrzM2JO
h0avJR33JTF00IxUH7m5ifk6yD1N784lMl8H/3EZb7bajnw9Fs+sdhv/hRh6
dO30m9OY2JOvx1eNu206QSzo8ZPHhz6cOzGXh1DndWemm4nxjB/pfVL/Yn4e
+PLoWYW3A/l5mFnoM97+g5gzYNoqu1e++SXyDXBQuJZZVBLzBigejPLtR4kF
Ax59br58ZJKYy8fkFoWyY5b5+ZjQDlQ8rHAkPx8uycaX608SC/nY0V2z4+Lv
xFwBOmKqq+ZXiFGA5jWCun+/E/kF+Dl03Cz7T2KhAE+C1vbHxzmTX4jlvI+2
yb8lRiEalcORLk+J+UJYRdxy/cJLRn4hrh+faGkqJ+aK0HZH2V5zkNi1CNXa
HsOJQRn+A5eEEg0=
       "]]}}, {}}, {{{}, {}, 
     {GrayLevel[0.5], Thickness[0.005], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwYJW6nDrtvCKUz+Hgl3/J
UV0NxhdwuDkp8nn4ZAUoX8Qh4/BDxgs/5aF8CYdLBxPebT0tB+XLOBwz9ZSY
M1MWyldw+FeeccwiQAbKV3IoiDx69YCaNJSv4vDfNLe2/bAklK/m8ODXDoa1
9RJQvoZDsCEHw81gcShfy+Hr9tad326JQvk6DpvWt8lJ3BGB8vUc4jrcXtoe
EYbyDRx+LGGve+IoBOUbOhRvXN8ZUCUI5Rs5BORonf4qKQDlGzuU7g6wsfjB
B+WbOOw9bvVO4zEPlG/qoOw17VrUCi4o38yhbWK2VbU8O5Rv7rB893WxUzKs
UL6Fw3vLX/+c9NigfEsH49633x0P/LSH8K2g8t+gfGsHbua1Va8mf4TybaDy
z6B8W6g5DAwA6nx01A==
       "]]}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  Epilog->InsetBox[
    FormBox[
     StyleBox[
     "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
     TraditionalForm], 
    Scaled[{0.05, 0.95}]],
  Frame->{True, True, False, False},
  FrameLabel->{{
     FormBox["\"Number of copies of allele\"", TraditionalForm], None}, {
     FormBox["\"Generation\"", TraditionalForm], None}},
  FrameTicks->{{{{0., 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{0, 150}, {0., 9.210340371976184}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, {{0., 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.756390795815605*^9, 3.7563908352676067`*^9}, {
   3.7563909809790487`*^9, 3.756391039268383*^9}, 3.756391082981555*^9, {
   3.75649150196146*^9, 3.756491510493539*^9}, {3.756491541003747*^9, 
   3.756491703378837*^9}, 3.756491734151883*^9, {3.764202721210169*^9, 
   3.7642027362319098`*^9}, {3.7642499406207933`*^9, 3.7642499565698442`*^9}, 
   3.7642500287952433`*^9, {3.769259408410757*^9, 3.7692594721272163`*^9}, {
   3.769259506059464*^9, 3.7692595262366457`*^9}, {3.769259585259186*^9, 
   3.769259695169592*^9}, {3.769259787495201*^9, 3.7692598242401114`*^9}, {
   3.769259860235731*^9, 3.769259879605158*^9}, {3.769260045103189*^9, 
   3.769260058298608*^9}, {3.771164178326008*^9, 3.7711642499409857`*^9}, 
   3.771543729738551*^9, 3.7715437698977547`*^9, 3.782251450148861*^9, 
   3.784900591890554*^9, 3.784903245653945*^9}]
}, Closed]],

Cell["\<\
Note that the first mutation is subcritical, but the second mutation makes \
the double mutant supercritical (we can see this because we keep track of \
what is supercritical in the sims):\
\>", "Text",
 CellChangeTimes->{{3.764249506228717*^9, 3.764249515282794*^9}, {
   3.7642496888785257`*^9, 3.76424970120361*^9}, {3.7692602977053347`*^9, 
   3.7692603018155537`*^9}, {3.771543915156007*^9, 3.7715439328509417`*^9}, 
   3.771544043382402*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"n0", "=", "\"\<10000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "\"\<4\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", "\"\<0.010000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "\"\<0.01000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "\"\<0.50\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", "\"\<-0.30\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mutmax", "=", "\"\<2\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rep", "=", "\"\<675\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"genmax", "=", "150"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nmax", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ymax", "=", 
    SuperscriptBox["10", "4"]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{
   "datadir", "<>", "\"\<supercrit_kmuts_N\>\"", "<>", "n0", "<>", 
    "\"\<_n\>\"", "<>", "n", "<>", "\"\<_U\>\"", "<>", "U", "<>", 
    "\"\<_Es\>\"", "<>", "Es", "<>", "\"\<_mmax\>\"", "<>", "mmax", "<>", 
    "\"\<_mwt\>\"", "<>", "mwt", "<>", "\"\<_mutmax\>\"", "<>", "mutmax", 
    "<>", "\"\<_rep\>\"", "<>", "rep", "<>", "\"\<.csv\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"supermuts", "=", 
    RowBox[{"Transpose", "[", 
     RowBox[{"PadRight", "[", "%", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListLogPlot", "[", 
   RowBox[{"supermuts", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "genmax"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "nmax"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Generation\>\"", ",", "\"\<Number of copies of allele\>\""}], 
      "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "n0", ",", "n", ",", "U", ",", "Es", ",", "mmax", ",", "mwt", ",", "r", ",",
    "mutmax", ",", "rep", ",", "genmax", ",", "nmax", ",", "ymax"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.764249460297406*^9, 3.7642494972191677`*^9}, 
   3.7642496838919067`*^9, {3.764250121596263*^9, 3.764250121879079*^9}, {
   3.771543941005742*^9, 3.7715440006018257`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, {}, {}, 
    {Hue[0.1421359549995791, 0.6, 0.6], 
     LineBox[{{13., 0.}, {14., 0.6931471805599453}, {15., 0.}, {16., 0.}}], 
     LineBox[{{20., 0.}, {21., 0.}, {22., 0.6931471805599453}, {23., 
      1.0986122886681098`}, {24., 0.6931471805599453}}], 
     LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQFWDgwowNrhveWvf056z+whfBs0vi0a386Bm3lt
1avJH6F8ezR5B1T5BjQ+gyOq/Q1ofAYnVPManNDkndH0O6OZ74Jmv4sDk4LW
L+7Vf6Dyrg7hUUbripT+Q+VdHcRCt+7emM0ENdcNTb8b1D3foPrd4fIAMCdR
Lg==
      "]], LineBox[CompressedData["
1:eJxdz2tIU2Ecx/GDl5oua2lOm8MtKrqBIKGpUf60FBNTd3X3DWFQjK5LX2jm
orKbJsMsKYqhRRcVS7MSs847SxuWgiVGkpOKqJxgM21Jl/33Yh44HL48z+f/
PGdV8QGpOYhhmJ1/339f31OAydS5+cyEj+n/01YAbnBr2Ze6KV8zhYGNQtrv
of0Lmi3E5ppvMxnsLHkJgsQb57jNXvISWJu3prc3MvB5CfiKzu77liBfsxJI
qhM3hZwK8TUjxa3uN/w+YaivIUWV3ZJWLlpMXgq7y1qeOUPNSpG3pfKRKyGY
vAwV14ee8D9QQ0b3XUReFjiPlS04Xw5Rzu5U/l3/+fLA+9jkC7wc7o7Xvyui
w8grIJp39qe4w8krYHn++OlQF5e8Aj29ad/Xu5aQVyC/5UKWuTOCvBI3XjSV
co8sJa/EcMSZPbP5tG5TBu5nlfBEdB33JtE8pihwHUXYIfcmh2bTPFtR4Hy2
CN2Ci9e6JnnkVTAd0v/q+7ycvApfo9Rmz9lI8iokZl/pynVSsyqcr7m5tjU4
irwaWdsmjg7M0TrUGL+anDRa5/fqv/9/euxnpd+r0f+w887hg36vgY4jsDWk
riCvgXBUBZ6d2qZBe1tVfOw7alYDVU4tb/wZNaOF2BVd36SOJq9FsiCsacpB
bdPi3DFDTMs0NatFltnVUd3AJ69D/4b994ReauggS+QwI7IY8jqY1MrZyxZq
VgehY98neQ81o4ejnsPpHaSGHu51vfGhe2PJ69GQt0bKqaFm9Xi5fSJb6qRm
DHgfFzIW7qGGAW/djqYe60ryBtTatZEnXlGzBpT0iMraUgTkjVide2lYc5sa
RsRnzD/I9VDbjJj8kT/tEceRNyK6zTpQaqVmTNg1yB8pOUktNoG3zFvc6IzD
HxlsK7w=
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  Frame->{True, True, False, False},
  FrameLabel->{{
     FormBox["\"Number of copies of allele\"", TraditionalForm], None}, {
     FormBox["\"Generation\"", TraditionalForm], None}},
  FrameTicks->{{{{0., 
       FormBox["1", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["5", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {3.912023005428146, 
       FormBox["50", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.214608098422191, 
       FormBox["500", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {8.517193191416238, 
       FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{0, 150}, {0., 6.950814768442584}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, {{0., 
      FormBox["1", TraditionalForm]}, {1.6094379124341003`, 
      FormBox["5", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {3.912023005428146, 
      FormBox["50", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.214608098422191, 
      FormBox["500", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {8.517193191416238, 
      FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{
  3.7642495008354807`*^9, 3.764250122222436*^9, {3.7715439385497627`*^9, 
   3.771544003617297*^9}, 3.7822514598144007`*^9}]
}, Closed]],

Cell["\<\
The blue replicate is also 2-step rescue\
\>", "Text",
 CellChangeTimes->{{3.764250055719748*^9, 3.764250064826706*^9}, {
   3.7642501648691063`*^9, 3.764250171720592*^9}, 3.771544041151711*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"n0", "=", "\"\<10000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "\"\<4\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", "\"\<0.010000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "\"\<0.01000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "\"\<0.50\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", "\"\<-0.30\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mutmax", "=", "\"\<2\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rep", "=", "\"\<629\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"genmax", "=", "150"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nmax", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ymax", "=", 
    SuperscriptBox["10", "4"]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{
   "datadir", "<>", "\"\<alleles_N\>\"", "<>", "n0", "<>", "\"\<_n\>\"", "<>",
     "n", "<>", "\"\<_U\>\"", "<>", "U", "<>", "\"\<_Es\>\"", "<>", "Es", 
    "<>", "\"\<_mmax\>\"", "<>", "mmax", "<>", "\"\<_mwt\>\"", "<>", "mwt", 
    "<>", "\"\<_mutmax\>\"", "<>", "mutmax", "<>", "\"\<_rep\>\"", "<>", 
    "rep", "<>", "\"\<.csv\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alleles", "=", 
    RowBox[{"Transpose", "[", 
     RowBox[{"PadRight", "[", "%", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{
   "datadir", "<>", "\"\<kmuts_N\>\"", "<>", "n0", "<>", "\"\<_n\>\"", "<>", 
    "n", "<>", "\"\<_U\>\"", "<>", "U", "<>", "\"\<_Es\>\"", "<>", "Es", 
    "<>", "\"\<_mmax\>\"", "<>", "mmax", "<>", "\"\<_mwt\>\"", "<>", "mwt", 
    "<>", "\"\<_mutmax\>\"", "<>", "mutmax", "<>", "\"\<_rep\>\"", "<>", 
    "rep", "<>", "\"\<.csv\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"allmuts", "=", 
    RowBox[{"Transpose", "[", 
     RowBox[{"PadRight", "[", "%", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ListLogPlot", "[", 
     RowBox[{
      RowBox[{"alleles", "[", 
       RowBox[{"[", 
        RowBox[{"2", ";;"}], "]"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "genmax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Frame", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
      ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Generation\>\"", ",", "\"\<Number of copies of allele\>\""}], 
        "}"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"\"\<B\>\"", ",", "14", ",", "Bold"}], "]"}], ",", 
           RowBox[{"Scaled", "@", 
            RowBox[{"{", 
             RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}], ","}], "*)"}],
       "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Thickness", "[", "0.005", "]"}]}]}], "\[IndentingNewLine]", 
     "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{
      RowBox[{"allmuts", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Gray", ",", 
         RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{
   "datadir", "<>", "\"\<supercrit_kmuts_N\>\"", "<>", "n0", "<>", 
    "\"\<_n\>\"", "<>", "n", "<>", "\"\<_U\>\"", "<>", "U", "<>", 
    "\"\<_Es\>\"", "<>", "Es", "<>", "\"\<_mmax\>\"", "<>", "mmax", "<>", 
    "\"\<_mwt\>\"", "<>", "mwt", "<>", "\"\<_mutmax\>\"", "<>", "mutmax", 
    "<>", "\"\<_rep\>\"", "<>", "rep", "<>", "\"\<.csv\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"supermuts", "=", 
    RowBox[{"Transpose", "[", 
     RowBox[{"PadRight", "[", "%", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListLogPlot", "[", 
   RowBox[{"supermuts", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "genmax"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "nmax"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Generation\>\"", ",", "\"\<Number of copies of allele\>\""}], 
      "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "n0", ",", "n", ",", "U", ",", "Es", ",", "mmax", ",", "mwt", ",", "r", ",",
    "mutmax", ",", "rep", ",", "genmax", ",", "nmax", ",", "ymax"}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.74267566307705*^9, 3.742675738028081*^9}, {
   3.742675793382869*^9, 3.7426757941699123`*^9}, {3.7426758242657747`*^9, 
   3.7426758650463943`*^9}, {3.7426786610125723`*^9, 3.742678707278528*^9}, {
   3.742678865359585*^9, 3.7426788708994293`*^9}, {3.7431786248700647`*^9, 
   3.74317867251116*^9}, {3.743178774984033*^9, 3.743178793853217*^9}, {
   3.7431788660578403`*^9, 3.743178966613968*^9}, {3.743179006583357*^9, 
   3.743179036592964*^9}, {3.743179072719985*^9, 3.743179135126026*^9}, {
   3.743179179293623*^9, 3.743179217109619*^9}, {3.7431792852033854`*^9, 
   3.7431793547671432`*^9}, {3.7431795886138687`*^9, 3.743179665943205*^9}, {
   3.7431796963860826`*^9, 3.743179703976123*^9}, {3.743180184364689*^9, 
   3.743180184726823*^9}, {3.7432776211771593`*^9, 3.743277700536654*^9}, {
   3.7432777376714373`*^9, 3.743277919986001*^9}, 3.743278353152574*^9, {
   3.743278802125987*^9, 3.743278805400436*^9}, {3.743279048593625*^9, 
   3.743279076393252*^9}, {3.743279166224839*^9, 3.743279168335823*^9}, {
   3.7432792160679407`*^9, 3.743279240129554*^9}, {3.7432795039697323`*^9, 
   3.743279517934054*^9}, {3.743279693387833*^9, 3.7432797386881723`*^9}, {
   3.7438764370845757`*^9, 3.7438764425864573`*^9}, {3.743876481903409*^9, 
   3.743876520919177*^9}, 3.743876570192697*^9, {3.74387660075054*^9, 
   3.7438766008485327`*^9}, {3.743876634210388*^9, 3.7438767564934883`*^9}, {
   3.743876792932558*^9, 3.743876860830018*^9}, {3.743876897126893*^9, 
   3.743876900159235*^9}, {3.743876940413685*^9, 3.743877121718658*^9}, {
   3.7438771591939993`*^9, 3.743877232237978*^9}, 3.7438773082588673`*^9, {
   3.743877547277384*^9, 3.743877581979311*^9}, {3.7510320460797*^9, 
   3.7510320550121317`*^9}, {3.751559153848452*^9, 3.751559165390586*^9}, {
   3.751559218454067*^9, 3.751559236146096*^9}, 3.751644701386467*^9, 
   3.751644892512967*^9, {3.751645475830846*^9, 3.751645504983404*^9}, {
   3.75639074905398*^9, 3.756390749866386*^9}, {3.756390787404292*^9, 
   3.756390834637045*^9}, {3.7563909770961313`*^9, 3.7563910383208933`*^9}, {
   3.756391080443749*^9, 3.7563910821087923`*^9}, {3.756491500205241*^9, 
   3.7564917308287497`*^9}, 3.764202603898903*^9, {3.764202705100109*^9, 
   3.764202735459268*^9}, {3.764250038948617*^9, 3.764250113784154*^9}, {
   3.771543818461954*^9, 3.771543828884036*^9}, {3.7715439840618963`*^9, 
   3.771543994654084*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, {}, 
     {Hue[0.9060679774997897, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}, {5., 
       0.}}]}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {Hue[0.030679774997896203`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}, {5., 0.}, {6., 
       0.6931471805599453}}]}, 
     {Hue[0.266747752497686, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}, {5., 0.6931471805599453}, {6., 
       0.}}]}, {}, 
     {Hue[0.7388837074972656, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}}]}, 
     {Hue[0.9749516849970554, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}}]}, {}, {}, 
     {Hue[0.6831556174964248, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 1.0986122886681098`}, {4., 
       1.0986122886681098`}, {5., 1.0986122886681098`}, {6., 
       1.0986122886681098`}, {7., 0.}, {8., 0.}, {9., 0.}, {10., 0.}}]}, {}, 
     {Hue[0.15529157249600445`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.39135954999579425`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 0.}, {5., 
       0.}}]}, {}, 
     {Hue[0.8634955049953739, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.09956348249516367, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}}]}, 
     {Hue[0.3356314599949535, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.5716994374947433, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.6931471805599453}, {5., 0.}}]}, 
     {Hue[0.8077674149945295, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 1.0986122886681098`}, {4., 
       1.6094379124341003`}, {5., 0.6931471805599453}, {6., 
       1.0986122886681098`}, {7., 1.6094379124341003`}, {8., 
       1.791759469228055}, {9., 2.1972245773362196`}, {10., 
       1.791759469228055}, {11., 1.791759469228055}, {12., 
       2.1972245773362196`}, {13., 2.302585092994046}, {14., 
       1.9459101490553132`}, {15., 1.6094379124341003`}, {16., 
       1.9459101490553132`}, {17., 1.791759469228055}, {18., 
       1.3862943611198906`}, {19., 0.}}]}, 
     {Hue[0.04383539249432289, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, {}, 
     {Hue[0.5159713474939025, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.7520393249936888, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 1.0986122886681098`}, {5., 
       1.3862943611198906`}, {6., 0.}}]}, {}, {}, {}, 
     {Hue[0.696311234992848, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.9323792124926413, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, {}, {}, {}, {}, {}, {}, 
     {Hue[0.5848550549911664, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.8209230324909598, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.6931471805599453}}]}, 
     {Hue[0.05699100999074602, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}}]}, 
     {Hue[0.2930589874905394, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 0.6931471805599453}, {
       5., 1.0986122886681098`}, {6., 0.}, {7., 0.}}]}, 
     {Hue[0.5291269649903256, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 
       1.3862943611198906`}, {5., 0.6931471805599453}, {6., 0.}}]}, {}, 
     {Hue[0.0012629199899052423`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}}]}, {}, {}, 
     {Hue[0.7094668524892711, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}}]}, {}, {}, 
     {Hue[0.4176707849886441, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, {}, {}, 
     {Hue[0.12587471748801704`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.3619426949878033, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 0.}, {5., 0.}, {6., 
       0.}}]}, {}, 
     {Hue[0.8340786499873758, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {Hue[0.19475842498528095`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, 
     {Hue[0.4308264024850672, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, {}, 
     {Hue[0.9029623574846397, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}, {6., 0.}, {7., 
       0.6931471805599453}, {8., 0.6931471805599453}, {9., 
       0.6931471805599453}, {10., 0.}}]}, {}, 
     {Hue[0.3750983124842264, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 0.6931471805599453}, {
       6., 0.6931471805599453}, {7., 0.}}]}, 
     {Hue[0.6111662899840127, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, {}, 
     {Hue[0.0833022449835994, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}}]}, 
     {Hue[0.31937022248338565`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}}]}, 
     {Hue[0.5554381999831719, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 
       0.6931471805599453}}]}, 
     {Hue[0.7915061774829582, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, {}, {}, 
     {Hue[0.4997101099823311, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}}]}, {}, 
     {Hue[0.9718460649819178, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 
       0.6931471805599453}}]}, 
     {Hue[0.2079140424817041, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, {}, 
     {Hue[0.6800499974812766, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}, {6., 0.}, {7., 0.}, {8., 
       0.}}]}, {}, {}, {}, 
     {Hue[0.6243219074804358, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, 
     {Hue[0.8603898849802363, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 
       1.3862943611198906`}, {6., 1.0986122886681098`}, {7., 0.}}]}, 
     {Hue[0.09645786248002253, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}}]}, 
     {Hue[0.3325258399798088, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}, {6., 0.}}]}, 
     {Hue[0.568593817479595, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 1.0986122886681098`}, {5., 
       1.3862943611198906`}, {6., 0.}}]}, 
     {Hue[0.8046617949793813, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.6931471805599453}}]}, {}, {}, 
     {Hue[0.5128657274787543, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}, {6., 0.}, {7., 
       0.6931471805599453}}]}, 
     {Hue[0.7489337049785405, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 0.}, {6., 
       0.}}]}, {}, 
     {Hue[0.2210696599780988, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.6931471805599453}, {6., 
       0.6931471805599453}, {7., 0.}, {8., 0.6931471805599453}}]}, 
     {Hue[0.45713763747789926`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, {}, {}, {}, 
     {Hue[0.4014095474770727, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}}]}, 
     {Hue[0.6374775249768447, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}, {6., 0.}}]}, 
     {Hue[0.8735455024766452, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}, {6., 1.0986122886681098`}, {7., 
       1.3862943611198906`}, {8., 0.}}]}, 
     {Hue[0.10961347997641724`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}}]}, 
     {Hue[0.3456814574762177, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.6931471805599453}, {6., 0.6931471805599453}, {
       7., 0.6931471805599453}, {8., 0.}, {9., 0.}, {10., 0.}, {11., 0.}}]}, 
     {Hue[0.5817494349760182, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.}}]}, 
     {Hue[0.8178174124757902, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.6931471805599453}}]}, 
     {Hue[0.05388538997559067, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.}, {7., 0.}}]}, {}, {}, 
     {Hue[0.7620893224749636, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.}}]}, {}, 
     {Hue[0.23422527747453614`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}}]}, {}, 
     {Hue[0.7063612324741086, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}}]}, 
     {Hue[0.9424292099739091, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.6931471805599453}, {6., 0.6931471805599453}, {
       7., 0.}, {8., 0.}, {9., 0.}}]}, {}, {}, {}, {}, {}, {}, {}, 
     {Hue[0.8309730299722276, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}}]}, 
     {Hue[0.06704100747199959, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.6931471805599453}, {6., 0.}}]}, 
     {Hue[0.30310898497180006`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}}]}, {}, 
     {Hue[0.7752449399713726, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.}, {7., 0.}, {8., 
       0.6931471805599453}, {9., 0.6931471805599453}}]}, {}, 
     {Hue[0.2473808949709735, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}}]}, 
     {Hue[0.4834488724707455, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.6931471805599453}, {7., 0.}, {8., 
       0.6931471805599453}, {9., 0.6931471805599453}, {10., 0.}}]}, {}, 
     {Hue[0.955584827470318, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.6931471805599453}, {6., 
       0.6931471805599453}}]}, 
     {Hue[0.1916528049701185, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.}}]}, 
     {Hue[0.42772078246991896`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.}}]}, 
     {Hue[0.663788759969691, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.}}]}, 
     {Hue[0.8998567374694915, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.6931471805599453}, {7., 0.}}]}, 
     {Hue[0.1359247149692635, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}}]}, {}, 
     {Hue[0.6080606699688644, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.6931471805599453}, {6., 0.6931471805599453}, {
       7., 0.}, {8., 0.}}]}, 
     {Hue[0.8441286474686365, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.}}]}, 
     {Hue[0.08019662496843694, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.6931471805599453}}]}, 
     {Hue[0.3162646024682374, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 1.0986122886681098`}, {7., 0.}, {8., 
       0.6931471805599453}}]}, {}, {}, {}, 
     {Hue[0.2605365124673824, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.6931471805599453}, {7., 0.}, {8., 
       1.0986122886681098`}, {9., 0.}, {10., 0.}}]}, 
     {Hue[0.49660448996718287`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}}]}, {}, 
     {Hue[0.9687404449667554, 0.6, 0.6], Thickness[0.005], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQDQEiDgwoQMLBuPftd8cDP+0hfBmH95a//jnpfYPy
FRyKV1vbb1rEANWnhMZXQeOrOYiFbt29MZsJytdAk9dCM18HzT16aHwDNL4h
VP8zqH4jNHljNL6JAzfz2qpXkz9C1ZuiyZuhmWcOlwcAFg01OQ==
       
       "]]}, {}, {}, {}, {}, 
     {Hue[0.14908033246570085`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 0.}}]}, {}, {}, 
     {Hue[0.8572842649650738, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 1.3862943611198906`}, {7., 
       0.6931471805599453}, {8., 0.}, {9., 0.}, {10., 0.}}]}, 
     {Hue[0.09335224246484586, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 0.}}]}, {}, {}, {}, 
     {Hue[0.03762415246401929, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}}]}, 
     {Hue[0.27369212996381975`, 0.6, 0.6], Thickness[0.005], 
      LineBox[CompressedData["
1:eJxdlntUjGkcx18aYbGIbquYYnaTYSlqEX1TUa5NGk3T7Z3LO+73SyuLl4MW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       "]]}, {}, {}, 
     {Hue[0.9818960624631643, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}}]}, 
     {Hue[0.21796403996296476`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.6931471805599453}, {7., 
       1.0986122886681098`}, {8., 1.0986122886681098`}}]}, 
     {Hue[0.4540320174627652, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 0.}}]}, 
     {Hue[0.6900999949625373, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.6931471805599453}, {7., 0.6931471805599453}, {
       8., 0.}, {9., 1.0986122886681098`}}]}, 
     {Hue[0.9261679724623377, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 1.0986122886681098`}, {7., 0.}, {8., 0.}}]}, 
     {Hue[0.1622359499621382, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.6931471805599453}, {7., 0.}, {8., 
       0.6931471805599453}}]}, {}, 
     {Hue[0.6343719049617107, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 1.0986122886681098`}, {7., 
       0.6931471805599453}, {8., 0.}}]}, 
     {Hue[0.8704398824614827, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.6931471805599453}, {7., 
       1.0986122886681098`}, {8., 0.6931471805599453}, {9., 0.}, {10., 0.}, {
       11., 0.6931471805599453}, {12., 1.0986122886681098`}, {13., 
       1.0986122886681098`}, {14., 0.}, {15., 0.}, {16., 0.}, {17., 
       0.}}]}, {}, {}, 
     {Hue[0.5786438149608557, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 0.6931471805599453}, {8., 
       1.0986122886681098`}, {9., 0.}}]}, 
     {Hue[0.8147117924606562, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 0.}}]}, {}, {}, 
     {Hue[0.5229157249600291, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 0.6931471805599453}, {8., 0.6931471805599453}, {
       9., 0.}}]}, 
     {Hue[0.7589837024598012, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 1.0986122886681098`}, {8., 
       0.6931471805599453}, {9., 1.3862943611198906`}, {10., 
       1.3862943611198906`}, {11., 1.6094379124341003`}, {12., 
       1.3862943611198906`}}]}, 
     {Hue[0.9950516799596016, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 0.}, {8., 0.6931471805599453}}]}, 
     {Hue[0.2311196574594021, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 0.6931471805599453}}]}, {}, 
     {Hue[0.7032556124589746, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 1.0986122886681098`}, {8., 
       0.6931471805599453}, {9., 0.}}]}, {}, 
     {Hue[0.17539156745854712`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 0.}}]}, {}, 
     {Hue[0.6475275224581196, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 0.6931471805599453}}]}, 
     {Hue[0.8835954999579201, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 0.}, {8., 0.}}]}, 
     {Hue[0.11966347745772055`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 0.}, {8., 0.6931471805599453}, {9., 
       0.6931471805599453}, {10., 1.6094379124341003`}, {11., 
       1.3862943611198906`}, {12., 1.3862943611198906`}, {13., 
       0.6931471805599453}}]}, {}, {}, {}, {}, 
     {Hue[0.300003364956666, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}, {9., 0.}}]}, {}, 
     {Hue[0.7721393199562385, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}, {9., 0.6931471805599453}}]}, 
     {Hue[0.008207297456067408, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}, {9., 0.}, {10., 0.}, {11., 
       1.0986122886681098`}, {12., 1.0986122886681098`}}]}, 
     {Hue[0.24427527495583945`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.6931471805599453}, {9., 0.6931471805599453}, {
       10., 0.}, {11., 0.6931471805599453}}]}, 
     {Hue[0.4803432524556115, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}, {9., 1.0986122886681098`}, {10., 
       1.6094379124341003`}, {11., 1.0986122886681098`}, {12., 
       1.3862943611198906`}, {13., 1.0986122886681098`}, {14., 
       0.6931471805599453}, {15., 1.0986122886681098`}, {16., 
       0.6931471805599453}, {17., 0.}}]}, 
     {Hue[0.7164112299554404, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}}]}, {}, 
     {Hue[0.18854718495498446`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}}]}, 
     {Hue[0.42461516245481334`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.6931471805599453}, {9., 0.6931471805599453}, {
       10., 1.0986122886681098`}, {11., 0.}}]}, 
     {Hue[0.6606831399545854, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 1.0986122886681098`}, {9., 
       1.3862943611198906`}, {10., 1.791759469228055}, {11., 
       0.6931471805599453}, {12., 1.3862943611198906`}, {13., 
       0.6931471805599453}}]}, {}, 
     {Hue[0.1328190949541863, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}, {9., 0.6931471805599453}, {10., 
       0.6931471805599453}, {11., 0.}, {12., 0.}, {13., 0.}}]}, {}, 
     {Hue[0.6049550499537304, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{8., 0.}, {9., 0.}, {10., 0.}}]}, 
     {Hue[0.8410230274535024, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{8., 0.}, {9., 0.}}]}, 
     {Hue[0.07709100495333132, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{8., 0.}, {9., 0.}, {10., 0.}, {11., 0.}, {12., 0.}, {13., 
       0.}}]}, 
     {Hue[0.31315898245310336`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{8., 0.}, {9., 0.}}]}, 
     {Hue[0.5492269599528754, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{8., 0.}, {9., 0.}, {10., 0.}}]}, {}, 
     {Hue[0.02136291495247633, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{8., 0.}, {9., 0.6931471805599453}, {10., 
       1.3862943611198906`}, {11., 0.}}]}, {}, {}, 
     {Hue[0.7295668474518493, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{9., 0.}, {10., 0.}, {11., 0.}}]}, 
     {Hue[0.9656348249516213, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{9., 0.}, {10., 0.}}]}, 
     {Hue[0.20170280245145022`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{9., 0.}, {10., 0.6931471805599453}}]}, {}, {}, 
     {Hue[0.9099067349508232, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{9., 0.}, {10., 0.}, {11., 0.6931471805599453}, {12., 0.}, {
       13., 0.}, {14., 0.}}]}, {}, {}, 
     {Hue[0.6181106674501393, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{9., 0.}, {10., 0.}}]}, {}, 
     {Hue[0.09024662244974024, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{9., 0.}, {10., 0.}}]}, 
     {Hue[0.3263145999495123, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{9., 0.}, {10., 0.}}]}, 
     {Hue[0.5623825774493412, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{9., 0.}, {10., 0.}}]}, 
     {Hue[0.7984505549491132, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{10., 0.}, {11., 1.0986122886681098`}, {12., 
       1.9459101490553132`}, {13., 1.3862943611198906`}, {14., 0.}, {15., 
       0.}, {16., 0.}, {17., 0.}}]}, {}, 
     {Hue[0.27058650994871414`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{10., 0.}, {11., 0.}}]}, {}, 
     {Hue[0.7427224649482582, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{11., 0.}, {12., 0.}, {13., 0.}}]}, {}, 
     {Hue[0.21485841994785915`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{11., 0.}, {12., 0.}, {13., 0.}}]}, {}, {}, 
     {Hue[0.9230623524472321, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{12., 0.}, {13., 0.6931471805599453}}]}, {}, 
     {Hue[0.3951983074467762, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{12., 0.}, {13., 0.}, {14., 0.6931471805599453}, {15., 0.}, {
       16., 0.}, {17., 0.}, {18., 0.}, {19., 0.6931471805599453}, {20., 
       0.6931471805599453}}]}, 
     {Hue[0.6312662849466051, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{13., 0.}, {14., 0.}, {15., 0.6931471805599453}, {16., 0.}, {
       17., 0.}, {18., 0.}}]}, 
     {Hue[0.8673342624463771, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{13., 0.}, {14., 0.6931471805599453}, {15., 
       0.6931471805599453}, {16., 0.}}]}, {}, {}, {}, {}, 
     {Hue[0.04767414994535102, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{14., 0.}, {15., 0.}, {16., 0.}, {17., 0.}}]}, 
     {Hue[0.28374212744512306`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{14., 0.}, {15., 0.}}]}, 
     {Hue[0.5198101049448951, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{14., 0.}, {15., 0.}}]}, 
     {Hue[0.7558780824446671, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{15., 0.}, {16., 0.}}]}, 
     {Hue[0.991946059944496, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{15., 0.}, {16., 1.0986122886681098`}, {17., 
       0.6931471805599453}, {18., 1.0986122886681098`}, {19., 
       0.6931471805599453}, {20., 0.6931471805599453}, {21., 
       1.0986122886681098`}, {22., 0.}}]}, {}, 
     {Hue[0.4640820149440401, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{16., 0.}, {17., 1.3862943611198906`}, {18., 
       1.3862943611198906`}, {19., 1.0986122886681098`}, {20., 
       1.0986122886681098`}, {21., 0.6931471805599453}}]}, 
     {Hue[0.700149992443869, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{16., 0.}, {17., 0.6931471805599453}, {18., 
       1.3862943611198906`}, {19., 0.}, {20., 0.}, {21., 0.}, {22., 0.}, {23.,
        0.}}]}, 
     {Hue[0.936217969943641, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{16., 0.}, {17., 0.}, {18., 0.6931471805599453}, {19., 
       0.6931471805599453}, {20., 0.6931471805599453}}]}, 
     {Hue[0.17228594744341308`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{17., 0.}, {18., 0.6931471805599453}, {19., 
       0.6931471805599453}}]}, 
     {Hue[0.40835392494324196`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{18., 0.}, {19., 0.}, {20., 1.0986122886681098`}, {21., 
       1.3862943611198906`}, {22., 0.}, {23., 0.}, {24., 0.}, {25., 0.}, {26.,
        0.}, {27., 0.}, {28., 0.}}]}, 
     {Hue[0.644421902443014, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{19., 0.}, {20., 0.}}]}, {}, 
     {Hue[0.11655785744261493`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{21., 0.}, {22., 0.}, {23., 0.}, {24., 0.6931471805599453}, {
       25., 0.6931471805599453}}]}, 
     {Hue[0.352625834942387, 0.6, 0.6], Thickness[0.005], 
      LineBox[CompressedData["
1:eJxdz39QzHkcx/FvP640uKP06yqqs3NJHLmrQfTqF0X6pa1t+/XdH99FfhVH
JyfLoEOaqziktIXo9GMqXX50blPHhA43Gj/Tkp8nrvMj6qRz4/35Y3dnmuYx
r33u+/t1kS+PEow5jiv+8Pf//4+faeD0PtMN7GPgGfh7av97/4m9vh89E8bO
7v1Dj74j+yJW6lm1wnWQDH2rYdD7Gex+GGpSmfFXvhHd9de32h8rj073rS3l
aA/QtzoANuL6UzWLjWkPNNgDEeq9vqFrogntQfCoMzXzyjGnPQg1Vct3Towf
Qvss9NRdGVhnbUH7LPR55H1/eAmZm03vP4z22QiryAkS6ofTHoyQ8qqfRYWf
0R6MuILKEmuPEbSHYNW4nfl5tWR1CISiMuO1mpG0z8FVodfC7QRZPcdgnws+
LfHf84/ZPhe926psE1+xPRSTTzp8eW+VJe2hyBd68hMOk7l5+lbP0/8+F4bx
Tjb2C2RsDzPYw7F9xyFRpYkV7eHoahxQj/dmewS6reKE3q1kRMBMbFTX08x+
L0K/10bgfsq4aQNZZC4SEV9pXL+1G0V9JA7c3ywPUJHVkZC+uOUlGmC9gbko
1LzNeWIH1kfB8ZYEI3JZH4XpKSv28MfI2iiMP2f3+uBdMjcflpXti3oyWT8f
wXOyb9bGsd7A2vnYZNp6fshu1kejtnrLaLvbrI+GV/fDjgpza+qj8e6Aqcuj
y6yPRtFxn/j8KtaLMSIrTdlZynox7khysrLfsPtibGnbbS/xoN/TirEu3tfn
WDSZi8HenP0pZ1aTEYPm4Jf7XRrZ/Ri8bth8ovcm62MQWKizPLGV9bFI9pph
1tHG+liYN31R6NHN+lh4vZC6ze1kfSwyPTL2LethvQRj067c6LO2oV6Cdrcl
srIG1kvgld+yMMSS9RIs37HG3iqf9XH6Rhxar27avKqV9Qa7Ng5tARL7B29Z
L0WBc/1nDx+xXopcp0XdBV2slxo8vxQXuw4MwJ2el4uHp22xLGELe/54FJQ3
BbyuJKvj4aLZMMqvjayNx56pp356dob1CchZvX6jzx3WJ+D6Ll5acZn1CRhW
7h3ZWMz6BED+y7W8dNYn6j8PEvHbmH12RRasT0ThJVGI2TbWJ2Lkj2Gcnyfr
k7Bg8cMA7XDWJ+nv6iRsKLqcbJ/K+iS87D/7++2brE9GQXhfJz/I+mQ8T2xq
kJ1lfbL++2mTcfqk5ZCenazncepBrWNnGdmZR31CBh+7hP0ejyChqy57D5nn
9Xs1D+ml4Yv23iVreFRHm5r+85zd49G6qyLyqZvtR+t4rKmJfOuWQeZksGp2
mWBbTHaWYXXN6DxxBxkylKcU2XnUk3kZMnxKZorH2tF9GXKmPDW6GUnWyHA+
qfrFaW+yVoZY1ZG3/SZknQwLS21FWdZkTo6WUelrnF+w+3Lo+kaLN06iHXLU
cqXq7SPIvBy5XSvX+r+h76vlKHEtdEytJWvk6OkVMnUlZK0cOW/44KXt7P3l
SHJ//WrxGHZfAacpWe1j5GRnBQTRZKOZF9h9BSZsuJE09BW7r8DU9Ogus372
/gr84TLDb7bYnu4rsN5pcMqyZWStAh6HNLbu2WSdAuGO/PGvncicEg5bp1Xf
Hkt2VkLkuDC+NJIMJVrbZy1t8ibzSpRJniz09iWrlbgf+MP65zJ2X6l/T6uE
dtJWVeo2dl+Ji78m3TM9yO4LyHaZ3tzXyO4LaKorbTFx/5zuC+iWlWlaviHz
Ar7zbNalJ5DVAkI7DpoFVpA1AsoXW78/Uk7WftjNp3xyoYOsE3A3JLP32SCZ
U8HmsZRzdnWg+yqYNqZe9/6UDBVEg9tz++zJvIHVKpwLqPPKsCBrVAhSBASZ
icnaD07b1X1nDVmnQsifNjdWbSJzC3DEUSQI1xzwH+fcmvQ=
       
       "]]}}, {}}, {{{}, {}, 
     {GrayLevel[0.5], Thickness[0.005], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQDQEf7MVCt+7emK3kABVwaFivZGpxUBHK53DgEZSe
kyUF4ws4bPls3KxYpQDlizjk8ETY794sD+VLODxkNSq55C0H5cs4XF4xK/8Y
lyyUr+CwatXvRWnvpaF8JYfwgy8ceZZLQfkqDvs3evdwnZKE8tUchAu8D+bV
SkD5Gg4cdf3Sp+LFoXwth6kNtosFncSgfB0HszfP7q5hF4Xy9Rxikh491nkh
DOUbOED8KwTlGzoUb1zfGVAlCOUbOSg6pneW/hOA8o0d1kuv2X7Jmx/KN3Hw
W9PnmrqVF8o3dbjG25Hx0w/GN3P4xruz8Y8pD5Rv7mDc+/a74wFOKN/CIbDH
UJullQXKt3RYvvu62CkZVijfyqF23uU9Yg+ZoXxrh+LV1vabFjFA+TYO4VFG
64qU/ttD+LZQ839C+XYO3Mxrq15N/gjl2zu8t/z1z0nvGZTvADUHChrQ+AyO
qOobHNHMc0LlN6DxGZzh5gEArTGORw==
       "]]}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  Frame->{True, True, False, False},
  FrameLabel->{{
     FormBox["\"Number of copies of allele\"", TraditionalForm], None}, {
     FormBox["\"Generation\"", TraditionalForm], None}},
  FrameTicks->{{{{0., 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{0, 150}, {0., 9.210340371976184}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, {{0., 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.764250046815776*^9, 3.76425007362672*^9}, {
   3.764250106858333*^9, 3.764250114430511*^9}, {3.771543821317505*^9, 
   3.771543830609419*^9}, 3.7715438740200357`*^9, 3.771544007520598*^9, 
   3.782251461901538*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, {}, {}, 
    {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxdz39QzHkcx/FvP640uKP06yqqs3NJHLmrQfTqF0X6pa1t+/XdH99FfhVH
JyfLoEOaqziktIXo9GMqXX50blPHhA43Gj/Tkp8nrvMj6qRz4/35Y3dnmuYx
r33u+/t1kS+PEow5jiv+8Pf//4+faeD0PtMN7GPgGfh7av97/4m9vh89E8bO
7v1Dj74j+yJW6lm1wnWQDH2rYdD7Gex+GGpSmfFXvhHd9de32h8rj073rS3l
aA8w2ANgI64/VbPYmPZA/e+rAxHqvb6ha6IJ7UHwqDM188oxpz0INVXLd06M
H0L7LPTUXRlYZ21B+yz0eeR9f3gJmZtN7z+M9tkIq8gJEuqH0x6MkPKqn0WF
n9EejLiCyhJrjxG0h2DVuJ35ebVkdQiEojLjtZqRtM/BVaHXwu0EWT3HYJ8L
Pi3x3/OP2T4XvduqbBNfsT0Uk086fHlvlSXtocgXevITDpO5efpWz9P/PheG
8U429gtkbA8z2MOxfcchUaWJFe3h6GocUI/3ZnsEuq3ihN6tZETATGxU19PM
fi9Cv9dG4H7KuGkDWWQuEhFfaVy/tRtFfSQO3N8sD1CR1ZGQvrjlJRpgvYG5
KNS8zXliB9ZHwfGWBCNyWR+F6Skr9vDHyNoojD9n9/rgXTI3H5aV7Yt6Mlk/
H8Fzsm/WxrHewNr52GTaen7IbtZHo7Z6y2i726yPhlf3w44Kc2vqo/HugKnL
o8usj0bRcZ/4/CrWizEiK03ZWcp6Me5IcrKy37D7Ymxp220v8aDf04qxLt7X
51g0mYvB3pz9KWdWkxGD5uCX+10a2f0YvG7YfKL3JutjEFioszyxlfWxSPaa
YdbRxvpYmDd9UejRzfpYeL2Qus3tZH0sMj0y9i3rYb0EY9Ou3OiztqFegna3
JbKyBtZL4JXfsjDEkvUSLN+xxt4qn/Vx+kYcWq9u2ryqlfUGuzYObQES+wdv
WS9FgXP9Zw8fsV6KXKdF3QVdrJcaPL8UF7sODMCdnpeLh6dtsSxhC3v+eBSU
NwW8riSr4+Gi2TDKr42sjceeqad+enaG9QnIWb1+o88d1ifg+i5eWnGZ9QkY
Vu4d2VjM+gRA/su1vHTWJ+o/DxLx25h9dkUWrE9E4SVRiNk21idi5I9hnJ8n
65OwYPHDAO1w1ifp7+okbCi6nGyfyvokvOw/+/vtm6xPRkF4Xyc/yPpkPE9s
apCdZX2y/vtpk3H6pOWQnp2s53HqQa1jZxnZmUd9QgYfu4T9Ho8goasuew+Z
5/V7NQ/ppeGL9t4la3hUR5ua/vOc3ePRuqsi8qmb7UfreKypiXzrlkHmZLBq
dplgW0x2lmF1zeg8cQcZMpSnFNl51JN5GTJ8SmaKx9rRfRlypjw1uhlJ1shw
Pqn6xWlvslaGWNWRt/0mZJ0MC0ttRVnWZE6OllHpa5xfsPty6PpGizdOoh1y
1HKl6u0jyLwcuV0r1/q/oe+r5ShxLXRMrSVr5OjpFTJ1JWStHDlv+OCl7ez9
5Uhyf/1q8Rh2XwGnKVntY+RkZwUE0WSjmRfYfQUmbLiRNPQVu6/A1PToLrN+
9v4K/OEyw2+22J7uK7DeaXDKsmVkrQIehzS27tlknQLhjvzxr53InBIOW6dV
3x5LdlZC5LgwvjSSDCVa22ctbfIm80qUSZ4s9PYlq5W4H/jD+ucydl+pf0+r
hHbSVlXqNnZfiYu/Jt0zPcjuC8h2md7c18juC2iqK20xcf+c7gvolpVpWr4h
8wK+82zWpSeQ1QJCOw6aBVaQNQLKF1u/P1JO1n7Yzad8cqGDrBNwNySz99kg
mVPB5rGUc3Z1oPsqmDamXvf+lAwVRIPbc/vsybyB1SqcC6jzyrAga1QIUgQE
mYnJ2g9O29V9Zw1Zp0LInzY3Vm0icwtwxFEkCNcc8B/cTpq7
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  Frame->{True, True, False, False},
  FrameLabel->{{
     FormBox["\"Number of copies of allele\"", TraditionalForm], None}, {
     FormBox["\"Generation\"", TraditionalForm], None}},
  FrameTicks->{{{{0., 
       FormBox["1", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["5", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {3.912023005428146, 
       FormBox["50", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.214608098422191, 
       FormBox["500", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {8.517193191416238, 
       FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{0, 150}, {0., 6.960347729101308}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, {{0., 
      FormBox["1", TraditionalForm]}, {1.6094379124341003`, 
      FormBox["5", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {3.912023005428146, 
      FormBox["50", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.214608098422191, 
      FormBox["500", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {8.517193191416238, 
      FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.764250046815776*^9, 3.76425007362672*^9}, {
   3.764250106858333*^9, 3.764250114430511*^9}, {3.771543821317505*^9, 
   3.771543830609419*^9}, 3.7715438740200357`*^9, 3.771544007520598*^9, 
   3.782251462006022*^9}]
}, Closed]],

Cell["\<\
but the yellow replicate is 1-step\
\>", "Text",
 CellChangeTimes->{{3.764250175175392*^9, 3.7642501803325167`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"n0", "=", "\"\<10000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "\"\<4\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", "\"\<0.010000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "\"\<0.01000\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "\"\<0.50\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", "\"\<-0.30\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mutmax", "=", "\"\<2\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rep", "=", "\"\<752\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"genmax", "=", "150"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nmax", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ymax", "=", 
    SuperscriptBox["10", "4"]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{
   "datadir", "<>", "\"\<alleles_N\>\"", "<>", "n0", "<>", "\"\<_n\>\"", "<>",
     "n", "<>", "\"\<_U\>\"", "<>", "U", "<>", "\"\<_Es\>\"", "<>", "Es", 
    "<>", "\"\<_mmax\>\"", "<>", "mmax", "<>", "\"\<_mwt\>\"", "<>", "mwt", 
    "<>", "\"\<_mutmax\>\"", "<>", "mutmax", "<>", "\"\<_rep\>\"", "<>", 
    "rep", "<>", "\"\<.csv\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alleles", "=", 
    RowBox[{"Transpose", "[", 
     RowBox[{"PadRight", "[", "%", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{
   "datadir", "<>", "\"\<kmuts_N\>\"", "<>", "n0", "<>", "\"\<_n\>\"", "<>", 
    "n", "<>", "\"\<_U\>\"", "<>", "U", "<>", "\"\<_Es\>\"", "<>", "Es", 
    "<>", "\"\<_mmax\>\"", "<>", "mmax", "<>", "\"\<_mwt\>\"", "<>", "mwt", 
    "<>", "\"\<_mutmax\>\"", "<>", "mutmax", "<>", "\"\<_rep\>\"", "<>", 
    "rep", "<>", "\"\<.csv\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"allmuts", "=", 
    RowBox[{"Transpose", "[", 
     RowBox[{"PadRight", "[", "%", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ListLogPlot", "[", 
     RowBox[{
      RowBox[{"alleles", "[", 
       RowBox[{"[", 
        RowBox[{"2", ";;"}], "]"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "genmax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Frame", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
      ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Generation\>\"", ",", "\"\<Number of copies of allele\>\""}], 
        "}"}]}], ",", 
      RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Epilog", "\[Rule]", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"\"\<B\>\"", ",", "14", ",", "Bold"}], "]"}], ",", 
           RowBox[{"Scaled", "@", 
            RowBox[{"{", 
             RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}], ","}], "*)"}],
       "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Thickness", "[", "0.005", "]"}]}]}], "\[IndentingNewLine]", 
     "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{
      RowBox[{"allmuts", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Gray", ",", 
         RowBox[{"Thickness", "[", "0.005", "]"}]}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Import", "[", 
   RowBox[{
   "datadir", "<>", "\"\<supercrit_kmuts_N\>\"", "<>", "n0", "<>", 
    "\"\<_n\>\"", "<>", "n", "<>", "\"\<_U\>\"", "<>", "U", "<>", 
    "\"\<_Es\>\"", "<>", "Es", "<>", "\"\<_mmax\>\"", "<>", "mmax", "<>", 
    "\"\<_mwt\>\"", "<>", "mwt", "<>", "\"\<_mutmax\>\"", "<>", "mutmax", 
    "<>", "\"\<_rep\>\"", "<>", "rep", "<>", "\"\<.csv\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"supermuts", "=", 
    RowBox[{"Transpose", "[", 
     RowBox[{"PadRight", "[", "%", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListLogPlot", "[", 
   RowBox[{"supermuts", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "genmax"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "nmax"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Generation\>\"", ",", "\"\<Number of copies of allele\>\""}], 
      "}"}]}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "n0", ",", "n", ",", "U", ",", "Es", ",", "mmax", ",", "mwt", ",", "r", ",",
    "mutmax", ",", "rep", ",", "genmax", ",", "nmax", ",", "ymax"}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.74267566307705*^9, 3.742675738028081*^9}, {
   3.742675793382869*^9, 3.7426757941699123`*^9}, {3.7426758242657747`*^9, 
   3.7426758650463943`*^9}, {3.7426786610125723`*^9, 3.742678707278528*^9}, {
   3.742678865359585*^9, 3.7426788708994293`*^9}, {3.7431786248700647`*^9, 
   3.74317867251116*^9}, {3.743178774984033*^9, 3.743178793853217*^9}, {
   3.7431788660578403`*^9, 3.743178966613968*^9}, {3.743179006583357*^9, 
   3.743179036592964*^9}, {3.743179072719985*^9, 3.743179135126026*^9}, {
   3.743179179293623*^9, 3.743179217109619*^9}, {3.7431792852033854`*^9, 
   3.7431793547671432`*^9}, {3.7431795886138687`*^9, 3.743179665943205*^9}, {
   3.7431796963860826`*^9, 3.743179703976123*^9}, {3.743180184364689*^9, 
   3.743180184726823*^9}, {3.7432776211771593`*^9, 3.743277700536654*^9}, {
   3.7432777376714373`*^9, 3.743277919986001*^9}, 3.743278353152574*^9, {
   3.743278802125987*^9, 3.743278805400436*^9}, {3.743279048593625*^9, 
   3.743279076393252*^9}, {3.743279166224839*^9, 3.743279168335823*^9}, {
   3.7432792160679407`*^9, 3.743279240129554*^9}, {3.7432795039697323`*^9, 
   3.743279517934054*^9}, {3.743279693387833*^9, 3.7432797386881723`*^9}, {
   3.7438764370845757`*^9, 3.7438764425864573`*^9}, {3.743876481903409*^9, 
   3.743876520919177*^9}, 3.743876570192697*^9, {3.74387660075054*^9, 
   3.7438766008485327`*^9}, {3.743876634210388*^9, 3.7438767564934883`*^9}, {
   3.743876792932558*^9, 3.743876860830018*^9}, {3.743876897126893*^9, 
   3.743876900159235*^9}, {3.743876940413685*^9, 3.743877121718658*^9}, {
   3.7438771591939993`*^9, 3.743877232237978*^9}, 3.7438773082588673`*^9, {
   3.743877547277384*^9, 3.743877581979311*^9}, {3.7510320460797*^9, 
   3.7510320550121317`*^9}, {3.751559153848452*^9, 3.751559165390586*^9}, {
   3.751559218454067*^9, 3.751559236146096*^9}, 3.751644701386467*^9, 
   3.751644892512967*^9, {3.751645475830846*^9, 3.751645504983404*^9}, {
   3.75639074905398*^9, 3.756390749866386*^9}, {3.756390787404292*^9, 
   3.756390834637045*^9}, {3.7563909770961313`*^9, 3.7563910383208933`*^9}, {
   3.756391080443749*^9, 3.7563910821087923`*^9}, {3.756491500205241*^9, 
   3.7564917308287497`*^9}, 3.764202603898903*^9, {3.764202705100109*^9, 
   3.764202735459268*^9}, {3.764250038948617*^9, 3.764250113784154*^9}, {
   3.764250155176237*^9, 3.7642501560694017`*^9}, {3.771543899497498*^9, 
   3.77154390170741*^9}, {3.7715440172964697`*^9, 3.771544027151114*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, {}, {}, {}, 
     {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 0.6931471805599453}, {
       5., 0.}, {6., 0.6931471805599453}, {7., 0.}}]}, {}, {}, 
     {Hue[0.08640786499873876, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 
       1.0986122886681098`}, {5., 1.0986122886681098`}, {6., 0.}}]}, {}, {}, 
     {Hue[0.7946117974981064, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 
       0.6931471805599453}}]}, {}, {}, {}, {}, 
     {Hue[0.9749516849970554, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.21101966249684523`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.44708763999663503`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.6831556174964248, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}, {5., 0.}}]}, {}, {}, 
     {Hue[0.39135954999579425`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 0.}, {5., 
       0.}}]}, {}, 
     {Hue[0.8634955049953739, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}}]}, 
     {Hue[0.09956348249516367, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}}]}, {}, 
     {Hue[0.5716994374947433, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 1.3862943611198906`}, {5., 
       0.6931471805599453}, {6., 0.6931471805599453}, {7., 
       0.6931471805599453}, {8., 1.0986122886681098`}}]}, 
     {Hue[0.8077674149945295, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, {}, 
     {Hue[0.27990336999410914`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 0.}}]}, {}, 
     {Hue[0.7520393249936888, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, {}, 
     {Hue[0.22417527999326836`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 
       0.6931471805599453}}]}, 
     {Hue[0.4602432574930617, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {Hue[0.5848550549911664, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.8209230324909598, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}, {5., 0.}, {6., 0.}}]}, {}, {}, 
     {Hue[0.5291269649903256, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 0.}, {5., 0.}}]}, 
     {Hue[0.765194942490119, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, {}, 
     {Hue[0.2373308974896915, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, {}, 
     {Hue[0.7094668524892711, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.9455348299890574, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}}]}, 
     {Hue[0.18160280748885782`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.4176707849886441, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}}]}, 
     {Hue[0.6537387624884303, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}}]}, 
     {Hue[0.8898067399882166, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.12587471748801704`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}, {5., 0.}}]}, {}, 
     {Hue[0.5980106724875895, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 
       1.3862943611198906`}, {5., 1.3862943611198906`}, {6., 
       1.6094379124341003`}, {7., 0.}}]}, 
     {Hue[0.8340786499873758, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.07014662748717626, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.6931471805599453}}]}, 
     {Hue[0.3062146049869625, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.5422825824867488, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}}]}, 
     {Hue[0.778350559986535, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.6931471805599453}, {5., 0.}}]}, 
     {Hue[0.014418537486335481`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.}, {5., 1.0986122886681098`}, {6., 
       0.6931471805599453}}]}, {}, {}, 
     {Hue[0.7226224699856942, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 1.0986122886681098`}, {5., 
       0.6931471805599453}, {6., 
       0.}}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {Hue[0.31937022248338565`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{2., 0.}, {3., 0.}, {4., 0.6931471805599453}, {5., 0.}, {6., 
       0.}}]}, 
     {Hue[0.5554381999831719, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 
       1.0986122886681098`}, {6., 1.6094379124341003`}, {7., 
       1.0986122886681098`}}]}, 
     {Hue[0.7915061774829582, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, 
     {Hue[0.027574154982758614`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}, {6., 0.}}]}, 
     {Hue[0.26364213248254487`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 1.0986122886681098`}, {6., 
       1.0986122886681098`}, {7., 1.0986122886681098`}, {8., 0.}}]}, 
     {Hue[0.4997101099823311, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, {}, {}, 
     {Hue[0.2079140424817041, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, 
     {Hue[0.44398201998149034`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, {}, 
     {Hue[0.916117974981077, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, 
     {Hue[0.1521859524808633, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}, {6., 0.6931471805599453}}]}, 
     {Hue[0.38825392998064956`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}}]}, 
     {Hue[0.6243219074804358, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, {}, 
     {Hue[0.09645786248002253, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, {}, {}, 
     {Hue[0.8046617949793813, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 1.0986122886681098`}, {5., 0.}, {6., 0.}}]}, {}, 
     {Hue[0.276797749978968, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}, {6., 0.6931471805599453}, {7., 
       1.0986122886681098`}, {8., 0.}, {9., 0.}, {10., 0.6931471805599453}, {
       11., 1.0986122886681098`}, {12., 0.6931471805599453}, {13., 
       1.0986122886681098`}, {14., 0.}}]}, 
     {Hue[0.5128657274787543, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, {}, 
     {Hue[0.985001682478341, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 0.}}]}, {}, {}, 
     {Hue[0.6932056149776997, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, {}, {}, 
     {Hue[0.4014095474770727, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, {}, 
     {Hue[0.8735455024766452, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 0.}, {6., 
       1.0986122886681098`}, {7., 1.3862943611198906`}, {8., 
       0.6931471805599453}, {9., 0.}, {10., 1.0986122886681098`}}]}, {}, 
     {Hue[0.3456814574762177, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, 
     {Hue[0.5817494349760182, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}}]}, {}, {}, 
     {Hue[0.28995336747539113`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}}]}, {}, 
     {Hue[0.7620893224749636, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 1.0986122886681098`}, {5., 0.}}]}, 
     {Hue[0.9981572999747357, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 1.3862943611198906`}, {5., 
       0.6931471805599453}, {6., 0.}}]}, 
     {Hue[0.23422527747453614`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.}, {5., 0.}, {6., 0.6931471805599453}}]}, 
     {Hue[0.4702932549743366, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 
       1.0986122886681098`}, {6., 1.791759469228055}, {7., 
       0.6931471805599453}, {8., 0.6931471805599453}, {9., 0.}, {10., 
       0.6931471805599453}, {11., 0.}, {12., 0.}, {13., 0.6931471805599453}, {
       14., 1.0986122886681098`}, {15., 1.0986122886681098`}, {16., 
       0.}}]}, {}, {}, {}, 
     {Hue[0.4145651649734816, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.}}]}, {}, 
     {Hue[0.8867011199730541, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}}]}, 
     {Hue[0.12276909747285458`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.}}]}, 
     {Hue[0.35883707497265505`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.}, {7., 0.}, {8., 
       0.6931471805599453}, {9., 0.6931471805599453}}]}, {}, 
     {Hue[0.8309730299722276, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.6931471805599453}}]}, 
     {Hue[0.06704100747199959, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}}]}, {}, {}, {}, {}, 
     {Hue[0.2473808949709735, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.6931471805599453}}]}, {}, {}, {}, {}, {}, 
     {Hue[0.663788759969691, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.6931471805599453}}]}, 
     {Hue[0.8998567374694915, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.6931471805599453}, {6., 0.6931471805599453}, {
       7., 0.6931471805599453}, {8., 0.6931471805599453}}]}, {}, 
     {Hue[0.37199269246906397`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.6931471805599453}, {7., 0.}, {8., 
       0.6931471805599453}, {9., 0.}, {10., 1.0986122886681098`}, {11., 0.}, {
       12., 0.}, {13., 0.}}]}, 
     {Hue[0.6080606699688644, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.6931471805599453}, {6., 0.6931471805599453}, {
       7., 0.6931471805599453}, {8., 0.}, {9., 0.}, {10., 
       0.}}]}, {}, {}, {}, 
     {Hue[0.5523325799680094, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}, {6., 0.}}]}, {}, {}, 
     {Hue[0.2605365124673824, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{4., 0.}, {5., 0.}}]}, {}, {}, 
     {Hue[0.9687404449667554, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 0.}, {8., 0.}}]}, 
     {Hue[0.20480842246655584`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}}]}, 
     {Hue[0.4408763999663279, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 0.}, {8., 0.}, {9., 0.}}]}, 
     {Hue[0.6769443774661283, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 1.0986122886681098`}, {8., 0.}, {9., 
       0.}, {10., 0.}, {11., 0.}, {12., 0.}, {13., 0.}, {14., 0.}, {15., 
       0.}, {16., 0.}, {17., 0.}, {18., 0.}}]}, {}, 
     {Hue[0.14908033246570085`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 1.6094379124341003`}, {7., 
       1.0986122886681098`}, {8., 1.0986122886681098`}, {9., 
       1.6094379124341003`}, {10., 1.791759469228055}, {11., 
       1.3862943611198906`}, {12., 0.6931471805599453}, {13., 
       1.6094379124341003`}, {14., 0.6931471805599453}, {15., 
       0.6931471805599453}}]}, {}, {}, {}, {}, 
     {Hue[0.3294202199646463, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 0.}}]}, 
     {Hue[0.5654881974644468, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 0.}}]}, 
     {Hue[0.8015561749642188, 0.6, 0.6], Thickness[0.005], 
      LineBox[CompressedData["
1:eJxdlntYzPkex0cnm4qVSyPXsmcjSovQhda7bKOL6DbdL9PUdJvpsugiYQrL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       "]]}, 
     {Hue[0.03762415246401929, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.6931471805599453}, {7., 0.6931471805599453}, {
       8., 1.3862943611198906`}, {9., 0.}}]}, 
     {Hue[0.27369212996381975`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 0.}, {8., 0.}, {9., 
       0.6931471805599453}, {10., 0.6931471805599453}, {11., 0.}, {12., 
       0.}}]}, {}, 
     {Hue[0.7458280849633923, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.6931471805599453}}]}, 
     {Hue[0.9818960624631643, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}}]}, 
     {Hue[0.21796403996296476`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}}]}, 
     {Hue[0.4540320174627652, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}}]}, 
     {Hue[0.6900999949625373, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}}]}, {}, 
     {Hue[0.1622359499621382, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}}]}, 
     {Hue[0.39830392746191023`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 1.0986122886681098`}, {7., 
       1.6094379124341003`}, {8., 1.6094379124341003`}, {9., 
       1.0986122886681098`}, {10., 1.0986122886681098`}, {11., 
       0.6931471805599453}, {12., 0.6931471805599453}, {13., 
       1.6094379124341003`}, {14., 1.0986122886681098`}, {15., 0.}}]}, 
     {Hue[0.6343719049617107, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}}]}, 
     {Hue[0.8704398824614827, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.6931471805599453}, {7., 0.}, {8., 0.}, {9., 
       0.6931471805599453}, {10., 0.}, {11., 0.}, {12., 
       1.0986122886681098`}, {13., 1.0986122886681098`}, {14., 
       1.0986122886681098`}, {15., 0.6931471805599453}, {16., 
       0.6931471805599453}, {17., 0.}, {18., 0.6931471805599453}}]}, 
     {Hue[0.1065078599612832, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 0.6931471805599453}}]}, {}, 
     {Hue[0.5786438149608557, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}}]}, {}, 
     {Hue[0.05077976996045663, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.6931471805599453}, {7., 
       1.0986122886681098`}}]}, {}, {}, 
     {Hue[0.7589837024598012, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.6931471805599453}, {7., 
       1.0986122886681098`}}]}, 
     {Hue[0.9950516799596016, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 0.}, {7., 0.}, {8., 0.6931471805599453}, {9., 
       1.0986122886681098`}, {10., 1.3862943611198906`}, {11., 0.}}]}, 
     {Hue[0.2311196574594021, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{5., 0.}, {6., 1.3862943611198906`}, {7., 
       1.3862943611198906`}, {8., 1.0986122886681098`}, {9., 
       1.0986122886681098`}, {10., 0.}}]}, 
     {Hue[0.46718763495917415`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 0.}}]}, 
     {Hue[0.7032556124589746, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 0.}}]}, {}, 
     {Hue[0.17539156745854712`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 0.}, {8., 0.6931471805599453}}]}, {}, {}, 
     {Hue[0.8835954999579201, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 0.6931471805599453}, {8., 
       0.6931471805599453}}]}, 
     {Hue[0.11966347745772055`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 1.0986122886681098`}, {8., 
       0.6931471805599453}, {9., 0.}}]}, {}, {}, 
     {Hue[0.8278674099570651, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 0.}}]}, 
     {Hue[0.06393538745686556, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 0.6931471805599453}, {8., 
       1.3862943611198906`}}]}, 
     {Hue[0.300003364956666, 0.6, 0.6], Thickness[0.005], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQESDgwoQAaNr4DGV3J4b/nrn5PeM3sIX8WBm3lt
1avJH6F8NTS+hoNx79vvjgd+QvlaDkwKWr+4V/+B8nUcwqOM1hUp/Yfy9aDm
f4PyDdD0G6LJG6HZZ4zmXhM095qiyZuh6TdHk7dA02+JJm8F5wMAMgJCOw==

       "]]}, 
     {Hue[0.5360713424564665, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 0.}}]}, {}, 
     {Hue[0.008207297456067408, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 0.}, {8., 0.}, {9., 0.6931471805599453}, {10., 
       0.}}]}, {}, 
     {Hue[0.4803432524556115, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{6., 0.}, {7., 0.}, {8., 0.}, {9., 0.}}]}, {}, {}, 
     {Hue[0.18854718495498446`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}}]}, 
     {Hue[0.42461516245481334`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.6931471805599453}}]}, 
     {Hue[0.6606831399545854, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}}]}, 
     {Hue[0.8967511174543574, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.6931471805599453}, {9., 0.}, {10., 0.}, {11., 
       0.}}]}, 
     {Hue[0.1328190949541863, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}}]}, 
     {Hue[0.36888707245395835`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}}]}, {}, 
     {Hue[0.8410230274535024, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 1.0986122886681098`}, {9., 
       0.6931471805599453}, {10., 0.}, {11., 0.6931471805599453}, {12., 
       0.6931471805599453}, {13., 0.6931471805599453}, {14., 
       1.3862943611198906`}, {15., 1.791759469228055}, {16., 
       1.0986122886681098`}, {17., 1.0986122886681098`}, {18., 0.}, {19., 
       0.6931471805599453}}]}, {}, 
     {Hue[0.31315898245310336`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}, {9., 0.}}]}, 
     {Hue[0.5492269599528754, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}}]}, 
     {Hue[0.7852949374527043, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}, {9., 1.0986122886681098`}, {10., 
       1.3862943611198906`}, {11., 1.791759469228055}, {12., 
       1.9459101490553132`}, {13., 1.791759469228055}, {14., 
       1.791759469228055}, {15., 1.6094379124341003`}, {16., 0.}, {17., 
       0.6931471805599453}, {18., 0.}, {19., 0.}}]}, {}, {}, {}, {}, 
     {Hue[0.9656348249516213, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}, {9., 1.0986122886681098`}, {10., 
       1.3862943611198906`}, {11., 0.}, {12., 0.}}]}, 
     {Hue[0.20170280245145022`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}, {9., 0.}}]}, 
     {Hue[0.43777077995122227`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}, {9., 0.6931471805599453}, {10., 0.}, {11., 
       0.6931471805599453}}]}, {}, {}, 
     {Hue[0.14597471245059523`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.6931471805599453}, {9., 
       1.0986122886681098`}, {10., 0.6931471805599453}}]}, {}, {}, {}, 
     {Hue[0.09024662244974024, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.}, {9., 1.0986122886681098`}, {10., 
       0.6931471805599453}, {11., 0.6931471805599453}}]}, 
     {Hue[0.3263145999495123, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{7., 0.}, {8., 0.6931471805599453}, {9., 0.}}]}, 
     {Hue[0.5623825774493412, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{8., 0.}, {9., 0.}, {10., 0.}, {11., 0.}}]}, {}, {}, 
     {Hue[0.27058650994871414`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{8., 0.}, {9., 1.0986122886681098`}, {10., 
       1.0986122886681098`}, {11., 1.3862943611198906`}, {12., 
       1.6094379124341003`}, {13., 2.0794415416798357`}, {14., 
       0.6931471805599453}, {15., 0.}}]}, {}, 
     {Hue[0.7427224649482582, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{8., 0.}, {9., 0.}, {10., 0.6931471805599453}}]}, {}, 
     {Hue[0.21485841994785915`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{8., 0.}, {9., 0.}, {10., 0.6931471805599453}, {11., 0.}}]}, 
     {Hue[0.4509263974476312, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{8., 0.}, {9., 0.}, {10., 0.}}]}, {}, {}, {}, 
     {Hue[0.3951983074467762, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{8., 0.}, {9., 0.}, {10., 0.}, {11., 0.}}]}, 
     {Hue[0.6312662849466051, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{8., 0.}, {9., 1.0986122886681098`}, {10., 
       0.6931471805599453}}]}, 
     {Hue[0.8673342624463771, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{8., 0.}, {9., 0.}}]}, {}, {}, {}, {}, 
     {Hue[0.04767414994535102, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{9., 0.}, {10., 0.}}]}, {}, {}, 
     {Hue[0.7558780824446671, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{9., 0.}, {10., 0.6931471805599453}, {11., 0.}, {12., 
       0.6931471805599453}}]}, 
     {Hue[0.991946059944496, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{9., 0.}, {10., 0.}, {11., 0.}, {12., 0.}}]}, 
     {Hue[0.22801403744426807`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{9., 0.}, {10., 0.}}]}, {}, 
     {Hue[0.700149992443869, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{9., 0.}, {10., 0.}, {11., 0.6931471805599453}, {12., 0.}, {
       13., 0.}, {14., 0.}}]}, {}, 
     {Hue[0.17228594744341308`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{10., 0.}, {11., 0.}, {12., 0.}}]}, 
     {Hue[0.40835392494324196`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{10., 0.}, {11., 0.}}]}, {}, 
     {Hue[0.880489879942786, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{10., 0.}, {11., 0.}, {12., 1.0986122886681098`}, {13., 
       1.3862943611198906`}, {14., 1.0986122886681098`}, {15., 
       0.6931471805599453}, {16., 0.}, {17., 0.}, {18., 0.}, {19., 
       0.6931471805599453}, {20., 0.6931471805599453}, {21., 0.}}]}, 
     {Hue[0.11655785744261493`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{10., 0.}, {11., 1.0986122886681098`}, {12., 
       1.3862943611198906`}}]}, 
     {Hue[0.352625834942387, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{10., 0.}, {11., 0.}}]}, 
     {Hue[0.588693812442159, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{11., 0.}, {12., 0.}, {13., 0.}, {14., 0.6931471805599453}, {
       15., 0.6931471805599453}, {16., 0.}}]}, {}, {}, 
     {Hue[0.296897744941532, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{11., 0.}, {12., 1.0986122886681098`}, {13., 0.}}]}, 
     {Hue[0.532965722441304, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{11., 0.}, {12., 0.}, {13., 0.6931471805599453}, {14., 
       0.}}]}, 
     {Hue[0.7690336999411329, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{11., 0.}, {12., 0.6931471805599453}}]}, 
     {Hue[0.00510167744090495, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{11., 0.}, {12., 0.}}]}, 
     {Hue[0.241169654940677, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{12., 0.}, {13., 0.}, {14., 0.}}]}, 
     {Hue[0.4772376324405059, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{12., 0.}, {13., 0.}, {14., 0.}}]}, {}, 
     {Hue[0.94937358744005, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{13., 0.}, {14., 0.}, {15., 0.}}]}, 
     {Hue[0.18544156493987884`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{13., 0.}, {14., 0.}}]}, 
     {Hue[0.4215095424396509, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{13., 0.}, {14., 1.0986122886681098`}, {15., 0.}, {16., 0.}, {
       17., 0.}, {18., 0.}, {19., 0.6931471805599453}, {20., 0.}}]}, 
     {Hue[0.6575775199394229, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{13., 0.}, {14., 0.}}]}, {}, {}, {}, {}, {}, {}, 
     {Hue[0.3100533624379409, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{15., 0.}, {16., 0.}}]}, 
     {Hue[0.5461213399377698, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{15., 0.}, {16., 0.}}]}, {}, 
     {Hue[0.018257294937313873`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{17., 0.}, {18., 0.}, {19., 0.}, {20., 0.}}]}, 
     {Hue[0.25432527243714276`, 0.6, 0.6], Thickness[0.005], 
      LineBox[{{17., 0.}, {18., 1.3862943611198906`}, {19., 
       1.6094379124341003`}, {20., 2.0794415416798357`}, {21., 
       1.791759469228055}, {22., 2.0794415416798357`}, {23., 
       1.6094379124341003`}, {24., 1.3862943611198906`}, {25., 
       1.3862943611198906`}, {26., 0.}, {27., 0.}}]}, {}, 
     {Hue[0.7264612274366868, 0.6, 0.6], Thickness[0.005], 
      LineBox[CompressedData["
1:eJxdlXtUjfkax7dOpGLk0hbGlHNObqVB6DIa3zJtXUS33f2y27W77d1l0EXC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       
       "]]}}, {}}, {{{}, {}, 
     {GrayLevel[0.5], Thickness[0.005], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw2CIiUmF7XhHK53BIPlLA
22wH4ws4zLWTfTdxoQKUL+IgXPvMrZMTxpdwiNex/Nv+UQ7Kl3EIbZrOMnGz
LJSv4LBM9h9/TbYMlK/kUMW47enMAGkoX8WBibPZolNDCspXcyiYmed/4oAE
lK/hsDJrroTOVnEoX8uhqy5OfM0XUShfx2Hp1GLBnQ4wvp6D3M7ibe2nhaF8
A4fezZza++4LQfmGDqlzlzFVLxCE8o0cfN2OHX1iKwDlGzuscDx89JgkL5Rv
4iD/7+xpiw9cUL6pw1mpD6+mCMD4Zg7GvW+/Ox7ghPLNHd5b/vrnpMcG5Vs4
QMKbCcq3dAiPMlpXpPTfHsK3gqr/BuVbQ/nPoHwbqD4GBgBlaGob
       "]]}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  Frame->{True, True, False, False},
  FrameLabel->{{
     FormBox["\"Number of copies of allele\"", TraditionalForm], None}, {
     FormBox["\"Generation\"", TraditionalForm], None}},
  FrameTicks->{{{{0., 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{0, 150}, {0., 9.210340371976184}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, {{0., 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.764250156916621*^9, 3.771543904097765*^9, 
  3.771544027965953*^9, 3.782251466613822*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, {}, 
    {Hue[0.9060679774997897, 0.6, 0.6], 
     LineBox[{{3., 0.}, {4., 0.}, {5., 1.0986122886681098`}, {6., 
      1.0986122886681098`}, {7., 0.6931471805599453}}]}, 
    {Hue[0.1421359549995791, 0.6, 0.6], LineBox[{{7., 0.}, {8., 0.}}], 
     LineBox[CompressedData["
1:eJxdlXtUjfkax7dOpGLk0hbGlHNObqVB6DIa3zJtXUS33f2y27W77d1l0EXC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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  Frame->{True, True, False, False},
  FrameLabel->{{
     FormBox["\"Number of copies of allele\"", TraditionalForm], None}, {
     FormBox["\"Generation\"", TraditionalForm], None}},
  FrameTicks->{{{{0., 
       FormBox["1", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["5", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {3.912023005428146, 
       FormBox["50", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.214608098422191, 
       FormBox["500", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {8.517193191416238, 
       FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{0, 150}, {0., 6.940222469119639}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, {{0., 
      FormBox["1", TraditionalForm]}, {1.6094379124341003`, 
      FormBox["5", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {3.912023005428146, 
      FormBox["50", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.214608098422191, 
      FormBox["500", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {8.517193191416238, 
      FormBox["5000", TraditionalForm]}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.764250156916621*^9, 3.771543904097765*^9, 
  3.771544027965953*^9, 3.782251466635929*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure 2", "Subsubsection",
 CellChangeTimes->{{3.784899716602643*^9, 3.784899717538375*^9}, {
  3.784900539169342*^9, 3.784900547616172*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GraphicsColumn", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"fig2a", ",", "fig2b"}], "}"}], ",", 
   RowBox[{"Spacings", "\[Rule]", 
    RowBox[{"-", "30"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{"figdir", "<>", "\"\<Figure2.eps\>\""}], ",", "%"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.784899724298213*^9, 3.784899776005975*^9}, {
   3.784899821904286*^9, 3.784899842912471*^9}, {3.784900259563116*^9, 
   3.784900306720999*^9}, {3.7849003384131107`*^9, 3.78490033967591*^9}, 
   3.784900539169818*^9, {3.7849006074498787`*^9, 3.784900611147958*^9}, {
   3.7849032803309526`*^9, 3.78490328352244*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{{}, {}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwiHH4eFrogiKUz+Gguttj
kosJjC/gcLhDZN77pQpQvohDp7hdR68wjC/h0Ff/2s2AQR7Kl3GI6bgrIrxH
FspXcFjw16LbolUGyldyCOk4dKbERhrKV3F4MvVI8wt9KShfzeGr0PeUI2qS
UL6Gg85mFjazPnEoX8uhodT+i5WaGJSv47BO9rKS1nMRKF/PQaWccbLZe2Eo
38DBe/NHr0BzGN/QoeDa50OJikJQvpEDj/Ch8oKX/FC+scO2DxP0pc7yQfkm
DiscDx89JskL5Zs6KHtNuxa1ggvKN3M4K/Xh1RQBGN/cYeLj4mqn7+xQvoWD
vIevpdgqVijf0sHHvH77Yz1mKN/KITzKaF2R0n97CN/aoXi1tf2mRQxQeRsH
bua1Va8mM0L5tmjydmj67R3eW/7656T3zB4AskF0Pw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVw2JXt9LX3miKUz+GwIrDq
pbQNjC/gsKk3YffLqQpQvohDmZOV36Pf8lC+hIM8h8LszKtyUL6Mw12xN7nR
M2ShfAUHqeXB079myED5Sg6Nv/cue/VTCspXcShrZ0ri2CEJ5as5HDy9yCah
TQLK13D48C217sFCcShfy2HWyoPOX9eKQfk6DvmMv9tWWYtC+XoOQmuvZn6o
E4HyDRyeZGla/W0XhvINHfYeb7//o14IyjdyEHpx4NDqIEEo39hhvfSa7Ze8
+aF8EwddW72Q/c94oXxThw+bL/6tFeWE8s0cIOHJBOWbOxj3vv3ueOCnPYRv
gca3dOBmXlv1avJHewDSbWr/
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw8LASXqt9XhHK53DoLNm+
464tjC/gYON5z3LdPAUoX8QhTFXvZw8jjC/hMIVzi/eCG3JQvoyDyGE2d+6d
slC+goPzlvhzx9bLQPlKDkEiezSPr5eG8lUc9tncNr+cLQXlqznYWnkaKiVI
QvkaDg9+yoU2GUhA+VoO2w9wuc9/LQbl6zh4vLq+j69bBMrXczi9bevKogJh
KN/A4Y1wZOq3TiEo39Dh9R31Fv0mASjfyKF0d4CNxQ8+KN/YITzKaF2REj+U
b+Kw7cMEfamzMHlTB94iI+vLTbxQvplD9okd+y7v5IbyzR1+6kyqWZ7DCeVb
oPEtHT5svvi3VhTGt0KTt3bwMa/f/liPGcq3cWBS0PrFvfqPPYRv68DNvLbq
1eSPUL6dw3vLX/+c9L5B+fYOxaut7TctYoDqd0CVb0DwAXlYg7E=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVwcBG6E+l4WRHK53C45Cny
64oJjC/gMNdO9t3EhQpQvohD11yX9UYX5KF8CYfihd+vblglB+XLOOwIXsS8
v1sWyldweK6079oCXxkoX8lhuu6SS7v+SUH5Kg5yxS5KVz5KQvlqDtuufzYR
Oi4B5Ws4lNxafELwhjiUr+Uwa+VB569rxaB8HYeTV1paS0+KQvl6DtZZRTMS
tohA+QYOcjuLt7WfFobyDR2OBByY3bBLCMo3cijeuL4zoEoQyjd2kJZ4/GLi
JAEo38TBOeSPGasbH5Rv6qDsNe1a1AouKN/MoW1itlW1PDuUb+4g7+FrKbaK
Fcq3cChebW2/aREDlG/pwM28turVZEYo3wqNb+0QHmW0rkjpvz2Eb+NQO+/y
HrGHzFB5WzS+nQMkPpmgfHs0+xyg5n+EmNfg4PDe8tc/J71vUPMdofxnUHk0
PoMTXD8A8p2TyQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVw2PXkdZ/KBUUon8Ph+Ycn
nZJGML6AQ+79Fa9mzFCA8kUcBC7rvvr4Rh7Kl3AwkV6x3vGIHJQv47Az+MkW
qRZZKF/B4dBqPvXDPjJQvpLDtcnMmy4ESUP5Kg6OuapWmaFSUL6aw1eh7ylH
1CShfA2Hx3eCChvZJKB8LYcbUxOi1lwQg/J1HP4VfVflPCoK5es53Ivoa+/5
LgLlGzjI7Sze1n5aGMo3dDB0m7XT66wQlG/kEMO+aJa0qyCUb+yQ4zRhL99C
PijfxCFKe6LHuQpuKN/U4cRR2/KSXRxQvplD28Rsq2p5dijf3MHHvH77Yz1m
KN/CARLeTFC+pQM389qqV5MZoXwrNHlrB+Pet98dD/y0h/BtHN5b/vrnpPcN
yreF8p9B+XZQ8z5C+fZo8g6o+hsc0Mx3RNXfgOADAB17k1k=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVw2LDyzs7T5xWhfA6H5Knp
HiwWML6Ag3Kd40KtuQpQvojDOlZ+oTYOGF/CwWvDb4YbD+SgfBmH5FtPjjQe
lIXyFRye9Sp8rTokA+UrOSRckt82P1oayldxCGn8f/GKkxSUr+bguTtf/DOj
JJSv4XBAZDV74itxKF/Lgfvyl8J/dWJQvo7DzL55WYfKRKF8PQehtVczP9SJ
QPkGDicrXWxS1IShfEOHpidJvU/WCEL5Rg4nr6l8+c0D4xs7CL4REfsgxgfl
mzgoe027FrWCC8o3dWibmG1VLc8O5Zs5QMKTCco3dwiPMlpXpPTfHsK3QONb
Ohj3vv3ueOAnlG/l8N7y1z8nvW9QvjWavI0DN/PaqleTP0L5tmjydmj67dH4
Dqj8Bhj/GVTeEU3eEU3eCW4/AOuznHQ=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwaNXfzVZ/SRHK53AQabm2
ucccxhdwqC2UXxA+QwHKF3Fgneh7KPi/PJQv4bBZ5Hnc3X9yUL6Mw70frLWr
zslC+QoOW/M/x76ZLQPlKzkwBnzmNJ8mDeWrOOyzuW1+OVsKyldzaF5zSDg0
ThLK13DYxLCooVtAAsrXcuCo65c+FS8O5es4zCtdcctASQzK13PYtL5NTuKO
CJRv4KD7XLqBiwXGN3SIjD/kERUhDOUbOeyLUT0oxy0E5Rs72Id/ifGTFoTy
TRy6jVLvzE4QgPJNHf4zBP5PKOGH8s0cdG31QvY/44XyzR1mX+P+ucyUG8q3
cDDuffvd8QAnlG/p0DYx26panh3Kt3LgZl5b9WoyI5Rv7fDe8tc/J71v9hC+
DVT+oz0ArstpZQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwiPnCf+/AOUUon8PBSGlh
mogJjC/gkK9q9vHECgUoX8RhHSu/UBsHjC/h8NM85PvrE3JQvoxDaNN0lomb
ZaF8BYdH/PwvN5TIQPlKDv28r2YqhElD+SoOMdz7ImYLS0H5ag6MVto7z3NK
QvkaDiXGx2xLz4pD+VoO20+Ls/5JEIPydRwE2gtT7i8SgfL1HOR2Fm9rPy0M
5Rs4zNy/vDxURwjKN3SwD/8S4yctCOUbOVRqHv+Z6i8A5Rs7RM5au1BUB8Y3
cdh73OqdxmMeKN/UYYXj4aPHJHmhfDOHb7w7G/+YwuTNHYx73353PMAJ5Vs4
bFyXP0UvmgPKt3TwMa/f/liPGcq3QuNbO0DihwnKt3HgZl5b9WoyI5Rv68Ck
oPWLe/UfewjfzuG95a9/TnrfoHx7NL4DKr/BAWreR3sAsz+AdA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwmD/x3sroS4pQPofDyzne
jvyGML6Aw50X96cKLlSA8kUcOkqT5z7lgfElHOLTT08J+S4H5cs47K/JCP33
XhbKV3BQZ9f8nbRfBspXctDe08k6N10ayldxyJbJN5lhLQXlqzlcfdvA8fqx
BJSv4VC5MfCHRpU4lK/l0PnrwirJv6JQvo5DhEe/wKP9IlC+nkN2BHtg8nRh
KN/AYamV8Ynlc4WgfEMH2dV/rsWYC0L5Rg6Rs9YuFNURgPKNHdZLr9l+yZsf
yjdx2Hvc6p3GYx4o39ThrNSHV1MEuKB8M4faeZf3iD1khvLNHYx73353PPDT
HsK3cOBmXlv1avJHKN/S4b3lr39Oes/sAci3ZtA=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw2CIiUmF7XhHK53C4KPTC
pMQRxhdwuHDVQGDdOgUoX8TBtkK5xUoIxpdwMN1z4tu/F3JQvoyDyGE2d+6d
slC+gkObmNJVwyQZKF/JIdHXKZTfUhrKV3FQKn+x5LqRFJSv5tA382p1uYck
lK/h8OCnXGiTgQSUr+XQV1bfZHNPDMrXcXjTd26T/SVRKF/PIcKjX+DRfhEo
38Dh9LatK4sKhKF8Q4c3wpGp3zqFoHwjB11BjY+zLgpA+cYOvDlCrzsKYXwT
h/XSa7Zf8uaH8k0dLu64+uXGD24o38xh47r8KXrRHFC+ucOJo7blJbtgfAsH
nc0sbGZ97FC+pUNV/a+D2avYoHwrBx/z+u2P9ZihfGuH4tXW9psWMUD5Ng7c
zGurXk3+aA/h28L5AB/Xb+A=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQEf7MVCt+7emK3kABVwWMPPJJ17RRHK53BInpru
wWIB4ws43Hlxf6rgQgUoX8SB4bdN2AVWGF/CYW38intZ5+WgfBmHc7+Tbr3s
k4XyFRxeeFZ+1/CSgfKVHI5vOXGyUlYayldxmDmryvTLPEkoX83hfIqHT/JK
CShfw+Fzm2uEq5E4lK/l0FBq/8VKTQzK13EQaC9Mub9IBMrXcxDiFt/zbI8w
lG/gMHP/8vJQHSEo39CheOP6zoAqQSjfyOHzv12RTewCUL6xA4/wofKCl/xQ
vomD58p1q1TnwPimDtknduy7vJMbyjdzOCv14dUUAS4o39xh+e7rYqdkWKF8
CzS+pQMk/JmgfCs0vrUDN/PaqleTGaF8G4fwKKN1RUr/7SF8WzR5OwcmBa1f
3Kv/QOXtHYx73353PPATyndA5Tc4oKl3dHhv+eufk943qDwan8EJyn8GlXdC
0+8Mdc9HqLwzXD0AMfCiGw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwOCXI8kPmoiKUz+GQe7/o
9mV9GF/A4TqH3Se++QpQvoiDkeQPdUFBGF/C4ax1p9Gnt3JQvozDixjhX3O2
yUL5Cg5z9ByuXIyQgfKVHNQblDLDXKShfBWHW//Ovn56ThLKV3MwUPj5z3q5
BJSv4aCzmYXNrE8cytdyaHypuP+RpxiUr+PQXnWk4sccEShfz+GNcGTqt04h
KN/AwfLc7gXHHghA+YYOkbPWLhTVgfGNHJgUtH5xr+aB8o0dThy1LS/ZxQHl
mzh82Hzxb60oJ5Rv6jDxcXG103d2KN/MQd7D11JsFSuUb+7QNjHbqloeJm/h
8N7y1z8nPTYo3xLqH5i8FRrfGk29jUPtvMt7xB4yQ/m2Dj7m9dsf68H4dmh8
e4fwKKN1RUr/7SF8B6j//kD4DQ4Oxr1vvzse+GkPAPRwf6g=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwUFkQbW5xUxHK53CIkm53
zjWD8QUc5tyPu+E/SQHKF3FQWenxbSYzjC/hcIlXnlfhmByUL+NwtaTZqPmI
LJSv4KDPeuGyQpcMlK/k8P6r35dvCtJQvooD+83zKbeZpKB8NQdFicS/Z+9K
QPkaDq+3zL1vsEocytdy2Hk6clt4pBiUr+PwlHXat+3TRaF8PYcIj36BR/tF
oHwDh6mqfyMZ5gtD+YYOWSU/tjGGC0H5Rg5XUr9xauwUhPKNHSo1j/9M9ReA
8k0cdG31QvY/44XyTR1mX+P+ucyUG8o3c9DZzMJm1scO5Zs7yHv4WoqtYoXy
LRyKV1vbb1rEAOVbOry3/PXPSe+bPYRvhca3hvKf2QMA4ZhpOw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQEf7MVCt+7emK3kABVwaGud4GVxSRHK53AIZJRd
lW0M4ws4bFqqMEN9jgKUL+LwNmP3heuv5KF8CQeX1xPW926Xg/JlHM5smOrX
lykL5Ss4KCq8MekxlIHylRwUVYwuep6RgvJVHH7qTKpZniMJ5as5TFzEPOGd
nQSUr+FwZnsIl4qkOJSv5WD2KUrD+74olK/jcC+ir73nuwiUr+eg+1y6gYsF
xjdw2Hu8/f6PeiEo39Bht9SUuTvfC0D5Rg4BOVqnv0rC+MYOziF/zFjd+KB8
E4drvB0ZP/14oXxTh+wTO/Zd3skN5Zs5fNh88W+tKCeUb+6gs5mFzayPHcq3
cGibmG1VLQ/jWzpMfFxc7fQdxrdCU2/tULza2n7TIgYo38bBuPftd8cDP+0h
fFs0vp3De8tf/5z0nkH59g7hUUbripT+Q/kODkwKWr+4V/+B8Bsc0NQ7ovIb
YPxvUHknNHk0PoOzAzfz2qpXkz9C5dH4DC5o8i5o7ndFta/BFU3eDU2/G5r9
7nA+AEifx2g=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwMGYoVA66qAjlczj4+cTJ
JzjD+AIONbEnklq2K0D5Ig5euvdt0mVgfAmH2uYvNT7i8lC+jMNq3vWzfE/K
QvkKDpObdx55M18Gyldy+PQjr//kBmkoX8Uhv+jJ+dwlUlC+msPPy/nsLuWS
UL6Gg9H/FMn9CySgfC0Hi6P11fN2iUP5Og43piZErbkgBuXrOYTeZO3sqBaF
8g0cLqzZ29l8TQTKN3SI63B7aXtEGMo3crhkP4lF/K4glG/soOiY3ln6TwDK
N3HQFdT4OOsijG/qkOM0YS/fQj4o38yBSUHrF/dqHijf3OHD5ot/a0U5oXwL
h4mPi6udvrND+ZYOy3dfFzslwwrlWzm0Tcy2qpaHyVs7BPYYarO0skD5Ng7c
zGurXk1mhPJtHYpXW9tvWsQA5ds5vLf89c9J75s9hG8PVf/RHgC7YXfi
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw+PBlXiv3VUUon8NhUqT4
9y59GF/AwUbt/7OcaQpQvojDn/xy1pqP8lC+hIORX7X5rotyUL6Mg+vb3E3+
h2WhfAWHeSmijoe6ZaB8JYe+H/9XyNVJQ/kqDimHtxn28EpB+WoOdbLiSz89
lYDyNRxY87mNc4+KQ/laDnvfBPv5LxaD8nUcVgu+k1DbLArl6zksftKa5Jwm
AuUbOBwJODC7YZcQlG/o8ExfyThPUxDKN3JYcnJxGXcJH5Rv7DChhXnH/Vgu
KN/EYfnu62KnZFihfFOH95a//jnpsUH5Zg618y7vEXvIDOWbOxSvtrbftIgB
yrdwYFLQ+sW9+o89hG+JxreCmvcNyreG8p9B+TZwPgCvwXDA
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwqPLJ5JK7rAjlczgwfyiP
YjSC8QUcgoQ+xfd1K0D5Ig5uoR9m73khD+VLONSU3LjmtkcOypdx2BG8iHl/
tyyUr+DwZBnj0dBqGShfySFgu5aiubM0lK/isH1zq1XiNkkoX81BUjo7Y3qu
BJSv4XDIe4XWxRhxKF/LYWqD7WJBJzEoX8dBkeXug89/RKB8PYeYZuOoGy+E
oHwDhyup3zg1dgpC+YYOQi8OHFodBOMbOfDmCL3uKBSA8o0deIQPlRe85Ify
TRyOfuYPjirkgfJNHZS9pl2LWsEF5Zs5yHv4WoqtYoXyzR18zOu3P9ZjhvIt
HCDhzQTlW6LxrRzCo4zWFSn9t4fwrR3eW/7656T3zR4AfFpknw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwePtlgkDeWUUon8Nhr4tC
0TpbGF/A4WWVofW81QpQvojDkT+bSos0YHwJh6NzGCsey8hD+TIOU1dqamj8
lIXyFRziDdS/i12RgfKVHNqZ/Mt3H5eG8lUc+hvjDwfWSEH5ag61K6eaR9tK
QvkaDnME7dku/hSH8rUcLByUmRw+iUH5Og6rBd9JqG0WhfL1HNbJXlbSei4C
5Rs4RMYf8oiKEIbyDR24Fv+IczsqCOUbOZRqTpk8aZMAlG/s4Ot27OgTWxjf
xME55I8ZqxsflG/qcI23I+OnHy+Ub+Zg3Pv2u+MBTijf3GH57utip2RYoXwL
ByYFrV/cq//YQ/iWDu8tf/1z0vsG5Vuh8a3R+DZQ/jN7AKTSbiQ=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwEEo5ajf3nCKUz+Fwsflx
31otGF/AobZQfkH4DAUoX8Rhe3yd8dWP8lC+hENZTq5E8kk5KF/G4YnBtSfi
C2WhfAUHDzfhU1uWyED5Sg7rN6qo8ddKQ/kqDqtfO6b7mUhB+WoO8bkb58+4
KgHlazgIH1bUFZ8vDuVrOVzOubPzRIoYlK/jINBemHJ/kQiUr+cgxC2+59ke
YSjfwMFt78ssh4uCUL6hQ/Fqa/tNiwSgfCMHX7djR5/YwvjGDrxFRtaXm3ih
fBOHizuufrnxgxvKN3U4K/Xh1RQBLijfzOG95a9/TnpsUL65w/Ld18VOybBC
+RZQ+xigfEuo+m/2AHIhY7g=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQDQEf7MVCt+7emK3kABVwKBI/lshzWRHK53BYEVj1
UtoGxhdwEJtop3NhvgKUL+IQvyhEM5kbxpdwuFAh/XflDzkoX8ZBUHV+2MVL
slC+gsPbor/TebbJQPlKDj3Xwj887ZWG8lUcyvo2L6gqlYLy1RziczfOn3FV
AsrXcDCeLLuxbqY4lK/l8Kbv3Cb7S6JQvo5DYI+hNkurCJSv5/Bc81OlYYAw
lG/g0N27VHUtM4xv6DBz//LyUB0hKN/IQVri8YuJkwSgfGMHHuFD5QUv+aF8
E4dtHyboS53lg/JNHZacXFzGXQLjmzlMaGHecT+WC8o3d9i4Ln+KXjQHlG8B
dR8LlG/p0DYx26panh3Kt3KonXd5j9hDZijf2oGbeW3Vq8mMUL4Nmn5bNL6d
g495/fbHejD99mjmOaCqb3BwkPfwtRRbxQqVd0TlNzg6LN99XeyUDEzeyYFJ
QesX9+o/9hB5J6j7PkL4DM4O7y1//XPSe2YPAM2ijTs=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEf7MVCt+7emK3kABVwaPtpuODpNUUon8PBJlkx
J9ENxhdwSOhqj/qyVQHKF3HYqveC0UAOxpdwUDnd/3afrDyUL+PgVs9zhpNP
DspXcKjpVDHr/CAD5Ss5GJ90nZBzTRrKV3FY9vJbi/9tKShfzcHsV+7+vesl
oXwNhxk+KkEcvRJQvpaD37mAI8szxKF8HYcF/ExSf1zFoHw9h8Men+cp7hGF
8g0cZG5HOAhMFIHyDR02FxR/jqoQhvKNHKLd93P92iAE5Rs7CL04cGh1kCCU
b+JgeW73gmMPBKB8UwfnkD9mrG58UL6Zw8UdV7/c+MEN5Zs7nDhqW16yiwPK
t3Bom5htVS3PDuVbOvzUmVSzPIcTyrdy+LD54t9aURjfGk29DRrf1qGq/tfB
7FVsUL6dg495/fbHesxQvr1DYI+hNksrC5Tv4CDv4WsptooVwm9wQFPv6ABJ
D0xQeUc0/U4O3Mxrq15NZoTKOznUzru8R+whTL+zw3vLX/+c9L7ZQ+Rh/GcQ
PoMLKr8BwQcA9ciikw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwKN2XpWd3RhHK53A4bj/r
s4YVjC/g8LLK0HreagUoX8ShszL/TQoPjC/hsFBs46TkB3JQvoxDQlONpud6
WShfwSH7nA5n0UQZKF/JQezWqibvRmkoX8WBPW3nqZtlUlC+msOktxkaddaS
UL6Gw4OfcqFNBhJQvpaDhYMyk8MnMShfx6FH/MKkb4WiUL6eQzCDxbmNgiJQ
voFDScbyff5iQlC+ocNuqSlzd74XgPKNHJxD/pixuvFB+cYORz/zB0cV8kD5
Jg4njtqWl+zigPJNHWrnXd4j9pAZyjdzYFLQ+sW9+o89hG+Oxrdw4GZeW/Vq
8kco39LhveWvf056z6B8KzR5azS+jYNx79vvjgd+Qvm2cP0ALCpygg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwWMzOZs58SRHK53D4uFMi
ssAKxhdwkCi5sO3dPAUoX8RBuPaZWycnjC/hcGpZSuaV23JQvowDQ/WX8zJH
ZaF8BYf8ztbW3DQZKF/JQVQ2ViuYSRrKV3HYzH7p2C8OKShfzcGyPOQx2y8J
KF/D4XXKpqZPa8ShfC2H7Qe43Oe/FoPydRxmnRLatWCdKJSv53BA2+ntmiIR
KN/AwXvzR69Ac2Eo39Dhkv0kFvG7glC+kUO3Ueqd2QkCUL6xg+AbEbEPYnxQ
volD9okd+y7v5IbyTR3OSn14NUWAC8o3Q+ObO7RNzLaqlmeH8i0caudd3iP2
kBnKt3TwMa/f/lgPxrdyWL77utgpGVYo3xpNv41D8Wpr+02LGKB8Wwdu5rVV
ryZ/tAcAK+Fu9g==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwqJy81Jb7oiKUz+HAUfvj
3kZLGF/AIWZ9QYvLbAUoX8Th2tHnNxgZYHwJB5fXE9b3bpeD8mUcnJZcWzGx
QxbKV3DYWPj09ZpIGShfySG/xj/V1VcayldxmLfANDLBUArKV3Pom3m1utxD
EsrXcHCbzflxubYElK/l0FdW32RzTwzK13GY2Tcv61CZKJSv5xCT9Oixzgth
KN/AYe/x9vs/6oWgfEMHXUGNj7MuCkD5Rg48wofKC17yQ/nGDn5r+lxTt/JC
+SYO2Sd27Lu8kxvKN3U4cdS2vGQXB5Rv5lA77/IesYfMUL65A5OC1i/u1X/s
IXwLNL6lQ/Fqa/tNixig6q0cuJnXVr2a/BEqb+1g3Pv2u+OBn1C+jcN7y1//
nPS+Qfm2aHw7KP+ZPQAM7X4K
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwUBaw3zLhkiKUz+FgpLQw
TcQExhdw2H54mrruPAUoX8TB5d+rXn0OGF/Cwe72FDGGW3JQvoyDC7MHw7fJ
slC+gsOWm9vmtIfIQPlKDr7WfZu3/pCC8lUc+idGCzVfkITy1RwmKzx9EeAo
AeVrOESd582c+VAMytdyaG45fGf6AVEoX8fhgLbT2zVFIlC+noPczuJt7aeF
oXwDh4TC2N+nXghC+YYOvDlCrzsKBaB8Iwce4UPlBS/5oXxjB8E3ImIfxPig
fBMHZa9p16JWcEH5pmh8Mwfj3rffHQ9wQvnmDm0Ts62q5dmhfAuH5buvi52S
YYXyLR0g4c8E5Vs5BPYYarO0skD51mjyNmh8W4fwKKN1RUr/7SF8OzS+vUPx
amv7TYsYoOodHN5b/vrnpPcNIt/gAHXvT3sA0hd+6g==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwiPnCf+/AOUUon8Phx3+D
mA5DGF/A4Xgiv8iiWQpQvohDbPr1B7k/5KF8CYc8I4mGDXvloHwZB7aGkNc3
pspC+QoOJY6+8m2lMlC+ksOWdc0d4k7SUL6Kg+vRvOpJqlJQvppD7cqp5tG2
klC+hsOnGdz/et6LQ/laDgv4maT+uIpB+ToOuwp0vgcziUL5eg7pU5lKeI1F
oHwDh97NnNr77gtB+YYORwIOzG7YBeMbOXAt/hHndlQQyjd2kJZ4/GLiJAEo
38RhvfSa7Ze8+aF8UwfBNyJiH8T4oHwzB+eQP2asbjC+ucNPnUk1y3M4oXwL
h4mPi6udvrND+ZYO8h6+lmKrWKF8K4fwKKN1RUr/7QHVwmCe
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwyLz2uGzrWUUon8Oh32fV
iiJ9GF/AQdvCaglHmwKUL+LgPl1PR+OmPJQv4dB7qCOVbZEclC/jMO+v0c3P
PrJQvoJDzKdXQt+/SUP5Sg7LXn5r8b8tBeWrOPhFVBt+vCYJ5as5KPuWhjXE
SkD5Gg6RShYLboSJQ/laDur3AheWsopB+ToOfxazKD6/IALl6zmUi85m6F8m
DOUbOPRu5tTed18Iyjd0SJ27jKl6gSCUb+Qgu/rPtRhzGN/YoXR3gI3FDz4o
38RhQgvzjvuxXFC+qUPtvMt7xB4yQ/lmDoE9htosrSxQvrmDce/b744HftpD
+BZofEs4HwCe32QO
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwkHdPUz56RRHK53Cw+rC4
K9gYxhdwSA/c+2X1XAUoX8SB40b7OyNOGF/Cga9G/QXfcTkoX8ZhR/Ai5v3d
slC+goOx/0k2g3IZKF/JYcO8nLAYbWkoX8VhvbachcsHSShfzaHE0qpDeKkE
lK/hsFBpjkzBJnEoX8shIOib9PomMShfx8Fs8pEMTyFRKF/PgV2OJeTIJWEo
38Bh+sMexnsfhaB8Q4fijes7A6oEoXwjB1+3Y0ef2ApA+cYOpbsDbCx+8EH5
Jg7ZJ3bsu7yTG8o3daiq/3UwexUblG/mIO/haym2ihXKN3dgUtD6xb36jz2E
b+HAzby26tXkj1C+pcN7y1//nPS+QflWUP4zKN8ajW+Dpt8WjW+Hpt4eje8A
5wMAdw6Afg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwWMXgV3TvqiKUz+Hwccpc
URMLGF/AQWrR2tP98xWgfBEHlZUe32Yyw/gSDoe8Tq6U3C8H5cs42GgxS0VH
yUL5Cg5m0v7pPLYyUL6SQ82BOtVzEtJQvorDPn+he7tXSUL5ag5n7J64BZ2V
gPI1HF5vmXvfYJU4lK/lsICfSeqPqxiUr+OQfHvPnuVvRKB8PYdziREfP98U
hvINHBYuOSHaf00Iyjd0KNWcMnnSJgEo38hhtY1ShsZhfijf2GHvcat3Go95
oHwTh4mPi6udvrND+aYO7y1//XPSY4PyzRyq6n8dzF4F45s7LN99XeyUDCuU
b+EACW8mKN/Swbj37XfHAz/tIXwrNL61Azfz2qpXkz9C+TZQ+55B+bZwPgB0
hHfu
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVweC8/Ydfhm4pQPofD7T8H
ufW8YHwBh0v7yjMfrlKA8kUcEj8vEzIRhfElHKYJLrU1+yMH5cs4MFR/OS9z
VBbKV3CI2xisvXOBDJSv5ND34/8KuTppKF/FofDWHwH3eCkoX81h5TO9Gy8i
JKF8DYeN6/Kn6EVLQPlaDkcPLr5xIEkcytdxYPvAf21ihhiUr+fwmy/d/qCr
KJRv4PAu98hX42/CUL6hw97j7fd/1AtB+UYO0hKPX0ycJADlGztEzlq7UFQH
xjcBqrd6p/GYB8o3dZD38LUUW8UK5Zs5BPYYarO0skD55g7czGurXk1mhPIt
HGrnXd4j9pAZyrd0CI8yWlek9N8ewrdyeG/565+T3jco3xrKfwbl20DN+wjl
28LlAefneAQ=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw8OTwCom8pgjlczg8iZzw
Zr4VjC/g4PtQ5mrAAgUoX8SBdcohBV5uGF/CQWxZs8Hvv3JQvowDr+Eh//pT
slC+gkMrB8eftfkyUL6SQ6KvUyi/pTSUr+Jw5IbXLOenklC+msODE68Fc8Vh
fA2Hso1yk0LvikP5Wg6NLxX3P/IUg/J1HFYWnL2Y0ScK5es5LH7SmuScJgLl
GzhoqrA/+e4uDOUbOnT3LlVdywzjGzmUZCzf5y8mBOUbO1RqHv+Z6i8A5Zs4
zL7G/XOZKTeUb+owoYV5x/1YLijfzEFnMwubWR87lG/u0DYx26paHsa3cAjs
MdRmaWWB8i0dmBS0fnGv/mMP4Vs5vLf89c9J7xuUb+1g3Pv2u+OBn1C+jQM3
89qqV5M/Qvm2aHw7qP5n9gBfLHLj
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwOCXI8kPmoiKUz+Ew0fiJ
iqAVjC/gMM9wc8zOfgUoX8Qh5d6rbROfykP5Eg6rez8U1fTLQfkyDlxt8hz/
EmShfAWHT7PC3J96y0D5Sg7XJjNvuhAkDeWrONQ9WekppiIF5as5ZF11ZZ0r
KAnlazjEe+9x2HNIHMrXclApvHjzp6gYlK/j4FcsUD3tqAiUr+dwLjHi4+eb
wlC+gYOmCvuT7+4wvqHDt6514rFfBKF8Iwf78C8xftIwvrGDr9uxo09sBaB8
E4dvvDsb/5jyQPmmDieO2paX7OKA8s0cqup/HcxexQblmzv4mNdvf6zHDOVb
OEDCmwnKt3Qw7n373fHAT3sI38rhveWvf056z6B8azS+jQM389qqV5M/2gMA
YNdx/Q==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwMOXSXstxXRHK53CQc3ll
t8wZxhdwCNqQbyy8UwHKF3Hgd5/sImUI40s4BG3vs9yiJg/lyzicDTn584W0
HJSv4DD52Pbt2uyyUL6Sw7sklrsbXkpD+SoOx+6opT6fKgXlqznc+LBg8d5i
SShfw+Hw8i1zzGdJQPlaDqXmaqlbU8WhfB0HI/H5iTFtYlC+noMiy90Hn/+I
QPkGDkLc4nue7RGG8g0d9sWoHpTjFoLyjRz+MwT+Tyjhh/KNHXKcJuzlW8gH
5Zs48BYZWV9u4oXyTR3k/509bfGBC8o3c9DZzMJm1scO5Zs7vLf89c9Jjw3K
t3ConXd5j9hDZijf0iGwx1CbpZUFyrdyMO59+93xwE97CN8aqv+ZPQAXImcT

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwOMAg9ffVWUUon8NhBmOS
cocVjC/g8HqFkfSnhQpQvohDJcecqVZ/5KF8CYdnySxHdefKQfkyDluC7az1
3WShfAUHq3KNeZe2SUP5Sg6OuapWmaFSUL6Kw8mrbrkHzSWhfDWH5auv3Pj+
RhzK13CwcFBmcvgkBuVrOZy80tJaelIUytdxmLvDJnryOhEoX8/Bx7x++2M9
YSjfwCGGfdEsaVdBKN8QjW/kUKl5/GeqvwCUb+xwjbcj46cfL5Rv4qDsNe1a
1AouKN/U4cRR2/KSXRxQvpnD8t3XxU7JsEL55g46m1nYzPrYoXwLNHlLB27m
tVWvJjNC+VYOTApav7hX/7GH8K0dildb229axACVt4H6hxnKt0XTb4em3t4h
PMpoXZHSf6h5Dg7GvW+/Ox74CeE3OMDtAwDBvXu8
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwmPEh51nBPUUon8Nh8ddn
C5/Yw/gCDtl+j7i01ytA+SIOQk93h1nzwvgSDoULt6qEbpKD8mUcNK7PWMbc
KwvlKzi0cnD8WZsvA+UrOST6OoXyW0pD+SoOfY8Kt8iKSkH5ag6Zuydkbr0p
AeVrOPB+mfPSe444lK/lsPN05LbwSDEoX8ch9CZrZ0e1KJSv51A77/IesYfC
UL6BQ2T8IY+oCBjf0GHm/uXloTpCUL6Rw+s76i36TQJQvrGDrq1eyP5nvFC+
iYP8v7OnLT5wQfmmDlX1vw5mr2KD8s0cThy1LS/ZxQHlmzss331d7JQMK5Rv
gca3hLqPGcq3cuBmXlv1ajIjlG/twKSg9Yt79R97CN/G4b3lr39Oet+gfFu4
PACCq3Lh
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw4Fr8I87tqCKUz+EQ8DB7
71dVGF/Agd1etOtymwKUL+Lwmq9ny+J/8lC+hIPd7SliDLfkoHwZh1s7Nm/5
s0oWyldwuPYwcuqeFBkoX8mhnCHe/t5nKShfxWH/Ru8erlOSUL6ag9a1tUIc
MySgfA2HYEMOhpvB4lC+lkPlBJGrnoxiUL6Ow4U1ezubr4lA+XoOcR1uL22P
CEP5Bg4+5vXbH+vB+IYOP7yfcjT6CEH5Rg6Rs9YuFNURgPKNHbJP7Nh3eSc3
lG/i8FNnUs3yHE4o39ThxFHb8pJdHFC+mUPtvMt7xB4yQ/nmaHwLh/Aoo3VF
Sv/tIXxLByYFrV/cq/9A+VYO7y1//XPS+2YPAFIwaLA=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw8Gw3E+U4rwjlczjIrv5z
LcYcxhdwWK63OS1jjgKUL+Jw7ejzG4wMML6Ew9pTiQ+6bspB+TIOW93t5i/b
KQvlKzi479ApWNsuA+UrORiLJ6mtKZOG8lUctM+94PTzk4Ly1RykO63W31GR
hPI1HM65x3F/lZGA8rUc1lgvOeb1QgzK13GYpbCV/9lzUShfz6G96kjFjzki
UL6Bg5NewpSiBGEo39Ah2n0/168NQlC+kYPlud0Ljj0QgPKNHTxXrlulOocf
yjdxiJy1dqGoDkze1GG99Jrtl7xh8mYOgm9ExD6I8UH55g7y/86etvjABeVb
OExoYd5xPxbGt3T4qTOpZnkOJ5Rv5VBV/+tg9io2KN/aITzKaF2R0n97AKQK
aLE=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwMC/fZmV0QxHK53DIXPL8
pJg1jC/gcOfF/amCCxWgfBGHux8ZGvmEYXwJh/j001NCvstB+TIOe19PzW96
KAvlKzjEffasC1wkA+UrOax74Lt+Qps0lK/icOWa74UibykoX81BUSLx79m7
ElC+hoPV68cN66eJQ/laDg2l9l+s1MSgfB2HJD/NFf94RKF8PYeqSu3n11RF
oHwDh0ezzUxvTxaC8g0dTl5T+fKbRxDKN3L4zxD4P6GEH8o3dth73OqdxmMe
KN/E4RvvzsY/pjC+qcOEFuYd92O5oHwzh6r6XwezV7FB+eYO8h6+lmKrWKF8
CwcmBa1f3Kv/2EP4lg7czGurXk3+COVbofGtHd5b/vrnpPcMyrdB49vC+QCi
k3kX
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVw0J2ixZtzShHK53BIPlLA
22wH4ws4tFx7ar9xiQKUL+LA+PBWtKcUjC/hcJ9rb8VnRnkoX8ah2VWUreqs
LJSv4MDTPG3a2koZKF/J4dT+fxPPyktD+SoOBzcvOsKsJQXlqzmInL1z8t9L
CShfw+Ep0/aySY/EoXwtB8UFjSKOZ8WgfB2HHvELk74VikL5eg4Gsc3L964Q
gfINHGrnXd4j9lAYyjd0gPhfCMo3clB0TO8s/ScA5Rs7lO4OsLH4wQflmzjo
2uqF7H/GC+WbOlzccfXLjR/cUL6Zw1mpD6+mCHBB+eZo8hYOyl7TrkWtgMlb
Osj/O3va4gOMb+Wgs5mFzayPHcq3dmibmG1VLQ/j20Ddzwzl2zpwM6+tejWZ
Ecq3Q5O3d3hv+eufk943ewDckn0b
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwcDh1Ibf/piKUz+Hwccpc
URMLGF/AoeXaU/uNSxSgfBGHjtLkuU95YHwJhw91H2oWn5GD8mUcHF45XAtd
JAvlKzg8a97Q+y1cBspXcph9jfvnMlNpKF/F4bCPSHzoIkkoX81hzZWIytsR
ElC+hsNHvtDDmvriUL6Ww1WNnMRl20WhfB2HuTtsoievE4Hy9Rxikh491nkh
DOUbOPRu5tTed18Iyjd0+Na1Tjz2iyCUb+RgeW73gmMPBKB8Y4fdUlPm7nwP
45s4RM5au1BUB8Y3dbjG25Hx048Xyjdz+Ma7s/GPKQ+Ub+4QpT3R41wFN5Rv
gca3dNi4Ln+KXjQHlG/lsHz3dbFTMqxQvrVDeJTRuiKl//YQvo1D8Wpr+02L
GKDytmjydg7GvW+/Ox74CeXbO7y3/PXPSe+bPQANxX+8
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQEf7MVCt+7emK3kABVw8P+9k2/9OUUon8OB5UG0
aZMljC/gIDbRTufCfAUoX8Thee4exom8ML6EQ9mhj7krvshB+TIOLsweDN8m
y0L5Cg4fb8b2RSTKQPlKDumyvUUXYqWhfBWHU4znrdQDpaB8NYeaY+vucX2S
gPI1HIQPK+qKzxeH8rUcdvdMWF69UQzK13F4b/nrn5MejK/n0F51pOLHHBEo
38BB97l0AxcLjG/oMP1hD+O9j0JQvpFD05Ok3idrBKF8Y4fP/3ZFNrELQPkm
Dtd4OzJ++vFC+aYO2Sd27Lu8kxvKN3Ooqv91MHsVG5Rv7lC82tp+0yIGKN/C
wbj37XfHAz/tIXxLNL6VQ3iU0boipf9QvjUa3waNb+vApKD1i3v1HyjfDs0+
ewdI/DJB+Q4O3Mxrq15NZoTwGxyg4fUNqt8Rld/giOY+JzR5GP8ZVN4Zav5H
qLwzmvkuqO5rcEEz3xXVPw2uaP5xQ/VPgxua/91RzWtwR5P3QJP3QAtPT1R+
gyfcfwDTT91N
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwsLimL7z+jiKUz+EQG8k/
/aobjC/g8H3qjw33tihA+SIOh/8FKnJowfgSDg+3/SvOcZGH8mUcBGeqXXht
LQflKzjYqyTkSTHJQvlKDhuOb/FoeCsN5as4OGudjb27TgrKV3NYMNNSrT1G
EsrXcCjbKDcp9K44lK/lcPv4llvXi8WgfB2Hi2vOf1bJFYXy9Rxq513eI/ZQ
GMo3cNhesCxSTxTGN3QouPb5UKKiEJRv5PD6jnqLfpMAlG/soGurF7L/GS+U
b+JwccfVLzd+cEP5pg7y/86etvjABeWbOch7+FqKrWKF8s2h9jND+RYOkPBm
gvItHcKjjNYVKf23h/CtHJgUtH5xr/4D5Vs7cDOvrXo1+SOUb+Pw3vLXPye9
Z/YAax1x0A==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwkNoscunoKUUon8NBr/HH
zFBNGF/AYZ7h5pid/QpQvojDHcNpc1y+yEP5Eg53th+KenVLDsqXcUhoqtH0
XC8L5Ss4ME75vE82QwbKV3JIuCS/bX60NJSv4tBY+bZcUVoKyldz4NJujuX8
IAHlazgcESmvVPgkDuVrOawPYWH5+E4MytdxWC34TkJtsyiUr+cgtPZq5oc6
ESjfwMF780evQHNhKN/QYV+M6kE5biEo38hBWuLxi4mTBKB8Y4ejn/mDowp5
oHwThwktzDvux3JB+aYOxr1vvzse4ITyzRxq513eI/aQGco3dwiPMlpXpPTf
HsK3QONbQvX/hPKt0PjWDu8tf/1z0vsG5dugydtC5Z9B+XZwPgBgL3wR
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwsJ3pV3/3vCKUz+Fg2Jd/
i1Udxhdw2LzX6qR1rQKUL+Iwe2HUl6hL8lC+hEN/9OzO/lI5KF/G4d4qoTVd
7rJQvoLD9dDbTCG8MlC+ksO89zorRb5KQfkqDv9CxWS7b0hC+WoOe4ojf5tt
k4DyNRx6dr2/FdctDuVrOWSZ5/E1hIpB+ToOybf37Fn+RgTK13NQKWecbPZe
GMo3cNhesCxSTxTGN3Q4eU3ly28eQSjfyOEab0fGTz9eKN/YgbfIyPpyE4xv
4jChhXnH/VguKN/Uwbj37XfHA5xQvpnDe8tf/5z02KB8c4fi1db2mxYxQPkW
DkwKWr+4V/+xh/AtoeqfQflWDtzMa6teTf5oDwBxPGd6
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwiNYS0J1xVRHK53DY3PfH
wd0JxhdwWPkv8t3FxQpQvojDEZcKFhEZGF/CwXq/uxqjmDyUL+Oga6sXsv+Z
LJSv4DAraO6O5JsyUL6Sw4qFi9ObW6WhfBWHBcnGPocapaB8NYeTV91yD5pL
QvkaDi3/7wSxcUpA+VoOB/jM9x4SEofydRzOOkdIPv0hCuXrOWxa3yYncUcE
yjdwiIw/5BEVIQzlGzokFMb+PvVCEMo3cgjI0Tr9VVIAyjd2OPqZPziqkAfK
N3FQ9pp2LWoFF5Rv6lBV/+tg9io2KN/MIbDHUJullQXKN3coXm1tv2kRA5Rv
4cDNvLbq1WRGKN/SgUlB6xf36j/2EL6Vw3vLX/+c9J5B+dZQ/jco3wYuDwC/
eWxH
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVwWHdwxbuFVxShfA6HSzHm
PXvMYXwBh8YTbdLLVipA+SIOOZHr5Z7zwfgSDv+sGi8/fSkH5cs4vIgR/jVn
myyUr+CwOF9eZEmdDJSv5ODseU/mnac0lK/icCu1RC6FRQrKV3MwUPj5z3q5
BJSv4XD04OIbB5LEoXwthxW3D0+de00UytdxOKDt9HZNkQiUr+fwclqR41p7
YSjfwGFfjOpBOW4hKN/QQdExvbP0nwCUb+TwnyHwf0IJP5Rv7DD7GvfPZabc
UL6Jg85mFjazPnYo39QBEn5MUL6Zw3vLX/+c9L7ZQ/jmUP4zewAYeF2m
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVwOLCv9ZfnJUUon8PhlM2N
TdP1YHwBh9N+Ll+W9CpA+SIOHrJnesVeykP5Eg7BR9eF3TokB+XLOHhvauuW
6ZaF8hUc7jakZK0OloHylRx+NZxbYBUuDeWrONxKLZFLYZGC8tUcknZssDx0
WwLK13Do2fX+Vly3OJSv5TDnvKonW5cYlK/j8Gcxi+LzCyJQvp6Dzoe+ddv7
haF8A4cjAQdmN+wSgvINHWLYF82SdhWE8o0cVtsoZWgc5ofyjR2cQ/6Ysbrx
QfkmDkc/8wdHFfJA+aYOxr1vvzse4ITyzRzaJmZbVcuzQ/nmDieO2paX7OKA
8i0cAnsMtVlaWaB8SzS+lUPtvMt7xB4yQ/nWaPI2Dj7m9dsf68HkbR2YFLR+
ca/+Yw/h2zm8t/z1z0nvG5RvjybvgCrf4ODAzby26tXkj1B5R1R+AxqfwQnq
35/2ADc0j74=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw8OTwCom8pgjlczhsfpB/
+LITjC/gMHHL9GcMqxWgfBEH46NO28xEYHwJB8XnyzVOnJKD8mUc/l2ZMuHm
fFkoX8GhxNFXvq1UBspXcnBNdnZlC5WG8lUc4vOErL7rSEH5ag66jTfjuL9I
QPkaDiXGx2xLz4pD+VoOx3oOlZftF4PydRw+BF7un2omCuXrOczya/z1mEsE
yjdwmJz6YXLMciEo39Bht9SUuTvfC0D5Rg4BOVqnv0rC+MYOKxwPHz0myQvl
mzjMvsb9c5kpN5Rv6qCzmYXNrI8dyjdzaJuYbVUtD+ObOyzffV3slAwrlG/h
wM28turVZEYo39KBSUHrF/fqP/YQvhWavDWavI3De8tf/5z0nkH5tnA+AP1J
cGc=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwSK24NOHQNUUon8Nh0uoW
z7WmML6AQ8jzpyd3TVaA8kUcFjE82sPOCeNLOEwIXCpcd0UOypdx2Hrv5pNN
RbJQvoLD3hBvNQNnGShfyWHee52VIl+loHwVB7+IasOP1yShfDWHVFVDRrvT
ElC+hsPBw0uZrkWKQ/laDpdz7uw8kSIG5es4LN99XeyUjCiUr+fALscScuSS
MJRv4BB8rbPnkiyMb+hQkrF8n7+YEJRv5PBMX8k4T1MQyjd2yD6xY9/lndxQ
vonDWakPr6YIcEH5pg4fNl/8WyvKCeWbOVTV/zqYvYoNyjd3eG/565+THoxv
4cDNvLbq1WRGKN/SIbDHUJullQXKt0KTt0bj2ziERxmtK1L6bw/h2zoY9779
7njgJ5RvB7XvGZRvD9X/Ecp3QFXf4ACXBwAA34aH
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw6BV/73XnpCKUz+Gguttj
kosJjC/gUPIqPXPRKgUoX8TBtkK5xUoIxpdw+FXNkKDGIg/lyzgILXf5yPBH
FspXcHALOy075a0MlK/kYB56fu3JQ9JQvopDWd/mBVWlUlC+msOKVbs6uBQl
oXwNhyqbhXahKhJQvpbD9gNc7vNfi0H5Og6CE/wYHI1gfD2HTevb5CTuiED5
Bg7B1zp7LskKQ/mGDkIvDhxaHSQI5Rs5eK5ct0p1Dj+Ub+zAW2RkfbmJF8o3
cVD2mnYtagUXlG/q8GHzxb+1opxQvpkDJDyZoHxzNL6FQ3iU0boipf/2EL6l
w3vLX/+c9L5B+VYOxr1vvzse+GkPAFmiY6A=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwmPV6ZdPPC4pQPoeDjHNZ
rJMujC/gUMk7a/2biQpQvoiDFbeAdx4zjC/hEKEss9f+tRyUL+MQ67pWm3Gb
LJSv4KBxKqntdrEMlK/k8F+oaY6GjzSUr+Kw+rVjup+JFJSv5qD/33Dza2ZJ
KF/DofSX+vqTp8ShfC2HZX9XyKvNEYPydRxW3D48de41UShfz8HszbO7a9hh
fAOHWX6Nvx5ziUD5hg6TUz9MjlkuBOUbOeyLUT0oxw3jGzt0G6XemZ0gAOWb
OOw9bvVO4zEPlG/q8GHzxb+1opxQvpkDJDyZoHxzBx/z+u2P9ZihfAuH8Cij
dUVK/+0hfEuH95a//jnpfYPyraD8Z/YADAtnsg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw2JXt9LX3miKUz+FwwyhD
3t0Txhdw8DWdfvDtMgUoX8Th0iIp6SfcML6EQ/vSh3nHvstB+TIOe0vu+Qid
k4XyFRwk1gbX6ZySgfKVHFJ+PJkzYZE0lK/i8CX/vG9UoRSUr+YgyT/FaoGl
JJSv4fD3iHz3llviUL6WQ1X9r4PZq8SgfB2HdbKXlbSei0D5eg5zG65W8a8T
hvINHPbFqB6U4xaC8g0dKjWP/0z1F4DyjRxynCbs5VvIB+UbO/it6XNN3coL
5Zs4fOPd2fjHlAfKN3U4K/Xh1RQBLijfzGHvcat3Go9h8uYORz/zB0cVwvgW
Dj91JtUsz+GE8i0d2iZmW1XLs0P5Vg4+5vXbH+sxQ/nWDtzMa6teTWaE8m0c
mBS0fnGv/mMP4ds6vLf89c9J7xmUbwfnAwAUOnee
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVwaHznF69xUhHK53CQ3LRK
abEjjC/g4C/yYLXgOgUoX8ShR0B3AxcXjC/hkGLAve7RNzkoX8ZhRdYUc/51
slC+goP7Dp2Cte0yUL6Sg1nmkVuzl0hD+SoO9+48T++fIQXlqznsOHZT0aRA
EsrXcJBf3Nuk7isB5Ws5hC2bbRTOIw7l6zicdY6QfPpDFMrXc7jO1n5d9pMI
lG/gMFX1byTDfGEo39AhoTD296kXglC+kUPkrLULRXUEoHxjh/Aoo3VFSvxQ
vonDNd6OjJ9+vFC+qcPFHVe/3PjBDeWbOZyV+vBqigAXlG/uoLOZhc2sjx3K
t3Coqv91MHsVG5Rv6bB893WxUzKsUL6Vg7yHr6XYKhjfGmr/f3sI38aBm3lt
1avJjFB5WzS+nQOTgtYv7tV/oOrtHYpXW9tvWsQAlXdwMO59+93xwE+IfIMD
VP9HqHpHOB8AEF6Cyw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwiLq8mu/lJUUon8PBM/z5
Ty5LGF/A4QGnxesTUxWgfBGHMicrv0e/5aF8CYcep6qbitvkoHwZh4XTeyT2
F8hC+QoOe1PuTTYzkYHylRwOaM2/5CkqDeWrOJwxe84VelcSyldzsBNTXfPr
iASUr+FQtlFuUuhdcShfy8Ehadv1SeViUL6Ow8U15z+r5IpC+XoOTgeD5bTl
RaB8A4eNn6TmV2UIQ/mGDvtiVA/KcQtB+UYOQi8OHFodJAjlGzvw5gi97igU
gPJNHHiLjKwvN/FC+aYOF3dc/XLjBzeUb+Yg/+/saYsPXFC+ucOJo7blJbs4
oHwLh+W7r4udkmGF8i0dqup/HcxexQblWzn4mNdvf6zHDOVbO4RHGa0rUvpv
D+HbOHAzr616NfkjlG/r8N7y1z8nvW/2AMrCdGc=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwOLHlwguRS4pQPoeDTeR5
Cxs7GF/A4eHcaYnJqxSgfBGHP1e225xmgfElHP5ZNV5++lIOypdxsCsKcLSa
LwvlKzhcZPjv/LdGBspXcujnfTVTIUwayldxeLnfc/asn5JQvppDRYPg9PKL
ElC+hsPbNs5VrR3iUL6WQ+NLxf2PPMWgfB2HD4GX+6eaiUL5eg7nEiM+fr4p
DOUbOPzwfsrR6CME5Rs6yK7+cy3GXBDKN3LgLTKyvtzEC+UbO2Sf2LHv8k5u
KN/EQdlr2rWoFVxQvqmDce/b744HOKF8MwedzSxsZn3sUL65w3vLX/+c9Nig
fAsHH/P67Y/1mKF8S6j+n/YQvpUDN/PaqleTP0L51lD9z+wBeUBwWA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwaGud4GVxSRHK53AwUlqY
JmIC4ws4LFn+/pFDrwKUL+KwPGb5yXs35aF8CQfdWKnLkxbIQfkyDpLSAR0m
nbJQvoLDp1lh7k+9ZaB8JYf9uyb3TxGQhvJVHLI3VhQkf5aE8tUc5D2Pyk2e
JwHlazgcPbj4xoEkcShfy6Gh1P6LlZoYlK/jYJ1VNCNhiwiUr+eQHcEemDxd
GMo3cFhqZXxi+VwhKN/QgWvxjzi3o4JQvpGDomN6Z+k/ASjf2OEab0fGTz9e
KN/E4RvvzsY/pjxQvqnDhBbmHfdjuaB8MzS+uQMkfJmgfAsHJgWtX9yr/9gD
AGTqW5k=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwsPdfHel1VhHK53Ao2nI7
ol4PxhdwWPkv8t3FxQpQvoiD1emZ35O/y0P5Eg6HvE6ulNwvB+XLOCyc3iOx
v0AWyldwMLsaKcOiKgPlKzn4Wvdt3vpDCspXcZh+5OzSkN2SUL6ag7znUbnJ
8ySgfA0Hnc0sbGZ94lC+lsPWmKqE8BwxKF/HoTba3mZLiCiUr+cQ9em2mepf
YSjfwKFS8/jPVH8BKN/QgUlB6xf3ah4o3whqPjuUb+xQO+/yHrGHzFC+iQM3
89qqV5MZoXxTB+Pet98dD/y0h/DNHN5b/vrnpPcNyjeHmv8HyreA6v8I5VtC
1T+D8q3g5gEAyG9oOg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw8P+9k2/9OUUon8PBM/z5
Ty5LGF/A4aBX8H7eSQpQvojDBMYzS15/lofyJRxy2DoZLPbKQfkyDo1/T376
GyAL5Ss4NNWdm6r0RRrKV3KYurY94vBJKShfxaFv5tXqcg9JKF/NYcbBeczt
YRJQvoZDsCEHw81gcShfy8Ehadv1SeViUL6Ow8U15z+r5IpC+XoOHl49tzZF
ikD5Bg5C3OJ7nu0RhvINHQzdZu30OisE5Rs5JBTG/j71QhDKN3ZQdEzvLP0n
AOWbODiH/DFjdeOD8k0dmBS0fnGv5oHyzRyMe99+dzzACeWbOyzffV3slAwr
lG/hoLOZhc2sjx3Kt3R4b/nrn5MeG5Rv5VA77/IesYfMUL411Pw/9hC+DdT8
n1C+LVT/MyjfDs4HAGQneEw=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7MVCt+7emK3kABVweCYZNkvwiCKUz+Hwc82q
HlMdGF/A4d6r92r2XQpQvoiD4J6kJfdOy0P5Eg5Vlne+vV4iB+XLOOwIXsS8
v1sWyldwaOXg+LM2XwbKV3LYYLfDakeMNJSv4nB0K/ubtQlSUL6aw4MTrwVz
xSWhfA2HcLYvd8JMJaB8LYeH2qmHuHXEoXwdh5JfK5UMrcSgfD2HP4tZFJ9f
EIHyDRy8N3/0CjQXhvINHS7ZT2IRvysI5Rs5rLZRytA4zA/lGzsc/cwfHFXI
A+WbOKxwPHz0mCQvlG/qYNz79rvjAU4o38xh+e7rYqdkWKF8cwd5D19LsVUw
voVDYI+hNksrC5Rv6QAJfyYo3wpq3k97CN8ajW/jwM28turVZEaoeluH4tXW
9psWMUD5dg7hUUbripT+Q9Xbo+l3QOU3oPEZHB2YFLR+ca/+A5V3hNr3ESrv
hMpvcELT74ym3xlNv4vDe8tf/5z0ntkDAJq8pbw=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwsFt3Z8+1K4pQPodD1GeT
gw5WML6Ag7Sf2v+NCxWgfBGHpV3W/zt/y0P5Eg4FGwquTDgrB+XLOGztfvRy
20JZKF/BoSk0bFm0vwyUr+QQ+yrn0XshaShfxaF/YrRQ8wVJKF/N4erbBo7X
jyWgfA0H1nxu49yj4lC+lgPbB/5rEzPEoHwdB4sse6NecVEoX89B50Pfuu39
wlC+gcNSK+MTy+cKQfmGDsUb13cGVAlC+UYO3Uapd2YnCED5xg45ThP28i3k
g/JNHKK0J3qcq+CG8k0dPmy++LdWlBPKN3Mw7n373fEAjG/uMPFxcbXTd3Yo
38JB3sPXUmwVK5Rv6cCkoPWLe/UfewjfCo1v7RAeZbSuSOk/lG/j8N7y1z8n
vW9Qvi0a386Bm3lt1avJH6F8e6j8MyjfAc4HACjRhB0=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwWHdwxbuFVxShfA4HhzS3
yjfWML6Aw1w72XcTFypA+SIOG37JntdlgPElHFZ9Uhd/f18OypdxKK7sSrhc
KQvlKzgkXdu87KC5DJSv5JA4JWSbh7I0lK/isMLNceqmP5JQvppDfO7G+TOu
SkD5Gg6ZfD9CcpeLQ/laDsv+rpBXmyMG5es4/OZLtz/oKgrl6znEX98ad7lC
BMo3cIiMP+QRFSEM5Rs6zNy/vDxURwjKN3J4fUe9Rb9JAMo3duARPlRe8JIf
yjdxuMbbkfHTjxfKN3WI0p7oca6CG8o3c5D/d/a0xQcuKN/cQdlr2rWoFTC+
hcPy3dfFTsmwQvmWDpDwZ4LyrRy4mddWvZrMCOVbOzApaP3iXv3HHsK3cXhv
+eufk943KN8Wyn9mDwBq13RC
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw4P4qp7vivCKUz+Hwco63
I78hjC/gMEXaLHjfTAUoX8ThbcbuC9dfyUP5Eg4a7akKN6bJQfkyDjyqkzcv
9ZeF8hUcNpkLyt5mk4HylRz275rcP0VAGspXcUg5vM2wh1cKyldzWLrp6OKO
yxJQvobDyalrAl9riEP5Wg51OlWz8z6IQvk6DtVXK3kZEkSgfD2H55qfKg0D
hKF8AwfDXdLqj0qFoHxDhyup3zg1dgpC+UYOlud2Lzj2QADKN3bgET5UXvCS
H8o3cSjdHWBj8YMPyjd1UPaadi1qBReUb+ZQVf/rYPYqNijf3IGbeW3Vq8mM
UL6FQ/Fqa/tNixigfEsHJgWtX9yr/9hD+FYO7y1//XPS+wblW6PxbdD4tg7G
vW+/Ox74CeXboZlnj6beAeqejxB+gwNcPwAc+Yen
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwmLhUyeX9eUUon8Phhf3N
t8laML6Aw81qR1+xGQpQvojDhCC3pZM+y0P5Eg6XXfs0uQ7IQfkyDiV/xc+m
FspC+QoOlp9OGgQ4yUD5Sg6ikRcrDa2koXwVB7liF6UrHyWhfDWHq28bOF4/
loDyNRx+bOcOlzkhDuVrOVTV/zqYvUoMytdx0Iq2OLrPXxTK13Ngl2MJOXJJ
GMo3cOjdzKm9774QlG/oMHP/8vJQHRjfyKF44/rOgCpBKN/YoXi1tf2mRQJQ
volDeJTRuiIlfijf1MFvTZ9r6lZeKN/M4afOpJrlOZxQvrnDe8tf/5z02KB8
Cwcf8/rtj/WYoXxLqPw3ewjfCsp/BuVbw/kAUExrEw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQEf7MVCt+7emK3kABVwMC/fZmV0QxHK53Dw+Jot
XeYE4ws48J0uPiq7UQHKF3E48DWKRVcdxpdw2BKVvSRfTB7Kl3HQSBa3zHki
C+UrOPyZu9Xl/QEZKF/J4dK6BeHbV0lD+SoOZX2bF1SVSkH5ag4nr7rlHjSX
hPI1HMLTVvz4xSwB5Ws5ZOv9vn/ppBiUr+OwsuDsxYw+UShfz4FdjiXkyCVh
KN/A4Y1wZOq3TiEo39Bht9SUuTvfC0D5Rg7bPkzQlzrLB+UbOwi+ERH7IAbj
m6DxTR0u7rj65cYPbijfzOHoZ/7gqEIeKN/c4RvvzsY/pjC+hUP2iR37Lu+E
qbdE02/lYNz79rvjAU4o39rhxFHb8pJdHFC+jYOPef32x3rMUL6tAyT+mKB8
Owd5D19LsVWsUL49mnoHh/Aoo3VFSv/twdwGBwdu5rVVryZ/hPAZHB3eW/76
56T3DCrviCbvBHXfT6i8E1weAAkamVs=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVweGx7dgXfOUUon8NhRsvj
uCxLGF/AwWfa/jN96xSgfBEHmWL7S4L8ML6EwzTBpbZmf+SgfBmHLzV++79s
koXyFRxWOCeJ9rrLQPlKDhl2IfsUGKWhfBUH610Ma23/SUL5ag5JOzZYHrot
AeVrOISnrfjxixnG13JQXNAo4nhWDMrXcWCaMf+3R4MolK/nMFX1byTDfGEo
38DhxxL2uieOQlC+ocPrO+ot+k0CUL6RQ47ThL18C/mgfGMH49633x0PcEL5
Jg4/dSbVLM+B8U0dlu++LnZKhhXKN3Ooqv91MHsVG5Rv7vDe8tc/Jz0Y38Kh
dt7lPWIPmaF8Swdu5rVVryYzQvlWUPt+2kP41lD93+wBRJdr6w==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwCNu5dkr2BUUon8Nh7vKj
3rZmML6Aw9GDWrW8yxWgfBGHv162ao+EYXwJh/jLbvb1b+WgfBmHf1emTLg5
XxbKV3DgvLOlf9EEGShfyeFgzP97iX7SUL6Kg/zRtqvXn0lC+WoOqaqGjHan
JaB8DQer148b1k8Th/K1HGatPOj8da0YlK/jkN9bKSk8WRTK13O4ztZ+XfaT
CJRv4DC34WoV/zphKN/Q4ZL9JBbxu4JQvpEDb47Q645CASjf2KF0d4CNxQ8+
KN/E4eKOq19u/OCG8k0dlL2mXYtawQXlm6HxzR1+6kyqWZ7DCeVbOGxclz9F
L5oDyrd0OHHUtrxkF4xv5fDe8tc/Jz02KN/awce8fvtjPWYo38aBSUHrF/fq
P/YQvi1U/Tco3w7OBwA9Onrw
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw+Nmd83/GRUUon8Phfeil
7/7qML6Agwlz5m/5WQpQvojDs45Fqv335aF8CYfrNQUtXOvkoHwZh8bCNXuX
lshC+QoOjWZa7V6eMlC+kkPY9QNssiLSUL6Kw79QMdnuG5JQvppDTyiXx6X1
ElC+hoPF0frqebvEoXwth3exB7cnHhOD8nUcTv960dW2VBTK13MI7DHUZmkV
gfINHMpFZzP0LxOG8g0dthcsi9QThfGNHGLYF82SdhWE8o0dcpwm7OVbyAfl
mzh8493Z+MeUB8o3dTgr9eHVFAEuKN/MQWczC5tZHzuUbw61nwXKt3AIjzJa
V6T03x7Ct3QoXm1tv2kRA1TeysG49+13xwM/ofLWDu8tf/1z0vtmDwB+/2eK

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwSE/2n8h4TRHK53BInpru
wWIB4ws4FHY4vn45RwHKF3HIfuTHVvdKHsqXcChe+P3qhlVyUL6MQ/brVHXW
NlkoX8Ghuaqx2D5MBspXcqhVi9t9k1sayldxuPXv7Oun5yShfDWHG4KfJDNL
JKB8DYedMpG5J1TFoXwth/eWv/456YlB+ToOHwIv9081E4Xy9Rxikh491nkh
DOUbOBjuklZ/VCoE5Rs6KDqmd5b+E4DyjRyWKXvdMjkE4xs78AgfKi94yQ/l
mzh0G6XemZ0Akzd18FvT55q6lRfKN3O4uOPqlxs/uKF8c4cJLcw77sdyQfkW
DhvX5U/Ri+aA8i0dqup/HcxexQblWznIe/haiq1ihfKtHQJ7DLVZWlmgfBuH
8CijdUVK/+0hfFsHbua1Va8mf7QHADukcNA=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVw+Hk2/6DiXkUon8PBJDn/
3kdRGF/AYUPq3jkLJyhA+SIODjuZev+9lYfyJRyKF36/umGVHJQv4zCV48TC
KzmyUL6Cw8ebsX0RiTJQvpLDqf3/Jp6Vl4byVRwaK9+WK0pLQflqDlffNnC8
fiwB5Ws4iPqlmT/bLg7lazk4JG27PqlcDMrXcQi9ydrZUS0K5es5+BULVE87
KgLlGziolDNONnsvDOUbOixcckK0/5oQlG/kcMl+Eov4XUEo39jBc+W6Vapz
+KF8E4ejn/mDowp5oHxThxNHbctLdnFA+WYOG9flT9GLhvHNHT5svvi3VpQT
yrdwaJuYbVUtzw7lWzrUzru8R+whM5Rv5RAeZbSuSOm/PYRv7QCJHyaovA2a
eluHwB5DbZZWFijfzsG49+13xwM/ofrt0fgODtzMa6teTf5oDwDAyILg
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQDQEf7MVCt+7emK3kABVwsPv8wHPZdUUon8PhaojO
EUZPGF/AoeiE/4rU7QpQvoiD833NpxckYHwJh5w/x4zYWeWhfBkHdvZ7H6c+
lYXyFRyct8SfO7ZeBspXchBdX3y+rFgayldx0PxTY/8zXwrKV3NQlcmIXhQo
CeVrOMgv7m1S95WA8rUcgmf+fxwgIw7l6zisuH146txrolC+noN2v9s5p9Mi
UL6Bw+aC4s9RFcJQvqHDD++nHI0+QlC+kcMyZa9bJocEoHxjh/Aoo3VFSvxQ
vomD4BsRsQ9ifFC+qUOU9kSPcxXcUL6Zw4fNF//WinJC+eYOVfW/DmavYoPy
LRwCewy1WVpZoHxLB0j4M0H5Vg7vLX/9c9KDqbdG02+Dxrd1kPfwtRRbxQrl
26GZb4+m3sHBx7x++2M9Zgi/wcGhdt7lPWIPoXwGR1R+g6ND8Wpr+02LGKDy
TtDw+G8PkXdy4GZeW/Vq8kcIn8EZ6v5v9gCp55V0
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwYLd4UPXknCKUz+GwJctg
nbcijC/gYBPhX1fcoADlizgsvPsjtOq8PJQv4XCnfdlOuflyUL6MQ4nbKbG1
wbJQvoLDp3nLtE2ZZKB8JYfyuar/Ay9KQfkqDrUbr0/1S5eE8tUcqmwW2oWq
SED5Gg4zLHdPe3tIDMrXctCKtji6z18Uytdx8PDqubUpUgTK13MwdJu10+us
EJRv4MDNvLbq1WRBKN/QYb30mu2XvPmhfCOHJScXl3GX8EH5xg5R2hM9zlVw
Q/kmDj91JtUsz+GE8k0dNq7Ln6IXzQHlmzmcOGpbXrILxjd30NnMwmbWxw7l
WzjIe/haiq1ihfItHXzM67c/1mOG8q0caudd3iP2EMa3dmBS0PrFvfqPPYRv
g8a3hfrnoz0AcfBtHw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw4N6oeSXygiKUz+GgGrTV
/6spjC/gEK4yXSlougKUL+Kw4ZfseV0GGF/CwXTPiW//XshB+TIOPWKfuPfM
kYXyFRyuxZ7R0MqVgfKVHNw7l3uJG0pD+SoO/0LFZLtvSEL5ag4vI85WvKuQ
gPI1HDKvqepxTxSH8rUceFaaB+6ZLwbl6zisuH146txrolC+noPJpd5y1V0i
UL6Bw1TVv5EM84WhfEOHrJIf2xjDhaB8I4dL9pNYxO8KQvnGDsuUvW6ZHBKA
8k0cBN+IiH0Q44PyTR3OSn14NUWAC8o3c6idd3mP2ENmKN/cARK+TFC+hYOP
ef32x3oweUuH95a//jnpPbOH8K3gfACKzmUL
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVw+HT6zOed5xWhfA6HSatb
PNeawvgCDvPs1rOyTlSA8kUcMg4/ZLzwUx7Kl3D4oHqO3eG6HJQv45D95cfK
L4tkoXwFh4qoiXXvXWSgfCUHUdlYrWAmaShfxWHDT6E+pbeSUL6ag82ua60X
uySgfA0Hnc0sbGZ94lC+lgP35S+F/+rEoHwdh8yUrxX66qJQvp5DMIPFuY2C
IlC+gcPCJSdE+68JQfmGDi4NFX8N2wWhfCMHHuFD5QUv+aF8YwfBNyJiH8T4
oHwTh+wTO/Zd3skN5Zs6fNh88W+tKCeUbwZ1HzuUb+4w8XFxtdN3GN/Coar+
18HsVWxQvqWDvIevpdgqVijfyqF23uU9Yg+ZoXxrByYFrV/cq//YQ/g2aHxb
h+LV1vabFjFA1ds5GPe+/e544CdU3h6N74Cqv8HBITzKaF2R0n+ovKMDN/Pa
qleTP0Ll0fgMTg7vLX/9c9J7Zg8Am4uRrA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwOHUi2/XdSUUon8OB+UN5
FKMRjC/gYPf+xpPHExSgfBGHwl3ffFPey0P5Eg4Lk983bt0iB+XLOFT/VPSI
LJaF8hUczEsK7+QbyUD5Sg4b5uWExWhLQ/kqDgyT27tmKklB+WoOCT+f/+wV
loTyNRwOiKxmT3wlDuVrOQR82XJyhwuMr+Ow4vbhqXOviUL5eg6b1rfJSdwR
gfINHMpFZzP0LxOG8g0dot33c/3aIATlGznIrv5zLcZcEMo3dlim7HXL5JAA
lG/isO3DBH2ps3xQvqmDste0a1EruKB8M4e2idlW1fLsUL65w/Ld18VOybBC
+RYOkPBmgvIt0fhWDsa9b787HvhpD+FbO3Azr616NfmjPQBxp2yG
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwiHH4eFrogiKUz+GQfGin
x1JrGF/AIdCpyeXMXAUoX8SBa2Xr2R2MML6Ew6c7prGf18tB+TIOqbI/Zm6I
lIXyFRwsqoX4HujJQPlKDu+/+n35piAN5as4xJz35Nx7WxLKV3M4Y/fELeis
BJSv4SDql2b+bLs4lK/lEBD0TXp9kxiUr+MQPGeKdJWhKJSv51BVqf38mqoI
lG/gsPd4+/0f9UJQvqHDyWsqX37zCEL5Rg7hUUbripT4oXxjhyjtiR7nKrih
fBMHZa9p16JWcEH5pg46m1nYzPrYoXwzh+W7r4udkmGF8s0duJnXVr2azAjl
W0DN/28P4Vs6vLf89c9J7xuUb+Vg3Pv2u+OBn/YA1INmRw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwEHstpz/tviKUz+FgfyNX
/mkAjC/gELQh31h4pwKUL+JgeIRzaoIsjC/hYLRVMcuCXR7Kl3FgZ7/3cepT
WShfwWGy/smVYstloHwlB9dkZ1e2UGkoX8Uhe2NFQfJnSShfzYFda1uP2BYJ
KF/DYc112QfLl4hD+VoOW2OqEsJzxKB8HYeZffOyDpWJQvl6DucSIz5+vikM
5Rs4aMuKSaYnCkH5hg7FG9d3BlQJQvlGDievqXz5zQPjGzsE5Gid/iopAOWb
oPFNHVY4Hj56TJIXyjdzUPaadi1qBReUb+5g3Pv2u+MBTijfwmHjuvwpetEc
UL6lQ1X9r4PZq9igfCuH4tXW9psWMUD51lD9P+0BQgZmcA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwcPbwrLU4qwjlczjYzZM5
cc8AxhdweGx+fwLzbAUoX8RBzHSZ30YOGF/C4dLBhHdbT8tB+TIOx0w9JebM
lIXyFRzmpYg6HuqWgfKVHJau7ur7pC8N5as4pBzeZtjDKwXlqzkwinR8/vdX
AsrXcOCo65c+FS8O5Ws5KG3imHXUVwzK13G4F9HX3vNdBMrXc4hJevRY54Uw
lG/gEHyts+eSLIxv6PB4z98GbXMhKN/I4fO/XZFN7AJQvrGDc8gfM1Y3Pijf
xGHjuvwpetEcUL6pQ2CPoTZLKwuUb4bGN3fwMa/f/liPGcq3cAiPMlpXpPTf
HsK3dGBS0PrFvfqPPQCdKl0+
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwODCPa9vLU4pQPofDpLtv
ld9ow/gCDvuPKMsdmqIA5Ys4fDnQuIDjhTyUL+HwVGVW4/RjclC+jIPalq/T
zdfIQvkKDlvOPTx4oVYGyldykE9q/D3VVhrKV3GYLmS7f91jSShfzUHk7J2T
/15KQPkaDpbuVxw2rReH8rUc+srqm2zuiUH5Og7/ir6rch4VhfL1HK6ztV+X
/SQC5Rs4yO0s3tZ+WhjKN3TIKvmxjTFcCMo3ckgojP196oUglG/sUKo5ZfKk
TQJQvonDf4bA/wkl/FC+qUPp7gAbix98UL6Zw+xr3D+XmXJD+eYOxr1vvzse
4ITyLRw+bL74t1YUxrd0OHHUtrxkFweUb+WwfPd1sVMyrFC+tUN4lNG6IqX/
9hC+jQOTgtYv7tV/oHxbqPk/7QF01nsU
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwWPmpbcevS4pQPofD2t+l
2zT1YXwBh20PbeV9pilA+SIOOjYZP9OZYHwJh9S2ZdlFL+WgfBmH7C8/Vn5Z
JAvlKzjos164rNAlA+UrORROXb/odbA0lK/ikHJ4m2EPrxSUr+YgcvbOyX8v
JaB8DYcf27nDZU6IQ/laDltjqhLCc8SgfB2Hx41CGgXJolC+noPuc+kGLhYR
KN/AYe/x9vs/6oWgfEMHTT9lEddcQSjfyKFS8/jPVH8BKN/YYYXj4aPHJHmh
fBOHD5sv/q0V5YTyTR02rsufohfNAeWbORSvtrbftIgByjdH41s4MClo/eJe
/ccewrd04GZeW/Vq8kco3wrOBwCoQGdj
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwKHDbKR19UxHK53CINTkX
tMMBxhdwuLSvPPPhKgUoX8Sh8mzf2d+sML6Ew84T7B83vZaD8mUc7pjxcN7d
JQvlKzj0zI+auHOODJSv5JAu21t0IVYayldxWHe+MtDKXArKV3O4J81yn+ub
BJSv4dBj9S/NuVwcytdyWNTIs2lJoBiUr+OgfVzi65KHIlC+nkN2BHtg8nRh
KN/AYV+M6kE5biEo39BBV1Dj46yLAlC+kUOO04S9fAv5oHxjh4s7rn658YMb
yjdxWL77utgpGVYo39TBx7x++2M9ZijfDI1v7hDYY6jN0soC5Vs4QMKbCcq3
RFNv5RAeZbSuSOm/PYRv7fDe8tc/J71vUL4NGt8Wyn8G5dvB+QCYlnhh
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwMD8kELLjpCKUz+HwPvTS
d391GF/AoWfh8vsVkxWgfBGHOs4FqZyMML6EQ8GGgisTzspB+TIOXtdkTreu
kIXyFRzigl4tOR0nA+UrOcgI7GSf4iYN5as4KJW/WHLdSArKV3OYWyuTtnSy
BJSv4fCRL/Swpr44lK/lsKiRZ9OSQDEoX8dB+7jE1yUPRaB8PYftBcsi9USF
oXwDBxsjn3a+BEEo39DB1+3Y0Se2AlC+kYPfmj7X1K28UL6xw8UdV7/c+MEN
5Zs4fNh88W+tKCeUb+qwfPd1sVMyrFC+mcN7y1//nPTYoHxzBx/z+u2P9Zih
fAuH4tXW9psWMUD5llD13+whfCsHbua1Va8mf7QHADZ6ZyA=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw2Nj9d5HaFUUon8Pho/Fr
XzdrGF/AYdNd918FCxSgfBEHfvv+9D18ML6Ew9r4FfeyzstB+TIOP2d/X6m8
UhbKV3DYcu7hwQu1MlC+ksOvXRbR/6uloXwVh3XnKwOtzKWgfDWHvplXq8s9
JKF8DYc4ra9fsuUloHwth/UhLCwf34lB+ToOp3+96GpbKgrl6zkE6C9QKpEQ
gfINHH4sYa974igE5Rs66ApqfJx1UQDKN3IIjzJaV6TED+UbO1zccfXLjR/c
UL6Jw8THxdVO39mhfFOHtonZVtXyML6Zw3vLX/+c9NigfHOoef/tIXwLB0h4
M0HlLdHkrdD41lDzvkH5Ng7czGurXk3+aA8AR9lz7g==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwWGZZ8rH9siKUz+Hg5P88
9ZU/jC/g0Puq7M3VHQpQvojDCv0Y/TRBGF/C4Y2Nxr3PV+SgfBmHTcnic7zb
ZaF8BYfHUWUuIRIyUL6Sw8TnBSmND6WgfBUHQ6dlqksXSEL5ag7nUzx8kldK
QPkaDj273t+K6xaH8rUclDZxzDrqKwbl6ziE3mTt7KgWhfL1HJwOBstpy4tA
+QYOMc3GUTdeCEH5hg4lGcv3+YvB+EYO0hKPX0ycJADlGzuU7g6wsfjBB+Wb
OHzj3dn4x5QHyjd1qKr/dTB7FRuUb+awfPd1sVMyrFC+uQM389qqV5MZoXwL
B0h4M0H5lg5MClq/uFf/sYfwrRzeW/7656T3zB4AP9Jlyw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVw+L15m9Xbw4pQPoeDsmWv
i7k6jC/g0Oocv+V6iwKUL+Kw8O6P0Krz8lC+hIPS+r03Pk6Ug/JlHHLVT+2V
rZaF8hUcHkeVuYRIyED5Sg5PP222OLBJCspXcZgh9vZE4nJJKF/N4WXE2Yp3
FRJQvobD5zbXCFcjcShfy8FsZVCsV7UYlK/jUBttb7MlRBTK13OI63B7aXtE
GMo3cNh7vP3+j3ohKN/QgZt5bdWryYJQvpHDf4bA/wkl/FC+sUN4lNG6IiUY
38SBt8jI+nITL5Rv6iD/7+xpiw9cUL6Zw3vLX/+c9NigfHMHH/P67Y/1mKF8
CzS+JdR+RijfyoFJQesX9+o/9hC+NVT+I5RvgyZvC7XvG5RvhyZvD9cPACU8
ezw=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw0DD4mOJ8WhHK53BQlNzq
c9QUxhdwuOW+7tG9mQpQvojD9JtOFe2f5KF8CQfZ8C92D8/LQfkyDkmmr8J/
1clC+QoOc9Y2PDznKgPlKzk8fqCz2dpIGspXceD6b5z15p4klK/mcCN9Sv66
tRJQvoZD5cbAHxpV4lC+lsPX7a07v90ShfJ1HFpYTp7imC4C5es5eG/+6BVo
LgzlGzj8WMJe98RRCMo3dOg2Sr0zO0EAyjdyWHJycRl3CR+Ub+wwoYV5x/1Y
LijfxOGs1IdXUwRgfFMHeQ9fS7FVrFC+mUN4lNG6IqX/9hC+uYNx79vvjgd+
QvkWDtzMa6teTf4I5VuiyVvB5QEZImv1
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwUHc4JNF9WhHK53DQ+Rl+
6bMSjC/gMC3NulalRAHKF3G4WN28f3KXPJQv4VDI6P/0doYclC/jkN2qYleo
KwvlKzisfBNZZfdJGspXcmDRXmHIcV8Kyldx+PywdWHYVUkoX83h/7SdyY8e
SkD5Gg6Z11T1uCeKQ/laDmwf+K9NzBCD8nUcnHWunmduFYXy9Rxkbkc4CEwU
gfINHDZ+kppflSEM5Rs6PJptZnp7shCUb+Qgu/rPtRhzQSjf2IFH+FB5wUt+
KN/EYYXj4aPHJHmhfFOHKO2JHucquKF8M4eN6/Kn6EVzQPnmDrXzLu8Re8gM
5Vs4VNX/Opi9ig3Kt0STt3IoXm1tv2kRA5Rv7RAeZbSuSOm/PYRv48DNvLbq
1eSP9gBHmmzV
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBwAGIQDQEf7MVCt+7emK3kABVw2Hdmg3vzdUUon8PBIc2t
8o01jC/g4LliXezFBQpQvojDtxtX967+Lw/lSzhc41fb8GipHJQv47AwZn0t
a7QslK/goKjwxqTHUAbKV3KYU3glxOSpFJSv4mD2K3f/3vWSUL6awwwflSCO
XgkoX8PB0v2Kw6b14lC+loPgBD8GRyMxKF/HYZ3sZSWt5yJQvp6DzO0IB4GJ
ML6Bw3PNT5WGAcJQvqHD4z1/G7TNhaB8IweXhoq/hu2CUL6xg6/bsaNPbAWg
fBMHHuFD5QUv+aF8U4cVjoePHpPkhfLNHE4ctS0v2cUB5Zs7tE3MtqqWZ4fy
LRwCewy1WVpZoHxLh+W7r4udkmGF8q0cuJnXVr2azAjlWzsUr7a237SIAcq3
cQiPMlpXpPTfHsK3har/COXbOTApaP3iXv0HyrdH0++Aym9wcPAxr9/+WI8Z
Ku/oAEkPTFB5R4f3lr/+OemxQeWdHKrqfx3MXgXlNzg5yHv4Woqtgrnf2aF2
3uU9Yg+h5jU4o5rH4IJmvouDce/b744HfkLd64rqnwZXNHk3qHu+QeXd0Pzr
jibvjhY+HlD5Z1B5DzR5T1T7GjxRzWPwQtPvhRa+3mj+80Zzvw9qfDf4oMW3
L2r8Nvii+c8PzX9+qO5h8EeTR+MzBMD5AAZdEbc=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwUBLiEPa4oAjlczjU6ij9
m2sP4ws46FbO+ZK2UgHKF3H48MA8ql8IxpdwKJGxrDnzSg7Kl3FodhVlqzor
C+UrOIQeYLZtWCoD5Ss5NPs/it5bLg3lqzjMW2AamWAoBeWrOeg23ozj/iIB
5Ws4iPqlmT/bLg7laznMK11xy0BJDMrXcfhduKDeN0MUytdzmOXX+OsxlwiU
b+AQfK2z55KsMJRv6CC7+s+1GHNBKN/IoVLz+M9UfwEo39ghx2nCXr6FfFC+
iYNx79vvjgc4oXxThxNHbctLdnFA+WYOEx8XVzt9Z4fyzR2q6n8dzF7FBuVb
OPiY129/rMcM5Vs6cDOvrXo1mRHKt3J4b/nrn5PeM3sAC1pjnA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwSKkw3DHlliKUz+Fgkf7c
eqkHjC/g0N33NaZgqQKUL+Kg6lnheFMMxpdwCEr9ZWX2RQ7Kl3F4fr7+6edr
slC+gsO8rvOzPPbIQPlKDi0sgQsv7JOG8lUcsn49Tv0XLAXlqzlcPi7DfItd
EsrXcIj33uOw55A4lK/lYKW24caaXjEoX8dh+e7rYqdkRKF8PQeVcsbJZu+F
oXwDh5n7l5eH6ghB+YYOr++ot+g3CUD5Rg7KXtOuRa3ggvKNHarqfx3MXsUG
5Zs4MClo/eJe/ccewjd18DGv3/5Yjxkqb4bGN3cw7n373fHAT6h6CzS+pcN7
y1//nPS+QflWaPLWaHwbB27mtVWvJn+0BwDBJnYw
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw4L1yL6vmmiKUz+Hwccpc
URMLGF/AgctvR4vAAgUoX8SB7+eP1pVsML6Ewz+rxstPX8pB+TIOGsniljlP
ZKF8BYfJ+idXii2XgfKVHDbY7bDaESMN5as43FdyebzLXwrKV3OwtfI0VEqQ
hPI1HK5frT3VZSMB5Ws5yHVkrfwiKg7l6zisFnwnobZZFMrXc6i+WsnLkCAC
5Rs4xDQbR914IQTlGzpcSf3GqbFTEMo3cijVnDJ50iYBKN/YwW9Nn2vqVl4o
38SBSUHrF/dqHijf1EHZa9q1qBVcUL6Zw4fNF//WinJC+eYOEx8XVzt9Z4fy
LRwCewy1WVpZoHxLNL6Vg85mFjazPph6azR5GwdIfDFB+bYO4VFG64qU/ttD
+HYOxr1vvzse+Anl2zu8t/z1z0nvGZTv4MDNvLbq1eSPEH6DA1weABE5fTA=

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwyLV0ur3qtiKUz+Fgtiqw
KNsOxhdwKHmVnrlolQKUL+IgZhQT8kEKxpdwWGEcf32XuDyUL+PwYd3X1qIL
slC+gkNY4oR272UyUL6SQ36Nf6qrrzSUr+KgVP5iyXUjKShfzeFe2MPKI9yS
UL6Gw6m49Z/2mUtA+VoOH/lCD2vqi0P5Og4fAi/3TzUThfL1HGKSHj3WeSEM
5Rs4QPwrBOUbOpy8pvLlN48glG/kIPhGROyDGB+Ub+wwoYV5x/1YLijfxGHj
uvwpetEcUL6pw8THxdVO39mhfDMHH/P67Y/1mKF8c4fwKKN1RUr/7SF8Cwcm
Ba1f3Kv/QPmWDsa9b787HvgJ5Vuh8a3R1Ns4vLf89c9J7xuUb4vGt0NTbw+V
f2YPAIaOfyg=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwyLz2uGzrWUUon8PhhTZv
Q7otjC/gwOe+fE3vNAUoX8Th0ITV55U+ykP5Eg6JB35F7zwiB+XLOIj9XH7+
9wxZKF/BQaL0Y8GUZhkoX8nh9pHfR3MjpaF8FYcJLcw77sdKQflqDrUbr0/1
S5eE8jUc+L+sC35rJAHlazlEnefNnPlQDMrXcVBkufvg8x8RKF/PoapS+/k1
VRjfwMF780evQHNhKN/QQXb1n2sx5oJQvpGD5bndC449EIDyjR2u8XZk/PTj
hfJNHH7qTKpZnsMJ5Zs6BPYYarO0skD5Zg7hUUbripT+20P45g618y7vEXvI
DJW3cPAxr9/+WA/Gt3Qw7n373fHAT6h6KwcmBa1f3Kv/2AMAzAZrXQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQEf7MVCt+7emK3kABVwMC/fZmV0QxHK53DY1Zy4
ntkFxhdwWNm4W7x0rQKUL+LAcaP9nREnjC/hYHk+zr70lhyUL+Pg9HD6vui5
slC+gsOaDwf6kqJloHwlh3iBi88Z3ktB+SoOyw7tPZZ1QhLKV3PYUxz522yb
BJSv4fA6ZVPTpzXiUL6Ww3vLX/+c9MSgfB2Hkp2HFA57iUL5eg6z/Bp/PeYS
gfINHBYuOSHaf00Iyjd0kF3951qMuSCUb+TwTF/JOE8Txjd2qNQ8/jPVXwDK
N3FYcnJxGXcJH5Rv6sCkoPWLezUPlG/m8I13Z+MfUxjf3OHEUdvykl0cUL6F
Q1X9r4PZq9igfEuH5buvi52SYYXyrRwCewy1WVpZoHxrNHkbNHlbh9p5l/eI
PWSG8u3Q1Nuj8R0cuJnXVr2azAjhNzg4GPe+/e544Kc9RN4Rld/gCA3fZ1B5
Jyj/G1QewQcA0W2ZDQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw4Pvywn3VCUUon8PB8m2g
YJIRjC/gMOd+3A3/SQpQvojDtaPPbzAywPgSDts3VL0JuSYH5cs4vGycYLNm
nSyUr+Cw4K9Ft0WrDJSv5PDwhKjH+yppKF/FoV/Ff451vxSUr+ZwTtHW0T1U
EsrXcHhvYOW76Ys4lK/l8C724PbEY2JQvo7DxTXnP6vkikL5eg66z6UbuFhE
oHwDh3Xu74PKeYShfEOHgmufDyUqCkH5Rg6afsoirrmCUL6xwzN9JeM8TRjf
xOHzv12RTewCUL6pwzXejoyffrxQvpnDWakPr6YIcEH55g7Ld18XOyXDCuVb
OIRHGa0rUvpvD+FbovGtHLiZ11a9mvwRyrd2eG/565+T3jN7AGLsaoM=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwmHHh08fvdxWhfA4H0/nT
Hl11hfEFHHYrhdrs3KgA5Ys4vFd8+0BEE8aXcLDxzXP6qCUP5cs4JFUZrLz7
SRbKV3AIYN+56MMpGShfyWHb8Q/f7KdLQ/kqDmb/X2170isF5as5SPJPsVpg
KQnlazhMVnj6IsBRAsrXcpjoLq5XdV0MytdxOHmlpbX0pCiUr+cQ4dEv8Gi/
CJRv4LC9YFmknqgwlG/ooOiY3ln6TwDKN3KInLV2oagOjG/skOM0YS/fQj4o
38Qh+8SOfZd3ckP5pg7GvW+/Ox7ghPLNHKrqfx3MXsUG5Zs7BPYYarO0skD5
Fg7czGurXk1mhPItHSDhzwTlWzm8t/z1z0nvmz0AQiBoyQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwuLzQu5rjjCKUz+FQ/aJQ
T0MbxhdwmJjI4X2sVwHKF3G49m9a+x0OGF/CofXary+15+SgfBmH55u+xBbm
y0L5Cg6O0o3m7N4yUL6Sw+W7+79x8EpD+SoO8kfbrl5/JgnlqzkEbFTwDNsh
AeVrOPzYzh0uc0IcytdykOvIWvlFFMbXcZilsJX/2XNRKF/Pob3qSMWPOSJQ
voHD9Ic9jPc+CkH5hg42Rj7tfAmCUL6Rg334lxg/aRjf2MFz5bpVqnP4oXwT
B8E3ImIfxPigfFOHvcet3mk85oHyzRyMe99+dzzACeWbOyzffV3slAwrlG/h
UFX/62D2KjYo39JB3sPXUmwVTN7Kwce8fvtjPWYo39qhdt7lPWIPYXwbNHlb
NL6dA5OC1i/u1X/sIXx7h/eWv/456X2D8h3gfAD+0X6K
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwiDN8sVblmiKUz+Gw7Z35
Z01dGF/AQf/IxocFkxSgfBGH+8y3Kz7ckofyJRwqg045tB2Xg/JlHM79Trr1
sk8WyldweMI5V824TwbKV3K4feT30dxIaShfxeHWv7Ovn56ThPLVHDJ3T8jc
elMCytdwyF2SxN6WJw7lazks4GeS+uMqBuXrOGSmfK3QVxeF8vUc3uUe+Wr8
TRjKN3DwMa/f/lgPxjd0sDHyaedLEITyjRzWS6/ZfsmbH8o3dvjGu7PxjykP
lG/icOKobXnJLg4o39RBZzMLm1kfO5Rv5lA77/IesYfMUL65Q/Fqa/tNixig
fAs0vqWDce/b744HftpD+FYO7y1//XPS+wblWztwM6+tejX5oz0AY9Nv8A==

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw2DQjyuPbOUUon8PhUox5
zx5zGF/AQdXiv/DjWQpQvojDwq1FQnsEYHwJh7PWnUaf3spB+TIOl6ZsmvP8
gCyUr+AwuXnnkTfzZaB8JYddez481q2XhvJVHJy1zsbeXScF5as5zBB7eyJx
uSSUr+Gg1O0Qdn2qBJSv5fC3SNG31EIcytdx2Psm2M9/sRiUr+fwuFFIoyBZ
FMo3cDiXGPHx801hKN/QoelJUu+TNYJQvpFDqeaUyZM2CUD5xg4rHA8fPSbJ
C+WbOHzYfPFvrSgnlG/q0DYx26panh3KN3MoXm1tv2kRA5Rv7hAeZbSuSOm/
PYRv4WDc+/a744GfUL6lw3vLX/+c9L5B+VZQ/jMo3xrOBwDBSHPc
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwOCb5O6D5liKUz+Hw7EWB
2RNjGF/A4ehBrVre5QpQvoiDX7rp/t//5KF8CQenSwZFzzfIQfkyDgdfn7ga
WicL5Ss4CKemBgYby0D5Sg6Nv/cue/VTCspXceD6b5z15p4klK/mcP1q7aku
GwkoX8PhUE+/4GIlcShfy+Hj9qBgZTsxKF/HYZ3sZSWt5yJQvp7Dz8Tiv41b
haF8A4cjAQdmN+wSgvINHVLnLmOqXiAI5Rs52Id/ifGThvGNHTxXrlulOocf
yjdx0LXVC9n/jBfKN3XgLTKyvtwE45s5/NSZVLM8hxPKN3dYvvu62CkZVijf
wqF23uU9Yg+ZoXxLh/Aoo3VFSv/tIXwrh/eWv/456X2D8q0dmBS0fnGv/gPl
26DxbaHqn9kDABT0dls=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwcOM5L3HlmiKUz+EgMmX2
6z0mML6Ag0G1n8zd1QpQvoiD7h+ZeU8YYXwJB5XSt9Mrn8hB+TIO3X27z289
JAvlKzhc5V7LKtsoA+UrORiLJ6mtKZOG8lUcNiT4mG9zlYLy1Ryuvm3geP1Y
AsrXcOic6s4qf0EcytdyyNb7ff/SSTEoX8ehcoLIVU9GGF/PYfnu62KnZESh
fAOHWX6Nvx5ziUD5hg5soYybPxwWgvKNHB7NNjO9PRnGN3bgZl5b9WqyIJRv
4sCbI/S6o1AAyjd1WG2jlKFxmB/KN3PY9mGCvtRZPijf3GHvcat3Go95oHwL
hwktzDvux3JB+ZYOZ6U+vJoiAONbObRNzLaqlmeH8q2h7meF8m2g7mGE8m2h
/I/2EL6dw3vLX/+c9J7ZAwD3IXQO
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwSE/2n8h4TRHK53CoFFJp
UbCF8QUc1K4sDb6xRgHKF3HY4GBZoyEP40s43Nn2TFVTQh7Kl3Ew4TFtO/tK
FspXcHhg4bdf4o0MlK/kcGndgvDtq6ShfBWHxgS37dPzpKB8NYfgHX8MGE0k
oXwNhwVTOTiOXxKH8rUc5vFM3yZyRQzK13GYdUpo14J1olC+noNfsUD1tKMi
UL6Bg495/fbHesJQvqGD4S5p9UelQlC+kYOuoMbHWRcFoHxjh/Aoo3VFSvxQ
vonDtg8T9KXO8kH5pg57j1u903jMA+WbOcj/O3va4gMXlG/usHz3dbFTMqxQ
voUDN/PaqleTGaF8SwcmBa1f3Kv/2EP4VlD5j1C+tcN7y1//nPSe2QMA7Shm
lg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVweGPy6eT+44pQPodDnWhE
8gk9GF/AgeNq9Iz8+QpQvojDT4O+g5EMML6Ew/YNVW9CrslB+TIOx0w9JebM
lIXyFRxaOTj+rM2XgfKVHL7IXZ5yq0cayldx6G+MPxxYIwXlqzkY2ixW+OUr
CeVrOFz4/OPAhXgJKF/L4XOba4SrkTiUr+Pw3vLXPyc9MShfz0HhsejUxZGi
UL6BQ9Px8NhfPiJQvqHDkYADsxt2CUH5Rg5XUr9xauwUhPKNHXKcJuzlW8gH
5Zs47D1u9U7jMQ+Ub+qQfWLHvss7uaF8M4e2idlW1fLsUL65w/Ld18VOybBC
+RYOkPBmgvItoe79Zg8AVJtlzw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwmHBcarPeVUUon8Mh7Yn0
tWA7GF/AYeW/yHcXFytA+SIOd55Lp8/+Kw/lSzhwaUyx5rgiB+XLOEhKB3SY
dMpC+QoOz5X2XVvgKwPlKznYHFiakMYvDeWrOOzf6N3DdUoSyldz+D9tZ/Kj
hxJQvoaDmJVCEU+tOJSv5ZCe/cz5AK8YlK/jcC+ir73nuwiUr+cQ9em2mepf
YSjfwGHv8fb7P+qFoHxDhxj2RbOkXQWhfCMHXUGNj7MuCkD5xg5LTi4u4y7h
g/JNHJxD/pixusH4pg4rHA8fPSbJC+WbORj3vv3ueIATyjd3aJuYbVUtzw7l
WzjIe/haiq1ihfItHQJ7DLVZWlmgfCuH8CijdUVK/+0hfGsHSPwwQeVtHJgU
tH5xr/4Dlbd1eG/565+T3jco3w6Nbw/lP7MHAD2xeMA=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwuLta2P3NdUUon8Mh7Yn0
tWA7GF/AoerftGmBSxSgfBGHwE2va/bww/gSDr9na7X94JCH8mUcjon4llm+
koXyFRye9Sp8rTokA+UrOZiHnl978pA0lK/i8C+6K11zgxSUr+YwacH9X/ez
JKF8DQfLnfX3RfUkoHwth1n+P+8n/BeD8nUcFB6LTl0cKQrl6znoPpdu4GIR
gfINHGKajaNuvBCC8g0dfng/5Wj0gfGNHJYpe90yOSQA5Rs78AgfKi94yQ/l
mzjo2uqF7H/GC+WbOkxoYd5xP5YLyjdzmPi4uNrpOzuUb+4ACV8mKN/CITzK
aF2R0n97CN8STd7Kwbj37XfHAz+h8tZofBsHbua1Va8mf7QHAJk6chk=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVwiOK9zFZ6VRHK53CYJ/XO
WtsBxhdw4PaKrjw3TwHKF3EQrn3m1skJ40s45OjrTZH6Kgflyzictp75fe0e
WShfwUHSfX514CwZKF/J4faR30dzI6WhfBUH+aNtV68/k4Ty1RxSVQ0Z7U5L
QPkaDn+LFH1LLcShfC2H079edLUtFYXydRw8vHpubYoUgfL1HHQ+9K3b3i8M
5Rs47D3efv9HvRCUb+hQqjll8qRNAlC+kUOO04S9fAv5oHxjB+eQP2asbjC+
iYP8v7OnLT5wQfmmDh82X/xbK8oJ5Zs5LN99XeyUDCuUb+7ApKD1i3v1H3sI
38IhPMpoXZHSfyjf0uG95a9/TnrfoHwrNPXWaOptHCDxxQQ13xZNvx2U/wzK
t0fjOzhwM6+tejX5I4Tf4IAm7wjnAwBDp43d
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7MVCt+7emK3kABVwaLg95478bUUon8NBw0hn
npM3jC/gsHjZnz1aKxSgfBGH70x5a60FYXwJh6YT0XqRr+SgfBkH1j/LNZ0e
y0L5Cg4xPGmmC9bIQPlKDisWLk5vbpWG8lUcLq95foYnUwrKV3NgFOn4/O+v
BJSv4bBgKgfH8UviUL6Ww/bT4qx/EsSgfB2HTevb5CTuiED5eg46H/rWbe8X
hvINHFLnLmOqXiAI5Rs6SEs8fjFxkgCUb+TgHPLHjNWND8o3dpD38LUUW8UK
5Zs4BPYYarO0skD5pmh8M4faeZf3iD1khvLN0fgWaHxLNL6VQ/Fqa/tNixig
fGsH49633x0P/LSH8G0cuJnXVr2azAiVt3V4b/nrn5PeM6i8HZT/Dcq3d2BS
0PrFvfoPlO+AKt/ggGa+I6r6Bkc085zQ9Duh2e8Mdd9HqDwan8EFzgcA3aGm
Yg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwWMPPJJ17RRHK53BYUrp3
XZwTjC/goFs550vaSgUoX8ShhJk7O1caxpdwSDHgXvfomxyUL+PwYd3X1qIL
slC+gsOpDCnlQ00yUL6Sg2jkxUpDK2koX8XhsfJB43n7JKF8NYeAjQqeYTsk
oHwNB94vc156zxGH8rUcGudeiJcsEIPydRyWTi0W3OkgCuXrOcRwSDXMsBSB
8g0ckk4o7TJuEIbyDR1m7l9eHqojBOUbOZRqTpk8aZMAlG/ssOTk4jLuEj4o
38TBb02fa+pWXijf1CFKe6LHuQpuKN/M4cRR2/KSXRxQvrlDVf2vg9mr2KB8
C4fAHkNtllYWKN/Swce8fvtjPWYo38ohPMpoXZHSf3sI39rhveWvf056z+wB
fnVk3g==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwUBLiEPa4oAjlczicWa7a
8tASxhdwcGApPia4RAHKF3H4adB3MJIBxpdwOLUsJfPKbTkoX8bB65rM6dYV
slC+ggPvtatvuZJloHwlh4LIo1cPqElD+SoOxr1vvzsekITy1RzWXImovB0h
AeVrOHDU9UufiheH8rUc1O8FLixlFYPydRy0oi2O7vMXhfL1HNqrjlT8mCMC
5Rs4bC9YFqknKgzlGzoUXPt8KFFRCMo3cjh5TeXLbx5BKN/Y4fUd9Rb9JgEo
38ThGm9Hxk8/Xijf1CFKe6LHuQpuKN/MQf7f2dMWH7igfHOHs1IfXk0RgPEt
HNomZltVy7ND+ZYOVfW/DmavYoPyrRwg8cEE5Vs7vLf89c9J75k9AKATaic=

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwOGx4V7j/giKUz+HQ7Ppc
tcAQxhdwKDgcuE5gugKUL+LwXLBp9XwWGF/C4c0bm8at1+WgfBmHwFfzf1Z2
yUL5Cg45qz22q0nJQPlKDhOfF6Q0PpSC8lUc5IpdlK58lITy1Rw+zdVz28EL
42s43FbOWnRcTQLK13J4b5/n+ZBVHMrXcYg3s2W7e1YUytdziPDoF3i0XwTK
N3DIjmAPTJ4uDOUbOszcv7w8VEcIyjdyeH1HvUW/SQDKN3bwW9PnmrqVF8o3
cTj6mT84qpAHyjd1mNDCvON+LBeUb+Zw4qhteckuDijf3OG95a9/TnpsUL6F
w/Ld18VOybBC+ZYOkPBngvKtoOq/2UP41g7czGurXk3+COXboMnbosnbwfkA
ev13rA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwmF1xLSj0tCKUz+HQ7Ppc
tcAQxhdwuHTy1i6VqQpQvoiDjk3Gz3QmGF/CITNug8653XJQvozD3ZNPfa93
ykL5Cg5Zb+rLPwXKQPlKDmIvohgUlKShfBWHzw9bF4ZdlYTy1RwYJ1z697JR
AsrXcJiz/V23LKc4lK/lcNY5QvLpD1EoX8fBOqtoRsIWEShfz2HjJ6n5VRnC
UL6BQwz7olnSroJQvqHD53+7IpvYBaB8I4fZ17h/LjPlhvKNHS7uuPrlxg8Y
38Thp86kmuU5nFC+qUNgj6E2SysLlG/m4GNev/2xHjOUb+4ACV8mKN/CoXi1
tf2mRQxQvqUDk4LWL+7Vf+whfCuH95a//jnpfYPyraH8Z/YA7t1tiA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwqLmmvr/1jCKUz+GwL3gN
9wY9GF/Aoe/B+tz1fQpQvohD790pblNvyUP5Eg4a7akKN6bJQfkyDr+3/29k
jJeF8hUcLBk35J+zk4HylRwSp4Rs81CWhvJVHJYd2nss64QklK/mwC6T8tS2
XwLK13Co3Bj4Q6NKHMrXcnBR5dO5LygG5es4tLCcPMUxXQTK13Pw3vzRK9Bc
GMo3cPixhL3uiaMQlG/oULxxfWdAlSCUb+TAI3yovOAlP5Rv7JDjNGEv30I+
KN/E4RvvzsY/pjxQvqnDT51JNctzOKF8M4faeZf3iD1khvLN0fgWDu8tf/1z
0vtmDwCLB15z
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwsOe9OnXmZUUon8Ph7WNj
16mmML6AwxPzhkzD6QpQvoiDCp/tychv8lC+hENQ6i8rsy9yUL6Mw2re9bN8
T8pC+QoOX3+lzNKskYHylRxkBHayT3GThvJVHKZnijMslJGC8tUcXNc/aJu4
RwLK13DIXZLE3pYnDuVrOTTOvRAvWSAG5es4ZKZ8rdBXF4Xy9RwC9BcolUiI
QPkGDicrXWxS1IShfEOHx3v+NmibC0H5Rg7Fq63tNy0SgPKNHbZ9mKAvdZYP
yjdx+Ma7s/GPKQ+Ub+qg7DXtWtQKLijfzOGnzqSa5TmcUL65g7yHr6XYKlYo
38LBx7x++2M9Zijf0oFJQesX9+o/9hC+lcN7y1//nPS+QfnWaPI2DuFRRuuK
lP7bAwC6MGfS
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVweKL/cm7LeUUon8NB4Ctr
rY4JjC/g4PtQ5mrAAgUoX8ThQoeEDwM7jC/hIBXa9MfkkRyUL+Mg2vr0qvQh
WShfwaHrv/zSj7EyUL6Sw8GY//cS/aShfBWHn1FbHN+wSkH5ag5c2s2xnB8k
oHwNh/iDDZJcwjC+lsM8nunbRK6IQfk6Ds46V88zt4pC+XoOUZ9um6n+FYby
DRxOVrrYpKjB+IYOsqv/XIsxF4TyjRw+/9sV2cQuAOUbO3zj3dn4x5QHyjdx
YFLQ+sW9GsY3dVD2mnYtagUXlG/mENhjqM3SygLlm0PV/7GH8C0c3lv++uek
9wzKt4TzAa/uXus=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwEEo5ajf3nCKUz+HAvaOo
vlANxhdwYJzHnNxZpQDlizi0Hj/2w2+vPJQv4aDCy6N3c5kclC/jwKLCdnR9
tCyUr+DQJqZ01TBJBspXclhttfHO4xdSUL6Kw+9Vry6010hC+WoOExcxT3hn
JwHlazhsnbXMsY9fHMrXcpgom/lm1mNRKF/HQbvf7ZzTaREoX89hll/jr8dc
ML6Bg+EuafVHpUJQvqHDbqkpc3e+F4DyjRxW2yhlaBzmh/KNHUp3B9hY/OCD
8k0corQnepyr4IbyTR1mX+P+ucwUxjdz+LD54t9aUU4o39xh+e7rYqdkWKF8
Cwcf8/rtj/WYoXxLh/Aoo3VFSv/tIXwrNL61w3vLX/+c9L5B+TYOxr1vvzse
+Anl28L5AEABc6A=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwmLhUyeX9eUUon8Mhf2M2
+1sTGF/AQTNVYM3RlQpQvohDFh9jSaQcjC/hcPbJSwk+XXkoX8ah9ULbqvvf
ZKF8BQeHgKQZge9koHwlhwn9F3xFvkpD+SoOtpucXkxYKwXlqzlMF7Ldv+6x
JJSv4XB7fnph52oJKF/LIaP6XtoiJnEoX8dhteA7CbXNolC+nkP89a1xlytE
oHwDh1l+jb8ec8H4hg7TH/Yw3vsoBOUbObjtfZnlcFEQyjd2KF5tbb9pkQCU
b+Lw+d+uyCZ2GN/UQddWL2T/M14o38xh73GrdxqPeaB8c4co7Yke5yq4oXwL
h6r6XwezV7FB+ZYOgT2G2iytLFC+FdQ+Bijf2sG49+13xwM/7SF8G4f3lr/+
Oel9swcAZrJwQA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwUL79b6baJUUon8Ph+fEz
vxbrwvgCDq8a5PLSpipA+SIO04OF9KdelYfyJRwmRNjH2KfIQfkyDs4yU8Ma
XWWhfKC+wLQvO39JQ/lKDvPP8/BNviQF5as46CxdIK7VIwnlqzmsuRJReTtC
AsrXcAg25GC4GSwO5Ws5PFp4JVRASgzK13FY/KQ1yTlNBMrXc4iMP+QRFSEM
5Rs4ZJX82MYYLgTlGzrYGPm08yUIQvlGDts+TNCXOssH5Rs7XNxx9cuNH9xQ
volD28Rsq2p5dijf1IGbeW3Vq8mMUL6ZA5OC1i/u1X/sIXxzqPxHKN8CjW/p
8N7y1z8nvWdQvpWDce/b744HftoDAGaQZXI=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwcNv7MsvhoiKUz+HwMc+O
7b8VjC/gMPG+g1rQYgUoX8RB6OnuMGteGF/CYQ7PguuLPshB+TIODNVfzssc
lYXyFRxuvvq5fVKPDJSv5LBhXk5YjLY0lK/ikHJ4m2EPrxSUr+bALpPy1LZf
AsrXcHjKtL1s0iNxKF/LYXfPhOXVG8WgfB2HeDNbtrtnRaF8PQftfrdzTqdF
oHwDB+/NH70CzYWhfEOHb13rxGO/CEL5Rg7LlL1umRwSgPKNHf4zBP5PKOGH
8k0cVjgePnpMkhfKN3U4+pk/OKqQB8o3czDuffvd8QAnlG/usHz3dbFTMqxQ
voUDJLyZoHxLh+LV1vabFjFA+VYOTApav7hX/7GH8K0d3lv++uek98weAOuW
atI=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwYNc3+PbsmCKUz+GQeMiV
L84axhdw+Lp1bXXhEgUoX8RBfM3U6xP5YXwJh07ZS8yPfslB+TIOrRfaVt3/
JgvlKziEJU5o914mA+UrOairyQe3LJCG8lUc5rzujevtkYLy1Ryyl1ZJlelI
QvkaDsKHFXXF54tD+VoOrqmPN/fMEIPydRxWC76TUNssCuXrOVRVaj+/pioC
5Rs4LFxyQrT/mhCUb+jgtvdllsNFQSjfyEHRMb2z9J8AlG/s4Ot27OgTWxjf
xOEb787GP6Y8UL6pA5OC1i/u1TC+mUP2iR37Lu/khvLNHX7qTKpZnsMJ5Vs4
LN99XeyUDCuUb+kQ2GOozdLKAuVbOXAzr616NZkRyrd2eG/565+T3jd7CN8G
zgcAqXxtcg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwWMPPJJ17RRHK53AQ+Ra6
RdgBxhdwkPZT+79xoQKUL+Jw7H/RmvsiML6Ew5s3No1br8tB+TIOrm9zN/kf
loXyFRzaxJSuGibJQPlKDvt3Te6fIiAN5as4/AsVk+2+IQnlqzn0Vzou0zgp
AeVrOBwRKa9U+CQO5Ws5WKltuLGmVwzK13H4zZduf9BVFMrXc5DbWbyt/bQw
lG/gEHyts+eSLIxv6ND0JKn3yRpBKN/IYZmy1y2TQwJQvrHD53+7IpvYYXwT
NL6pA5OC1i/u1TxQvpmD/L+zpy0+cEH55mh8C4fsEzv2Xd7JDeVbOpw4alte
sosDyrdykPfwtRRbxQrlWzv4mNdvf6zHDOXboPFtofb/sYfw7Ry4mddWvZr8
Ecq3d3hv+eufk943KN8Byn8G4Tc4wNUDALEmhTs=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwWG3BFtt0UhHK53BQSTf1
UzWD8QUcGD8wBqmsUoDyRRwyl03/b8kD40s4WJ6Psy+9JQflyzgcvy73dvdG
WShfwaHwyplwrjYZKF/JQTd/Wd1ZPWkoX8Whjd1egU9dCspXc7j6toHj9WMJ
KF/DYaHSHJmCTeJQvpZD40vF/Y88xaB8HYfgOVOkqwxFoXw9B6eDwXLa8iJQ
voHD9oJlkXqiwlC+ocOj2WamtycLQflGDs/0lYzzNAWhfGMHX7djR5/YCkD5
Jg6eK9etUp3DD+WbOuja6oXsf8YL5Zs5HP3MHxxVyAPlmzuclfrwaooAF5Rv
4SDv4WsptooVyrd0qJ13eY/YQ2Yo38qBm3lt1avJH+0hfGs0vo3De8tf/5z0
ntkDAJsiZxQ=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVw8JnUnR18XBHK53C4/iHo
qawejC/gcM0+7oPoZAUoX8RhAuOZJa8/y0P5Eg6nV8lVHF0hB+XLODg9nL4v
eq4slK/gUPf4pFV5vQyUr+Twq+HcAqtwaShfxSHU5laKyi1JKF/N4bjjBq5H
hySgfA2HowcX3ziQJA7lazks4GeS+uMqBuXrOMzsm5d1qEwUytdz+PXDeVG5
jgiUb+Bg6DZrp9dZISjf0EHTT1nENVcQyjdyeH1HvUW/SQDKN3YIjzJaV6TE
D+WbOOja6oXsf8YL5Zs6TGhh3nE/lgvKN3Ooqv91MHsVG5Rv7gAJXyYo38KB
SUHrF/fqP/YQvqWDce/b744HftoDAA5OY2c=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw6Pm3d7v2dUUon8NhtV1X
3kkfGF/AIbQ1tT1/nQKUL+LA/yrGjYUDxpdw4NKYYs1xRQ7Kl3E43fH88vPl
slC+gsOMntyft9tkoHwlh0bTzq+mWtJQvopDn/UUzUYuKShfzUHe86jc5HkS
UL6GA1+FVti9yeJQvpbDo4VXQgWkxKB8HYd8xt9tq6xFoXw9hydZmlZ/24Wh
fAMHV9snNed/CUH5hg5ci3/EuR0VhPKNHIpXW9tvWiQA5Rs7lO4OsLH4wQfl
mziclfrwaooAF5Rv6vBTZ1LN8hxOKN/MYeO6/Cl60RxQvrlDYI+hNksrC5Rv
4eBjXr/9sR4zlG/pEB5ltK5I6b89hG/l8N7y1z8nvWdQvjWU/80eACjGaHQ=

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwsHJ9vGXVRUUon8PhkK6r
9FMzGF/AYYq0WfC+mQpQvohDxuGHjBd+ykP5Eg55RhING/bKQfkyDpebbkfX
zJaF8hUc2kOVJKTDZaB8JYczVacSF4lLQ/kqDts3t1olbpOE8tUctK6tFeKY
IQHlazhkXlPV454oDuVrOTS+VNz/yFMMytdxuLBmb2fzNREoX8/hZ2Lx38at
wlC+gcM69/dB5TwwvqFDwbXPhxIVhaB8I4fijes7A6oEoXxjh20fJuhLneWD
8k0cmBS0fnGv5oHyTR0mtDDvuB/LBeWbOUx8XFzt9J0dyjd3qKr/dTB7FRuU
b+Eg7+FrKbaKFcq3dPAxr9/+WI8ZyreCmv/HHsK3dnhv+eufk94zKN8Gyv9m
DwAwcW5A
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwiDW24dh4TRHK53Bw4FZI
eGMO4ws4POC0eH1iqgKUL+LA8Nsm7AIrjC/h4JrCqht0WA7Kl3F4KfWKU69S
FspXcHiutO/aAl8ZKF/J4fiWEycrZaWhfBWHyuAunRP/JaF8NQdJhaNhj1lh
fA0HS/crDpvWi0P5Wg6ffx07eueWGJSv47Cy4OzFjD5RKF/Poa+gdFV0sAiU
b+BQLjqboX+ZMJRv6PCta5147BdBKN/IYbfUlLk73wtA+cYO2z5M0Jc6ywfl
mziscDx89JgkL5Rv6mDc+/a74wFOKN/Moar+18HsVWxQvrmDj3n99sd6zFC+
hUPtvMt7xB7C+JYO3Mxrq15NZoTyrRyKV1vbb1rEAOVbo8nboMnbOoRHGa0r
UvpvD+HbQd3z0x4AkFt2hQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwmF1xLSj0tCKUz+GQ9/Np
6iQjGF/AgevW0fzW2QpQvoiD4IWvtR4sML6Ew4TApcJ1V+SgfBmHGdvdY30P
yEL5Cg6K2Qsmp7XIQPlKDuFJXifijaWhfBWHJ1OPNL/Ql4Ly1Rz6Zl6tLveQ
hPI1HLZKPrv/5b44lK/l0MD/vSXOFMbXcZilsJX/2XNRKF/P4c9iFsXnF0Sg
fAOHqE+3zVT/CkP5hg5vhCNTv3UKQflGDk1PknqfrBGE8o0dLM/tXnDsgQCU
b+Kw5OTiMu4SPijf1GFCC/OO+7FcUL6Zw4fNF//WinJC+eYO7y1//XPSY4Py
LRwCewy1WVpZoHxLByYFrV/cq//YQ/hWDtzMa6teTf4I5VtD9X+zBwCyQW7z

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVw8OIXPP78giKUz+GQlH2O
L9EFxhdwuDsl9c6pnQpQvojD1fa85h/qML6Ew/5azudC/PJQvoyDGM+Z+dff
yUL5Cg6PHlsoKm2SgfKVHOZumfA/YbY0lK/i8J+rNWmevBSUr+ZQc2zdPa5P
ElC+hkPmNVU97oniUL6Ww+3jW25dLxaD8nUc7kX0tfd8F4Hy9Rw2fpKaX5Uh
DOUbOPzwfsrR6CME5Rs66ApqfJx1UQDKN3IIjzJaV6TED+UbO8j/O3va4gMX
lG/ikH1ix77LO7mhfFOHE0dty0t2cUD5Zg6Q8GSC8s0dmBS0fnGv/mMP4Vs4
vLf89c9J75k9AP9RYjs=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw8Gw3E+U4rwjlczgkHnLl
i7OG8QUcbDzvWa6bpwDlizhMljkx9ygzjC/hMCFwqXDdFTkoX8ZBtz/BQWaO
LJSv4GBRLcT3QE8GyldyOKA1/5KnqDSUr+IQ8nljzu7LklC+msPLiLMV7yok
oHwNh62zljn28YtD+VoOjxZeCRWQEoPydRxiOKQaZliKQPl6DtqyYpLpiUJQ
voFD8cb1nQFVglC+oUPp7gAbix98UL6Rw9HP/MFRhTxQvrHDhBbmHfdjuaB8
E4eN6/Kn6EVzQPmmaHwzh6r6XwezV7FB+eYOkPBlgvItHIpXW9tvWsQA5Vs6
GPe+/e544Kc9hG/l8N7y1z8nvWdQvjWcDwCwN2Yu
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwUBLiEPa4oAjlczgEVPHk
P7SD8QUclGWfH1VfqQDlizioelY43hSD8SUcXp/XT5J9LAflyzjc4+Q20t0i
C+UrOMR99qwLXCQD5Ss5xKaufGxXIA3lqzj0iBqoFOhJQflqDvv2yIUwv5GA
8jUctko+u//lvjiUr+VwrOdQedl+MShfx+E3X7r9QVdRKF/PYXNB8eeoCmEo
38Bhe8GySD1RGN/QwaWh4q9huyCUb+RgeW73gmMPBKB8YwfeIiPry028UL6J
Q/aJHfsu7+SG8k0dzkp9eDVFgAvKN3P4sPni31pRTijf3EFnMwubWR87lG/h
ENhjqM3SygLlWzoUr7a237SIAcq3cgiPMlpXpPTfHsK3djDuffvd8cBPKN/G
4b3lr39Oes/sAU7PanU=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwOLiF0SVvvyKUz+FQtOV2
RL0ejC/gsO2hrbzPNAUoX8Th+Y8TOjZ8ML6EA5/+vF0F3+SgfBkH17e5m/wP
y0L5Cg6KQnVyzP0yUL6SQ/O3/c8im6ShfBWHN4nLFhwxlYLy1Rw8d+eLf2aU
hPI1HLZKPrv/5b44lK/lMI9n+jaRK2JQvo7Dm75zm+wviUL5eg7X2dqvy34S
gfINHHSfSzdwscD4hg7emz96BZoLQ/lGDoZus3Z6nRWC8o0dvnWtE4/9Igjl
mzhcSf3GqbETxjd1CMjROv1VUgDKN3NY4Xj46DFJXijf3OHD5ot/a0U5oXwL
h7aJ2VbV8uxQvqVD8Wpr+02LGKB8Kwdu5rVVryZ/tAcAFwtl8w==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVwaPr14+3PK4pQPodDpZBK
i4ItjC/g8LbqI1fWCgUoX8RhhX6MfpogjC/h4L/5qUTqOzkoX8ZBbcvX6eZr
ZKF8BQdj/5NsBuUyUL6Sw+MHOputjaShfBWHs1IfXk0RkILy1RxupE/JX7dW
AsrXcKgqUc5f7SgO5Ws5LOBnkvrjKgbl6zgsnVosuNNBFMrXc4j6dNtM9a8w
lG/gEO2+n+vXBiEo39BB6MWBQ6uDBKF8I4f10mu2X/Lmh/KNHY5+5g+OKuSB
8k0clL2mXYtawQXlmzpU1f86mL2KDco3cyhebW2/aREDlG/uEB5ltK5I6b89
hG+BxrdE41uh6bdG49s4cDOvrXo1mRHKt3WonXd5j9hDZijfzsHHvH77Yz0Y
394BEr9MUL6Dw3vLX/+c9L5B7GtwcGBS0PrFvfoP1H5HqPwzewAZoIXr
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwyDziovjgsiKUz+Hg7Wrw
44IhjC/gMOd+3A3/SQpQvojDjnDdRUkv5KF8CYcDR9d+fbVTDsqXcWDaEhnx
e64slK/gkN/Z2pqbJgPlKzlcTD/iIckuDeWrOEyseB6/UFIKyldzyLrqyjpX
UBLK13CY+Li42um7OJSv5bC7Z8Ly6o1iUL6OQ3PL4TvTD4hC+XoOQmuvZn6o
E4HyDRyea36qNAwQhvINHX54P+Vo9BGC8o0cFB3TO0v/CUD5xg6+bseOPrGF
8U0cImetXSiqA+ObOuw9bvVO4zEPlG/mEKU90eNcBTeUb+4g/+/saYsPXFC+
hYNx79vvjgc4oXxLh8AeQ22WVhYo3wqNb+1QvNraftMiBijfxqGq/tfB7FVs
UL6tQ+28y3vEHjJD+XYOkPhkgvLt0fQ7OLy3/PXPSe+ZPQCiun9p
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwuCApsvz3KUUon8PBa85p
W3MVGF/AYfbS64HxrQpQvoiDW+iH2XteyEP5Eg6FC7eqhG6Sg/JlHAx33KjR
nSAL5Ss4WH46aRDgJAPlKzn4Wvdt3vpDCspXcXBk774rsFkSyldz4HQ68cov
WwLK13DgqOuXPhUvDuVrORz2+DxPcY8olK/j4OHVc2tTpAiUr+cQ02wcdeOF
EJRv4FBw7fOhREUY39Dh5DWVL795BKF8I4clJxeXcZfwQfnGDnuPW73TeMwD
5Zs4zL7G/XOZKTeUb+qgs5mFzayPHco3c6idd3mP2ENmKN/cITzKaF2R0n97
CN/C4b3lr39Oes+gfEs4HwAHtWRn
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwKP0il/jljiKUz+HgkOZW
+cYaxhdw4Fhvmu87TwHKF3F4Jbt0pTY7jC/h8Gb234rg33JQvozDpSmb5jw/
IAvlKzjwNE+btrZSBspXcpBPavw91VYayldxyN5YUZD8WRLKV3NQlEj8e/au
BJSv4cD/ZV3wWyMYX8thhuXuaW8PiUH5Og6zTgntWrBOFMrXc5i7wyZ68joR
KN/AITL+kEdUhDCUb+ggoGMofe6/IJRv5CC7+s+1GHMY39jh879dkU3sAlC+
iUPp7gAbix98UL6pQ/aJHfsu7+SG8s0cJrQw77gfywXlmzu0Tcy2qpZnh/It
HOQ9fC3FVrFC+ZYO3Mxrq15NZoTyrdD41mh8G4f3lr/+Oel9s4fwbdH4dlD+
MyjfHo3vgMpvQOMzOKLJI/gALiSTjg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw2GK2N3PPRUUon8Oh32fV
iiJ9GF/AYen9Q59kJihA+SIOyk+mlhz7IQ/lSzi8kpnstO+OHJQv4+Cx7cgj
9z5ZKF/B4dBqPvXDPjJQvpLDVN/LNvK/paB8FYd/oWKy3TckoXw1hzVXIipv
R0hA+RoOH/lCD2vqi0P5Wg7vLX/9c9ITg/J1HO5F9LX3fBeB8vUcgq919lyS
FYbyDRy4Fv+IczsqCOUbOgTkaJ3+KikA5Rs5LDm5uIy7hA/KN3b4qTOpZnkO
J5Rv4tA2MduqWp4dyjdF45s5BPYYarO0skD55g7czGurXk1mhPItHCDhzQTl
W6LxrRyKV1vbb1rEAOVbOzApaP3iXv3HHsK3gZr3Ecq3hfMBzplxJw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVweB5VwSx6RRHK53B43KfA
c8kRxhdwkHw5l7FpiwKUL+LwZKth8itpGF/CISj1l5XZFzkoX8YhfJNGUsQm
WShfwYFJ/rOpV4MMlK/kUP7J0SfYWhrKV3Goe7LSU0xFCspXc7iRPiV/3VoJ
KF/DIdiQg+FmsDiUr+WQZZ7H1xAqBuXrOGj3u51zOi0C5es5zPJr/PWYC8Y3
cNhesCxST1QYyjd0ENAxlD73XxDKN3KQlnj8YuIkASjf2OE/Q+D/hBJ+KN/E
wW9Nn2vqVl4o39Thp86kmuU5nFC+mcNZqQ+vpghwQfnmDu8tf/1z0mOD8i0c
lu++LnZKhhXKt3SAhD8TlG+Fxrd2CI8yWlek9N8ewrdxMO59+93xwE8o3xZN
3s6BSUHrF/fqP1C+vQM389qqV5M/QvkOUPd8g/Ab0PgMjnA+ADE7hQ4=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVweB5VwSx6RRHK53CQYp62
YIk5jC/gsHi3iH/2XAUoX8ThDO+8hzIsML6Eg05m+NeTh+WgfBmHwFsNUkVr
ZaF8BQffHz+NgnNkoHwlh1q1uN03uaWhfBWHuLSFjWwNklC+msOpuPWf9plL
QPkaDutDWFg+vhOD8rUcVgu+k1DbLArl6zgc0HZ6u6ZIBMrXc4hpNo668UII
yjdwkF3951qMuSCUb+gQOWvtQlEdASjfyKFS8/jPVH8Y39hhhePho8ckeaF8
Ewdlr2nXolZwQfmmDvIevpZiq1ihfDOH2nmX94g9ZIbyzdH4Fg6Q8GaC8i0d
jHvffnc88NMewrdyeG/565+T3jN7AFOWZKk=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwSHmqmrr7jCKUz+GwzWQ7
4xZjGF/AYUZD0vGoNQpQvohDQI7W6a+SML6EA5/+vF0F3+SgfBmHBVOY614e
loXyFRze3ZPeU9chA+UrORxqk44KiZCG8lUcDldMq5svJgXlqzlIKhwNe8wq
CeVrOLw3sPLd9EUcytdyiGEIFguYKAbl6zisFnwnobZZFMrXczig7fR2TZEI
lG/g8FzzU6VhgDCUb+gwc//y8lAdISjfyMHGyKedL0EQyjd24BE+VF7wkh/K
N3EQfCMi9kGMD8o3dXAO+WPG6gbjmzl8493Z+MeUB8o3d9i4Ln+KXjQHlG/h
sHz3dbFTMqxQviUa38pB3sPXUmwVjG/tUDvv8h6xh8xQvo0DJL6YoHxbByYF
rV/cq//YQ/h2Dsa9b787HvhpDwDALm83
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwOPe+0c7wtiKUz+FwZrlq
y0NLGF/AweIrb3PfMgUoX8Th+o3fnFLSML6Ew8c3T0q6X8hB+TIOP2d/X6m8
UhbKV3Dw/fHTKDhHBspXcgjpOHSmxEYayldx0G33XbnytCSUr+Zwe356Yedq
CShfw+GQ9wqtizHiUL6Wg0PStuuTysWgfB2Hkp2HFA57iUL5eg7BDBbnNgqK
QPkGDuvc3weV8whD+YYOe4+33/9RLwTlGzm4NFT8NWwXhPKNHSo1j/9M9ReA
8k0ceIuMrC838UL5pg4/dSbVLM/hhPLNHLiZ11a9mswI5Zs7MClo/eJe/cce
wrdw8DGv3/5Yjxkqb+mwfPd1sVMyrFC+lUN4lNG6IqX/UPXWUPM+2gMArGhs
Bw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwiDW24dh4TRHK53BgPPrj
aIk5jC/g4MlgqW+0SAHKF3GYLHNi7lFmGF/CYdUndfH39+WgfBkHh1cO10IX
yUL5Cg5f7z8qE4+VgfKVHGZf4/65zFQayldxUCp/seS6kRSUr+ZQ0SA4vfyi
BJSv4bB89ZUb39+IQ/laDvt2CXF8mCIG5es4/Cv6rsp5VBTK13NQKWecbPZe
GMo3cNh7vP3+j3ohKN/QwW3vyyyHi4JQvpGDrqDGx1kXBaB8Y4f/DIH/E0r4
oXwToH6rdxqPeaB8U4co7Yke5yq4oXwzB53NLGxmfexQvrlDVf2vg9mr2KB8
Cwd5D19LsVWsUL6lw/Ld18VOycD4Vmh8awdI/DBB+TYO3Mxrq15NZoTybdHM
t0OTt3coXm1tv2kRA5Tv4GDc+/a744Gf9mBug4MDk4LWL+7Vf+wBx42CDg==

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVw4PGSr7p5RBHK53B4fvzM
r8W6ML6AQ3NV67aELgUoX8Sh4F8v7+s/8lC+hIOFL1dV4lM5KF/GQV709SGP
vbJQvoLDV7v9wuvcZKB8JQeu/KdN9SekoHwVh4xrchs2L5WE8tUcXDmY/3zZ
KAHlaziUmqulbk0Vh/K1HMw+RWl43xeF8nUc/ixmUXx+QQTK13Ngl2MJOXJJ
GMo3cPixhL3uiaMQlG/o4Ot27OgTWwEo38jhGm9Hxk8/Xijf2OEb787GP6Y8
UL6JQ9vEbKtqeXYo39RBZzMLm1kfjG/mULza2n7TIgYo39zhveWvf0563+wB
XpxY/w==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwOLzOJOX6JUUon8MhSywh
6qstjC/g8KucOdl/vgKUL+JQebbv7G9WGF/CYYvc95CJ9+SgfBmHnicbpCp2
y0L5Cg6HWh16r+fJQPlKDnbXN8ZtcpeG8lUcDl/c9Z2NRwrKV3NgtNLeeZ5T
EsrXcFioNEemYJM4lK/l0FBq/8VKTQzK13EQWns180OdCJSv53B629aVRQXC
UL6BQ1bJj22M4UJQvqFDDPuiWdKuglC+kYO0xOMXEycJQPnGDjlOE/byLeSD
8k0csk/s2Hd5JzeUb+pw4qhteckuDijfzEHZa9q1qBVcUL65w8THxdVO39mh
fAuHwB5DbZZWFijf0qF23uU9Yg+ZoXwrh/Aoo3VFSv/tIXxrByYFrV/cq/9A
+TYO3Mxrq15N/gjl28L5ALcEceg=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwsHJ9vGXVRUUon8Ph++pd
ZVfMYXwBh6SGCXYbFyhA+SIOBf96eV//kYfyJRwWrlKTNr4rB+XLOPit6XNN
3SoL5Ss4+P74aRScIwPlKzlcTD/iIckuDeWrOFQGd+mc+C8J5as5cHebV67d
JwHlazgcPLyU6VqkOJSv5dBQav/FSk0MytdxuBfR197zXQTK13M4vW3ryqIC
YSjfwOFIwIHZDbuEoHxDB67FP+LcjgpC+UYOlud2Lzj2QADKN3bwdTt29Ikt
jG/ioGurF7L/GS+Ub+rwYfPFv7WinFC+mYPOZhY2sz52KN8cjW/hsHFd/hS9
aA4o39Khqv7XwexVbFC+lcPy3dfFTsmwQvnWDrXzLu8Re8gM5ds4cDOvrXo1
mRHKt4XyP9oDAG2Oc4U=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw6P+uwjL3tCKUz+Gwoz9z
WYwJjC/gsM5zibb+fAUoX8RhR7juoqQX8lC+hMPUdc1iJRPloHwZB1fhrUne
KbJQvoLD4/knTvxnkYHylRxaHr0IKPgoBeWrOLzc7zl71k9JKF/NYemmo4s7
LktA+RoOVq8fN6yfJg7laznEMASLBUwUg/J1HILnTJGuMhSF8vUcqiq1n19T
FYHyDRximo2jbrwQgvINHWyMfNr5EgShfCOH0t0BNhY/+KB8Y4eLO65+ufGD
G8o3cfjGu7PxjykPlG/qwKSg9Yt7NYxv5jChhXnH/VguKN/c4cRR2/KSXRxQ
voXDWakPr6YIwOQtHd5b/vrnpMcG5Vs5BPYYarO0skD51g7czGurXk1mhPJt
HHzM67c/1mOG8m0djHvffnc88NMewrdzCI8yWlek9B/Kt0eTd0DlNzhA7X9m
DwDydoaN
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwEOUr9PlwWxHK53CQiRJY
UeAN4ws4pK+PmfR3iwKUL+IQvyhEM5kbxpdw0InbUrf3vRyUL+PgVNQ+8cIS
WShfwWGZ7D/+mmwZKF/JIaTj0JkSG2koX8Uh5PPGnN2XJaF8NQd2rW09Ylsk
oHwNhwMiq9kTX4lD+VoODRzGdZ+fiEH5Og7Tly1coSQH4+s57CrQ+R7MJArl
GzhEfbptpvpXGMo3dHC1fVJz/pcQlG/k8GMJe90TRxjf2CF17jKm6gWCUL6J
Q6nmlMmTNglA+aYOpbsDbCx+8EH5Zg6Rs9YuFNWByZs7CL4REfsgBpO3cFD2
mnYtagUXlG/psHz3dbFTMqxQvpVDYI+hNksrC5Rv7cDNvLbq1WRGKN/G4b3l
r39Oet/sIXxbNL4dVP1HewBGbHLp
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw2GK2N3PPRUUon8PB8m2g
YJIRjC/gIBZmbV20SAHKF3HQscn4mc4E40s4lOXkSiSflIPyZRymcLZcXNor
C+UrOBxazad+2EcGyldyOLX/38Sz8tJQvorDq6ZmNeF1klC+msOFzz8OXIiX
gPI1HM5sD+FSkRSH8rUc2A8qz9F5Iwrl6zgYxDYv37tCBMrXc/iZWPy3casw
lG/gMHP/8vJQHSEo39BB009ZxDVXEMo3cijVnDJ50iYBKN/YwTnkjxmrGx+U
b+Iw+xr3z2Wm3FC+qcOEFuYd92O5oHwzB53NLGxmfexQvjka38JB3sPXUmwV
K5Rv6VC82tp+0yIGKN/Kwbj37XfHAz/tIXxrByYFrV/cq/9A+TYO7y1//XPS
+2YPALtrZ4o=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwqDuU/b3/lCKUz+GQ23bK
bK4ZjC/gwM7Hw3JumQKUL+IQc53D+DUTjC/h8OaNTePW63JQvoxDdboRG5+D
LJSv4BActFHM56M0lK/kMJcjofLSDSkoX8XhsfJB43n7JKF8NYemnLfdy69L
QPkaDsGGHAw3g8WhfC0H9oPKc3TeiEL5Og7x17fGXa4QgfL1HJ5rfqo0DBCG
8g0cUucuY6peIAjlGzrEsC+aJe0K4xs5vL6j3qLfJADlGzt0G6XemZ0A45s4
5DhN2Mu3kA/KN3W4uOPqlxs/uKF8M4cPmy/+rRXlhPLNHQJ7DLVZWlmgfAuH
4tXW9psWMUD5lg5MClq/uFf/sYfwrdD41g7czGurXk3+COXboPFtHd5b/vrn
pPfMHgASKW/4
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwWMXgV3TvqiKUz+Eg8537
3xsXGF/AwaDaT+buagUoX8Th97db1QK8ML6Ew3qH2L6q+3JQvozDKvXC9e/a
ZaF8BYcZPbk/b7fJQPlKDjL7Zj5pi5KG8lUcguNEuqd6SEH5ag4Vuf0WpcGS
UL6Gw/+s5I4Tz8WhfC2Hd7EHtyceE4PydRwurjn/WSVXFMrXc5CI33Opz00E
yjdwYAtl3PzhsBCUb+ggoGMofe6/IJRv5HDymsqX3zwwvrEDb47Q645CASjf
xEHXVi9k/zNeKN/UYUIL8477sVxQvpnDxMfF1U7f2aF8c4faeZf3iD1khvIt
HOQ9fC3FVrFC+ZYOy3dfFzslA+NbOfiY129/rAdTb+1QvNraftMiBijfxiE8
ymhdkdJ/ewjf1oGbeW3Vq8kfoXw7NL69w3vLX/+c9J7ZAwCYcXs/
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwONrL7nfkgiKUz+HwJHLC
m/lWML6Aw8qd7+7yzFOA8kUcOkqT5z7lgfElHO6x/uf9v04OypdxOLiB9/Ou
6bJQvoKDu0PHR4Y8GShfyaH2rLVbmZg0lK/i0PeocIusqBSUr+agKJH49+xd
CShfw2Fl1lwJna3iUL6Wg87WxaF/dotB+ToOvwsX1PtmiEL5eg5b7dN+1OSI
QPkGDu9yj3w1/iYM5Rs6RLvv5/q1QQjKN3JInbuMqXqBIJRv7PBMX8k4TxPG
N3EIjzJaV6TED+WbOlzj7cj46ccL5Zs5RGlP9DhXwQ3lmztsXJc/RS+aA8q3
cNDZzMJm1scO5VtCzftvDwCsUGAT
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQEf7MVCt+7emK3kABVwMEx55Xf8rCKUz+HAo3RD
R8MexhdwkFq09nT/fAUoX8Th3+3Mec94YXwJh7S6tGfL78pB+TIO+tl+T6+s
kYXyFRzspP0uGq+TgfKVHPi/7fL4kC0N5as4xOcJWX3XkYLy1RySdmywPHRb
AsrXcOCo65c+FS8O5Ws5lPxaqWRoJQbl6zgk+Wmu+McjCuXrOWRHsAcmTxeG
8g0c9h5vv/+jXgjKN3TgWvwjzu2oIJRv5KDomN5Z+k8Ayjd2iJy1dqGoDoxv
4uAc8seM1Y0Pyjd1KN0dYGPxA8Y3c1jhePjoMUleKN/cIfvEjn2Xd3JD+RYO
P3Um1SzP4YTyLR02rsufohfNAeVbOVTV/zqYvYoNyrd2WL77utgpGVYo3wZN
vS0a387hw+aLf2tFYebbO0x8XFzt9J0dyndANa/BwYGbeW3Vq8mMUHlHh/Ao
o3VFSv/tIfKOaPJOaPJofAZnVPUNzg7Fq63tNy1igOp3cWBS0PrFvfoPVL+L
w3vLX/+c9L5B9btC9X+0BwC3JaZ/
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw2M6hcy/wqiKUz+GQp+ac
JOEE4ws4TJ/RXHBiswKUL+JQffbAxsMaML6Ew8tJ7c0r2OWhfBmHx58y3+36
KgvlKzjcjhZjn3RJBspXcnj2ceaLS8+koXwVh9uXCzRyDktB+WoO4tXvLRpL
JaF8DQeH+3XRgm4SUL6WQwP/95Y4U3EoX8fhqkZO4rLtolC+nkPT8fDYXz4i
UL6Bw/aCZZF6osJQvqFD05Ok3idrBKF8I4fIWWsXiuoIQPnGDktOLi7jLuGD
8k0cvvHubPxjygPlmzqcOGpbXrKLA8o3c3hv+eufkx4blG/uIO/haym2ihXK
t3BgUtD6xb36jz2Eb+lg3Pv2u+OBn1C+FVT/MyjfGs4HAGS9bsw=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwaGud4GVxSRHK53Aoeb+m
u9caxhdweLPCRbposQKUL+Lg8u9Vrz4HjC/h8MZG497nK3JQvoxDcIpNl/QJ
WShfwWHO2oaH51xloHwlBz7rGwozVaWhfBWHiRXP4xdKSkH5ag5JOzZYHrot
AeVrOPTsen8rrlscytdyUNrEMeuorxiUr+OgfVzi65KHIlC+nkNch9tL2yPC
UL6BQ0yzcdSNF0JQvqFDtPt+rl8bYHwjB/vwLzF+0oJQvrHDeuk12y9580P5
Jg57j1u903jMA+WbOnzj3dn4xxTGN3P4qTOpZnkOJ5Rv7lA77/IesYfMUL6F
g495/fbHejC+pcN7y1//nPS+2UP4VlD+M3sA1kVqWw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwCBfZayx7XBHK53BYlLGl
N8IKxhdwaLn21H7jEgUoX8TB+mjBSzFmGF/CYe2pxAddN+WgfBmHqyXNRs1H
ZKF8BQcuVjuns5kyUL6SQ3iW6jIVaWkoX8VB/mjb1evPJKF8NQebXddaL3ZJ
QPkaDj273t+K6xaH8rUc6nSqZud9EIXydRyWTi0W3OkA4+s5WGcVzUjYIgLl
Gzg46SVMKUoQhvINHWbuX14eqiME5Rs5cDOvrXo1WRDKN3aInLV2oaiOAJRv
4rBees32S978UL6pwzfenY1/THmgfDOHCS3MO+7HckH55g4b1+VP0YvmgPIt
HKrqfx3MXsUG5Vs6yHv4WoqtYoXyraD2M0L51g5MClq/uFf/sYfwbRzeW/76
56T3DMq3hfK/Qfl2Dsa9b787HvgJ5dtDzfsI5TvA+QB00n6w
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVwWKDgspzxjiKUz+GwIFdN
ldkDxhdwyF44O99pvwKUL+Jw673G0+nGML6EQ/O5hPPc9vJQvoxDdveMDn5W
OShfwUHhwnXzm1dkoHwlhyjtiR7nKqShfBWH0Pob4cmOUlC+msPVtw0crx9L
QPkaDqJ+aebPtotD+VoOl3Pu7DyRIgbl6zgEz5kiXWUoCuXrOcR1uL20PSIM
5Rs4/PB+ytHoIwTlGzpo+imLuOYKQvlGDv8ZAv8nlPBD+cYOurZ6Ifuf8UL5
Jg5MClq/uFfzQPmmDspe065FreCC8s3Q+OYOxr1vvzse4ITyLdD4lg5tE7Ot
quXZoXwrB3kPX0uxVaxQvrWDj3n99sd6zFC+DRrfFmreT3sI386heLW1/aZF
DFB5e4f3lr/+Oel9g8o7QPnPIPwGND6DowM389qqV5M/2gMAJ+SDRw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwUL/JcfPAaUUon8OB08DM
I9QMxhdwiJbj8YmfoADlizh8/rcrsokdxpdwWLhKTdr4rhyUL+Nw29/+5qx5
slC+gkPrbX3N6DIZKF/JQSiOT/SUmTSUr+KgH2ai/OmLJJSv5rCizjfPQxrG
13CIP9ggySUsAeVrOfRfFug+4yUO5es4LGrk2bQkUAzK13PQPi7xdclDESjf
wCE7gj0webowlG/osNTK+MTyuUJQvpGDjZFPO1+CIJRv7FC82tp+0yIBKN/E
QddWL2T/M14o39Th6Gf+4KhCHijfzOHD5ot/a0U5oXxzh43r8qfoRXNA+RYO
8h6+lmKrWKF8Swcf8/rtj/WYoXwrh/eWv/456X2zh/CtHbiZ11a9mvwRyreB
8wH2cmUH
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwaNuxmiH4siKUz+EQxxfr
slgfxhdwMLqT8u1jnwKUL+JwQypM0e2ZPJQv4dDjVHVTcZsclC/jEPZ/SUR3
oyyUr+AQoiIvZRsjA+UrOWyYlxMWoy0N5as4rNeWs3D5IAnlqzmsEzz17OUi
CShfw0FnMwubWZ84lK/lsHL+sw3asWJQvo6Dh1fPrU2RIlC+noPOh7512/uF
oXwDB8Nd0uqPSoWgfEOHGPZFs6RdBaF8IwfnkD9mrG58UL6xw+xr3D+XmXJD
+SYOZ6U+vJoiwAXlmzpMfFxc7fSdHco3c1i++7rYKRlWKN/cARK+TFC+hYO8
h6+l2CqYvKWDj3n99sd6zFC+lQOTgtYv7tV/7CF8a4f3lr/+Oek9swcA7k1j
5w==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw2G+6Skb2qiKUz+FgE3ne
wsYOxhdwaKuIuC6wVAHKF3HQvdgaU8kK40s4THs7KZv9nByUL+MQ8P6b/fMG
WShfweHg54XFsioyUL6Swxk7hxWms6WgfBWHlc/0bryIkITy1Ryeb19jaBgi
AeVrOFSVKOevdhSH8rUc0rOfOR/gFYPydRyW774udkpGFMrXc2CXYwk5ckkY
yjdw2Hu8/f6PeiEo39Ch6UlS75M1glC+kUNAjtbpr5ICUL6xwzfenY1/THmg
fBOHs1IfXk0R4ILyTR3aJmZbVcuzQ/lmDvIevpZiq1ihfHMHbua1Va8mM0L5
Fg7GvW+/Ox74aQ/hW0LlP0L5VnA+ADlwZTk=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw2HT9hbzwNUUon8PhvOnG
iwscYHwBh1UNJgYTlipA+SIOPw36DkYywPgSDvUzVhd8OScH5cs4hG/SSIrY
JAvlKzgoCtXJMffLQPlKDq7Jzq5sodJQvopDSOP/i1ecpKB8NYfzKR4+ySsl
oHwNh2n9eQWrWsWhfC2H7afFWf8kiEH5Og6PG4U0CpJFoXw9h40/+l5KOIhA
+QYO69zfB5XzCEP5hg4JhbG/T70QhPKNHGRX/7kWYw7jGzt8/rcrsoldAMo3
cfjPEPg/oYQfyjd1uLjj6pcbP7ihfDOHnzqTapbncEL55g7Ld18XOyXDCuVb
ONTOu7xH7CEzlG/pwM28turVZEYo38qBSUHrF/fqP/YQvrXDe8tf/5z0nkH5
NlD1H6F8WzR5OzgfAC1hen4=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwWPmpbcevS4pQPoeDVMvd
Z/1uML6Ag7Sf2v+NCxWgfBEH7tYFuVs4YXwJBy6NKdYcV+SgfBkHwx03anQn
yEL5Cg71flm2NytkoHwlh/df/b58U5CG8lUczkp9eDVFQArKV3PYb8Aov5pf
EsrXcOCr0Aq7N1kcytdyaOAwrvv8RAzK13H4ur1157dbolC+noPTwWA5bXkR
KN/AYeGSE6L914SgfEMHGyOfdr4EQSjfyKF4tbX9pkUCUL6xw97jVu80HvNA
+SYOF3dc/XLjBzeUb+pg3Pv2u+MBTijfzEHew9dSbBUrlG8ONY8ByreAqv9p
D+FbOnAzr616NfmjPQAGl2Nb
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw8OH6U33+hiKUz+Gw3SCQ
WdQcxhdwuPtlEuea5QpQvojDp8lPJm4ShfElHBbyJkTv/y8H5cs4iLY+vSp9
SBbKV3A4lSGlfKhJBspXcthgt8NqR4w0lK/iYHhOZQfvD0koX83hxFHb8pJd
ElC+hkPPrve34rrFoXwtB/aDynN03ohC+ToOfxazKD6/IALl6zlkR7AHJk8X
hvINHPYeb7//o14Iyjd04M0Ret1RKADlGzn4relzTd3KC+UbO0RpT/Q4V8EN
5Zs4zL7G/XOZKYxv6rBxXf4UvWgOKN/Moar+18HsVWxQvrlDYI+hNksrC5Rv
4QAJbyYo39KBSUHrF/fqP/YQvpXDe8tf/5z0vkH51g7czGurXk3+COXboPFt
0fTbQfU/swcA7w53qg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwkD7Rk37gjiKUz+FgE3ne
wsYOxhdwEJtop3NhvgKUL+Lw9x1LucYveShfwuESrzyvwjE5KF/GQbc/wUFm
jiyUr+AgNTu0bGm8DJSv5MBtmXbvjbk0lK/iIH00OJ/FSwrKV3Nwdy3JZP4j
AeVrOBwQWc2e+Eocytdy2H6Ay33+azEoX8fBZc4DoZ2dolC+nsOm9W1yEndE
oHwDh6pK7efXVGF8Q4fI+EMeURHCUL6Rw5XUb5waOwWhfGOHZcpet0wOCUD5
Jg5+a/pcU7fyQvmmDspe065FreCC8s0czkp9eDVFAMY3d/ipM6lmeQ4nlG/h
0DYx26panh3Kt3RYvvu62CkZVijfygESH0xQvrUDk4LWL+7Vf+whfBuH95a/
/jnpfYPybR24mddWvZr8Ecq3Q5O3h/Kf2QMA4IZ2Iw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVw4O1LDJ5wRRHK53BI3r2b
5acdjC/gMLF+Z+DZdQpQvoiDqXKwRbcIjC/hEHSIK8nnoRyUL+Ogv91xd9MG
WShfweH1jcURjpNkoHwlhyrGbU9nBkhD+SoOTJzNFp0aUlC+msPJq265B80l
oXwNh6veh6IeKkpA+VoOrCWy2vU7xKB8HYeTV1paS0+KQvl6Di0sJ09xTBeB
8g0ckk4o7TJuEIbyDR20ZcUk0xOFoHwjB11BjY+zLgpA+cYO2z5M0Jc6ywfl
mzjkOE3Yy7cQxjd18FvT55q6lRfKN3PgLTKyvtwE45s7nJX68GqKABeUb+EQ
2GOozdLKAuVbOoRHGa0rUvpvD+FbOXAzr616NZkRKm+NJm/jYNz79rvjgZ9Q
vi1U/Uco387hveWvf05636B8ewcmBa1f3Kv/2AMAF1Vz0g==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwWHdwxbuFVxShfA6HBt+2
s6XWML6Aw8T6nYFn1ylA+SIOATlap79KwvgSDhHKMnvtX8tB+TIOLxsn2KxZ
JwvlKzjICAaqTE2VgfKVHMKuH2CTFZGG8lUcVrg5Tt30RxLKV3OoObbuHtcn
CShfw8HS/YrDpvXiUL6WQ0DQN+n1TWJQvo7DQeUWDQYlUShfz2Hxk9Yk5zQR
KN/AQfe5dAMXC4xv6OC9+aNXoLkwlG/kwLX4R5zbUUEo39jhP0Pg/4QSfijf
xCFKe6LHuQpuKN/U4cPmi39rRTmhfDOH4tXW9psWMUD55g7czGurXk3+aA/h
Wzi8t/z1z0nvmT0Aq0Rcsw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwOHJp2oRNFxShfA4H1Tee
sdN1YHwBh56oaTfXdytA+SIOrFpX57s8kIfyJRxK929IrpggB+XLOHC1yXP8
S5CF8hUcphyzXxsOFIfwlRwWuf4+U94iBeWrODxx6ah/lygJ5as5fJrB/a/n
vTiUr+Ggs3Vx6J/dYlC+lsPy3dfFTsmIQvk6DjFJjx7rvBCG8vUcSjKW7/MX
E4LyDRx2S02Zu/O9AJRv6PD5367IJnYY38jhG+/Oxj+mPFC+sYOy17RrUSu4
oHwTh7aJ2VbV8uxQvqlDYI+hNksrC5Rv5iDv4WsptooVyjdHk7eAuhcmb4nG
t3LgZl5b9WoyI5Rv7RAeZbSuSOm/PYRv4/De8tc/J71vUL4tVP1HewDvSnFk

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVweKL/cm7LeUUon8OBRWsH
1yxLGF/AQSzM2rpokQKUL+LA3bogdwsnjC/hcKzuaoHoRzkoX8ZhRdYUc/51
slC+gsOWcw8PXqiVgfKVHPJr/FNdfaWhfBUHw3MqO3h/SEL5ag4njtqWl+yS
gPI1HNoMt8tdDxCH8rUcvm5v3fntliiUr+NQVan9/JqqCJSv51Bw7fOhREUh
KN/AYbfUlLk73wtA+YYO0hKPX0ycBOMbOTiH/DFjdeOD8o3R+CYOgm9ExD6I
wfimDtknduy7vJMbyjdz+KkzqWZ5DieUb+4g7+FrKbaKFcq3cHhv+eufkx4b
lG/pAAl/JijfyiE8ymhdkdJ/ewjfGo1v42Dc+/a744GfUL4tGt/OgZt5bdWr
yR+hfHs0eQeH4tXW9psWMUDsa3CAmw8A/o+D7Q==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVwkGzPWrr9kCKUz+FwZMtW
j5UaML6AQ0/D9VzbVgUoX8Thvsui201P5KF8CQfr/fvvWc+Wg/JlHI6EGE/6
mSQL5Ss43OgTvPZARgbKV3I47rzZrIpTGspXcUhw/mDV8E0SyldzUJRI/Hv2
rgSUr+EgsyD3echecShfy2FrTFVCeI4YlK/jsFrwnYTaZlEoX89h44++lxIO
IlC+gUNMs3HUjRdCUL6hg9CLA4dWBwlC+UYOpbsDbCx+8EH5xg5+a/pcU7fy
QvkmDoJvRMQ+iMHkTR2itCd6nKvghvLNHDauy5+iF80B5Zs7tE3MtqqWZ4fy
LdD4lmh8K4faeZf3iD1khvKtHYpXW9tvWsQA5ds4MClo/eJe/ccewrdF49s5
GPe+/e544CeUb+/Azby26tXkj1C+g8N7y1//nPSeQfgNaHwGR7h6AISnh+Y=

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw8Kh47mhxRRHK53B4Ejnh
zXwrGF/AIXhueWnDBAUoX8Qh4/BDxgs/5aF8CYd/Vo2Xn76Ug/JlHJa1Gsu9
PCYL5Ss4qObt0r62WgbKV3L41XBugVW4NJSv4rBjN9P5YnYpKF/N4f+0ncmP
HkpA+RoOqpznIvSeikP5Wg46WxeH/tktBuXrOKjfC1xYygrj6zlo97udczot
AuUbOMR1uL20PSIM5Rs6vJxW5LjWHsY3ckidu4ypeoEglG/sUKo5ZfKkTQJQ
vokDk4LWL+7VPFC+qcOJo7blJbs4oHwzh+W7r4udkmGF8s0d5D18LcVWwfgW
DoE9htosrSxQviXUvD/2EL6Vw3vLX/+c9L5B+dYO3Mxrq15N/gjl28D5ACs9
bpI=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVweB5VwSx6RRHK53Boatlh
22oG4ws4TLzvoBa0WAHKF3Hgt+9P38MH40s4SF3o97p/VQ7Kl3E4uIH3867p
slC+gsPRz/zBUYUyUL6Sw4Z5OWEx2tJQvorDY+WDxvP2SUL5ag7rBE89e7lI
AsrXcHionXqIW0ccytdymFe64paBkhiUr+Mwd4dN9OR1IlC+nsPLaUWOa+2F
oXwDB8Nd0uqPSoWgfEOHZcpet0wOCUD5Rg6f/+2KbGKH8Y0deIuMrC838UL5
Jg7y/86etvjABeWbOkxoYd5xPxbGN3PQ2czCZtbHDuWbOyzffV3slAwrlG/h
wM28turV5I/2EL4lnA8A6D1f5A==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwsPdfHel1VhHK53CYwZik
3GEF4ws4fN26trpwiQKUL+KQE7le7jkfjC/hEK9j+bf9oxyUL+PgVNQ+8cIS
WShfwWGy/smVYstloHwlh9tHfh/NjZSG8lUcDm5edIRZSwrKV3O4fFyG+Ra7
JJSv4ZCxSFy1XVQCytdyUFzQKOJ4VgzK13H4EHi5f6qZKJSv58AuxxJy5JIw
lG/gMP1hD+O9j0JQvqFD6txlTNULBKF8I4f10mu2X/Lmh/KNHWZf4/65zJQb
yjdxeG/565+THhuUb+pQO+/yHrGHzFC+mQM389qqV5MZoXxzByYFrV/cq//Y
Q/gWUP3foHxLqPqPUL4VmnprNHkbqP5n9gBgbm8c
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwuFylfzr9nCKUz+GgddtG
+qcOjC/g8LrDrGDdNAUoX8RB4LLuq49v5KF8CYcctk4Gi71yUL6MQ8lf8bOp
hbJQvoKD2dVIGRZVGShfyUH+39nTFh+koHwVh1tirCvP+UtC+WoO/F/WBb81
koDyNRyCZ/5/HCAjDuVrOajfC1xYyioG5es4tFcdqfgxRwTK13OY23C1in+d
MJRv4NDdu1R1LTOMb+hwJfUbp8ZOQSjfyEFXUOPjrIsCUL6xg66tXsj+Z7xQ
volDlPZEj3MV3FC+qcOJo7blJbs4oHwzB53NLGxmfexQvrnDe8tf/5z02KB8
C4eN6/Kn6EXD1FuiqbdyCOwx1GZpZYHyrdH4Ng7Ld18XOyXDCuXbovHtHLiZ
11a9mswI5ds7hEcZrStS+m8P4Ts4GPe+/e544Kc9AM9Ldrs=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwqJ9TsEn/siKUz+Hw5SBD
SoULjC/g8LbqI1fWCgUoX8TB+KjTNjMRGF/C4eObJyXdL+SgfBmHWNe12ozb
ZKF8BYfCK2fCudpkoHwlB772+mUCk6ShfBWHJ1OPNL/Ql4Ly1RyEskNusb2T
gPI1HKxeP25YP00cytdymNpgu1jQSQzK13Ewe/Ps7hp2UShfz+H0tq0riwqE
oXwDB0O3WTu9zgpB+YYOQi8OHFodJAjlGzlUah7/meovAOUbOyw5ubiMu4QP
yjdx8FvT55q6lRfKN3Woqv91MHsVG5Rv5gAJTyYo39zBx7x++2M9ZijfwoGb
eW3Vq8mMUL6lQ+28y3vEHsLkrRyYFLR+ca/+Yw/hWzu8t/z1z0nvGZRvA+cD
AHhJcO0=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwiNI2e+B5RRHK53DImeT+
84ozjC/g4M0gdJ57vQKUL+LwPUhMvlgKxpdwWFDfN0dCSx7Kl3GYedB16oa3
slC+gkOTTL3ghA0yUL6SQ/yPmVoSedJQvorD4YppdfPFpKB8NYdUVUNGu9MS
UL6Gg6hfmvmz7eJQvpaDa+rjzT0zxKB8HYeZffOyDpWJQvl6DjEcUg0zLEWg
fAOHpVbGJ5bPFYLyDR1cGir+GrYLQvlGDtISj19MnCQA5Rs7+K3pc03dygvl
mzjwFhlZX26C8U0dJrQw77gfywXlmznobGZhM+tjh/LNHd5b/vrnpMcG5Vug
yVs6LN99XeyUDCuUb+XAzby26tVkRijf2oFJQesX9+o/9hC+DVT+I5RvCzX/
G5Rv52Dc+/a744GfUL49mn4HVP0NDnD1APu6fOI=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwkKtS3Hn0kiKUz+FQKaTS
omAL4ws4hLamtuevU4DyRRyc72s+vSAB40s4vHog/mQrszyUL+PAdWjlway7
slC+gkO+KIvEtb0yUL6Sw6eYH/yuydJQvorDjt1M54vZpaB8NQdJhaNhj1kl
oXwNB+/lXRHcfBJQvpbDLP+f9xP+i0H5Og73Xy8vDZ8jCuXrOQQzWJzbKCgC
5Rs4GLrN2ul1VgjKN3TQFdT4OOuiAJRv5LDk5OIy7hI+KN/YYfY17p/LTLmh
fBOHE0dty0t2cUD5pmh8M4efOpNqludwQvnmDm0Ts62q5dmhfAuH95a//jnp
sUH5lg7hUUbripT+20P4Vmh8a6j6Z/YAszRnwQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVw6BV/73XnpCKUz+EQu0Uo
9KcljC/g0N33NaZgqQKUL+LAOuWQAi83jC/h4L/5qUTqOzkoX8YhoalG03O9
LJSv4PCIn//lhhIZKF/JITzJ60S8sTSUr+KgH2ai/OmLJJSv5pCqashod1oC
ytdwWHNd9sHyJeJQvpbDokaeTUsCxaB8HYfQm6ydHdWiUL6eg3VW0YyELSJQ
voHDy2lFjmvthaF8Q4dvXevEY78IQvlGDuFRRuuKlPihfGOHizuufrnxgxvK
N3GY0MK8434sF5Rv6rBxXf4UvWgOKN/MQWczC5tZHzuUb+7QNjHbqloexrdw
eG/565+THhuUb+kQ2GOozdLKAuVbORSvtrbftIgByreGqv9mD+HbOBj3vv3u
eOAnlG+LJm8H5T+D8u3hfAA8TXou
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwkKtS3Hn0kiKUz+Gw1P2o
311TGF/A4e4kg59ecxWgfBGHCx0SPgzsML6Eg++pFTGed+SgfBkHvWeqOwsm
ykL5Cg4W1UJ8D/RkoHwlB5d71f+Er0pB+SoOU95WTZK/JAnlqzmcOGpbXrJL
AsrXcMi8pqrHPVEcytdyuH18y63rxWJQvo6DX7FA9bSjIlC+nsPLaUWOa+2F
oXwDB5eGir+G7YJQvqHDMmWvWyaHBKB8IwfPletWqc7hh/KNHVY4Hj56TJIX
yjdx+KkzqWZ5DieUb+og7+FrKbaKFco3c9DZzMJm1scO5Zs7LN99XeyUDEze
wqFtYrZVtTxM3tLBuPftd8cDP+0hfCsHbua1Va8mf7QHAE9cY2s=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwsOe9OnXmZUUon8Ph2Snr
jQ7aML6Awz7Fz283TVKA8kUchGufuXVywvgSDra/XicuuyQH5cs49Ih94t4z
RxbKV3Dw/fHTKDhHBspXcmDZU3DDnE8ayldxYLiSV5j9QhLKV3Por3RcpnFS
AsrXcCjomPWxsFAcytdy4Pw3hdPaTAzK13GwziqakbBFBMrXczi9bevKogJh
KN/AoXjj+s6AKkEo39Bht9SUuTvfC0D5Rg7rpddsv+TND+UbO/it6XNN3coL
5Zs4nDhqW16yiwPKN3WonXd5j9hDZijfzIFJQesX9+o/9hC+uUN4lNG6IqX/
UL4FGt8SjW+Fpt/awbj37XfHAz+hfBu4PABtSW+1
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVweKL/cm7LeUUon8Ph406J
yAIrGF/AQe3K0uAbaxSgfBGHWzK84o+4YHwJh/jLbvb1b+WgfBkHvzV9rqlb
ZaF8BYeJHZyr3jfKQPlKDm8iVrptypCG8lUcPj9sXRh2VRLKV3Mw+p8iuX+B
BJSv4XD04OIbB5LEoXwth/3ysyXmcopB+ToOB5VbNBiURKF8PQd2OZaQI5eE
oXwDh0ezzUxvTxaC8g0dYtgXzZJ2FYTyjRx4c4RedxQKQPnGDnuPW73TeMwD
5Zs4tE3MtqqWZ4fyTR1OHLUtL9nFAeWbOVTV/zqYvYoNyjd3YFLQ+sW9+o89
hG/hwM28turV5I9QvqXDe8tf/5z0vkH5VlD+M3sA3VZnKg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVwqJ9TsEn/siKUz+Gg1dXV
yqoH4ws42K+6tvv2ZAUoX8Thg86baeuey0P5Eg4qvDx6N5fJQfkyDt6b2rpl
umWhfAUHJSadHSwVMlC+koPo+uLzZcXSUL6Kw/dki7MTXktC+WoOh5dvmWM+
SwLK13B4vWXufYNV4lC+lsPeN8F+/ovFoHwdh5l987IOlYlC+XoOTcfDY3/5
iED5Bg4vpxU5rrUXhvINHfYeb7//o14IyjdySCiM/X3qhSCUb+xQvNraftMi
ASjfxKF0d4CNxQ8+KN8UqN/qncZjHijfzKGq/tfB7FVsUL65AyR8maB8C4fa
eZf3iD1khvIt0eStHJgUtH5xr/5jD+FbO4RHGa0rUvoP5dug8W3R9Ns5cDOv
rXo1mRHKt0fjO0D9wwDhN6DxGRyh6j/aAwDO3IgJ
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw2G+6Skb2qiKUz+FwISrM
a50BjC/gMKcy6tHS2QpQvojDkXVRi/Z8l4fyJRzE5u/XnLBWDsqXcTi4gffz
rumyUL6CQ35na2tumgyUr+SQX+Of6uorDeWrONxKLZFLYZGC8tUcmnLedi+/
LgHlazhMfFxc7fRdHMrXcpjoLq5XdV0MytdxWC34TkJtsyiUr+fgdDBYTlte
BMo3cNh7vP3+j3ohKN/Q4VvXOvHYL4JQvpGDomN6Z+k/ASjf2OH1HfUW/SYY
38ShdHeAjcUPPijf1CH7xI59l3dyQ/lmDm0Ts62q5dmhfHOHjevyp+hFc0D5
Fg7yHr6WYqtYoXxLB27mtVWvJjNC+VYOTApav7hX/7GH8K0d3lv++uek980e
AEhJaJo=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVweF20evK304pQPodD4qcj
eZNsYHwBh6KgPNmJCxSgfBEHf+tlPXO/yEP5Eg6FC7eqhG6Sg/JlHPSz/Z5e
WSML5Ss4bDJePbttrgyUr+Tg7HlP5p2nNJSv4mB9cX+xS5oUlK/mUHNs3T2u
TxJQvoYDX4VW2L3J4lC+loPZyqBYr2oxKF/H4apGTuKy7aJQvp6DyaXectVd
IlC+gcNU1b+RDPOFoXxDhzfCkanfOoWgfCOH1LnLmKoXCEL5xg6Vmsd/pvoL
QPkmDqW7A2wsfvBB+aYOTApav7hX80D5Zg7y/86etvjABeWbO5w4altesosD
yrdwmPi4uNrpOzuUb+lQO+/yHrGHzFC+lYOPef32x3owvrWDce/b744HftpD
+DYO7y1//XPSewbl26Lx7dD49g7czGurXk3+aA8A2o9/Tw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQEf7MVCt+7emK3kABVwuLta2P3NdUUon8MhK+n6
dX9bGF/AwfehzNWABQpQvojDzWMhu3fxwPgSDicdXH8f/iwH5cs48KkvbHh2
UhbKV3B4wjlXzbhPBspXcvi1yyL6f7U0lK/iEDzVdfq6WikoX82hXva/cV6e
JJSv4eA2m/Pjcm0JKF/LIXjm/8cBMuJQvo7D9GULVyjJiUH5eg7Bc6ZIVxmK
QvkGDnEdbi9tjwhD+YYOP5aw1z1xFILyjRyupH7j1NgpCOUbO3iuXLdKdQ4/
lG/ioGurF7L/GS+Ub+qQfWLHvss7uaF8MwedzSxsZn3sUL65w3vLX/+c9Nig
fAsHeQ9fS7FVrFC+pQM389qqV5MZoXwrh+LV1vabFjFA+dZofBuH8CijdUVK
/+0hfFs0vh3Uvm9Qvj3U/I9QvgOqfIMDmrwjmrwjmrwTVP4ZVB7BBwCrG5e0

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwUJ734nbxGUUon8OBqZTx
zhITGF/AwWvik0O/+xWgfBGH9TNDnq45Kw/lSziwHQuVF22Xg/JlHFJlf8zc
ECkL5Ss4xAW9WnI6TgbKV3IIT/I6EW8sDeWrOOwLu/ZE7bcklK/mELBRwTNs
hwSUr+HQf1mg+4yXOJSv5ZCe/cz5AK8YlK/jEMMh1TDDUgTK13Ngl2MJOXJJ
GMo3cHgjHJn6rVMIyjd0eH1HvUW/SQDKN3JwDvljxurGB+UbOxz9zB8cVcgD
5Zs4/NSZVLM8hxPKN3WY+Li42uk7O5Rv5lBV/+tg9io2KN/cIbDHUJullQXK
t3BYvvu62CkZVijf0sHHvH77Yz1mKN/KgUlB6xf36j/2EL61Q/Fqa/tNixig
8jYOxr1vvzse+AmVt3V4b/nrn5PeN3sAR0JwWA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQEf7MVCt+7emK3kABVweB5VwSx6RRHK53C4nVhn
6GsK4ws42Kj9f5YzTQHKF3EoVPzp2/1aHsqXcDi1LCXzym05KF/Gga1i1pWQ
ybJQvoLDmg8H+pKiZaB8JYfG33uXvfopBeWrOJS1MyVx7JCE8tUcbgh+ksws
kYDyNRz+Fin6llqIQ/laDlMbbBcLOolB+ToO2v1u55xOi0D5eg7ZEeyBydOF
oXwDB0O3WTu9zgpB+YYOAjqG0uf+C0L5Rg7rpddsv+TND+UbO1zccfXLjR/c
UL6JQ1X9r4PZq9igfFOH4tXW9psWMUD5Zg7vLX/9c9J7Zg8Asi5X1A==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVw2D9txaTSi4pQPoeDatBW
/6+mML6Aw8GFh3XZ5yhA+SIO/tbLeuZ+kYfyJRxUeHn0bi6Tg/JlHBZzTt+Q
XiML5Ss4COaw7ZyjIQPlKzmcMNhd0nNWCspXcdjnL3Rv9ypJKF/N4Wr0Q8uX
/8ShfA2Hz22uEa5GML6Ww5u+c5vsL4lC+ToOfsUC1dOOikD5eg5TVf9GMswX
hvINHB7v+dugbS4E5Rs62Bj5tPMlCEL5Rg7bPkzQlzrLB+UbO+w9bvVO4zEP
lG/iMPFxcbXTd3Yo39Rh+e7rYqdkWKF8M4faeZf3iD1khvLNHYx73353PPDT
HsK3cHhv+eufk94zKN/SgZt5bdWryR/tAfKSZYc=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwSHkq5sR/QxHK53DI7POZ
u88VxhdwyPZ7xKW9XgHKF3EQ4U9qmigA40s4fPnt+4P1vhyUL+MgL/r6kMde
WShfwSHk8Tq9l4tloHwlhwObz7zOnysN5as43M+srrGokILy1Ryc33upNzVL
QvkaDqfi1n/aZy4B5Ws5RCpZLLgRJg7l6zhMX7ZwhZKcGJSv52A2+UiGp5Ao
lG/gEJP06LHOC2Eo39BBU4X9yXd3GN/I4fGevw3a5kJQvrEDN/PaqleTBaF8
E4fXd9Rb9JsEoHxTByYFrV/cq3mgfDOHnzqTapbncEL55g7yHr6WYqtYoXwL
NL6lQ/Fqa/tNixigfCsH49633x0P/LSH8K0d3lv++uek9w3Kt0GTt0WTt4O6
96M9AGZSdb0=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw4BWbGyB6UxHK53BQPhn6
3MgVxhdw+NSnfjB0rQKUL+KwWOnf/KeCML6Eg+jcXUkyl+WgfBkH3iIj68tN
slC+gkPooXMzPK1loHwlB1/rvs1bf0hB+SoOnIW+Ak8PSkL5ag7c3eaVa/dJ
QPkaDkWSudff1otD+VoOZ50jJJ/+EIXydRwUHotOXRwJ4+s5nEuM+Pj5pjCU
b+BwJODA7IZdQlC+oQPX4h9xbkcFoXwjB2mJxy8mThKA8o0dVtsoZWgc5ofy
TRycQ/6YsbrxQfmmDvL/zp62+MAF5Zs5fNh88W+tKCeUb+4w8XFxtdN3dijf
wqGq/tfB7FVsUL6lAyT8maB8KwcmBa1f3Kv/2EP41g7vLX/9c9J7Zg8AjZhq
zA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw2LNe2jnhuiKUz+Gw10Wh
aJ0tjC/g4H1SSHflHAUoX8RB4kVSuiAfjC/h0Ff/2s2AQR7Kl3F491OCQ+K0
LJSv4PBcad+1Bb4yUL6Sg2jkxUpDK2koX8Xhe7LF2QmvJaF8NYfYfp2Z9/Il
oHwNB7Wa6xcPu4tD+VoOp3+96GpbKgrl6zhEePQLPNovAuXrOWz8JDW/KkMY
yjdwaHqS1PtkjSCUb+iwTNnrlskhASjfyGG1jVKGxmF+KN/YYe9xq3caj3mg
fBOHs1IfXk0R4ILyTR1q513eI/aQGco3cwiPMlpXpPTfHsI3R+NbODApaP3i
Xv0Hyrd0eG/565+T3jco38qheLW1/aZFDFDzrNH4Nmj6bdH4dmj22aPpd3Dg
Zl5b9WryR4h8gwPcfgDfq4N3
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw+P05a/WT04pQPoeD5NmO
79s1YXwBh/1HlOUOTVGA8kUcYtOvP8j9IQ/lSzjkGUk0bNgrB+XLOEhKB3SY
dMpC+QoOXKx2TmczZaB8JQehOD7RU2bSUL6Kg36YifKnL5JQvpoD44RL/142
SkD5Gg7BM/8/DpARh/K1HEp+rVQytBKD8nUcPgRe7p9qJgrl6znMbbhaxb9O
GMo3cNh7vP3+j3ohKN/Q4VvXOvHYL4JQvpFD8Wpr+02LBKB8Y4fVNkoZGof5
oXwTB/l/Z09bfOCC8k0dZl/j/rnMlBvKN3Ooqv91MHsVG5Rv7uBjXr/9sR4z
lG/hAAlvJijf0iE8ymhdkdJ/ewjfysG49+13xwM/oXxrNHkbNHlbByYFrV/c
q//YAwBF2HTn
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwOLCv9ZfnJUUon8Ohs2T7
jru2ML6Ag1iYtXXRIgUoX8ThVPe9NRP5YHwJhx9FYfNZJeWhfBkH5Q8P9l25
IwvlKzhENmyxSdkhA+UrOVw2mDw9Y440lK/isMj195nyFikoX81h0oL7v+5n
SUL5Gg7ey7siuPkkoHwth2V/V8irzRGD8nUctKItju7zF4Xy9Rymqv6NZJgv
DOUbOFyyn8QiflcQyjd0qNQ8/jPVXwDKN3KI0p7oca6CG8o3djDuffvd8QAn
lG/isHFd/hS9aA4o39RB3sPXUmwVK5Rv5vDe8tc/Jz02KN/cQWczC5tZHzuU
b4Emb+kACX8mKN/KgZt5bdWryYxQvjWU/9EeAPIBaEU=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw+HT6zOed5xWhfA4He3Up
/z/GML6Ag+eKdbEXFyhA+SIOwrXP3Do5YXwJB9WsuWaZwvJQvoyD8ocH+67c
kYXyFRzCEie0ey+TgfKVHAqnrl/0OlgayldxWHe+MtDKXArKV3P4tDjygLyR
JJSv4aDsWxrWECsB5Ws5yB259+OSrziUr+NQOUHkqiejGJSv52ByqbdcdZcI
lG/gkHRCaZdxgzCUb+iQUBj7+9QLQSjfCI1v7BA5a+1CUR0BKN/EYb30mu2X
vPmhfFOHizuufrnxgxvKN3NgUtD6xb2aB8o3dzj6mT84qhDGt3Aw7n373fEA
J5Rv6fDe8tc/Jz02KN/KIbDHUJullQXKt3YIjzJaV6T03x7Ct4Ga/wfKt3Uo
Xm1tv2kRA1S9HZp6ezS+gwM389qqV5MZIeobHKD2P7MHACySgjY=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwmFgpenLKdUUon8NhhvhD
2c8WML6AQ1EM/9RDsxSgfBEH8RsKJVtFYHwJh9fn9ZNkH8tB+TIOZ4s+MeUv
lYXyFRz2Xy21NiiSgfKVHPJr/FNdfaWhfBWHFW6OUzf9kYTy1RwCNip4hu2Q
gPI1HObKTd03204cytdymHNe1ZOtSwzK13Eo2XlI4bCXKJSv5zC34WoV/zph
KN/AIdp9P9evDUJQvqFD05Ok3idrBKF8Iwdft2NHn9gKQPnGDuul12y/5M0P
5Zs47D1u9U7jMQ+Ub+rwU2dSzfIcTijfzGHjuvwpetEcUL65w/Ld18VOybBC
+RYO3Mxrq15NZoTyLR0Cewy1WVpZoHwrh/eWv/456X2zh/CtHYx73353PPAT
yreB8wGG3G9L
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwOMAg9ffVWUUon8PBqPvR
qzodGF/A4c7CY2nSMxWgfBGHBn6ljUFsML6EQ6R606+nPPJQvoyD8XzNBPmN
slC+gkOTTL3ghA0yUL6Sg931jXGb3KWhfBWHyuAunRP/JaF8NYfjjhu4Hh2S
gPI1HF6nbGr6tEYcytdy4FlpHrhnvhiUr+Ow4vbhqXOviUL5eg7x17fGXa4Q
gfINHJ5kaVr9bReG8g0dSjKW7/MXE4LyjRy6jVLvzE4QgPKNHcKjjNYVKfFD
+SYO33h3Nv4x5YHyTR1OHLUtL9nFAeWbObRNzLaqlmeH8s0dAnsMtVlaWaB8
CzS+pQOTgtYv7tV/7CF8Kwdu5rVVryZ/tAcANa9ioA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVw+GlQcoz3mCKUz+Fwbb/p
1G5dGF/AYen9Q59kJihA+SIODjuZev+9lYfyJRwkS2JPlJyQg/JlHJStJs/o
qJCF8hUcuv7LL/0YKwPlKzlI+uanHhKUhvJVHPTDTJQ/fZGE8tUcmnLedi+/
LgHlazg08H9viTMVh/K1HKY22C4WdBKD8nUcaqPtbbaEiEL5eg4Gsc3L964Q
gfINHJJOKO0ybhCG8g0dHs02M709WQjKN3I4eU3ly28eQSjf2GG99Jrtl7z5
oXwTB+eQP2asbnxQvqmD35o+19StvFC+mYP8v7OnLT5wQfnmDlX1vw5mr2KD
8i0cIOHNBOVbOoRHGa0rUvpvD+FboclbOxSvtrbftIgByrdBU2+LxrdzeG/5
65+T3jMo3x7OBwCQN3r8
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQEf7MVCt+7emK3kABVwcBG6E+l4WRHK53Co2vlt
7l53GF/A4VvJjPPOGxSgfBEHVbOdnNu5YHwJh+Ql917teSYH5cs4aFyfsYy5
VxbKV3DYWPj09ZpIGShfyeHxA53N1kbSUL6KQ5/1FM1GLikoX82B0Up753lO
SShfw8HiaH31vF3iUL6WA/flL4X/6sSgfB2HdbKXlbSei0D5eg4q5YyTzd4L
Q/kGDtMf9jDe+ygE5Rs6aPopi7jmCkL5Rg6Kjumdpf8EoHxjh/8Mgf8TSvih
fBMHvzV9rqlbeaF8U4drvB0ZP/1gfDOH2de4fy4z5YbyzR0mtDDvuB/LBeVb
OJw4altesosDyrd0kPfwtRRbxQrlW6HxrdH4Ng4/dSbVLM/hhPJtHarqfx3M
XsUG5duhqbd3qJ13eY/YQ2Yo38EBEt9MEH6DgwOTgtYv7tV/7CHyjg7vLX/9
c9L7BuE3oPEZnBy4mddWvZr8ESrv5GDc+/a744GfUHlnVH6DM1T/M3sAe6ib
sw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwuHDo4ZG/1xWhfA6HnXxz
A8LtYXwBB5tmf/mmDQpQvogD75XlWsESML6Ew+vz+kmyj+WgfBmHnicbpCp2
y0L5Cg6KQnVyzP0yUL6Sw6YVx5OadKShfBWH/6a5te2HJaF8NQdXDuY/XzZK
QPkaDrf/S++OLhGH8rUc2D7wX5uYIQbl6zgk+Wmu+McjCuXrOaiUM042ey8M
5Rs4/PB+ytHoIwTlGzoIvThwaHWQIJRv5FC6O8DG4gcflG/skH1ix77LO7mh
fBOHizuufrnxA8Y3dfipM6lmeQ4nlG/m8N7y1z8nPTYo3xyNb+EQ2GOozdLK
AuVbOkDCnwnKt3LgZl5b9WoyI5RvDdX/zR7Ct0Hj20LVf4Ty7dD49g7GvW+/
Ox74CeU7wOUBN4mCwA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwcA2r3153RRHK53BoWzqn
+rwVjC/gsM5zibb+fAUoX8SBY5ND98178lC+hENNyY1rbnvkoHwZhybV6Lg7
s2ShfAWHSyZRn55Pl4HylRwOxvy/l+gnDeWrODjmqlplhkpB+WoOfTOvVpd7
SEL5Gg4PfsqFNhlIQPlaDgFB36TXN4lB+ToOZm+e3V3DLgrl6znI7Sze1n5a
GMo3cIh238/1a4MQlG/oIKBjKH3uvyCUb+Sg6JjeWfpPAMo3drA8t3vBsQcw
vonDeuk12y9580P5pg4rHA8fPSbJC+WbOfzUmVSzPIcTyjd3OHHUtrxkFweU
b+Hw3vLXPyc9Nijf0mH57utip2RYoXwrh+LV1vabFjFA+dYOxr1vvzse+GkP
4dug8W2h5j2zBwBqane9
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwcPbwrLU4qwjlczj0+6xa
UaQP4ws4LJ+3nltltgKUL+LQtcr4SQIXjC/hIDOlTiiCTR7Kl3EIWPq2ZNIf
WShfweGcj6zt550yUL6Sw6OfS5gDZ0pD+SoOwXEi3VM9pKB8NYcHJ14L5opL
QvkaDnwVWmH3JotD+VoOO09HbguPFIPydRxc5jwQ2tkpCuXrORjENi/fu0IE
yjdweJKlafW3XRjKN3T41rVOPPaLIJRv5CAt8fjFxEkCUL6xw5KTi8u4S/ig
fBOHa7wdGT/9eKF8Uwf5f2dPW3zggvLNHHQ2s7CZ9bFD+eYO3Mxrq15NZoTy
LRzeW/7656T3zR7Ct4TKf7QHAJ7kYCU=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVweNj21PXsGUUon8NBdbfH
JBcTGF/AwfehzNWABQpQvohDZ2X+mxQeGF/C4ZDXyZWS++WgfBkHtS1fp5uv
kYXyFRxCDzDbNiyVgfKVHCpuBz7oKJGG8lUcCm/9EXCPl4Ly1RwqcvstSoMl
oXwNh5VZcyV0topD+VoOc86rerJ1iUH5Og5mk49keAqJQvl6Du9yj3w1/iYM
5Rs4vBGOTP3WKQTlGzrYh3+J8ZMWhPKNHLqNUu/MThCA8o0drvF2ZPz044Xy
TRz2Hrd6p/GYB8o3dThx1La8ZBcHlG/mIO/haym2ihXKN3fgZl5b9WoyI5Rv
4QAJbyYo39LBuPftd8cDP+0hfCs0vjVU/0co38aBSUHrF/fqP1C+rcN7y1//
nPSe2QMAIllzAQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw2Hdmg3vzdUUon8Nh/TfJ
jw2+ML6Aw9ziFRlmaxWgfBEHLpdjP7q5YHwJhyS/h1sPPJSD8mUcGjZNa59+
RRbKV3AIebxO7+ViGShfyeEhS9f0s5ukoXwVh+cbayq+VElB+WoOfTOvVpd7
SEL5Gg5/j8h3b7klDuVrOcxaedD561oxKF/HgWnG/N8eDaJQvp6D0NqrmR/q
RKB8A4ekE0q7jBuEoXxDh3Xu74PKeWB8I4fUucuYqhcIQvnGDpGz1i4U1RGA
8k0cwqOM1hUp8UP5pg5MClq/uFfzQPlmDhvX5U/Ri+aA8s0d3lv++uekxwbl
Wzj4mNdvf6zHDOVbOnAzr616NZkRyrdC41tDzf9jD+HbQM37Zg8A6vlwUg==

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVweNXtnSR1RhHK53C4nVhn
6GsK4ws4hDx/enLXZAUoX8ShcNc335T38lC+hMNCsY2Tkh/IQfkyDmwNIa9v
TJWF8hUcQg+dm+FpLQPlKzmIysZqBTNJQ/kqDv9CxWS7b0hC+WoOWtfWCnHM
kIDyNRz4KrTC7k0Wh/K1HC7n3Nl5IkUMytdx+M2Xbn/QVRTK13Pw8Oq5tSlS
BMo3cFi45IRo/zUhKN/QQUDHUPrcf0Eo38hBWuLxi4mTBKB8YwddW72Q/c94
oXwTh2+8Oxv/mPJA+aYOUdoTPc5VcEP5Zg5tE7OtquXZoXxzNL6FAyS8maB8
SwcmBa1f3Kv/2EP4Vg7vLX/9c9L7BuVbQ/nP7AGIAGfh
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEf7MVCt+7emK3kABVw+HT6zOed5xWhfA6Hqytn
nz9oA+MLOFh85W3uW6YA5Ys4mBn+3b9TCMaXcHh9Xj9J9rEclC/joNuf4CAz
RxbKV3Bo5eD4szZfBspXcnD2vCfzzlMayldxePX4wg95OSkoX83hjN0Tt6Cz
ElC+hsMcQXu2iz/FoXwtB8UFjSKOZ8WgfB0HhceiUxdHikL5eg5Rn26bqf4V
hvINHE5WutikqMH4hg7futaJx34RhPKNHJ7pKxnnacL4xg67pabM3fleAMo3
cfjPEPg/oYQfyjd1WHJycRl3CR+Ub+bApKD1i3s1D5Rv7nBW6sOrKQJcUL6F
g7LXtGtRK2B8S4fZ17h/LjPlhvKtHNomZltVy7ND+dYOgT2G2iytLFC+jcPy
3dfFTsmwQvm2aPJ2Dj7m9dsf6zFD+fZo8g4Oxaut7TctYoDwGxwc3lv++uek
980eIu8Idf8fCL/BEU3eCZXf4OTAzby26tXkj1B5ZzT9zg6Q9MUEtd/FITzK
aF2R0n+ovAtcPwDCt6FN
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw+MQxOyL3kiKUz+GQJZYQ
9dUWxhdwWNm4W7x0rQKUL+JgHrL/UZMcjC/hYKx+6Np9JXkoX8Zh6kYWtrcP
ZKF8BQcmBa1f3KtloHwlh6NC2S3c3tJQvorDz6gtjm9YpaB8NQcu7eZYzg8S
UL6Gw+5FcnNqpGB8LYfTmnkbZP6IQfk6DpUTRK56MsL4eg4er67v4+sWgfIN
HN7lHvlq/E0Yyjd0eLznb4O2uRCUb+Sg6JjeWfpPAMo3duDNEXrdUQjjmzis
l16z/ZI3P5Rv6nBxx9UvN35wQ/lmDieO2paX7OKA8s0dlu++LnZKhhXKt3Co
nXd5j9hDZijf0qF4tbX9pkUMUL6Vw3vLX/+c9L7ZQ/jWUP4zKN8GTd7WgZt5
bdWryR/tAVDBdOU=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAmIQDQEf7MVCt+7emK3kABVw8Kh47mhxRRHK53Bgn71l
T5UNjC/g8MS8IdNwugKUL+LAscmh++Y9eShfwuH0KrmKoyvkoHwZh9/fVrBO
S5eF8hUc2kOVJKTDZaB8JYdX0hY3F8tJQ/kqDkyczRadGlJQvpqDdKfV+jsq
klC+hgNfhVbYvcniUL6WQ+UEkauejGJQvo6DIsvdB5//iED5eg5VldrPr6nC
+AYO69zfB5XzCEP5hg7futaJx34RhPKNHHzdjh19YisA5Rs7OIf8MWN144Py
TRwu7rj65cYPbijf1OGs1IdXUwS4oHwzhxNHbctLdnFA+eZofAsH49633x0P
cEL5lg4/dSbVLM+B8a0c2iZmW1XLs0P51g7Ld18XOyXDCuXboJln66CzmYXN
rA+m3s4hPMpoXZHSf3sI396heLW1/aZFDFB5BwcmBa1f3Kv/QOQb0PgMjg7c
zGurXk3+CJV3RDPPCdW8Bieoekao+c5o8s5Q//6E6ndBs98FzXxXh/eWv/45
6T2DyqPxGdxQzWtwQ3O/O5r5aHwGDwcf8/rtj/WYoe5D4zN4ornfE819Xmj2
e6GZ742m3xstfHzQ3OeDGt4MvnA+ADPX6tY=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVweG86JaT2giKUz+GQfLbK
8bkVjC/gMNHi5amOOQpQvogD65RDCrzcML6Ew9aFBfe2c8lD+TIOu9jjWqfd
k4XyFRyYFLR+ca+WgfKVHBIuyW+bHy0N5as4LDu091jWCUkoX82hxNKqQ3ip
BJSv4fC3SNG31EIcytdy6KqLE1/zRRTK13FYOrVYcKcDjK/nEKC/QKlEQgTK
N3DYe7z9/o96ISjf0CGhMPb3qReCUL6Rg6/bsaNPbAWgfGMHvzV9rqlbeaF8
E6B+q3caj3mgfFOHCS3MO+7HckH5Zg4+5vXbH+sxQ/nmDpDwZYLyLRyKV1vb
b1rEAOVbOnAzr616NfmjPQB4j2C+
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVw4BWbGyB6UxHK53BIPlLA
22wH4ws4TNwy/RnDagUoX8Sha5XxkwQuGF/CgWXdhRvJu+SgfBkHpi2REb/n
ykL5Cg5KTDo7WCpkoHwlh46zuWKFKtJQvoqD9S6Gtbb/JKF8NYfM3RMyt96U
gPI1HFZmzZXQ2SoO5Ws56GxdHPpntxiUr+NgJsW5+OMCUShfzyGGQ6phhqUI
lG/gcLLSxSZFTRjKN3Rw2/syy+GiIJRv5FC82tp+0yIBKN/YQddWL2T/M14o
38RB/t/Z0xYfuKB8U4eq+l8Hs1exQflmDoE9htosrSxQvrlD7bzLe8QeMkP5
Fg7czGurXk3+aA8A5MtY8Q==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwiGD5eWTiWUUon8PBWk9b
vd4WxhdwKF5tbb9pkQKUL+Jw57l0+uy/8lC+hMOqT+ri7+/LQfkyDn5r+lxT
t8pC+QoO1x5GTt2TIgPlKznICOxkn+ImDeWrOLSx2yvwqUtB+WoOFQ2C08sv
SkD5Gg4rs+ZK6GwVh/K1HBbwM0n9cRWD8nUcIjz6BR7tF4Hy9RyEuMX3PNsj
DOUbOBjuklZ/VCoE5Rs6PNNXMs7TFITyjRxKdwfYWPzgg/KNHZS9pl2LWsEF
5Zs4yHv4WoqtYoXyTR2W774udkoGxjeDhg8DlG+OxrdwYFLQ+sW9+o89hG/p
YNz79rvjgZ9QvpXDe8tf/5z0vkH51mh8GzS+LZT/DMq3g/MBF+R0dw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw+Mo459DHy4pQPodDZ8n2
HXdtYXwBB2XZ50fVVypA+SIO61j5hdo4YHwJh1Wf1MXf35eD8mUcmP4t3D+v
XhbKV3BYM9Oi5a2tDJSv5FDOEG9/77MUlK/iUC/73zgvTxLKV3MQc3ycs6ZM
AsrXcCjomPWxsFAcytdy+Lg9KFjZTgzK13Ewk+Jc/HGBKJSv59B0PDz2l48I
lG/gsPd4+/0f9UJQvqFD8cb1nQFVglC+kUPkrLULRXUEoHxjB11bvZD9z3ih
fBOHb7w7G/+Y8kD5pg4b1+VP0YvmgPLNHOQ9fC3FVrFC+eYOVfW/DmavYoPy
LRxq513eI/aQGcq3dChebW2/aREDlG/lwM28turVZEYo3xqNb+PgY16//bEe
TL8tVP6jPQD4GW/U
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwaNXfzVZ/SRHK53A4bj/r
s4YVjC/gcOZHwP+NixWgfBEHHZuMn+lMML6Eg2RJ7ImSE3JQvoxD2P8lEd2N
slC+gkPWm/ryT4EyUL6Sg7zBhoWFqdJQvorDrdQSuRQWKShfzcFA4ec/6+US
UL6GQ+XGwB8aVeJQvpaD4oJGEcezYlC+jkO8mS3b3bOiUL6eg8ztCAeBiSJQ
voHDkyxNq7/twlC+ocOV1G+cGjsFoXwjB94codcdhQJQvrFD9okd+y7v5Iby
TRzOSn14NUWAC8o3ddi4Ln+KXjQHlG/mIO/haym2ihXKN3fgZl5b9WoyI5Rv
gca3dDDuffvd8cBPewD4XV7p
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwuLta2P3NdUUon8OhXXvF
oskWML6AA+MHxiCVVQpQvohDJZ/lhlYGGF/CoTLolEPbcTkoX8bBfuJuufhV
slC+gkPXf/mlH2NloHwlB9X/3RN/SkpD+SoO0zPFGRbKSEH5ag7LIl5mmNtL
QvkaDjMOzmNuD5OA8rUcHmqnHuLWEYfydRxUCi/e/CkqBuXrOfgVC1RPOyoC
5Rs4TE79MDlmuRCUb+jQ9CSp98kaQSjfyEFa4vGLiZMEoHxjB11bvZD9z3ih
fBMH+X9nT1t84ILyTR1+6kyqWZ7DCeWbOZw4altesosDyjd3COwx1GZpZYHy
LRxq513eI/aQ2QEA+rFbKA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwuCApsvz3KUUon8PhgsWr
xPmaML6AwwFu9amyXQpQvojD+pkhT9eclYfyJRxK929IrpggB+XLOJwSOpi3
ok0WyldwWLc0VvGtoAyUr+RwpupU4iJxaShfxaHPeopmI5cUlK/m4H9dN4Hz
hwSUr+GwfPWVG9/fiEP5Wg6KCxpFHM+KQfk6Dk9Zp33bPl0UytdzaDoeHvvL
RwTKN3DQ+dC3bnu/MJRv6DBz//LyUB0hKN/IoXjj+s6AKkEo39hBWuLxi4mT
BKB8Ewce4UPlBS/5oXxTByYFrV/cq3mgfDOHnzqTapbncEL55g4+5vXbH+sx
Q/kWDsa9b787HvhpD+FbOnAzr616NfmjPQA3YGPy
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEf7MVCt+7emK3kABVw8Gw3E+U4rwjlczis2xnJ
4aQP4ws4SJRc2PZungKUL+IgZrrMbyMHjC/hYK8V52bCJw/lyzh8+pr04j67
HJSv4BBh9uE933sZKF/JQYD/T9Kis9JQvorDnNe9cb09UlC+moMk/xSrBZaS
UL6Gw4OfcqFNBhJQvpbDe/s8z4es4lC+jsNZ5wjJpz9EoXw9B+3jEl+XPBSB
8g0coj7dNlP9KwzlGzqwhTJu/nBYCMo3cijJWL7PXwzGN3awPLd7wbEHAlC+
iUN4lNG6IiV+KN/U4RvvzsY/pjxQvhka39zhp86kmuU5nFC+hcPy3dfFTsmw
QvmWaHwrB+Pet98dD/y0h/Ct0fg2UPv/Q/m2DtzMa6teTWaE6rdzYFLQ+sW9
+g9U3h5NvwMqv8EBTb0jKr8Bjc/ghKYfjc/gjKYfjc/g4vDe8tc/J71vUHkE
HwC7T6n/
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwSE/2n8h4TRHK53BQlNzq
c9QUxhdwmHjfQS1osQKUL+Jw7d+09jscML6Eg8vCj6GTLstB+TIOvEVG1peb
ZKF8BQfGx3XPsj1koHwlh00rjic16UhD+SoO04Vs9697LAnlqznIex6VmzxP
AsrXcLB0v+Kwab04lK/lwLPSPHDPfDEoX8dhZcHZixl9olC+nkNfQemq6GAR
KN/AoXczp/a++0JQvqHDJftJLOJ3BaF8IwdpiccvJk4SgPKNHbZ9mKAvdZYP
yjdx+Ma7s/GPKQ+Ub+ow8XFxtdN3dijfzCE8ymhdkdJ/ewjf3IFJQesX9+o/
UL6Fw3vLX/+c9L5B+ZZQ/jN7APoQYwM=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwqDxiff/kfUUon8NhntQ7
a20HGF/AIUXm7VqDBQpQvojDGd55D2VYYHwJhwxl7cmsT+SgfBmHnicbpCp2
y0L5Cg5M8p9NvRpkoHwlh7DrB9hkRaShfBUHrv/GWW/uSUL5ag52Yqprfh2R
gPI1HNZcl32wfIk4lK/lsOzvCnm1OWJQvo7D78IF9b4ZolC+nsOFNXs7m6+J
QPkGDk+yNK3+tgtD+YYOP7yfcjT6CEH5Rg5CLw4cWh0kCOUbO/i6HTv6xFYA
yjdxYFLQ+sW9mgfKN3WY0MK8434sF5Rv5vBTZ1LN8hxOKN/cYeO6/Cl60RxQ
voWDzmYWNrM+dijf0mH57utip2RYoXwrBx/z+u2P9ZihfGs0vo1DeJTRuiKl
//YQvq2Dce/b744HftoDALnCb2A=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwiDW24dh4TRHK53C4unL2
+YM2ML6Ag6/p9INvlylA+SIOf71s1R4Jw/gSDvxyAUvtBOWhfBmHjfPnlK1h
lIPyFRwmHth7UPWZDJSv5HA690jTkXXSUL6Kw+U1z8/wZEpB+WoO98IeVh7h
loTyNRxWZs2V0NkqDuVrOdw+vuXW9WIxKF/H4SnrtG/bp4tC+XoOc3fYRE9e
JwLlGzjEJD16rPNCGMo3dIh238/1a4MQlG/k8PqOeot+kwCUb+xQujvAxuIH
H5Rv4nBxx9UvN35wQ/mmDu8tf/1z0mOD8s0cIOHJBOWbOxj3vv3ueOCnPYRv
AVX/zB4A82BmMw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw6N7yOGD3VUUon8Ph++pd
ZVfMYXwBh6clZmpCixSgfBEHVbOdnNu5YHwJh+0bqt6EXJOD8mUctnY/erlt
oSyUr+Dw+sbiCMdJMlC+ksMGux1WO2KkoXwVhw0JPubbXKWgfDWHt+c/5tga
SEL5Gg7hbF/uhJlKQPlaDn1l9U0298SgfB2HeDNbtrtnRaF8PQeTS73lqrtE
oHwDh6QTSruMG4ShfEMHAR1D6XP/BaF8IwdpiccvJk4SgPKNHV7fUW/Rb4Lx
TRy2fZigL3WWD8o3dQjI0Tr9VRImb+bAW2RkfbmJF8o3d/ipM6lmeQ4nlG/h
0DYx26panh3Kt3Soqv91MHsVG5Rv5RAeZbSuSOm/PYRv7cCkoPWLe/UfKN8G
Td4WTd7OgZt5bdWryR+hfHs0eQeH95a//jnpfYPwG2D8Z/YA3v2Djg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwSAjZUatwThHK53AQ+Mpa
q2MC4ws4vC2r75s8XQHKF3E4NGH1eaWP8lC+hIPv57M1vz7KQfkyDsofHuy7
ckcWyldwOK++b/HD5TJQvpJDfo1/qquvNJSv4nA8YMWlOjspKF/NIXtplVSZ
jiSUr+Gw1uPWsyJGCShfy2GG5e5pbw+JQfk6Dj3iFyZ9KxSF8vUcaudd3iP2
UBjKN3CYnPphcsxyISjf0CGGfdEsaVdBKN/Iwdft2NEntgJQvrFDjtOEvXwL
+aB8E4e9x63eaTzmgfJNHTauy5+iF80B5Zs5LN99XeyUDCuUb+4QHmW0rkjp
vz2Eb+FQvNraftMiBqi8pYNx79vvjgd+QuWtHLiZ11a9mvwRyrd2eG/565+T
3jMo3waNbwvnAwBsrXpb
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwWOV00EjquiKUz+EwKSbb
YZMdjC/goKFs0HtyjgKUL+Ig9HR3mDUvjC/hkLzk3qs9z+SgfBmH8E0aSRGb
ZKF8BYc2MaWrhkkyUL6Sg2jkxUpDK2koX8WBYXJ710wlKShfzaHm2Lp7XJ8k
oHwNh8VM86epWsH4Wg7v7fM8H7KKQ/k6DpkpXyv01UWhfD0H3efSDVwsIlC+
gUNk/CGPqAhhKN/QwfLc7gXHHghA+UYO4VFG64qU+KF8YwfeIiPry028UL6J
Q/aJHfsu7+SG8k0dfupMqlmewwnlmzl82Hzxb60ojG/u8N7y1z8nPTYo38KB
m3lt1avJjFC+pQMk/JmgfCs0eWuo/m/2EL4NVP4jlG/rwKSg9Yt79R8o3w7q
/v9Qvj2a+Q4OtfMu7xF7yAzhNzigqXdE5Tc4wu0HAIkHhyo=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwOJ+wOaPnjiKUz+Hw6vP3
47UGML6AQ3U6x747PQpQvojDoQmrzyt9lIfyJRw+1H2oWXxGDsqXcXBcUXXk
ULUslK/g4H3t02JJUxkoX8nB17pv89YfUlC+isP3ZIuzE15LQvlqDnWy4ks/
PZWA8jUcrl+tPdVlA+NrOajVXL942F0cytdxUCm8ePOnqBiUr+egfVzi65KH
IlC+gUPUp9tmqn+FoXxDh+7epaprmWF8I4eSjOX7/MWEoHxjh5PXVL785hGE
8k0cuo1S78xOEIDyTR14i4ysLzfxQvlmDmelPryaIsAF5Zs7vLf89c9Jjw3K
t3DgZl5b9WoyI5RvCZX/Zg/hW0H5z+wBoMxu6A==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwmH8zgoPxgiKUz+GgfDL0
uZErjC/gwPP+Uf7NwwpQvojDga9RLLrqML6Eg/V+dzVGMXkoX8Zh4VVJc+Yv
slC+goM318U5c/bJQPlKDh5FSXsvbpWG8lUcFr6P538xUQrKV3MoiKs7qOIj
CeVrOFjurL8vqicB5Ws5vIs9uD3xmBiUr+Nw8kpLa+lJUShfz+HCmr2dzddE
oHwDh5fTihzX2gtD+YYOBdc+H0pUFILyjRyKN67vDKgShPKNHZxD/pixuvFB
+SYOe49bvdN4zAPlmzpMfFxc7fSdHco3c/Axr9/+WI8Zyjd3YFLQ+sW9+o89
hG/h8N7y1z8nvWdQvqUDN/PaqleTP0L5Vmh8awfj3rffHQ/8hPJtoPq/2QMA
trdygQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQEf7MVCt+7emK3kABVw4O1LDJ5wRRHK53DIbTtl
NtcMxhdwCFeZrhQ0XQHKF3GID3VsussA40s4xISvuvh3kRyUL+OgJy2tsDpe
FspXcAiw4HmebiUD5Ss5uHcu9xI3lIbyVRwOX9z1nY1HCspXc8jcPSFz600J
KF/DQe7IvR+XfMWhfC2H95a//jnpiUH5Og7X2dqvy34SgfL1HGKSHj3WeSEM
5Rs4TH/Yw3jvoxCUb+iwL0b1oBw3jG/kcPKaypffPIJQvrHDMmWvWyaHBKB8
E4f10mu2X/Lmh/JNHfzW9LmmbuWF8s0corQnepyr4IbyzaHuY4PyLRx8zOu3
P9ZjhvItHSDhzwTlWzlwM6+tejWZEcq3dihebW2/aREDlG/jEB5ltK5I6b89
hG8LVf8RyrdzMO59+93xwE8o3x6N7wB1zzcIvwGNz+CIal6DowOTgtYv7tV/
oPJOqPY3OKG53xmV3+CM5h8XNPvR+AyuaPa7osm7QfnP7AFPgLdu
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwsJ3pV3/3vCKUz+FgN0/m
xD0DGF/AoZJ31vo3ExWgfBGHAPO5of5f5aF8CQfxv5d4XS7KQfkyDj1in7j3
zJGF8hUcfH/8NArOkYHylRyitCd6nKuQhvJVHK5c871Q5C0F5as5LN10dHHH
ZQkoX8NBlfNchN5TcShfyyGy9p1rz1cxKF/H4eKa859VckWhfD0Hifg9l/rc
RKB8A4fezZza++4LQfmGDvbhX2L8pAWhfCMHJgWtX9yreaB8Y4efOpNqludw
QvkmDm0Ts62q5dmhfFOH2nmX94g9ZIbyzRwg4ckE5ZujyVs4GPe+/e544Kc9
hG/pwM28turV5I/2ADYjY1Y=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwOLzOJOX6JUUon8Pho/Fr
XzdrGF/AYbHm7u9mMxSgfBGHtLW7/zN8k4fyJRxuT3tW/+qgHJQv4xDrulab
cZsslK/gsLHw6es1kTJQvpIDV9vhZVKTpaF8FYd5C0wjEwyloHw1h1RVQ0a7
0xJQvoYD75c5L73niEP5Wg6sJbLa9TvEoHwdB61oi6P7/EWhfD2HpBNKu4wb
hKF8AweuxT/i3I4KQvmGDvbhX2L8pGF8I4dKzeM/U/0FoHxjB11bvZD9z3ih
fBOHvcet3mk85oHyTR2UvaZdi1rBBeWbOcy+xv1zmSk3lG/uYNz79rvjAU4o
38KhbWK2VbU8O5Rv6SDv4WsptooVyrdyKF5tbb9pEQOUb+3Azby26tXkj/YA
8oVmMg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwmLpVLXHRJUUon8Oh32fV
iiJ9GF/AoX9hlYLdBAUoX8TB0eXYars38lC+hIPJYuWkjXPkoHwZB3v2qFrW
cFkoX8HhwvN9USsMZKB8JQeWWTviJl+XgvJVHL6yv1qWvlESyldz4P+yLvit
kQSUr+Gw902wn/9iMShfy+E3X7r9QVdRKF/HIerTbTPVv8JQvp7DyUoXmxQ1
GN/AwaWh4q9huyCUb+jw+o56i36TAJRv5BCQo3X6qySMb+wg+EZE7IMYH5Rv
4vCNd2fjH1MeKN/UYfY17p/LTLmhfDOHCS3MO+7HckH55g5tE7OtquXZoXwL
Bx/z+u2P9ZihfEs0vpUDN/PaqleTP9oDAITGYho=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVw+Hg4UO3mWUUon8OhLaHi
XbghjC/g4PH0vs6tGQpQvohDzHUO49dMML6Ew3m33R8m7peD8mUcJOxSJ/wv
loXyFRzWLY1VfCsoA+UrOXy8eEpqha40lK/i0MZur8CnLgXlqzlcfdvA8fqx
BJSv4WA8WXZj3UxxKF/LYc55VU+2LjEoX8ehZOchhcNeolC+nkNVpfbza6oi
UL6Bw8IlJ0T7rwlB+YYOj/f8bdA2h/GNHF7fUW/RbxKA8o0dlpxcXMZdwgfl
mzhc3HH1y40f3FC+qYNx79vvjgc4oXwzh+W7r4udkmGF8s0duJnXVr2azAjl
WziERxmtK1L6bw/hWzowKWj94l79xx4AN59j6w==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwmLTD8XPLfUUon8PBbFVg
UbYdjC/gYMKc+Vt+lgKUL+Jw3p+ne9M3eShfwiHPSKJhw145KF/GQe+Z6s6C
ibJQvoLDs+YNvd/CZaB8JYcbR97Y82tKQ/kqDpvZLx37xSEF5as5rBM89ezl
IgkoX8NhodIcmYJN4lC+lkOdTtXsvA+iUL6OQ3vVkYofc0SgfD2Hl9OKHNfa
C0P5Bg5ue19mOVwUhPINHXiED5UXvOSH8o0csk/s2Hd5JzeUb+zQNjHbqlqe
Hco3cVi++7rYKRlWKN8UjW/mAAlPJijf3MHHvH77Yz1mKN8CTd4SjW/lULza
2n7TIgYo3xqNb4PGt3V4b/nrn5PeM3sAsz5y9w==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwcBG6E+l4WRHK53CI3SIU
+tMSxhdwmCJtFrxvpgKUL+IQsz9Fto4NxpdwePHxFpP+VjkoX8bhctPt6JrZ
slC+gsPdhpSs1cEyUL6Sw5mqU4mLxKWhfBUH1tyGvH8vJaF8NQcxx8c5a8ok
oHwNh498oYc19cWhfC2HeaUrbhkoiUH5Og6b1rfJSdwRgfL1HOI63F7aHhGG
8g0cDHdJqz8qFYLyDR2EXhw4tDpIEMo3cqjUPP4z1V8Ayjd24C0ysr7cxAvl
mzh8493Z+MeUB8o3ddi4Ln+KXjQHlG/msHz3dbFTMqxQvrlDeJTRuiKl//YQ
vgUa39KBSUHrF/fqP1C+FRrf2uG95a9/TnrfoHwbNHlbNHk7NL69Azfz2qpX
kz/aAwCoVnpv
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwUL79b6baJUUon8PhUox5
zx5zGF/A4Zrls00d6xWgfBGH58pvxGolYHwJh3gdy7/tH+WgfBmHv4zF72Ou
yUL5Cg4986Mm7pwjA+UrORS4uVS2p0lD+SoOT6YeaX6hLwXlqzm4u5ZkMv+R
gPI1HBRPfmy30ITxtRxuTE2IWnNBDMrXcVApvHjzpyiMr+ewfPd1sVMyolC+
gUN71ZGKH3NEoHxDBx/z+u2P9YShfCOHmfuXl4fqCEH5xg6yq/9cizEXhPJN
HLZ9mKAvdZYPyjd1uMbbkfHTjxfKN0PjmzvMvsb9c5kpN5Rv4aCzmYXNrI8d
yrd04GZeW/VqMiOUb+XApKD1i3v1H3sI39qheLW1/aZFDFB5Gwfj3rffHQ/8
hMrbwvkA51R0og==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVwUL/JcfPAaUUon8NhvX3+
VhkDGF/AYVNvwu6XUxWgfBGH8/483Zu+yUP5Eg4f6j7ULD4jB+XLODSpRsfd
mSUL5Ss4XHnNf1xyugyUr+Sw7oHv+glt0lC+isOrxxd+yMtJQflqDg9OvBbM
FZeE8jUcyjbKTQq9Kw7lazm4pj7e3DNDDMrXcTio3KLBoCQK5es5TFX9G8kw
XxjKN3AoyVi+z19MCMo3dNgtNWXuzvcCUL6RQ+SstQtFdWB8Y4ejn/mDowp5
oHwTB/l/Z09bfOCC8k0dIOHHBOWbORSvtrbftIgByjd3YFLQ+sW9+o89AOCn
W4M=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVw0Oma9XrhKUUon8Nh1iqv
zYXaML6Aw0SP6S7tUxWgfBEHu3nrV+19Lw/lSzj0HupIZVskB+XLOJQ2mSh+
SZGF8hUcPt6M7YtIlIHylRzOVJ1KXCQuDeWrOFjvYlhr+08SyldzUJRI/Hv2
rgSUr+GwMmuuhM5WcShfy2FrTFVCeI4YlK/joMhy98HnPyJQvp7DkyxNq7/t
wlC+gcOj2WamtycLQfmGDm57X2Y5XBSE8o0c1kuv2X7Jmx/KN3bgLTKyvtzE
C+WbOPzUmVSzPIcTyjd1mPi4uNrpOzuUb+YACU8mKN/cgZt5bdWryR/tAXg+
W9s=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwcMj+JXvuoiKUz+HwTF/J
OE8TxhdwOO3n8mVJrwKUL+KgY5PxM50JxpdwsDwfZ196Sw7Kl3H4dir+39P1
slC+gsPRz/zBUYUyUL6SA5/1DYWZqtJQvooD+83zKbeZpKB8NQdZ4/ar8kkS
UL6Gw6GefsHFSuJQvpaD+r3AhaWsYlC+jsPSqcWCOx1EoXw9h7gOt5e2R4Sh
fAMHiH+FoHxDh9d31Fv0mwSgfCMH55A/ZqxufFC+sUOU9kSPcxXcUL6Jg7yH
r6XYKlYo39SBm3lt1avJjFC+mcN7y1//nPSe2UP45mh8C6j6j1C+JVweAElA
X48=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwONrL7nfkgiKUz+Fgraet
Xm8L4ws4yG2ztru0SAHKF3HwZHVQeiIE40s4lB36mLviixyUL+Owdk9g+Yrb
slC+gkNgybQFV7bJQPlKDgc2n3mdP1cayldx0PxTY/8zXwrKV3MQu2u/q2Sa
JJSv4dBYvEX/jJcElK/lwFHXL30qXhzK13Ho/HVhleRfUShfz8HszbO7a9hh
fAOHJ1maVn/bhaF8Q4eskh/bGMOFoHwjh5PXVL785hGE8o0dAnK0Tn+VFIDy
TRwE34iIfRDjg/JNHY5+5g+OKuSB8s0czkp9eDVFgAvKN3c4cdS2vGQXB5Rv
4eBjXr/9sR4zlG/pwKSg9Yt79R97CN/KITzKaF2R0n8o3xpN3sbhveWvf056
3+wBYixu4g==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwOHs9zqTkhCKUz+GwbV2E
6nctGF/A4bH5/QnMsxWgfBGHLwcaF3C8kIfyJRx0Vj22qVwvB+XLOJy2nvl9
7R5ZKF/B4fdPrTqByTJQvpLDgv/9M7sWSkP5Kg79Kv5zrPuloHw1B0aRjs//
/kpA+RoOlu5XHDatF4fytRz2vgn2818sBuXrOKwWfCehtlkUytdzaDoeHvvL
RwTKN3Aw3CWt/qhUCMo3dNgXo3pQjhvGN3LgzRF63VEoAOUbO2z7MEFf6iwf
lG/iIPhGROyDGIxv6vCNd2fjH1MeKN/MYfY17p/LTLmhfHOHs1IfXk0R4ILy
LRwmPi6udvrODuVbOuhsZmEz64PxrRzkPXwtxVaxQvnWDuFRRuuKlP7bQ/g2
DkwKWr+4V/+B8m0duJnXVr2a/NEeADJDb/0=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwEJ+uO3veMUUon8OhPXEj
v54GjC/g8Lasvm/ydAUoX8RBYVlIk+VVeShfwmHizAllItvloHwZh+LKroTL
lbJQvoJDzmqP7WpSMlC+ksP88zx8ky9JQfkqDoZOy1SXLpCE8tUc1lyJqLwd
IQHlazjMWnnQ+etaMShfy6G55fCd6QdEoXwdh2AGi3MbBUWgfD2Hl9OKHNfa
C0P5Bg4uDRV/DdsFoXxDB0XH9M7SfwJQvpHD6zvqLfpNML6xw3+GwP8JJfxQ
vomD4BsRsQ9ifFC+qUOU9kSPcxXcUL6Zg3Hv2++OBzihfHOHjevyp+hFc0D5
Fg7vLX/9c9Jjg/ItHWrnXd4j9pAZyrdyKF5tbb9pEQOUb+0QHmW0rkjpvz2E
bwPV/w3Kt3XgZl5b9WryRyjfDk3eHo3vAOU/swcAHvOA8w==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVwSE/2n8h4TRHK53CY3cXg
6GsA4ws4ZKo/+nB5kgKUL+Lgb72sZ+4XeShfwsFEesV6xyNyUL6MQ6ieyPGK
BbJQvoJDm5jSVcMkGShfycHZ857MO09pKF/FYfVrx3Q/EykoX83h01w9tx28
klC+hsPjO0GFjWwSUL6Wg0PStuuTysWgfB2H5pbDd6YfEIXy9Rw8Xl3fx9ct
AuUbOCxcckK0/5oQlG/ooOmnLOKaKwjlGzkIvhER+yDGB+UbO0RpT/Q4V8EN
5Zs4VNX/Opi9ig3KN3V4b/nrn5MejG/mAAlPJijf3MG49+13xwM/7QGvEFeP

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwEHSNvp18URHK53D4vnpX
2RVzGF/A4avyqzN6kxSgfBGHSx+miZWwwPgSDorPl2ucOCUH5cs47AhexLy/
WxbKV3B44Vn5XcNLBspXcuCzvqEwU1UayldxELtrv6tkmiSUr+ZQkviCaVea
BJSv4ZDytHhLp7U4lK/loFJ48eZPUTEoX8dhnexlJa3nIlC+nsO5xIiPn28K
Q/kGDoZus3Z6nRWC8g0dXBoq/hq2C0L5Rg7LlL1umRwSgPKNHSo1j/9M9Yfx
TRxWOB4+ekySF8o3dTgr9eHVFAEuKN/Mwce8fvtjPWYo39wBEr5MUL6Fw3vL
X/+c9L7ZQ/iWDkwKWr+4V/+B8q0cuJnXVr2azAhVb40mb4Mmb4smbweV/2gP
AJXKdiE=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwmHBcarPeVUUon8PBM/z5
Ty5LGF/A4e2h7Ez+ZQpQvohDkNHfG9uFYXwJB524LXV738tB+TIOIgGxh8Uf
yUL5Cg7q7Jq/k/bLQPlKDvzfdnl8yJaG8lUcpmeKMyyUkYLy1Rwyd0/I3HpT
AsrXcLB6/bhh/TRxKF/L4b3lr39OemJQvo7DhTV7O5uviUD5eg7ZEeyBydOF
oXwDh30xqgfluIWgfEMHaYnHLyZOEoDyjRy2fZigL3WWD8o3RuObOHzj3dn4
x5QHyjd1OCv14dUUAS4o38xBZzMLm1kfO5Rv7vBTZ1LN8hxOKN8CTb2lw8Z1
+VP0ojmgfCs0/dZQ/7FB+TYOkPhigvJtHXzM67c/1mOG8u3Q5O0dildb229a
xADlO0DN+2YPAClSe5M=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVw4P4qp7vivCKUz+HwpT72
XrIFjC/goJkqsOboSgUoX8QhYN+T6EQlGF/C4Ux458QODnkoX8ZhZXCYm859
WShfwcHDTfjUliUyUL6Sw4Z5OWEx2tJQvoqD4TmVHbw/JKF8NQd2rW09Ylsk
oHwNh4VKc2QKNolD+VoOc86rerJ1iUH5Og4rC85ezOgThfL1HAL0FyiVSIhA
+QYOPub12x/rCUP5hg7czGurXk0WhPKNHCo1j/9M9ReA8o0dnEP+mLG68UH5
Jg7feHc2/jHlgfJNHTauy5+iF80B5Zs5QMKTCco3h9rHDOVbOLy3/PXPSe+b
PQAQflhQ
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw0DD4mOJ8WhHK53Dolpou
KqsD4ws4bJvTaC7crwDlizh80Hkzbd1zeShfwkHFstJj9ho5KF/G4aXUK069
SlkoX8EhOdl9d5a4DJSv5PBJ8gBr6UYpKF/F4bex8TrxTEkoX81Bb+am97F/
xKF8DQe2D/zXJmaIQflaDvci+tp7votA+ToOJytdbFLUhKF8PYeSjOX7/MWE
oHwDB6EXBw6tDhKE8g0deIQPlRe85IfyjRz2Hrd6p/GYB8o3dljhePjoMUle
KN/EQdlr2rWoFVxQvqmDce/b744HOKF8M4flu6+LnZJhhfLNHWrnXd4j9pAZ
yrdwgIQ3E5Rv6cCkoPWLe/UfewjfyoGbeW3Vq8kfoXxrh/eWv/456X2D8m3Q
5G3R5O3gfACyGHgN
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVweLF1SqTjcUUon8Ph93Kt
GnVDGF/Agae5eb3hEgUoX8RB92JrTCUrjC/hsH1D1ZuQa3JQvozDS6lXnHqV
slC+gkPooXMzPK1loHwlh/As1WUq0tJQvoqDXLGL0pWPklC+mkPBzDz/Ewck
oHwNh4VKc2QKNolD+VoOZx4v/uugJQbl6zjM7JuXdahMFMrXc6idd3mP2ENh
KN/AAeJfISjf0GG31JS5O98LQPlGDuFRRuuKlPihfGOHJScXl3GX8EH5Jg7Z
J3bsu7yTG8o3ddi4Ln+KXjQHlG8GtY8Zyjd3MO59+93xwE97CN/C4b3lr39O
et+gfEso/5k9ABbMZdc=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw2D9txaTSi4pQPocD49Ef
R0vMYXwBB81UgTVHVypA+SIOpQ0X3f+Lw/gSDmzZFX+uC8tD+TIOC6U77vvd
lIXyFRx8f/w0Cs6RgfKVHB4/0NlsbSQN5as4bN/capW4TRLKV3PYY/neoWii
BJSv4dBmuF3ueoA4lK/lcGNqQtSaC2JQvo5Dyc5DCoe9RKF8PYepqn8jGeYL
Q/kGDj+8n3I0+ghB+YYOio7pnaX/BKB8I4fwKKN1RUr8UL6xQ/aJHfsu7+SG
8k0clL2mXYtawQXlmzpMfFxc7fSdHco3c6iq/3UwexUblG/usHz3dbFTMqxQ
vgWavKWDj3n99sd6zFC+lYNx79vvjgd+2kP41g7vLX/9c9L7BuXbODApaP3i
Xv0Hyrd14GZeW/Vq8kco3w6q/pk9AAJue5E=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwkGSI9Gy/qAjlczgEzdwj
v8oGxhdwuNuekjNlrQKUL+JwKXCHD7M4jC/h8OStY8pWEXkoX8bhS1Pgkfms
clC+gsOsoLk7km/KQPlKDpfWLQjfvkoayldxWPqo/gtXvRSUr+aw/8n6/Q9N
JaF8DYflq6/c+P5GHMrXckja9+DTvy1iUL6Ow2rBdxJqm0WhfD2HpuPhsb98
RKB8A4elVsYnls8VgvINHWyMfNr5EgShfCMHz5XrVqnO4YfyjR10bfVC9j/j
hfJNHK7xdmT89IPxTR2Me99+dzzACeWbOehsZmEz62OH8s0dmBS0fnGv/mMP
4VtA1f+0BwD/aWDD
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwiDW24dh4TRHK53DgU570
cYkTjC/gsFsp1GbnRgUoX8Qhx2m2QqsYjC/hcPBgwmV2GXkoX8Zh3YIlpp1v
ZKF8BYd3Dp/evtokA+UrOXz6kdd/coM0lK/i8Kp/p5v1cSkoX83hVVOzmvA6
SShfw+H59jWGhiESUL6Ww6GefsHFSuJQvo5DnU7V7LwPolC+nkP89a1xlytE
oHwDh+BrnT2XZIWhfEOH4o3rOwOqBKF8I4fi1db2mxYJQPnGDs4hf8xY3fig
fBOHCS3MO+7HckH5pg4fNl/8WyvKCeWbOUDCkwnKN3dgUtD6xb36jz2Eb+Hw
3vLXPye9b1C+pQM389qqV5M/2gMAV4xkQw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwYNc3+PbsmCKUz+Fw4mf4
ysvaML6Aw/JL4ucXdylA+SIOHnzP/Ga8kYfyJRwylLUnsz6Rg/JlHH7O/r5S
eaUslK/gcPPVz+2TemSgfCWHLf4MSSpTpKF8FQftcy84/fykoHw1B0ObxQq/
fCWhfA2HTQyLGroFJKB8LYdZKw86f10rBuXrODxuFNIoSBaF8vUc4jrcXtoe
EYbyDRx6N3Nq77svBOUbOuyLUT0oxw3jGzn4uh07+sRWAMo3dtC11QvZ/4wX
yjdxMO59+93xACeUb+rQNjHbqlqeHco3cwjsMdRmaWWB8s0dIOHLBOVbOBSv
trbftIgByrd0CI8yWlek9N8ewreCmv8Tyrd2eG/565+T3jd7AFfIaUo=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwEJ+25sSt64pQPoeDUCXb
qgo3GF/AYfGyP3u0VihA+SIOvFeWawVLwPgSDqpZc80yheWhfBkHt6W3Ur++
loXyFRwOxi5d4LhKBspXcjAWT1JbUyYN5as4SB8NzmfxkoLy1RyePzsq8EVJ
EsrXcCj9pb7+5ClxKF/LwWxlUKxXtRiUr+Owq0DnezCTKJSv5xCgv0CpREIE
yjdw+Na1Tjz2iyCUb+igK6jxcdZFASjfyOHzv12RTewwvrHDkpOLy7hL+KB8
E4eLO65+ufGDG8o3dZD38LUUW8UK5Zs5+JjXb3+sxwzlmzsE9hhqs7SyQPkW
DkwKWr+4V/+xh/AtHcKjjNYVKf23BwAHIV1O
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQEf7MVCt+7emK3kABVwMOXSXstxXRHK53B49qLA
7IkxjC/gYL/q2u7bkxWgfBGHN3MaOj7/lYfyJRzeC1d/1NgnB+XLOLA1hLy+
MVUWyldwyO9sbc1Nk4HylRzCrh9gkxWRhvJVHG58WLB4b7EklK/m8Exp8dfU
ORJQvobDyalrAl9riEP5Wg6HPT7PU9wjCuXrOPgVC1RPOyoC5es5/Ews/tu4
VRjKN3CIdt/P9WuDEJRv6CC7+s+1GHNBKN/IoXR3gI3FDz4o39hhQgvzjvux
XFC+iYPOZhY2sz52KN/UARJ+TFC+mYNx79vvjgd+2gMAyAZZ0A==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwyLz2uGzrWUUon8PBYuu/
TBY3GF/AIUreOP31cgUoX8Qhx2m2QqsYjC/h0PChxOUEmzyUL+PwpcZv/5dN
slC+gsNV7rWsso0yUL6Sg+r/7ok/JaWhfBWHIze8Zjk/lYTy1RwUXm7eeuO+
BJSv4SB8WFFXfL44lK/lIDjBj8HRSAzK13FoOztdMkJHFMrXc0ifylTCaywC
5Rs4dPcuVV3LLAzlGzpYntu94NgDASjfyOHzv12RTewwvrHDeuk12y9580P5
Jg5+a/pcU7fyQvmmDspe065FreCC8s0clu++LnZKhhXKN3eonXd5j9hDZijf
wsHHvH77Yz0Y39KBSUHrF/fqP/YQvpWDce/b744HftoDAPFTZDc=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwUF3QwCh8RxHK53C4KPTC
pMQRxhdw0K2c8yVtpQKUL+JguEB2jhMzjC/hEJT6y8rsixyUL+Og/OHBvit3
ZKF8BQetx4cON1bJQPlKDuoNSplhLtJQvorDf67WpHnyUlC+mgN3t3nl2n0S
UL6GQ4/VvzTncnEoX8thlsJW/mfPRaF8HYcIj36BR/tFoHw9h6mqfyMZ5gtD
+QYOC5ecEO2/JgTlGzqkzl3GVL1AEMo3cihebW2/aZEAlG/scI23I+OnHy+U
b+Jw4qhteckuDijf1GHjuvwpetEwvpmDce/b744HOKF8c4e2idlW1fLsUL6F
AyS8maB8SwcmBa1f3Kv/2EP4Vg7vLX/9c9L7BuVbO4RHGa0rUvoP5ds4cDOv
rXo1+aM9AJn0a8o=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQEf7MVCt+7emK3kABVweH1SmunDVUUon8OhXFb0
eIUrjC/gwCOxfc3e1QpQvojDkrT/xsnCML6EQ1nTprU9X+WgfBmH2YY+Tjtu
yEL5Cg6S7vOrA2fJQPlKDmK3VjV5N0pD+SoOElIb1ZsfSEL5ag7/p+1MfvRQ
AsrXcDjkvULrYow4lK/lwPaB/9rEDDEoX8dh0/o2OYk7IlC+nsMsv8Zfj7lg
fAOHde7vg8p5hKF8Q4eZ+5eXh+oIQflGDm57X2Y5XBSE8o0dLM/tXnDsgQCU
b+Kw2kYpQ+MwP5Rv6iD4RkTsgxgflG/mcI23I+OnHy+Ub+7ApKD1i3s1D5Rv
4WDc+/a74wFOKN/SYeLj4mqn7+xQvpVD7bzLe8QeMkP51g4+5vXbH+vB+DZo
fFuH8CijdUVK/+0hfDuo+T+hfHuH95a//jnpfYPyHaDu+QPhNzigqXdEVd/g
6MDNvLbq1WRGqH1ODpD0wgThNzhB5T/aAwBg35Xc
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwuLta2P3NdUUon8PhhTZv
Q7otjC/gUHA4cJ3AdAUoX8RhgoX8LV9WGF/C4R3flBUem+WgfBmHHrFP3Hvm
yEL5Cg6pzl6mCvNloHwlB89LYjdLW6ShfBWH1a8d0/1MpKB8NQd315JM5j8S
UL6GA/+B4KVMEjC+loPigkYRx7NiUL6OQ+hN1s6OalEoX89B97l0AxeLCJRv
4HB629aVRQXCUL6hw5GAA7MbdglB+UYO37rWicd+EYTyjR2WKXvdMjkkAOWb
OHQbpd6ZnQDjmzowKWj94l7NA+WbOZyV+vBqigAXlG/u8N7y1z8nPTYo38KB
m3lt1avJH+0BmH5YaQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwmKb1er/fdUUon8OhXFb0
eIUrjC/gsG3DkyUqGxSgfBGHIKO/N7YLw/gSDsrf/4mrvZGD8mUcQpums0zc
LAvlKzi8P3dkm2igDJSv5LDNuijlur00lK/icOSG1yznp5JQvprDh80X/9aK
wvgaDreVsxYdV5OA8rUcPvKFHtbUF4fydRzSs585H+AVg/L1HATaC1PuLxKB
8g0cnmt+qjQMEIbyDR3c9r7McrgoCOUbOXz+tyuyiV0Ayjd2yD6xY9/lndxQ
vonDxMfF1U7f2aF8U4f3lr/+OemxQflmDj7m9dsf6zFD+eYOxr1vvzse+GkP
4Vs4MClo/eJe/QfKt3TgZl5b9WryR3sAjOlm6g==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwWPr5Fte1C4pQPodDoXJV
3yojGF/A4cyPgP8bFytA+SIO7Ie/ZAkwwfgSDiUyljVnXslB+TIODZumtU+/
IgvlKzgcydL6snWGDJSv5MCzRn2Ndr40lK/iYL2LYa3tP0koX83h6tsGjteP
JaB8DYc2w+1y1wPEoXwth91PN8ncXyYG5es4MM2Y/9ujQRTK13MwiG1evneF
CJRv4PBc81OlYYAwlG/o8K1rnXjsF0Eo38iheLW1/aZFAlC+sUN4lNG6IiV+
KN/EwW9Nn2vqVl4o3xSNb+awcV3+FL1oDijf3KFtYrZVtTw7lG+Bxrd0COwx
1GZpZYHyraD2M0D51g7GvW+/Ox74aQ/h26DxbR3eW/7656T3Dcq3c+BmXlv1
avJHKN8eKv/MHgBien1E
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwKBI/lshzWRHK53CQu3JY
67UTjC/gwPiBMUhllQKUL+JgW7pE+K4sjC/hcJ9rb8VnRnkoX8ZhWaux3Mtj
slC+goOrwvoji0/IQPlKDr6rpOdc2CIN5as4TGhh3nE/VgrKV3P4t0rWPFpS
EsrXcMhYJK7aLioB5Ws5uKY+3twzQwzK13HQirY4us9fFMrXc9j4o++lhIMI
lG/gcCTgwOyGXUJQvqFDQmHs71MvBKF8IwdpiccvJk4SgPKNHUp3B9hY/OCD
8k0clL2mXYtawQXlmzqcOGpbXrKLA8o3cwjsMdRmaWWB8s0dmBS0fnGv/mMP
4Vs4hEcZrStS+g/lWzpwM6+tejWZEareysG49+13xwM/ofLWDu8tf/1z0ntm
DwDPgGhH
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwiJy17JDIWUUon8NBgfHi
FSVLGF/AYVHbrP15yxSgfBEHu+Vz3qXxwfgSDqJzdyXJXJaD8mUcXJg9GL5N
loXyFRwKr5wJ52qTgfKVHBJ9nUL5LaWhfBWHs1IfXk0RkILy1Rw+zdVz28Er
CeVrOPw9It+95ZY4lK/lEMMQLBYwUQzK13FgmjH/t0eDKJSv5xB/fWvc5QoR
KN/Awce8fvtjPWEo39AB4n8hKN/IwaWh4q9huyCUb+xQqjll8qRNAlC+iUOO
04S9fAv5oHxThyjtiR7nKrihfDOHD5sv/q0V5YTyzR2W774udkqGFcq3gNrH
BOVbOhSvtrbftIgByrdy4GZeW/VqMiOUb42m3gZNva0Dk4LWL+7Vf+wB/5Bs
EA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwuHDo4ZG/1xWhfA4HFq0d
XLMsYXwBB6N97PIXlyhA+SIOx/4XrbkvAuNLOByJZTT9pS4P5cs47PtVvY7h
niyUr+DQMz9q4s45MlC+kkOU9kSPcxXSUL6Kw8HNi44wa0lB+WoO/jIJO0xk
JaF8DYdPM7j/9bwXh/K1HE5r5m2Q+SMG5es4zFLYyv/suSiUr+ewTvayktZz
ESjfwKHpeHjsLx8Y39DhjXBk6rdOISjfyCF17jKm6gWCUL6xw+s76i36TQJQ
vomDr9uxo09sYXxTB+eQP2asbnxQvpkDk4LWL+7VPFC+ucNPnUk1y3M4oXwL
B53NLGxmfexQvqXDe8tf/5z02KB8Kwd5D19LsVWsUL61Q+28y3vEHjJD+TYO
4VFG64qU/ttD+LZQ+/5A+XYO3Mxrq15N/gjl20PN/wblO6DyG2D8Z/YAH1yC
2g==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwiNI2e+B5RRHK53BQSq30
EXOE8QUcenf7HmdZpQDliziIGcWEfJCC8SUcfq/e+/nfTzkoX8aB69DKg1l3
ZaF8BYfrlm9OPbguA+UrOTxk6Zp+dpM0lK/ioLlm4qNdRVJQvpqD83sv9aZm
SShfw+Gcexz3VxkJKF/LYemdh5ev/hCD8nUc4s1s2e6eFYXy9Ryss4pmJGwR
gfINHF5OK3Jcay8M5Rs6lGQs3+cvJgTlGznoCmp8nHVRAMo3dvj8b1dkEzuM
b+KwwvHw0WOSvFC+qUP2iR37Lu/khvLNHGZf4/65zBTGN3dom5htVS3PDuVb
ONTOu7xH7CEzlG/pEB5ltK5I6b89hG/l8N7y1z8nvW9QvrUDk4LWL+7Vf6B8
G4fi1db2mxYxQPXbOnAzr616NfkjVN4Oqv8ZlG+PxneAqwcAzU6E0w==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQEf7MVCt+7emK3kABVwcMj+JXvuoiKUz+HAePTH
0RJzGF/AYfFuEf/suQpQvojDBE8DR3U2GF/CgZ9ha8jCfXJQvozD7+3/Gxnj
ZaF8BYeu//JLP8bKQPlKDv+FmuZo+EhD+SoOZ8yec4XelYTy1RzOp3j4JK+U
gPI1HCzdrzhsWi8O5Ws5WKltuLGmVwzK13FgmjH/t0eDKJSv5yC09mrmhzoR
KN/AwdX2Sc35X0JQvqHD4z1/G7TNYXwjh9S5y5iqFwhC+cYO2z5M0Jc6ywfl
mziERxmtK1Lih/JNHa7xdmT89OOF8s3Q+OYOxr1vvzse4ITyLRxOHLUtL9nF
AeVbOgT2GGqztLJA+VZQ8//bQ/jWDsWrre03LWKAyttAzfsJlbdFk7dD02+P
xndw4GZeW/Vq8kcIv8HB4b3lr39Oet+g8o4OTApav7hX/4HKO0LVM0LNd0K1
v8EJzXxnNP3OqPYxuKDa1+CCJu+Kpt8VzXw3NHk3NHl31PBocIe7FwDJscCJ

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwmPV6ZdPPC4pQPoeD8w83
1u8GML6Aw5zKqEdLZytA+SIOZU5Wfo9+y0P5Eg661v0sP3fIQfkyDos5p29I
r5GF8hUcVjgnifa6y0D5Sg6SvvmphwSloXwVh0U6wSJBjFJQvpqDu2tJJvMf
CShfw+G9gZXvpi/iUL6WQwP/95Y4Uxhfx2Fqg+1iQScxKF/PwWXOA6GdnaJQ
voHDrx/Oi8p1RKB8Q4d17u+DynmEoXwjh0v2k1jE7wpC+cYOxaut7TctEoDy
TRzCo4zWFSnxQ/mmDkc/8wdHFfJA+WYO8v/Onrb4wAXlmztsXJc/RS+aA8q3
QONbOrRNzLaqlmeH8q0cuJnXVr2azAjlWzswKWj94l79xx7Ct4HKf4TybR3e
W/7656T3DMq3Q5O3h8sDAAiyddo=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwSLFZ7aFzRhHK53C4Z5tU
d9MGxhdwCFeZrhQ0XQHKF3GI2si02Pu2PJQv4XDg6Nqvr3bKQfkyDpuSxed4
t8tC+QoOj84f3b8kSwbKV3I4KpTdwu0tDeWrOGyuYz1aqy0F5as5uLuWZDL/
kYDyNRwSIsN+Ts8Wh/K1HAQn+DE4GolB+ToO2sclvi55KALl6znUzru8R+yh
MJRv4JBV8mMbY7gQlG/o8ExfyThPUxDKN3IIyNE6/VVSAMo3dnAO+WPG6sYH
5Zs4XNxx9cuNH9xQvqmD/L+zpy0+cEH5Zg4THxdXO31nh/LNHarqfx3MXsUG
5Vs4yHv4WoqtYoXyLR0g4c8E5VtB3csM5Vs7BPYYarO0sjgAABzoZmQ=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwaH4fzv3zmCKUz+HAz2XO
/1MPxhdwaDHijtjdowDlizh80Hkzbd1zeShfwuH0KrmKoyvkoHwZh4OvT1wN
rZOF8hUcLjzfF7XCQAbKV3KQ9M1PPSQoDeWrOLzc7zl71k9JKF/NwXN3vvhn
Rhhfw6Fzqjur/AVxKF/L4VjPofKy/WJQvo7DxTXnP6vkikL5eg7VVyt5GRJE
oHwDh0ezzUxvTxaC8g0dUucuY6peIAjlGzmsl16z/ZI3P5Rv7MCkoPWLezUP
lG/icI23I+OnHy+Ub+owoYV5x/1YLijfzEH+39nTFh9gfHM0voXDWakPr6YI
wPiWDoE9htosrSxQvpVDeJTRuiKl//YQvrXDe8tf/5z0vkH5NlD+M3sATxJw
Tg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwsHJ9vGXVRUUon8Nhq7Gz
6ht9GF/AYc79uBv+kxSgfBGHnskLvRY8k4fyJRxkNH48FX8hB+XLOKzdE1i+
4rYslK/g4Lwl/tyx9TJQvpKDrNOMhFJXaShfxaGN3V6BT10KyldzUJRI/Hv2
rgSUr+FwyHuF1sUYcShfy2HfLiGOD1PEoHwdB4sse6NecVEoX88hmMHi3EZB
ESjfwKG7d6nqWmZhKN/QIaEw9vepF4JQvpFDDPuiWdKuML6xw+s76i36TQJQ
vomD58p1q1Tn8EP5pg5R2hM9zlVwQ/lmDhNamHfcj+WC8s0d5D18LcVWsUL5
Fg4THxdXO31nh/It0eStHN5b/vrnpMcG5Vs7LN99XeyUDEzexqF4tbX9pkUM
UL6tg3Hv2++OB37aQ/h2UP3P7AEwPXGY
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw4DZW9L91SxHK53CIyxfQ
+WgD4ws4tFx7ar9xiQKUL+JgetHdzlERxpdwOBPeObGDQx7Kl3GYkPTivuMu
WShfwYGnedq0tZUyUL6SQ8Il+W3zo6WhfBWHzeyXjv3ikILy1RxSVQ0Z7U5L
QPkaDqW/1NefPCUO5Ws5XM65s/NEihiUr+Pwu3BBvW+GKJSv51B9tZKXIUEE
yjdw2FxQ/DmqQhjKN3RgC2Xc/OGwEJRv5LBM2euWySEBKN/YYe9xq3caj3mg
fBMHZa9p16JWcEH5pg46m1nYzPrYoXwzB3kPX0uxVaxQvrmDj3n99sd6zFC+
hUPxamv7TYsYoHxLByYFrV/cq//YQ/hWDuFRRuuKlP5D+dYOxr1vvzse+Anl
2zi8t/z1z0nvmT0AaSlq7w==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwmPV6ZdPPC4pQPoeD6hvP
2Ok6ML6Aw+s76i36TQpQvohDUX3yzU0H5aF8CYfSOet4J3XIQfkyDtP1dJY/
9ZCF8hUcdPwXf07nkYHylRxEZWO1gpmkoXwVh5jznpx7b0tC+WoONruutV7s
koDyNRws3a84bFovDuVrORzrOVRetl8MytdxqI22t9kSIgrl6znoPpdu4GIR
gfINHKLd93P92iAE5Rs6XEn9xqmxUxDKN4L6TwDKN3bY9mGCvtRZPijfxEH+
39nTFh+4oHxTB+Pet98dD3BC+WYO8h6+lmKrWKF8c4faeZf3iD1khvIt0PiW
Du8tf/1z0vtmD+FbwfkALBhnIQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVw+Hg4UO3mWUUon8NB4Ctr
rY4JjC/gUPVv2rTAJQpQvohD66f6u5eUYXwJh08K0/74S8lD+TIO4Zs0kiI2
yUL5Cg7vHD69fbVJBspXchBdX3y+rFgayldxmLfANDLBUArKV3OoObbuHtcn
CShfw2Gu3NR9s+3EoXwtB52ti0P/7BaD8nUcVhacvZjRJwrl6zkk396zZ/kb
ESjfwMHpYLCctjyMb+jgpJcwpShBGMo3cni852+DtrkQlG/soOiY3ln6TwDK
N3GInLV2oagOjG/qIPhGROyDGB+Ub+ag7DXtWtQKLijf3CFKe6LHuQpuKN/C
YeLj4mqn7+xQviWaeisHeQ9fS7FVrFC+tUPxamv7TYsYoHwbBx/z+u2P9Zih
fFuH95a//jnpPbOH8O3Q+PYOxr1vvzse+AnlO6DKNzg4cDOvrXo1+SNU3hGV
3+CIZp4TnA8Ax3iUlw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwsHJ9vGXVRUUon8PhyO8V
X3XMYXwBh01LFWaoz1GA8kUcpvkdjWwUh/ElHGSm1AlFsMlD+TIODNVfzssc
lYXyFRwenT+6f0mWDJSv5GAsnqS2pkwayldxaGO3V+BTl4Ly1Rw8d+eLf2aU
hPI1HK5GP7R8+U8cytdy6Curb7K5Jwbl6zjU6VTNzvsgCuXrOVhnFc1I2CIC
5Rs4RMYf8oiKEIbyDR0EdAylz/0XhPKNHCzP7V5w7IEAlG/sEDlr7UJRHRjf
xOEab0fGTz9eKN/UQdlr2rWoFVxQvpmD/L+zpy0+wPjmDmelPryaIgDjWzj8
1JlUszyHE8q3dJD38LUUW8UK5Vs5vLf89c9Jjw3Kt3aAxA8TlG/jULza2n7T
IgYo39aBm3lt1avJjFC+HRrf3iE8ymhdkdJ/ewjfwYFJQesX9+o/EH6DA1T9
R3sAqmt8+w==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQEf7MVCt+7emK3kABVwSHmqmrr7jCKUz+Fg2Jd/
i1UdxhdwuHHA79inbgUoX8Th5cd5td5v5aF8CQep0KY/Jo/koHwZh40e+Uaz
VstC+QoO+6+WWhsUyUD5Sg7/hZrmaPhIQ/kqDjGJCese+EhB+WoOfTOvVpd7
SEL5Gg5bJZ/d/3JfHMrXcugrq2+yuScG5es4TJTNfDPrsSiUr+fwZzGL4vML
IlC+gYOHV8+tTZEwvqHDG+HI1G+dQlC+kYOmn7KIa64glG/s8J8h8H9CCT+U
b+LgHPLHjNWND8o3deAtMrK+3MQL5Zs5GPe+/e54gBPKN3c4K/Xh1RQBLijf
wuG95a9/TnpsUL6lQ1X9r4PZq2B8K4fAHkNtllYWKN/agZt5bdWryYxQvo0D
k4LWL+7Vf+whfFuH4tXW9psWMUDl7RzCo4zWFSn9h8rbo8k7QN33EyLf4AB1
zzOoekeofR+h8o5o5jmh2t/gBFcPADFmlL4=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJw10Vsow3EUB/C/reRac9kst+ZvLcSwuc3G/7sRJeUSLUpJFuUW8zIlHjyI
FLm8KCTygAm5pcwLEpKSFOWBRisZiabcd/6/Ov36nO+p83CialpKTQKGYeS/
9fe7n5OTlK9tLzewoAaiJx6uzMdRZC/kpN6tccm8RdApvu2NYzJyMC727i89
GN5SnOZtO4dskeRwlDgmXZa+CLIMmpfDpGJDOJlF70mTpFUeRpbjJNTpGBGF
khW4rBtpsS5KyTHQ5J9jZSmEHIcF7cx+wYOEHI+to4p1YwVvJWZHzQFbEJOT
UJw4xbZLg8nJOLTk6moVQWQV2uvndookgWQ13vqsIVWvAeQU2BNZdXMs71RY
Yg9cpiIROQ39KtP1eDXvdCRkKctsdn9yBgSyuA/feT+yBoM9ws2bKh9yJpyr
Z5+dYm+yFk+ajy+D0pOsg/teAnIWzPNabmWaIWfDV7jY4Rj2IHMoTO/auFUK
yYCxUmVtY7+5f3aD5p/dZvS0741yPdQDj+/6XRflBsrt3A9PNZAP
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVweKL/cm7LeUUon8Ph8KuQ
mQL2ML6Aw0SLl6c65ihA+SIOMftTZOvYYHwJB2aXgKKkQ3JQvozDLaPcfaFB
slC+gsPuH9u+iunKQPlKDnKO/7Z4fZOC8lUcytqZkjh2SEL5ag6dfy5f2+gs
AeVrOJzWzNsg80cMytdyeMo67dv26aJQvo5DVaX282uqIlC+nkPvZk7tffeF
oHwDhyup3zg1dgpC+YYOr++ot+g3CUD5Rg68RUbWl5t4oXxjhw+bL/6tFeWE
8k0c2iZmW1XLs0P5pg7vLX/9c9Jjg/LN0PjmDoE9htosrSxQvoWDvIevpdgq
VijfEqr+mz2Eb4XGt4bzAVPla/s=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwWGZZ8rH9siKUz+Ggcoc9
y9oYxhdwUL6v++fDEgUoX8Rh6m2LU99YYHwJh9fn9ZNkH8tB+TIO+5zmsm3e
LwvlKzi8f8JusPWgDJSv5CCzb+aTtihpKF/FwTFX1SozVArKV3PIuurKOldQ
EsrXcNjEsKihW0ACytdyeBd7cHviMTEoX8dhZt+8rENlolC+nsOvH86LynVE
oHwDh6VWxieWzxWC8g0ddktNmbvzvQCUb+SwXnrN9kve/FC+scPe41bvNB7z
QPkmDhvX5U/Ri+aA8k0d3lv++uekxwblmzlAwpMJyjd34GZeW/VqMiOUb+HA
pKD1i3v1H3sI3xIq/xHKt4Ka98weABj7aHU=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwMPrpleBzUhHK53CYKSKy
bIIGjC/g0Nr5SPB9hwKUL+JgxeE52fC1PJQv4dA+168kdLcclC/jEHG/3mtf
iyyUr+AwZ23Dw3OuMlC+ksP+XZP7pwhIQ/kqDsa9b787HpCE8tUcnN+tnJqb
IgHlazio1Vy/eNhdHMrXcphzXtWTrUsMytdxSPLTXPGPRxTK13N4rvmp0jBA
GMo3cPixhL3uiaMQlG/oILv6z7UYc0Eo38iBR/hQecFLfijf2GHvcat3Go95
oHwTB/l/Z09bfOCC8k0dJj4urnb6zg7lmzmclfrwaooATN7cYfnu62KnZFih
fAsHbua1Va8mM0L5lg7hUUbripT+20P4Vg5MClq/uFf/gfKtoeo/Qvk2aHxb
h/eWv/456X2zBwA303RY
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwSAjZUatwThHK53A4bj/r
s4YVjC/gwLHeNN93ngKUL+LAqnV1vssDeShfwiFP5y2r50w5KF/GQcIudcL/
YlkoX8FBannw9K8ZMlC+koPNgaUJafzSUL6Kg26778qVpyWhfDUHVw7mP182
SkD5Gg5bJZ/d/3JfHMrXcoisfefa81UMytdx+Lq9dee3W6JQvp5D29npkhE6
ML6Bw8YffS8lHESgfEMHnQ9967b3C0P5Rg7asmKS6YlCUL6xQ/Fqa/tNiwSg
fBMH3iIj68tNvFC+qcPsa9w/l5lyQ/lmDm0Ts62q5dmhfHMHSPgyQfkWaHxL
B+Pet98dD/y0h/CtHLiZ11a9mvwRyrd2eG/565+T3jMo3wbK/wbl2zowKWj9
4l79B8q3Q5O3RzPfAVV9gwOa+Y6o9jc4wuUBeT+Q/w==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwOD6r8caJw4pQPofDKpF/
q1IUYXwBh8NXszxv1ClA+SIOChf9ZcNOykP5Eg55RhING/bKQfkyDtOXX3e3
mSUL5Ss48F67+pYrWQbKV3LYv2ty/xQBaShfxYGz0Ffg6UFJKF/Noc/4NeOt
QAkoX8NhrtzUfbPtxKF8LYeV859t0I4Vg/J1HJJv79mz/I0IlK/nEJP06LHO
C2Eo38Chu3ep6lpmGN/Q4ZL9JBbxu4JQvpGDffiXGD9pGN/YYbWNUobGYX4o
38Th6Gf+4KhCHijf1KFtYrZVtTw7lG/m4GNev/2xHjOUb+5QvNraftMiBijf
wsG49+13xwM/7SF8SzS+lQMkPpig6q3R9Nugqbd1eG/565+T3jco3w7Kfwbl
26PxHRy4mddWvZr80R4AZVmDhQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQDQEf7MVCt+7emK3kABVwaGud4GVxSRHK53AImrlH
fpUNjC/g4H/uQdCx2QpQvoiD9dGCl2LMML6EQ8WEDeqez+SgfBmHez9Ya1ed
k4XyFRxab+trRpfJQPlKDrGpKx/bFUhD+SoOwVNdp6+rlYLy1RwuH5dhvsUu
CeVrOFRuDPyhUSUO5Ws5xJvZst09Kwrl6zho97udczotAuXrOTzJ0rT62y4M
5Rs49G7m1N53XwjKN3SQXf3nWoy5IJRv5PCfIfB/Qgk/lG/scHHH1S83fnBD
+SYOP3Um1SzP4YTyTR3OSn14NUWAC8o3c1i++7rYKRlWKN/cwce8fvtjPWYo
38IhPMpoXZHSf3sI3xKNb4XGt3bgZl5b9WoyI1S/DZq8LVT+I5Rvh8a3R1Pv
4PDe8tc/J71vEH6DgwOTgtYv7tV/oPKOqPobHKHqn0HlnVD5DU6o5jE4o5nv
7GDc+/a744GfUHkXNHk0PoMrmvkIPgAPtron
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQEf7MVCt+7emK3kABVwmPV6ZdPPC4pQPodDv8+q
FUX6ML6Aw9L7hz7JTFCA8kUcTvieKDV/Kg/lSziwfp9qaPBBDsqXcXjZOMFm
zTpZKF/Bod4vy/ZmhQyUr+Qw+xr3z2Wm0lC+isORG16znJ9KQvlqDpm7J2Ru
vSkB5Ws4CB9W1BWfLw7lazks+7tCXm2OGJSv4/C4UUijIFkUytdzmLvDJnry
OhEo38CBXY4l5MglYSjf0CHafT/Xrw1CUL6Rg9vel1kOFwWhfGOH4tXW9psW
CUD5Jg6rbZQyNA7zQ/mmDqW7A2wsfvBB+WYOTApav7hX80D55g4TWph33I/l
gvItHDauy5+iF80B5Vs6yHv4WoqtYoXyrRzeW/7656THBuVbOyzffV3slAxM
3sYhsMdQm6WVBcq3dfAxr9/+WI8ZyrdzqKr/dTB7FUy/PZr5DqjyDQ5o5jk6
cDOvrXo1mREq7+hQO+/yHrGHMPOdoOHBAJV3gqr/aA8ARk2NSA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw2PXkdZ/KBUUon8Nhp0dA
eZoOjC/gwL7zU4vdFAUoX8Rh/6ULF6M4YHwJB9M9J779eyEH5cs4HDP1lJgz
UxbKV3DgvLOlf9EEGShfyaHjbK5YoYo0lK/isMLNceqmP5JQvppDnaz40k9P
JaB8DYe/R+S7t9wSh/K1HIzE5yfGtIlB+ToOFln2Rr3iolC+noOHV8+tTZEi
UL6Bg5NewpSiBGEo39BBW1ZMMj1RCMo3ctgtNWXuzvcCUL6xg+fKdatU5/BD
+SYO/xkC/yeUwPimDtd4OzJ++vFC+WYOe49bvdN4zAPlmzt82Hzxb60oJ5Rv
4eBjXr/9sR4zlG+JxrdC41uj8W0cIPHFBOXbovHtHN5b/vrnpPfMHgCpHXTB

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwOM9X8lDyvCKUz+GQ23bK
bK4ZjC/gMPG+g1rQYgUoX8TBQMWhyYYfxpdwuPkl3nE6tzyUL+NwtaTZqPmI
LJSv4MCmH2qScVIGyldyWM5UcLJ2vjSUr+IQ9dzHXbZZCspXc4hLW9jI1iAJ
5Ws4bFyXP0UvWgLK13Kwev24Yf00cShfxyGGIVgsYKIYlK/n8LhRSKMgWRTK
N3ConXd5j9hDYSjf0KG7d6nqWmYY38jBbe/LLIeLglC+sUNAjtbpr5ICUL6J
w7YPE/SlzvJB+aYOyl7TrkWt4ILyzRxOHLUtL9nFAeWbO3Azr616NZkRyrdw
CI8yWlek9N8ewrd0MO59+93xwE8o38rhveWvf05636B8a6j+j1C+DVT+mT0A
4sBsCw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxdyVkowwEcB/A1tzUmzNwzZ+tvzdznviSNJJTzUclZWPMicjx5EEU8SKSU
DVvkmhAlSpJGpEhDOR9QypG7/f4vvvXr2+f3DSiryy/ncjgcye/9tSWPSmHB
/PJMjQT0wLTudGlnL4Bsj+/OcGOEgrUATFU9RzUkJrthrNCcO2L2J4uQti9X
X0/7kX2g+fTYLW/wJYshv48T37x4kyXo2jl3Mq97kYPQ3j1wUjHlSQ6BnXSh
SzgnIoch93lu25juQZYi9CxvtNFGSGZQrOoRXKy5kWWo6Odq+JGs5ciObV28
lLmSI5CxelsNkwtZgXCXsKdBk4AciZJB/ag7wzoKmTrDRPCQMzkafLUi8aCD
T47BEb+z8i2HdSy0qRubW56s42AyHj4fv/LI8QjMGjgq1TqSE/DG9DaP1zqQ
E8HMWtvGdNuRk/A4a/pscWf3ZLQMH6wIz63IKf+sRFGpwqCWfCstBrhi6Ttv
8sPiNoBnpW+663uiPRUP8e9fabIr5Q/8FYgI
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwaJRx37/yqiKUz+Gwue+P
g7sTjC/gwPiBMUhllQKUL+Ig9HR3mDUvjC/h4Jb4Y5/XezkoX8ZBtPXpVelD
slC+gsOfuVtd3h+QgfKVHF7uaSrYt0Yayldx2FS1dK7tZCkoX81h++ZWq8Rt
klC+hgPjhEv/XjZKQPlaDnPlpu6bbScO5es4NJTaf7FSE4Py9RzM3jy7u4Zd
FMo3cPB4dX0fX7cIlG/okB3BHpg8XRjKN3JwtX1Sc/6XEJRv7MDNvLbq1WRB
KN/EYduHCfpSZ/mgfFOHvcet3mk85oHyzRwu7rj65cYPbijf3MG49+13xwOc
UL4FGt8SjW/lUFX/62D2KjYo39ohPMpoXZHSf3sI38aheLW1/aZFDFB5W6j7
PtoDABn7eDk=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwUBaw3zLhkiKUz+GwQH/e
OitLGF/AwcbznuW6eQpQvogD65RDCrzcML6EQ7yO5d/2j3JQvozDpSmb5jw/
IAvlKzgcydL6snWGDJSv5NBxNlesUEUayldxYM1tyPv3UhLKV3Mw+p8iuX+B
BJSv4VC5MfCHRpU4lK/lEHqTtbOjWhTK13F4l3vkq/E3YShfz2Hv8fb7P+qF
oHwDBxsjn3a+BEEo39CheLW1/aZFAlC+kcNqG6UMjcP8UL6xg9+aPtfUrbxQ
volD9okd+y7v5IbyTR2UvaZdi1rBBeWbOXzYfPFvrSgnlG/uUDvv8h6xh8xQ
voVDeJTRuiKl//YQviXUfgaovJWDce/b744HfkLlrdH4Ng7czGurXk3+COXb
osnbOby3/PXPSe8blG+PJu8A1w8Ac9+FyQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQDQEf7MVCt+7emK3kABVwmBjHqnb/jCKUz+GQsiNg
0241GF/A4U/pw6ea3QpQvohDZfF9Gbnz8lC+hEPiwwffo6bJQfkyDlufsMRL
TZeF8hUcwhIntHsvk4HylRxOzXm5fFapNJSv4iDp/ltKxUoKyldzWFHnm+ch
LQnlazg0Fm/RP+MlAeVrOczjmb5N5IoYlK/jcPrXi662paJQvp6Dx6vr+/i6
RaB8A4eNn6TmV2UIQ/mGDtqyYpLpiUJQvpGDjZFPO1+CIJRv7PCfIfB/Qgk/
lG/isMLx8NFjkrxQvqmDste0a1EruKB8MzS+ucPEx8XVTt/ZoXwLB3kPX0ux
VaxQvqVDYI+hNksrC5Rv5cDNvLbq1WRGKN/aoXi1tf2mRQxQvo2Dj3n99sd6
zFC+rcPy3dfFTsnAzLND49s7QOKXCcp3cHhv+eufk943ezC3AY3P4IhqX4Mj
mrwT1H0fofrR+AzOcD4AvQKVYw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwUEnh/JF4RhHK53CYwZik
3GEF4ws4tFVEXBdYqgDlizjUFRhp9HHD+BIOZ607jT69lYPyZRxCm6azTNws
C+UrOLy7J72nrkMGyldyCOk4dKbERhrKV3FYpBMsEsQoBeWrOfRXOi7TOCkB
5Ws4rMyaK6GzVRzK13LYt0uI48MUMShfx6Ht7HTJCB1RKF/P4V3uka/G34Sh
fAMHw13S6o9KhaB8QwfLc7sXHHsgAOUbOby+o96i3wTjGztUah7/meoP45s4
lO4OsLH4wQflmzpc3HH1y40f3FC+mcNPnUk1y3M4oXxzh43r8qfoRXNA+RYO
xaut7TctYoDyLR2YFLR+ca/+Yw8AN4BgIQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwCNu5dkr2BUUon8PhyO8V
X3XMYXwBh+2Hp6nrzlOA8kUcfn+7VS3AC+NLOJwJ75zYwSEP5cs4/GUsfh9z
TRbKV3CYbLIk/vQRGShfyeHUPqtdR45IQ/kqDgvfx/O/mCgF5as5/N55gZ+t
UhLK13A4n+Lhk7xSAsrXchCzUijiqRWH8nUclDZxzDrqKwbl6zmYTT6S4Skk
CuUbOKxzfx9UziMM5Rs6COgYSp/7LwjlGznoCmp8nHVRAMo3dvBcuW6V6hx+
KN/EIcdpwl6+hXxQvqkDb5GR9eUmXijfzMG49+13xwOcUL65w/Ld18VOybBC
+RYOtfMu7xF7yAzlWzowKWj94l79xx7Ct4Lq/wnlWztwM6+tejX5I5Rv4/De
8tc/J71n9gAA1m8P
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwyPyz/0foOUUon8Nh7e/S
bZr6ML6AwzX7uA+ikxWgfBGHmP0psnVsML6EgymPiGHgKTkoX8aB/0NX/+ZJ
slC+gkNc0Kslp+NkoHwlh8QpIds8lKWhfBUHhit5hdkvJKF8NQfL8pDHbL8k
oHwNB4uj9dXzdolD+VoOW2OqEsJzxKB8HYc/i1kUn18QgfL1HGKajaNuvBCC
8g0c3Pa+zHK4KAjlGzoE5Gid/iopAOUbOYRHGa0rUuKH8o0d9h63eqfxmAfK
N3GI0p7oca6CG8o3daiq/3UwexUblG/mUDvv8h6xh8xQvjnUvP/2EL6FQ/Fq
a/tNixig8pYO3Mxrq15N/giVt3J4b/nrn5PeMyjfGs4HAMIJa9M=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVw+MQxOyL3kiKUz+Egu/rP
tRhzGF/AgT997/G61QpQvohD9VmGM6ZcML6Ew/8bJvqzt8lB+TIO2a9T1Vnb
ZKF8BQfF7AWT01pkoHwlB9dkZ1e2UGkoX8Whf2K0UPMFSShfzWGP5XuHookS
UL6Gw9s2zlWtHeJQvpbDztOR28IjxaB8HYeZffOyDpWJQvl6DrXzLu8ReygM
5Rs4vBGOTP3WKQTlGzpYntu94NgDASjfyCE8ymhdkRI/lG/scPQzf3BUIQ+U
b+KQfWLHvss7uaF8Uwfj3rffHQ9wQvlmDjqbWdjM+tihfHOH5buvi52SYYXy
LaDuYYbyLdH4Vg6Q+GCC8q0dildb229axADl2zj4mNdvf6wHU2+LxreDuv+/
PYRvD3XfTyjfwYGbeW3Vq8kf7QHGHH2w
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQDQEf7MVCt+7emK3kABVwWPmpbcevS4pQPoeDwFfW
Wh0TGF/A4eDCw7rscxSgfBGH6TedKto/yUP5Eg6ic3clyVyWg/JlHHii6wsO
rpSF8hUcvv5KmaVZIwPlKznICOxkn+ImDeWrOCyTZe27HCYF5as5iJy9c/Lf
SwkoX8Ph9n/p3dEl4lC+lsOZx4v/OmiJQfk6DmZvnt1dwy4K5es56D6XbuBi
EYHyDRyCr3X2XJIVhvINHRIKY3+feiEI5Rs5SEs8fjFxkgCUb+yw2kYpQ+Mw
P5Rv4lCpefxnqj9M3tShdHeAjcUPPijfzOHoZ/7gqEIeKN/c4cRR2/KSXRxQ
voXDT51JNctzOKF8S4f3lr/+OemxQflWDpD4YILyrR18zOu3P9ZjhvJtHKrq
fx3MXgVTb4vGt3OonXd5j9hDmHp7h+W7r4udkmGF8h1QzW9A4zM4OjApaP3i
Xv3HHiKPxmdwQpN3cihebW2/aREDVL8z1D/foPJofAYXNHkXNPNdHYx73353
PPATKo/GZ3BDk3eDmvcMKu+OZj4an8HDgZt5bdWryR+h8h5o8p5o/vNEVc/g
hWpfgxeafm+4egAhFuwU
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwWGZZ8rH9siKUz+Ewb3Xo
xAWGML6Aw/4jynKHpihA+SIOPZMXei14Jg/lSzjcnvas/tVBOShfxqG7KVe4
bp8slK/goPX40OHGKhkoX8lhm3VRynV7aShfxYH95vmU20xSUL6aw/kUD5/k
lRJQvoZDVYly/mpHcShfy6FygshVT0YxKF/H4c9iFsXnF0SgfD2H09u2riwq
EIbyDRz2Hm+//6NeCMo3dJBd/edajLkglG/kEB5ltK5IiR/KN3ZYcnJxGXcJ
H5Rv4hClPdHjXAU3lG/qMPFxcbXTd3Yo38xB3sPXUmwVK5Rv7lA77/IesYfM
UL6Fw3vLX/+c9L7ZQ/iWaHwrB27mtVWvJn+E8q3R5G2g/GdQvq2Dce/b744H
fkL5dmh8ezT9Dg5MClq/uFf/gfAbHNDMc0S1vwHBBwBi6Jc7
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw2KLqfPnPWUUon8Nh3urQ
iQsMYXwBh9z7K17NmKEA5Ys43HkunT77rzyUL+HwTzBbyP60HJQv43D35FPf
652yUL6CA6eUZHyTpgyUr+TQaNr51VRLGspXcZizWCri1DFJKF/NYY/le4ei
iRJQvobD2zbOVa0d4lC+lkPjS8X9jzzFoHwdB+usohkJW0SgfD2H6Q97GO99
FILyDRwe7/nboG0O4xs68OYIve4oFIDyjdD4xg7rpddsv+TND+WbOGSf2LHv
8k5uKN/UYeLj4mqn7+xQvplDVf2vg9mr2KB8cwedzSxsZn0weQuHwB5DbZZW
Fijf0qF23uU9Yg+ZoXwrh+LV1vabFjFA+dYO4VFG64qU/ttD+DYO7y1//XPS
e2YPABusb8o=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwMGYoVA66qAjlczh83CkR
WWAF4ws4PDa/P4F5tgKUL+JQyWe5oZUBxpdwWLhKTdr4rhyUL+Pw7VT8v6fr
ZaF8BYcnnHPVjPtkoHwlh9jUlY/tCqShfBWHlUfvJtpGSEH5ag77n6zf/9BU
EsrXcHjwUy60yUACytdymGG5e9rbQ2JQvo7Db750+4OuolC+ngO7HEvIkUvC
UL6Bw1Ir4xPL5wpB+YYOsqv/XIsxF4TyjRwCcrROf5UUgPKNHfzW9LmmbuWF
8k0cZl/j/rnMlBvKN3X4sPni31pRTijfzGH57utip2RYoXxzB0j4MkH5Fg61
8y7vEXvIDOVbOviY129/rAfjWzm8t/z1z0nvmz2Eb43Gt3HgZl5b9WryRyjf
1oFJQesX9+o/UL6dg3Hv2++OB35C+fYOxaut7TctYoCa7wBXDwDBFICG
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQDQEf7MVCt+7emK3kABVw6N7yOGD3VUUon8OBiceU
e7kLjC/g8PZQdib/MgUoX8ShozR57lMeGF/CwffUihjPO3JQvozD1zMnN1ZO
k4XyFRyM/U+yGZTLQPlKDqf2/5t4Vl4ayldxSDm8zbCHVwrKV3MomJnnf+KA
BJSv4XDIe4XWxRhxKF/LoeTXSiVDKzEoX8cheM4U6SpDUShfz6H6aiUvQ4II
lG/gsL1gWaSeqDCUb+hQcO3zoURFISjfyKFUc8rkSZsEoHxjhxynCXv5FvJB
+SYOgm9ExD6IwfimDkc/8wdHFfJA+WYOyl7TrkWt4ILyzR02rsufohfNAeVb
OEx8XFzt9J0dyrdE41s5BPYYarO0skD51g7Ld18XOyXDCuXboMnbOlTV/zqY
vYoNyrdDk7d3qJ13eY/YQ2Yo3wFVvsHBoW1itlW1PMx+R4cPmy/+rRXlhMo7
ornfyUHew9dSbBXUPQ1OaO5zRrWvwdkBkr6YoPIuDsWrre03LWKAyrs4+JjX
b3+sB3OfK2p4NLiime+GJu+G5l93NP+5o9nvgWa/h4Nx79vvjgd+2kPkPR24
mddWvZr8EcJvQPABv3zDsQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwqOO3m7f4rCKUz+GQueT5
STFrGF/AQbnOcaHWXAUoX8ShzMnK79FveShfwmGh2MZJyQ/koHwZh9bFcg0B
SbJQvoLDAdbTmuvtZaB8JYdEX6dQfktpKF/FYfqRs0tDdktC+WoOnX8uX9vo
LAHlazgc4DPfe0hIHMrXcnBR5dO5LygG5es4RH26bab6VxjK13PgWvwjzu2o
IJRv4HDymsqX3zwwvqHDf4bA/wkl/FC+kcM33p2Nf0x5oHxjB2WvadeiVnBB
+SYO2Sd27Lu8kxvKN0WTN3OY+Li42uk7O5Rv7iDv4WsptooVyrdwYFLQ+sW9
+o89hG/pwM28turV5I9QvpWDce/b744HfkL51mjyNmjytmjydg7vLX/9c9L7
BuXbo8k7QOWfQfgNDnB5AKzMhvU=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVwiPZQtLG9rgjlczjMk3pn
re0A4ws48J0uPiq7UQHKF3HYVHEwfZcMjC/hsOqTuvj7+3JQvozDaeuZ39fu
kYXyFRx8bOtL16yQgfKVHPp+/F8hVycN5as4eFvXeIokSUH5ag779siFML+R
gPI1HBYqzZEp2CQO5Ws57O6ZsLx6oxiUr+OwWvCdhNpmUShfz0H3uXQDF4sI
lG/gsPd4+/0f9UJQvqHD6zvqLfpNAlC+kYPfmj7X1K28UL6xw8UdV7/c+MEN
5Zs4/NSZVLM8hxPKN3XwMa/f/liPGco3czDuffvd8cBPewjf3IGbeW3Vq8kf
7QEMZlwC
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwWCLOr2l2ShHK53A4smWr
x0oNGF/AYYNJcqj2NAUoX8ThbcbuC9dfyUP5Eg7yi7h9b2+Ug/JlHErcTomt
DZaF8hUcnunyWWyUk4HylRzOawXf5torBeWrOLyZ/Th55xZJKF/NYU9x5G+z
bRJQvoZD5cbAHxpV4lC+lsO+XUIcH6aIQfk6Dr8LF9T7ZohC+XoOMRxSDTMs
RaB8AwfvzR+9As2FoXxDh0ezzUxvTxaC8o0cUucuY6peIAjlGzv8Zwj8n1DC
D+WbOOja6oXsf8YL5Zs6TGhh3nE/lgvKN3Nom5htVS3PDuWbO0x8XFzt9B3G
t3ConXd5j9hDZijf0oGbeW3Vq8mMUL6VQ3iU0boipf/2EL61A5OC1i/u1X+g
fBuH95a//jnpfYPybaH8Z/YAtmtxLw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwsLwdnsx8RRHK53DISrp+
3d8WxhdwiJ0hJMy9QgHKF3H4dztz3jNeGF/C4c62Z6qaEvJQvozDudAG4V0/
ZaF8BQeJtcF1OqdkoHwlh7Ke0vkeM6ShfBWHU4znrdQDpaB8NQdGK+2d5zkl
oXwNh5VZcyV0topD+VoOu59ukrm/TAzK13Go06manfdBFMrXczCIbV6+d4UI
lG/goKnC/uS7uzCUb+hwyX4Si/hdQSjfyOH1HfUW/SYBKN/YYcnJxWXcJXxQ
vomDste0a1EruKB8U4cTR23LS3ZxQPlmaHxzB0j4MkH5Fg7Fq63tNy1igPIt
HbiZ11a9mvzRHsK3cnhv+eufk94zewBUrWOj
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwUA6tTf90QxHK53BInpru
wWIB4ws4rGowMZiwVAHKF3H42eG6Zi07jC/h8M+q8fLTl3JQvoyDRrK4Zc4T
WShfwaHkvZSx5gEZKF/J4VPMD37XZGkoX8UhOE6ke6qHFJSv5uBi/t40Sk8S
ytdwOBW3/tM+cwkoX8vhtGbeBpk/YlC+jsPvwgX1vhmiUL6eQ2CPoTZLqwiU
b+DQ3btUdS2zMJRv6JBQGPv71AtBKN/IIcdpwl6+hXxQvrGDce/b744HOKF8
Ewd5D19LsVWsUL6pg495/fbHesxQvpkDJDyZoHxzNHkLB27mtVWvJjNC+ZYO
xaut7TctYoDyrRzeW/7656T3zR4Au1lg2A==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwiJy17JDIWUUon8PhkqfI
rysmML6Ag0T+/Qm3+hWgfBEHFT7bk5Hf5KF8CYewpYcz4m/LQfkyDqeEDuat
aJOF8hUcLjL8d/5bIwPlKzn0/fi/Qq5OGspXcZi3wDQywVAKyldzKJiZ53/i
gASUr+HwYzt3uMwJcShfyyGj+l7aIiYYX8fhzOPFfx20xKB8PQfrrKIZCVtE
oHwDh+eanyoNA4ShfEMHAR1D6XP/BaF8IwfeHKHXHYUCUL6xw2obpQyNw/xQ
vomDc8gfM1Y3Pijf1GFCC/OO+7FcUL6Zg85mFjazPnYo39xh+e7rYqdkWKF8
Cwd5D19LsVUwvqUDJPyZoHwrB27mtVWvJjNC+dYO7y1//XPS+2YP4dtA5T9C
+bZQ+WdQvh0a3x5Nv4ODce/b744HfkL4DQ5w8wAenIPD
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7MVCt+7emK3kABVwMEx55Xf8rCKUz+Egu/rP
tRhzGF/AYVadSMH/mQpQvoiDw06m3n9v5aF8CYeFye8bt26Rg/JlHJyWXFsx
sUMWyldw+JLrxFXgKAPlKzmwaK8w5LgvBeWrODT2TbudvkYSyldzcH63cmpu
igSUr+GwPoSF5eM7MShfy0FpE8eso74wvo7DasF3EmqbRaF8PQfrrKIZCVtE
oHwDh18/nBeV68D4hg4vpxU5rrUXhvKNHCDhIQTlGztwLf4R53ZUEMo3cfB1
O3b0ia0AlG/q4LemzzV1Ky+Ub+aw97jVO43HPFC+uYP8v7OnLT5wQfkWaHxL
B53NLGxmfexQvpVD8Wpr+02LGKB8a4fwKKN1RUr/7SF8GwcmBa1f3Kv/QPm2
Du8tf/1z0vsG5dtB+c+gfHs0vgOq+gY0PoOjAzfz2qpXkz9C5R3R9DuhyTs5
GPe+/e544CdU3hlVfYMzqnoGFzgfAHPnqzI=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwcPwSEeV3TxHK53C4/ecg
t54XjC/gsN9P8vny9QpQvoiDjPwRo/ViML6EwzO9bdN05OShfBmHtYf1jvIK
y0H5Cg7HnVZFK7yUgfKVHD50ZDw6eFQayldx2KTYrHFrrhSUr+bwaXHkAXkj
SShfw6Fn1/tbcd3iUL6Ww8ftQcHKdmJQvo6D2eQjGZ5ColC+nsO73CNfjb8J
Q/kGDpsLij9HVcD4hg6GbrN2ep0VgvKNHHQFNT7OuigA5Rs7LDm5uIy7hA/K
N3HIPrFj3+Wd3FC+qYNx79vvjgc4oXwzNL65w4mjtuUluzigfAuHqvpfB7NX
sUH5lg5MClq/uFf/sYfwrRzeW/7656T3Dcq3RuPbOHAzr616NfkjlG8L5wMA
A1p4Cw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwuLzQu5rjjCKUz+GwhGOm
yltdGF/AQWudnpR4uwKUL+JwaMLq80of5aF8CYdLBxPebT0tB+XLOPyc/X2l
8kpZKF/B4XFUmUuIhAyUr+RQr/v/jSeHNJSv4qCzdIG4Vo8klK/m4L28K4Kb
TwLK13CwUttwY02vGJSv5eAy54HQzk5RKF/HYfGT1iTnNBEoX89h+sMexnsf
haB8A4cf3k85Gn1gfEOHZ/pKxnmaglC+kUPp7gAbix98UL6xw9HP/MFRhTxQ
vomDce/b744HOKF8U4faeZf3iD1khvLNHLiZ11a9mswI5Zs7FK+2tt+0iAHK
t4DKf7SH8C0d3lv++uek9wzKt0LjW6Opt4HLAwAeZnBi
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwOHs9zqTkhCKUz+FwRav4
RLMxjC/g8IDT4vWJqQpQvoiDuRnr7slMML6Ew3qH2L6q+3JQvozD5abb0TWz
ZaF8BYfnSvuuLfCVgfKVHHTzl9Wd1ZOG8lUctm9utUrcJgnlqznMODiPuT1M
AsrXcFgfwsLy8Z0YlK/lsF9+tsRcThhfx+E6W/t12U8iUL6eg86HvnXb+4Wh
fAOHmGbjqBsvhKB8Q4eT11S+/OYRhPKNHJxD/pixuvFB+cYOOU4T9vIthPFN
HHiLjKwvN/FC+aYOe49bvdN4zAPlmzlEaU/0OFfBDeWbO2xclz9FL5oDyrdw
qKr/dTB7FRuUb+kACX8mKN/Kwce8fvtjPWYo39ohPMpoXZHSf3sA/uBn+w==

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwcPnZxhByWxHK53DIY71+
6bwDjC/gsG3DkyUqGxSgfBGHPKVOmThOGF/Coa/+tZsBgzyUL+Ow71f1OoZ7
slC+ggN30nmv2GsyUL6Sg0zyY7vLu6WhfBWHvetPLj27UArKV3MQu2u/q2Sa
JJSv4fDg1w6GtfUSUL6Ww+dfx47euSUG5es4/Cv6rsp5VBTK13NQZLn74PMf
ESjfwOHXD+dF5TowvqFDd+9S1bXMwlC+kcMb4cjUb51CUL6xg66gxsdZFwWg
fBOHJScXl3GX8EH5pg7XeDsyfvrxQvlmDsa9b787HuCE8s0dThy1LS/ZxQHl
WzhEaU/0OFfBDeVbOmxclz9FLxomb+Ug7+FrKbaKFcq3dqidd3mP2ENmKN/G
4b3lr39OemxQvq3D8t3XxU7JwNTbORSvtrbftIgByreHqv9mD+E7QPnP7AH7
vYLp
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVweCAeVH/usiKUz+EQ99mu
/qUjjC/gIP2C47b9agUoX8TB+KjTNjMRGF/CwWirYpYFuzyUL+OgabxmhsR+
WShfwSG/s7U1N00GyldyOCqU3cLtLQ3lqzgszTdUVnOXgvLVHD4tjjwgbyQJ
5Ws4ONyvixZ0k4DytRzkOrJWfhEVh/J1HKY22C4WdBKD8vUcrrO1X5f9JALl
Gzj8TCz+27hVGMo3dNCWFZNMTxSC8o0cdAU1Ps66KADlGzt4rly3SnUOP5Rv
4hClPdHjXAU3lG/qYNz79rvjAU4o38yhqv7XwexVbFC+uYOPef32x3rMUL6F
Q3iU0boipf/2EL6lAzfz2qpXkz9C+VYOTApav7hX/4HyrdHkbRzeW/7656T3
Dcq3RePbQfnP7AFn73KH
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVweG86JaT2giKUz+GQueT5
STFrGF/AYf8RZblDUxSgfBGHi8e1XLm/y0P5Eg6XeOV5FY7JQfkyDrf97W/O
micL5Ss47L9aam1QJAPlKzkk+jqF8ltKQ/kqDjHnPTn33paE8tUc6mTFl356
KgHlaziIiptqn20Sh/K1HFbOf7ZBO1YMytdxMLnUW666SwTK13M4vW3ryqIC
YSjfwCGm2TjqxgshKN/QIXXuMqbqBYJQvpEDb47Q645CASjf2MFz5bpVqnP4
oXwThxWOh48ek+SF8k0djHvffnc8wAnlmzm0Tcy2qpZnh/LNHSDhywTlW0DV
/7SH8C0duJnXVr2a/BHKt3J4b/nrn5PeMyjfGs4HAOMoarA=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVw2D9txaTSi4pQPofDpRjz
nj3mML6Aw5sVLtJFixWgfBEH9+vbJ9znhPElHBr5NNRSmOShfBmHBVOY614e
loXyFRwOqF6uvD9ZBspXcmj2fxS9t1wayldxOFwxrW6+mBSUr+ZgoPDzn/Vy
CShfw+Hg4aVM1yLFoXwtB+7LXwr/1YlB+ToOWtEWR/f5i0L5eg5xHW4vbY8I
Q/kGDpNTP0yOWS4E5Rs6aPopi7jmCkL5Rg7LlL1umRwSgPKNHbZ9mKAvdZYP
yjdx4C0ysr7cxAvlmzpkn9ix7/JObijfzOHD5ot/a0U5oXxzB3kPX0uxVaxQ
voVD8Wpr+02LGBwAIGhcvw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwsPdfHel1VhHK53Dg3lFU
X6gG4ws4aFtYLeFoU4DyRRze/jFZMv2MPJQv4RATvuri30VyUL6MQ/VPRY/I
YlkoX8Gh67/80o+xMlC+ksN61rOeL1iloXwVB/a73Rs3v5OE8tUc9hRH/jbb
JgHlaziIWSkU8dSKQ/laDo0vFfc/8hSD8nUcFFnuPvj8RwTK13OoqtR+fk0V
xjdw2F6wLFJPVBjKN3Rwaaj4a9guCOUbOZRqTpk8aZMAlG/sEB5ltK5IiR/K
N3GYfY375zJTbijfFI1v5vBh88W/taKcUL65w4QW5h33Y7mgfAuHjevyp+hF
c0D5lg6Q8GeC8q0cfMzrtz/WY4byrdH4NlD3/LeH8G0d3lv++uek9wzKt4Pz
AZ5EdeM=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw2GK2N3PPRUUon8Nh7e/S
bZr6ML6Ag3iMLt+lhQpQvojD53+7IpvYYXwJh8batmtnL8hB+TIODq8croUu
koXyFRx4X5h+Zy2WgfKVHNw7l3uJG0pD+SoO+8KuPVH7LQnlqzlMepuhUWcN
42s4xHvvcdhzSBzK13KYvmzhCiU5MShfx0HmdoSDwEQRKF/P4Wdi8d/GrcJQ
voGD7Oo/12LMBaF8QwddW72Q/c94oXwjB781fa6pW2F8Y4fsEzv2Xd7JDeWb
OERpT/Q4VwHjmzooe027FrWCC8o3Q+ObO0x8XFzt9J0dyrdwqKr/dTB7FRuU
b+mwcV3+FL1oDijfyuG95a9/TnoweWuHwB5DbZZWFijfBk2/rcPy3dfFTsmw
Qvl2DpD4ZILy7dH4Dg7Fq63tNy1igPAbHByYFLR+ca/+Yw8AFyqBHw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw8OIXPP78giKUz+GwzWQ7
4xZjGF/AwePpfZ1bMxSgfBEHwQtfaz1YYHwJB36GrSEL98lB+TIO8dmChkKT
ZKF8BYeLDP+d/9bIQPlKDr8azi2wCpeG8lUcJN1/S6lYSUH5ag7xuRvnz7gq
AeVrOPRY/UtzLheH8rUcSn6tVDK0EoPydRzuRfS193wXgfL1HHQ+9K3b3i8M
5Rs4FFz7fChRUQjKN3TwdTt29ImtAJRv5LDtwwR9qbN8UL6xw8UdV7/c+MEN
5Zs4fNh88W+tKCeUb4rGN3OQ9/C1FFvFCuWbO4RHGa0rUvpvD+FbOHAzr616
NZkRKm/pYNz79rvjgZ9QeSuH95a//jnpPYPyraH8b/YALE1utw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwSHmqmrr7jCKUz+Eg8JW1
VscExhdwuM5h94lvvgKUL+Jw9yNDI58wjC/hEJ9+ekrIdzkoX8ZBfmJs2Laj
slC+goOdtN9F43UyUL6SQ00sC8/hLmkoX8Vh3gLTyARDKShfzWHFql0dXIqS
UL6Gw+M7QYWNbBJQvpbDQ+3UQ9w64lC+jkOdTtXsvA+iUL6eg0WWvVGvOIxv
4DDLr/HXYy4RKN/QYeGSE6L914SgfCOH1LnLmKoXCEL5xg724V9i/KRhfBOH
bqPUO7MTBKB8U4ejn/mDowp5oHwzh7NSH15NEeCC8s0dJj4urnb6zg7lWzgs
331d7JQMK5Rv6eBjXr/9sR4zlG/l8N7y1z8nvWf2AMIBYJY=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwcA2r3153RRHK53Boqk5g
/GwE4ws45N5f8WrGDAUoX8Th+EkrzqVv5aF8CQdTHhHDwFNyUL6Mw+mO55ef
L5eF8hUc2sSUrhomyUD5Sg42B5YmpPFLQ/kqDl/ZXy1L3ygJ5as5lCS+YNqV
JgHlazikPC3e0mktDuVrOcxS2Mr/7LkolK/jYHKpt1x1lwiUr+fwJEvT6m+7
MJRv4BDtvp/r1wYhKN/QYZmy1y2TQwJQvpGDr9uxo09sYXxjhxWOh48ek+SF
8k0cvvHubPxjygPlmzowKWj94l4N45s5TGhh3nE/lgvKN3dom5htVS3PDuVb
OBSvtrbftIgByrd04GZeW/Vq8kd7AOwIYMQ=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwqPLJ5JK7rAjlczjwbtV5
a+QG4ws4cKw3zfedpwDlizisY+UXauOA8SUcXp/XT5J9LAflyzjc4+Q20t0i
C+UrOBzJ0vqydYYMlK/ksMwk6NrvfmkoX8UhOE6ke6qHFJSv5rBvj1wI8xsJ
KF/D4ZD3Cq2LMeJQvpbD7eNbbl0vFoPydRyss4pmJGwRgfL1HHQ+9K3b3i8M
5Rs47D3efv9HvRCUb+hQkrF8n78YjG/kEDlr7UJRHQEo39ghSnuix7kKbijf
xMG49+13xwOcUL6pQ9vEbKtqeXYo38xh+e7rYqdkWKF8cwdI+DJB+RZQ/T/t
IXxLh/eWv/456T2zBwAQcWCz
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQA2IQDQEf7MVCt+7emK3kABVw6N7yOGD3VUUon8PBJvK8
hY0djC/gwHXraH7rbAUoX8RBvfXhrJCH8lC+hIPwjZ5v9TvkoHwZh3O/k269
7JOF8hUcTveXStYnyED5Sg581jcUZqpKQ/kqDpXBXTon/ktC+WoOihKJf8/e
lYDyNRwqNwb+0KgSh/K1HOaVrrhloCQG5es4rJO9rKT1XATK13NIn8pUwmsM
4xs4HAk4MLthlxCUb+hQvHF9Z0CVIJRv5GAf/iXGTxrGN3ZY4Xj46DFJXijf
xEH+39nTFh+4oHxTh586k2qW53BC+WYOHzZf/FsrCuObOyh7TbsWtQKm3gJN
vaXDWakPr6YIwOStHCY+Lq52+s4O5Vs7vLf89c9Jjw3Kt3GonXd5j9hDZijf
1iE8ymhdkdJ/ewjfzoFJQesX9+o/UL69Q/Fqa/tNixig6h0cuJnXVr2a/BEi
34DGZ3CE2vcMKu+IJu/kYNz79rvjgZ9QeTQ+gzNcPwC7jZ/J
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwqLxwN1bspCKUz+GwL3gN
9wY9GF/AYVadSMH/mQpQvojDzw7XNWvZYXwJB53M8K8nD8tB+TIOTarRcXdm
yUL5Cg6n+0sl6xNkoHwlB27LtHtvzKWhfBWHV48v/JCXk4Ly1Rx0G2/GcX+R
gPI1HPRmbnof+0ccytdyONZzqLxsvxiUr+Mw65TQrgXrRKF8PYcD2k5v1xSJ
QPkGDrXzLu8ReygM5Rs6TH/Yw3jvoxCUb+TwYwl73RNHGN/YwT78S4yftCCU
b+KgK6jxcdZFASjf1MFz5bpVqnP4oXwzh/Aoo3VFSjC+ucM33p2Nf0x5oHwL
h9nXuH8uM+WG8i0dqup/HcxexQblWzm0Tcy2qpZnh/KtHXzM67c/1mOG8m0c
uJnXVr2azAjl20L5H+0BxHxy+w==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwmH8zgoPxgiKUz+Hw9rGx
61RTGF/AYdtDW3mfaQpQvoiD6WrJD6+fykP5Eg6LM99HpS+Vg/JlHCQW/D2a
2CoL5Ss4NFc1FtuHyUD5Sg6b0sXUVnFJQ/kqDux3uzduficJ5as5WJaHPGb7
JQHlazhk8v0IyV0uDuVrOew8HbktPFIMytdxOKjcosGgJArl6zlUVWo/v6Yq
AuUbOLCFMm7+cFgIyjd0uJL6jVNjpyCUb+RQqXn8Z6q/AJRv7OAc8seM1Y0P
yjdxyD6xY9/lndxQvqmDzmYWNrM+dijfzCGwx1CbpZUFyjd3kPfwtRRbxQrl
Wzj4mNdvf6zHDOVbOhSvtrbftIgByrdy4GZeW/VqMiOUb+3ApKD1i3v1H3sI
38bhveWvf05636B8WzgfAAIkbIw=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwEHstpz/tviKUz+Gw+Ouz
hU/sYXwBh7eHsjP5lylA+SIOz3+c0LHhg/ElHF7JTHbad0cOypdxeH6+/unn
a7JQvoLD0c/8wVGFMlC+ksOWdc0d4k7SUL6KQ2vnPFsZRSkoX82hKedt9/Lr
ElC+hgNfhVbYvcniUL6Wg9nKoFivajEoX8fh4przn1VyRaF8PQeVcsbJZu+F
oXwDh5hm46gbL4SgfEOHK6nfODV2CkL5Rg4nr6l8+c0D4xs78AgfKi94yQ/l
mzjwFhlZX27ihfJNHSa0MO+4H8sF5Zs5bFyXP0UvmgPKN3eoqv91MHsVG5Rv
4cDNvLbq1WRGKN/Swbj37XfHAz/tAXk4ZDA=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwiPnCf+/AOUUon8OhUkil
RcEWxhdw8H0oczVggQKUL+Ig/PflvTlSML6Eg67YErF7YvJQvowDm8G3ozUv
ZKF8BYfz6vsWP1wuA+UrORiLJ6mtKZOG8lUcYrj3RcwWloLy1RyePzsq8EVJ
EsrXcLA4Wl89b5c4lK/lYCQ+PzGmTQzK13FYvvu62CkZUShfzyEm6dFjnRfC
UL6BQ3YEe2DydBjf0GGplfGJ5XOFoHwjB5eGir+G7YJQvrHDMmWvWyaHBKB8
E4clJxeXcZfwQfmmDrxFRtaXm3ihfDOH2de4fy4z5YbyzR2Me99+dzzACeVb
OLy3/PXPSY8Nyrd0kPfwtRRbxQrlWzlA4oMJyreG6v9pD+HbQPU/g/JtHbiZ
11a9mvzRHgCzF3BI
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVw8Itj/3jvtiKUz+GwIFdN
ldkDxhdwUE1d/St6owKUL+JgeIRzaoIsjC/hwC8XsNROUB7Kl3HI3tZ6b+oX
WShfweGMZqDIs1syUL6SA+P7yX/+x0tD+SoOjrmqVpmhUlC+msM9aZb7XN8k
oHwNh+Ip62o5D4hD+VoO2Xq/7186KQbl6zh0/rqwSvKvKJSv57Cy4OzFjD4Y
38Ch6Xh47C8fESjf0EHnQ9+67f3CUL6RQ0yzcdSNF0JQvrFDQmHs71MvBKF8
E4fijes7A6pgfFOHZ/pKxnmaML6Zw+d/uyKb2AWgfHMHwTciYh/E+KB8C4ej
n/mDowp5oHxLh43r8qfoRXNA+VYOVfW/DmavYoPyrR2W774udkqGFcq3cQjs
MdRmaWWB8m0dwqOM1hUp/beH8O0cIPHJBJW3dyhebW2/aREDlO+Aym9wcGBS
0PrFvfoPVL8jKr/B0YGbeW3Vq8kf7QFgFIej
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwaLxsN6vtqiKUz+GQueT5
STFrGF/A4cyPgP8bFytA+SIOs3SSrk76Iw/lSzh8UD3H7nBdDsqXcQjVEzle
sUAWyldwcN+hU7C2XQbKV3LwvCR2s7RFGspXcdhUtXSu7WQpKF/NoW/m1epy
D0koX8NhE8Oihm4BCShfy6HNcLvc9QBxKF/Hgf2g8hydN6JQvp5D8Jwp0lWG
ML6BQ9Sn22aqf4WhfEMHH/P67Y/1YHwjB7e9L7McLgpC+cYOn//timxiF4Dy
TRwE34iIfRDjg/JNHc5KfXg1RYALyjdzeG/565+THhuUb+6wfPd1sVMyrFC+
BVT+mz2EbwnlP7MHADXoZLk=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwMD8kELLjpCKUz+Gguttj
kosJjC/gcPBzgoraRAUoX8ShkmPOVKs/8lC+hENyacuFlnVyUL6MA88fqW1v
02ShfAWH/OamhkPCMlC+ksOcwishJk+loHwVB7G79rtKpklC+WoOJZZWHcJL
JaB8DQdL9ysOm9aLQ/laDlZqG26s6RWD8nUckvw0V/zjEYXy9RycDgbLacuL
QPkGDmyhjJs/HBaC8g0deHOEXncUCkD5Rg6eK9etUp3DD+UbO0xoYd5xP5YL
yjdxeG/565+THhuUb+og7+FrKbaKFco3c/Axr9/+WI8Zyjd3KF5tbb9pEQOU
b+HApKD1i3v1H3sI39KBm3lt1avJH+0BciBbjA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQDQEf7MVCt+7emK3kABVw0N4exrrvhiKUz+Hw5SBD
SoULjC/gIP2C47b9agUoX8TBk9VB6YkQjC/h8EpmstO+O3JQvozD5abb0TWz
ZaF8BQep2aFlS+NloHwlB6E4PtFTZtJQvooDE2ezRaeGFJSv5qDwcvPWG/cl
oHwNh6dM28smPRKH8rUcFvAzSf1xFYPydRxc5jwQ2tkpCuXrOQQzWJzbKCgC
5Rs4sIUybv5wWAjKN3SQXf3nWoy5IJRv5JDjNGEv30I+KN/Y4RpvR8ZPP14o
38Th4o6rX2784IbyTR02rsufohfNAeWbOehsZmEz62OH8s0dAnsMtVlaWaB8
C4eJj4urnb7D5C0d2iZmW1XLw/hWDlX1vw5mr2KD8q0dfMzrtz/WY4bybRwg
8cUE5ds6hEcZrStS+m8P4ds5FK+2tt+0iAEqb4+m38Ghdt7lPWIPofwGBzR5
R1TzGxzR3O+EJu/kIO/haym2ihUq74xqf4Ozg3Hv2++OB35C3eeCpt/FgZt5
bdWryYxQ/a6o6htcHd5b/vrnpPcNqt8Nqv6jPQCRBKhP
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVwSAjZUatwThHK53DYUX6V
Q9oFxhdwWNVgYjBhqQKUL+JwxKWCRUQGxpdwKDv0MXfFFzkoX8Yh2S3748H7
slC+gsM7h09vX22SgfKVHL7IXZ5yq0cayldxOMV43ko9UArKV3OoyO23KA2W
hPI1HD6oH5djzZSA8rUctko+u//lvjiUr+PwLvbg9sRjYlC+nkOdTtXsvA+i
UL6BQ/LtPXuWvxGB8g0dfv1wXlSuA+MbOfRu5tTed18Iyjd22BejelCOG8Y3
cZBd/edajLkglG/qYB/+JcZPGsY3c/j8b1dkE7sAlG/u8I13Z+MfUx4o38Lh
xFHb8pJdHFC+pQMk/JmgfCuH95a//jnpfbOH8K0dmBS0fnGv/gPl2zj4mNdv
f6zHDFVv61C82tp+0yIGKN/OgZt5bdWryYxQvr1D7bzLe8QewtQ7OFTV/zqY
vYoNwm9wcJD38LUUW8UKlXdEdU+Do4Nx79vvjgd+Qu13gpr/0R4A3UCSEQ==

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwsJ3pV3/3vCKUz+HwvTMz
3FUJxhdwEJLYKNzVoQDlizjceC+XV3hDHsqXcFDh5dG7uUwOypdxaF0s1xCQ
JAvlKzhM6L/gK/JVGspXclj28luL/20pKF/FgfnKwut2rZJQvpqDmOPjnDVl
ElC+hsMh7xVaF2PEoXwtB8EJfgyORmJQvo6D2Ztnd9ewi0L5eg6/fjgvKtcR
gfINHDRV2J98dxeG8g0dfixhr3viKATlGzmUak6ZPGmTAJRv7NBtlHpndgKM
b+KQ4zRhL99CPijf1IG3yMj6chMvlG/mkH1ix77LO7mhfHOHizuufrnxA8a3
cPiw+eLfWlFOKN/Soar+18HsVWxQvpVD7bzLe8QeMkP51g6Q+GGC8m0cuJnX
Vr2azAjl2zqERxmtK1L6bw/h2zm8t/z1z0nvG5RvD1X/0R4AsBR7jg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwyDziovjgsiKUz+Fg8Py6
k6sjjC/gsG9i+bOmVQpQvoiD0NPdYda8ML6Eg033oTmiN+WgfBkHhr7ZQtOn
yEL5Cg7Pmjf0fguXgfKVHOp1/7/x5JCG8lUczpg95wq9KwnlqzlwOp145Zct
AeVrOGydtcyxj18cytdyOOzxeZ7iHlEoX8eh6Xh47C8fEShfz2Hv8fb7P+qF
oHwDB0XH9M7SfwJQvqHDkpOLy7hL+KB8I4fZ17h/LjPlhvKNHZbvvi52SoYV
yjdxeG/565+THhuUb+pQVf/rYPYqGN/MQWczC5tZHzuUb+4g7+FrKbYKpt/C
gZt5bdWryYxQvqUDk4LWL+7Vf+whfCs0vrVDeJTRuiKl/1C+DVT/RyjfFuqe
Z1C+HVweALU+diM=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw+Nmd83/GRUUon8PhdmKd
oa8pjC/gUCbJcixwoQKUL+LA9/NH60o2GF/CwUR6xXrHI3JQvozDFM6Wi0t7
ZaF8BYcVzkmive4yUL6Sw9+06PLln6SgfBWHBawHgo5XSUL5ag59xq8ZbwVK
QPkaDpFKFgtuhIlD+VoOzS2H70w/IArl6zgIrb2a+aFOBMrXc3DSS5hSlCAM
5Rs4zNy/vDxURwjKN3SQXf3nWoy5IJRv5BCQo3X6q6QAlG/scHHH1S83fnBD
+SYOHzZf/FsrygnlmzpsXJc/RS+aA8o3c/ipM6lmeQ5M3twhsMdQm6WVBcq3
cChebW2/aREDlG/pYNz79rvjgZ/2EL6Vw3vLX/+c9L5B+dZwPgD9ZW3R
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwcBG6E+l4WRHK53B4aHfM
VtodxhdweLTv8IXzSxWgfBGHOs4FqZyMML6Ew6WDCe+2npaD8mUcQrepH7G8
JAvlKziEPF6n93KxDJSv5MB+Rb00pUgayldxCDPepFmVLAXlqzlId1qtv6Mi
CeVrOEx8XFzt9F0cytdy2LdLiOPDFDEoX8dB4bHo1MWRolC+nkP11UpehgQR
KN/AIemE0i7jBmEo39Ch4NrnQ4mKQlC+kcMyZa9bJocEoHxjh/8Mgf8TSvih
fBOHJScXl3GX8EH5pg5R2hM9zlVwQ/lmDm0Ts62q5dmhfHOHjevyp+hFc0D5
FlD3w+QtHXQ2s7CZ9cH4Vg7yHr6WYqtYoXxrh+LV1vabFjFA+TYOxr1vvzse
+GkP4dui8e3Q+PYO3Mxrq15N/gjlO6DyGxwc3lv++uek9wwq74jKb0DwAeRU
jPQ=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwOLG2xbrthCKUz+Ewa5XX
5kJtGF/AYZ7h5pid/QpQvohDbtjFDzF35KF8CYdl1/KVHk+Rg/JlHF7nTzJR
dZGF8hUcvl0+4V/5TxrKV3LQrZBcW7VLCspXcTC0Wazwy1cSyldzaPl/J4iN
UwLK13BgLZHVrt8hBuVrOch7+FqKrRKF8nUcNq1vk5O4IwLl6znI7Sze1n5a
GMo3cOjdzKm9774QlG/oIKBjKH3uvyCUb+QgLfH4xcRJAlC+scO2DxP0pc7y
QfkmDkwKWr+4V/NA+aYO8v/Onrb4wAXlmzlMfFxc7fSdHco3d6iq/3UwexUb
lG/hwM28turVZEYo39KheLW1/aZFDFC+lUN4lNG6IqX/9hC+NdS+P1C+DZq8
LZp5dmjm2aOpd3B4b/nrn5PeNwi/wcHBuPftd8cDP+0BhYOBeg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwmFgpenLKdUUon8MhoIon
/6EdjC/gsGnSwTnvNylA+SIOxkedtpmJwPgSDpM51/0QZJSH8mUcTlvP/L52
jyyUr+Dw9f6jMvFYGShfyeFH3PrUCx7SUL6Kw7rzlYFW5lJQvpoDo0jH539/
JaB8DQdVznMRek/FoXwthxmWu6e9PSQG5es4/C5cUO+bIQrl6zls/NH3UsJB
BMo3cHiSpWn1t10Yyjd00PRTFnHNFYTyjRy6jVLvzE4QgPKNHXRt9UL2P+OF
8k0cjn7mD44q5IHyTR02rsufohfNAeWbOfiY129/rMcM5Zs7hEcZrStS+m8P
4Vs4GPe+/e544Kc9AKtlXmM=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwsOe9OnXmZUUon8NB9Y1n
7HQdGF/AISFK9klOtwKUL+LAfvhLlgATjC/h8Pq8fpLsYzkoX8bBb02fa+pW
WShfweHdPek9dR0yUL6SQ8qPJ3MmLJKG8lUcPt713jatUgrKV3OY9DZDo85a
EsrXcNgq+ez+l/viUL6Ww5zzqp5sXWJQvo6Ddr/bOafTIlC+noPczuJt7aeF
oXwDB4h/haB8Q4fdUlPm7nwvAOUbOeja6oXsf8YL5Rs7XNxx9cuNH9xQvomD
vIevpdgqVijf1CGwx1CbpZUFyjdz8DGv3/5YjxnKN0fjW0DtZ4LyLR3eW/76
56T3zR4Ag+RipA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEf7MVCt+7emK3kABVwCBfZayx7XBHK53Aw6n70
qk4HxhdwULX4L/x4lgKUL+Jw57l0+uy/8lC+hIPUhX6v+1floHwZh9Mdzy8/
Xy4L5Ss4POGcq2bcJwPlKznIOs1IKHWVhvJVHLI3VhQkf5aE8tUc4nM3zp9x
VQLK13D48C217sFCcShfy+H28S23rheLQfk6Dvci+tp7votA+XoOUZ9um6n+
FYbyDRx+eD/laPQRgvINHbgW/4hzOyoI5Rs5rLZRytA4zA/lGztc4+3I+OnH
C+WbODApaP3iXs0D5Zs6nJX68GqKABeUb+Zw4qhteckuDijf3KGq/tfB7FVs
UL4FGt/S4b3lr39OejC+lcPy3dfFTsmwQvnWaHwbh/Aoo3VFSv/tIXxbqHv+
QPl2aPL2DsWrre03LWKA6ndAlW9wQJN3RJN3dDDuffvd8cBPqHlODtzMa6te
Tf4IlXeCuv8ZVN4ZVX2DM1T+G1TeBU2/C1w/AGUAr1w=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVw0H2atPn1LUUon8NBNWir
/1dTGF/A4SHXyaqPCxSgfBGHCUFuSyd9lofyJRzqZ6wu+HJODsqXcdBPnJ9q
Wy4L5Ss43POZv6nfQQbKV3JYbbXxzuMXUlC+ikOPovXhn3skoXw1h6act93L
r0tA+RoOT5m2l016JA7laznEMASLBUwUg/J1HPyKBaqnHRWB8vUcnPQSphQl
CEP5Bg7R7vu5fm0QgvINHfYeb7//ox7GN3IQenHg0OogQSjf2GG1jVKGxmF+
KN/EYcnJxWXcJXxQvqkDk4LWL+7VPFC+mcPGdflT9KI5oHxzh7aJ2VbV8uxQ
vgUa39IhsMdQm6WVBcq3cpD38LUUW8UK5Vs7LN99XeyUDIxv4+BjXr/9sR4z
lG/rwM28turVZEYo387hveWvf0563+whfHso/5k9AN30eBM=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwyPyz/0foOUUon8OhULmq
b5URjC/gEK4yXSlougKUL+LQtcr4SQIXjC/hcKFC+u/KH3JQvoxDslv2x4P3
ZaF8BYfz6vsWP1wuA+UrOTR/2/8sskkayldxaKx8W64oLQXlqzk8U1r8NXWO
BJSv4RBsyMFwM1gcytdy6KqLE1/zRRTK13GI8OgXeLRfBMrXc+grKF0VHQzj
GzgcCTgwu2GXEJRv6FC82tp+0yIBKN/IoXR3gI3FDz4o39ghSnuix7kKbijf
xMG49+13xwOcUL6pQ9vEbKtqeXYo38zhveWvf056bFC+uUPtvMt7xB4yQ/kW
DtzMa6teTWaE8i3R+FYO4VFG64qU/ttD+NZQ+35C+TZQ9R+hfFs0vh3U/mf2
AIsmeWU=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwYN76wcPhqiKUz+HA35ex
s8QExhdweGx+fwLzbAUoX8ThZ4frmrXsML6EQ4SyzF7713JQvozDoVmKj49e
lYXyFRxEbn2sqjgjA+UrOazfqKLGXysN5as4lO6Vr1pvIQXlqzksi3iZYW4v
CeVrOFyNfmj58p84lK/lcFozb4PMHzEoX8fh5JWW1tKTolC+nkP89a1xlytE
oHwDh9Pbtq4sKhCG8g0dskp+bGMMF4LyjRye6SsZ52kKQvnGDp4r161SncMP
5Zs4MClo/eJezQPlmzr81JlUszyHE8o3c6iq/3UwexUblG/uIO/haym2ihXK
t3ConXd5j9hDZijfEo1v5WDc+/a744Gf9gBmKWcs
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBwBWIQDQEf7MVCt+7emK3kABVwiJy17JDIWUUon8Mh6rPJ
QQcrGF/AYeXOd3d55ilA+SIOzwWbVs9ngfElHA55nVwpuV8Oypdx0O1PcJCZ
IwvlKzh8/ZUyS7NGBspXcgjYrqVo7iwN5as4rDtfGWhlLgXlqzn8TauqSD0v
AeVrOFi9ftywfpo4lK/lwLPSPHDPfDEoX8fhKeu0b9uni0L5eg5Ca69mfqgT
gfINHJ5rfqo0DBCG8g0d2EIZN384LATlGzlcsp/EIn5XEMo3drA8t3vBsQcC
UL6Jw+d/uyKb2GF8U4fwKKN1RUr8UL6Zw97jVu80HvNA+eYOP3Um1SzP4YTy
LRx0NrOwmfWxQ/mWDu8tf/1z0mOD8q0cNq7Ln6IXzQHlW6Opt3E4K/Xh1RQB
LijfFk3eziGwx1CbpZUFyrd38DGv3/5YjxnKd3CAxDcThN+AxmdwRFXf4OhQ
vNraftMiBqi8k0PtvMt7xB7C5J0cqup/HcxeBXO/s4O8h6+l2CpWqLyzQ9vE
bKtqeZj7XBwmPi6udvoO5Te4oKpncEUNjwZXh+W7r4udkoHJu6Ga1+CGah6D
u8OJo7blJbug4dfgjhY+Hmju80CT90QNvwZPNPu9UPkNXmjh640aHg3eaPHr
gxq/DT5o5vuihb+vAzfz2qpXkxmh8n5o4e+Hpt8fzf3+aO4LQI1PhwAH4963
3x0P/LSHqA+A2vcRwj+AxmcIRFXvEAj13zN7ALYgD1c=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwmHlyNlPdKUUon8Oh2fW5
aoEhjC/g8IDT4vWJqQpQvojDAUOr20tYYXwJh0u88rwKx+SgfBmHDQJzuS2m
ykL5Cg6Wn04aBDjJQPlKDi9zxCzyn0lB+SoO1rsY1tr+k4Ty1Rz27ZELYX4j
AeVrOFRuDPyhUSUO5Ws5mK0MivWqFoPydRxOXmlpLT0pCuXrOcjcjnAQmCgC
5Rs4aKqwP/nuLgzlGzpoy4pJpicKQflGDoqO6Z2l/wSgfGOHJScXl3GX8EH5
Jg5MClq/uFfzQPmmDsa9b787HuCE8s3Q+OYOOptZ2Mz62KF8C4f3lr/+Oemx
QfmWDvIevpZiq1ihfCsHbua1Va8mMzoAAJMKW9o=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwqPLJ5JK7rAjlczjs5Jsb
EG4P4ws4TLpaKFS9UQHKF3Fo61Ju5ZWF8SUcOmUvMT/6JQflyzgwbYmM+D1X
FspXcPh4M7YvIlEGyldyEI28WGloJQ3lqziclfrwaoqAFJSv5qB1ba0QxwwJ
KF/DgffLnJfec8ShfC0H19THm3tmiEH5Og6ZKV8r9NVFoXw9B3Y5lpAjl4Sh
fAOHH0vY6544CkH5hg6lmlMmT9okAOUbORSvtrbftAjGN3aInLV2oagOjG/i
4Bzyx4zVjQ/KN3U4+pk/OKqQB8o3c5h9jfvnMlNuKN/c4cRR2/KSXRxQvoXD
T51JNctzOKF8SzS+lcPEx8XVTt/ZoXxrBx/z+u2P9ZihfBsHSHwxQfm2DkwK
Wr+4V/+xh/DtHN5b/vrnpPfNHgCE03ER
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVw8OTwCom8pgjlczic8LI6
U+gA4ws47JtY/qxplQKUL+LA5XLsRzcXjC/hsO3DBH2ps3JQvoyD96a2bplu
WShfwcHy00mDACcZKF/JoZwh3v7eZykoX8WBs9BX4OlBSShfzWGd4KlnLxdJ
QPkaDtP68wpWtYpD+VoOZiuDYr2qxaB8HYckP80V/3hEoXw9h76C0lXRwSJQ
voGDq+2TmvO/hKB8Q4fUucuYqhcIQvlGDqttlDI0DvND+cYOOU4T9vIt5IPy
TRy+8e5s/GPKA+WbOmSf2LHv8k5uKN/MoW1itlW1PDuUb+6wfPd1sVMyrFC+
hQM389qqV5M/2gMAgDlbrA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVw8LASXqt9XhHK53C45r1U
5owxjC/gkNN7rmfnDAUoX8Th3+3Mec94YXwJhw+q59gdrstB+TIOx0w9JebM
lIXyFRx4mqdNW1spA+UrOWjv6WSdmy4N5as4nGq8e4zbVgrKV3NYUeeb5yEt
CeVrOEx8XFzt9F0cytdyMBKfnxjTJgbl6zj85ku3P+gqCuXrObRXHan4MUcE
yjdwSDqhtMu4QRjKN3QwdJu10+usEJRv5GBj5NPOlyAI5Rs7vL6j3qLfJADl
mzhs+zBBX+osH5Rv6iD4RkTsgxiMb+ag7DXtWtQKLijf3OHEUdvykl0cUL6F
g7yHr6XYKlYo39Khqv7XwexVbFC+lUPtvMt7xB4yQ/nWaOptHAJ7DLVZWlmg
fFuH5buvi52SgcnbOby3/PXPSQ9mnj2avINDeJTRuiKl//ZgboODg3Hv2++O
B37aAwB46Hw0
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwWMPPJJ17RRHK53BI/HQk
b5INjC/goNPxMcVrhQKUL+Ig8SIpXZAPxpdwkLrQ73X/qhyUL+Mg9nP5+d8z
ZKF8BYe4oFdLTsfJQPlKDmIvohgUlKShfBWHxsq35YrSUlC+msODE68Fc8Ul
oXwNB1XOcxF6T8WhfC2HjOp7aYuYYHwdh+nLFq5QkhOD8vUcNv7oeynhIALl
Gzj88H7K0egjBOUbOjzTVzLO0xSE8o0cImetXSiqIwDlGztc4+3I+OnHC+Wb
OMj/O3va4gMXlG/qMKGFecf9WBjfzOGnzqSa5TmcUL65w3vLX/+c9NigfAsH
bua1Va8mM0L5lg7Fq63tNy1igPKtoOq/2QMAYvtjHg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwUBaw3zLhkiKUz+HA3FHW
o2cN4ws4xGxbfXDuTAUoX8RhssyJuUeZYXwJB29D47daN+SgfBmHsP9LIrob
ZaF8BQeRE5VhdX4yUL6Sw8eLp6RW6EpD+SoODFfyCrNfSEL5ag6MEy79e9ko
AeVrOPidCziyPEMcytdyuKqRk7hsuyiUr+MgtPZq5oc6EShfz8F780evQHNh
KN/A4Zm+knGepiCUb+iw2kYpQ+MwP5Rv5MBbZGR9uYkXyjd2uMbbkfHTD8Y3
cbi44+qXGz+4oXxThwktzDvux3JB+WYOG9flT9GL5oDyzR0mPi6udvrODuVb
OLy3/PXPSY8Nyrd0CI8yWlek9N8ewrdyKF5tbb9pEQNU3tqBSUHrF/fqP1B5
Gwfj3rffHQ/8hPJtHbiZ11a9mvwRyreDmv8MyreH8wEl6nzJ
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVwmK1slNd9ThHK53BQSTf1
UzWD8QUcildb229apADlizgs3FoktEcAxpdwMPKrNt91UQ7Kl3HIVT+1V7Za
FspXcDAvKbyTbyQD5Ss5uNyr/id8VQrKV3FYdmjvsawTklC+msPh5VvmmM+S
gPI1HNoMt8tdDxCH8rUcfhcuqPfNEIXydRwC9BcolUiIQPl6DlklP7YxhgtB
+QYOkbPWLhTVEYDyDR1KdwfYWPzgg/KNHHiLjKwvN/FC+cYORz/zB0cV8kD5
Jg5npT68miLABeWbOrRNzLaqlmeH8s0cuJnXVr2azAjlmzu8t/z1z0nvmz0A
9aNVUA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwuKj2/N2604pQPodDbtsp
s7lmML6AQ0jbac9n6xWgfBGHvCrtE54KML6EwwS5+E/X38lB+TIOu9jjWqfd
k4XyFRyct8SfO7ZeBspXcmB8P/nP/3hpKF/F4XjAikt1dlJQvprDJsfOpp//
JaB8DQdVznMRek/FoXwth8a5F+IlC8SgfB2H33zp9gddRaF8PYeNP/peSjiI
QPkGDq62T2rO/xKC8g0dDHdJqz8qhfGNHJ7pKxnnaQpC+cYO66XXbL/kzQ/l
mzjsPW71TuMxD5Rv6qDsNe1a1AouKN/M4b3lr39OemxQvrkDJHyZoHwLh+LV
1vabFjFA+ZZQ9d/sIXwrKP+ZPQDo/mrX
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwmF3eyvrxjCKUz+Gwbmck
h5M+jC/gMNHi5amOOQpQvohDfLrkpJMf5KF8CYcls4WUmxbJQfkyDl0qLWk8
RbJQvoKDRbUQ3wM9GShfyeFvWnT58k9SUL6KQ6jNrRSVW5JQvprDDB+VII5e
CShfw+FQT7/gYiVxKF/LYVEjz6YlgWJQvo7D78IF9b4ZolC+nkMwg8W5jYIi
UL6Bg+EuafVHpUJQvqFDDPuiWdKuglC+kUN4lNG6IiV+KN/Y4afOpJrlOZxQ
vonDxMfF1U7f2aF8U4fAHkNtllYWKN/MgZt5bdWryYxQvrnDe8tf/5z0vtlD
+BZofEsH49633x0P/ITyrRyYFLR+ca/+A+Vbo/Ft0NTbQu37aA8AvgRu0A==

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw6N7yOGD3VUUon8MhKfsc
X6ILjC/gENqa2p6/TgHKF3HIiVwv95wPxpdwSDHgXvfomxyUL+PAUP3lvMxR
WShfwSG/s7U1N00GyldyOKA1/5KnqDSUr+LA9d846809SShfzUG4wPtgXq0E
lK/hcPDwUqZrkeJQvpbDvNIVtwyUxKB8HYcIj36BR/tFoHw9h6hPt81U/wpD
+QYOGz9Jza/KgPENHfYeb7//o14IyjdycGmo+GvYLgjlGzustlHK0DjMD+Wb
OHzj3dn4x5QHyjd1yD6xY9/lndxQvpnDiaO25SW7OKB8c4flu6+LnZJhhfIt
HLiZ11a9mswI5Vs6hEcZrStS+m8P4Vs5GPe+/e544CeUbw1V/9EeAOHDbKs=

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw+HT6zOed5xWhfA4Hz79+
7UGWML6Aw8qd7+7yzFOA8kUcYq5zGL9mgvElHA55nVwpuV8Oypdx4C0ysr7c
JAvlKzhMspp4pnmmDJSv5JBf45/q6isN5as4rDtfGWhlLgXlqznoNt6M4/4i
AeVrOOxeJDenRgrG13L4yBd6WFNfHMrXcbBS23BjTa8YlK/nYPbm2d017KJQ
voFDVaX282uqIlC+ocP2gmWReqLCUL6RQ9OTpN4nawShfGMHHuFD5QUv+aF8
E4ccpwl7+RbyQfmmDh82X/xbK8oJ5Zs5LN99XeyUDCuUb+5g3Pv2u+OBn/YQ
voXDe8tf/5z0nkH5lg7czGurXk3+COVbofGtoeq/Qfk2cP0Ascpzlg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7MVCt+7emK3kABVweG86JaT2giKUz+Gw0b7n
l7cFjC/g8FNiTYvDLAUoX8Th7zuWco1f8lC+hEMjn4ZaChOML+NQYZHIuPaR
LJSv4OC8Jf7csfUyUL6Sg+3Wc7zLlklD+SoOFUaHH5THSEH5ag7MVxZet2uV
hPI1HNhlUp7a9ktA+VoOwocVdcXni0P5Og5ddXHia76IQvl6DutkLytpPReB
8g0coj7dNlP9KwzlGzoYus3a6XVWCMo3ctgXo3pQjhvGN3Z4IxyZ+q0Txjdx
sDHyaedLEITyTR14c4RedxQKQPlmDs4hf8xY3figfHOH2de4fy4z5YbyLRzO
Sn14NUWAC8q3dPiw+eLfWlFOKN/KYfnu62KnZFihfGuH8CijdUVK/+0hfBsH
JgWtX9yr/0D5tmh8OzS+vQMkfpmg5jmgmtfg4FBV/+tg9io2qLwjqvoGRwcf
8/rtj/WYofJODtzMa6teTWaEyjuh2efs8N7y1z8nvW9Q853R5F2g+j/aAwAV
7Jl6
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwKBI/lshzWRHK53CYaPxE
RdAKxhdwuLjnz7rOFQpQvoiDbYVyi5UQjC/hoJo11yxTWB7Kl3EQOczmzr1T
FspXcDjU6tB7PU8GyldycO9c7iVuKA3lqzi8enzhh7ycFJSv5pDw8/nPXmFJ
KF/DoeTW4hOCN8ShfC2HNdZLjnm9EIPydRyUNnHMOuoL4+s5/OZLtz/oKgrl
GzjI7Sze1n5aGMo3dOjuXaq6lhnGN3KIYV80S9pVEMo3dug2Sr0zO0EAyjdx
2PZhgr7UWT4o39Thp86kmuU5nFC+mUNV/a+D2avYoHxzh9p5l/eIPWSG8i0c
ildb229axADlWzqERxmtK1L6bw/hWzm8t/z1z0nvGZRvDeV/g/Jt4PIA4XJu
UA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwqDuU/b3/lCKUz+Hwc82q
HlMdGF/AYaLFy1MdcxSgfBGHQxNWn1f6KA/lSzh8SJ0lYrZKDsqXcXh+U72J
p1YWyldwMLsaKcOiKgPlKznwWd9QmKkqDeWrOMSc9+Tce1sSyldzeKa0+Gvq
HAkoX8Ohx+pfmnO5OJSv5TDnvKonW5cYlK/jUDlB5KonI4yv56DwWHTq4khR
KN/AISbp0WOdF8JQvqHDD++nHI0+QlC+kYPlud0Ljj0QgPKNHXKcJuzlW8gH
5Zs4MClo/eJezQPlmzp82Hzxb60oJ5Rv5qCzmYXNrI8dyjd3WL77utgpGVYo
38IBEt5MUL6lAzfz2qpXkxmhfCsH49633x0P/LSH8K0d3lv++uek98weAALJ
aUs=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwmHlyNlPdKUUon8Mh86Lr
6R4TGF/AgX3npxa7KQpQvojD//6oH3nH5KF8CQcDB7/3E8vkoHwZhwc9t3Qc
vGShfAWHSeslHDMUZaB8JYcN83LCYrSloXwVh0U6wSJBjFJQvppDRYPg9PKL
ElC+hkNBx6yPhYXiUL6WQ3r2M+cDvGJQvo5D8u09e5a/EYHy9Rxikh491nkh
DOUbOED8KwTlGzo801cyztMUhPKNHLqNUu/MThCA8o0dcpwm7OVbyAflmzhM
aGHecT+WC8o3dbi44+qXGz+4oXwzh43r8qfoRXNA+eYOtfMu7xF7yAzlWzj4
mNdvf6wH41s6vLf89c9J75s9hG/lwM28turV5I9QvjVU/pk9AMkYbFY=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw2PR21sX7FxWhfA6HmIf9
Rl3aML6Aw8HPCSpqExWgfBEHi7MKds5/5aF8CQcujSnWHFfkoHwZh+AUmy7p
E7JQvoLDZP2TK8WWy0D5Sg59P/6vkKuThvJVHARYH3fxR0tB+WoOSTs2WB66
LQHlazgkRIb9nJ4tDuVrOcw5r+rJ1iUG5es4HPb4PE9xjyiUr+cQf31r3OUK
ESjfwOFJlqbV33ZhKN/QYamV8Ynlc4WgfCOHpidJvU/WCEL5xg7dRql3ZicI
QPkmDuFRRuuKlPihfFOHJScXl3GX8EH5Zg7XeDsyfvrxQvnmDhNamHfcj+WC
8i0czkp9eDVFAMa3dKiq/3UwexUblG/lUDvv8h6xh8xQvrUDk4LWL+7Vf+wh
fBuH95a//jnpPYPybdH4dg7czGurXk3+aA8ADz14gQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwWGZZ8rH9siKUz+GgU5qV
LKgP4ws4aBtE/uidpwDlizi03mTTS+OF8SUcFq5Skza+Kwflyzg4vHK4FrpI
FspXcDj6mT84qlAGyldyKJy6ftHrYGkoX8XheMCKS3V2UlC+msMfxk/pO6Ik
oXwNhwc/5UKbDCSgfC2HyNp3rj1fxaB8HYeJsplvZj0WhfL1HK6ztV+X/SQC
5Rs4nEuM+Pj5pjCUb+iQOncZU/UCQSjfyCFy1tqFojoCUL6xw7YPE/SlzvJB
+SYO4VFG64qU+KF8U4fS3QE2Fj9g8mYOTApav7hX80D55g7GvW+/Ox7ghPIt
HD5svvi3VhTGt3SQ9/C1FFvFCuVbOby3/PXPSY8Nyrd2mPi4uNrpOzuUb+Pg
Y16//bEeM5Rvi8a3g9r30x7Ct4e65489AND+eIA=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwuPQ7pHPzFUUon8OhaMvt
iHo9GF/AgWO9ab7vPAUoX8SBjaPf8SMzjC/hELb0cEb8bTkoX8bh5+zvK5VX
ykL5Cg7uO3QK1rbLQPlKDjL7Zj5pi5KG8lUcGivflitKS0H5ag539rRb/Xwu
AeVrOFgcra+et0scytdycEjadn1SuRiUr+OQmfK1Ql9dFMrXc6iq1H5+TVUE
yjdweJKlafW3XRjKN3QouPb5UKKiEJRv5FC8cX1nQJUglG/sULza2n7TIgEo
38ShdHeAjcUPPijf1EHXVi9k/zNeKN/M4RpvR8ZPPxjfHE29BZp6S4e2idlW
1fLsUL6Vg7yHr6XYKlYo39qhqv7XwexVbFC+jcPy3dfFTsnA5G3R1Nuhyds7
MClo/eJe/cceANrEddw=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwiPnCf+/AOUUon8PhyOEe
8WNaML6Aw71X79XsuxSgfBGHCUFuSyd9lofyJRx+mod8f31CDsqXcRD7ufz8
7xmyUL6CQ+ttfc3oMhkoX8lh6equvk/60lC+ikNj5dtyRWkpKF/NgVGk4/O/
vxJQvobD3yPy3VtuiUP5Wg6zVh50/rpWDMrXcfjNl25/0FUUytdziOGQaphh
KQLlGzhMVf0byTBfGMo3dNh7vP3+j3ohKN/I4Zm+knGepiCUb+zAI3yovOAl
P5Rv4rDtwwR9qbN8UL6pwzfenY1/THmgfDMHZa9p16JWcEH55g4b1+VP0Yvm
gPItHN5b/vrnpMcG5Vs6GPe+/e544Kc9hG/lwM28turV5I9QvjVU/Td7AGD+
cLM=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCwAGIQDQEf7MVCt+7emK3kABVwUH/G8enBDUUon8NhwqQd
p+I9YHwBB1ELrqk+mxWgfBGH4tyw2cekYHwJh/+f3rZ1C8lD+TIOIofZ3Ll3
ykL5Cg5HsrS+bJ0hA+UrOfRlSfqLJ0pD+SoOKYe3GfbwSkH5ag4HTy+ySWiT
gPI1HNZcl32wfIk4lK/lcDnnzs4TKWJQvo7DyoKzFzP6RKF8PYcWlpOnOKaL
QPkGDjof+tZt7xeG8g0dJqd+mByzXAjKN3I4eU3ly28eQSjf2OHzv12RTewC
UL6Jw2obpQyNw/xQvqlD9okd+y7v5IbyzRwmPi6udvrODuWbO3zYfPFvrSgn
lG+Bxrd0eG/565+THhuUb+WwfPd1sVMyrFC+tUPtvMt7xB4yQ/k2aHxbh8Ae
Q22WVhYo3w5N3t7Bx7x++2M9GN/BARLfTBB+g4ODvIevpdgqmH2ODlX1vw5m
r4K6p8HR4cRR2/KSXRxQeScHnc0sbGZ9UP81OKHZ74zKb3BGc48LqnsaXND8
64qm3xVN3g3NfjeHs1IfXk0R4ILKu6OGf4M7qnoGD4eN6/Kn6EVD/dPg4fBT
Z1LN8hxYfHiihkeDJ5r/vBy4mddWvZrMCJX3cgiPMlpXpPTfHiLv7cCkoPWL
e/UfCL/BGxq/36DyPlD+M3sAEZvdqw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwOCb5O6D5liKUz+GQ8aHe
v9MBxhdweL3CSPrTQgUoX8SBZ0rLk4Zf8lC+hMOLj7eY9LfKQfkyDvqJ81Nt
y2WhfAWH9+eObBMNlIHylRwOxvy/l+gnDeWrOLSx2yvwqUtB+WoO7q4lmcx/
JKB8DYcP31LrHiwUh/K1HEp+rVQytBKD8nUcFB6LTl0cKQrl6znEX98ad7lC
BMo3cPDe/NEr0FwYyjd02BejelCOWwjKN3LQFdT4OOuiAJRv7LDtwwR9qbN8
UL6JwzXejoyffrxQvqlDlPZEj3MV3FC+GRrf3OGnzqSa5TmcUL6Fw4fNF//W
isL4lg4TWph33I/lgvKtHOT/nT1t8QHGt3bIPrFj3+WdMPNsHDauy5+iF80B
5ds61M67vEfsITOUb4fGt3d4b/nrn5PeN3sI38HBuPftd8cDPyH8Bgeo/DOo
vCMqvwHBBwDnLJI/
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwmD/x3sroS4pQPoeDVsey
p7ONYXwBh+scdp/45itA+SIO7qaH104QhPElHETn7kqSuSwH5cs4hOqJHK9Y
IAvlKziInKgMq/OTgfKVHB6d5U5u+C4F5as4WO9iWGv7TxLKV3PQurZWiGOG
BJSv4SAqbqp9tkkcytdyeLTwSqiAlBiUr+MQPGeKdJWhKJSv57C5oPhzVIUw
lG/gsPd4+/0f9UJQvqFD05Ok3idrBKF8I4fi1db2mxYJQPnGDjzCh8oLXvJD
+SYOKxwPHz0myQvlmzooe027FrWCC8o3c9i4Ln+KXjQHlG/uUFX/62D2KjYo
38Khdt7lPWIPmaF8SzS+FRrf2iE8ymhdkdJ/ewjfxsG49+13xwM/7QHmkW59

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwUFkQbW5xUxHK53B4cHh2
T4sPjC/g8LLK0HreagUoX8TBtkK5xUoIxpdwkA3/YvfwvByUL+PgwuzB8G2y
LJSv4LCx8OnrNZEyUL6SQ4GbS2V7mjSUr+JwK7VELoVFCspXc1gW8TLD3F4S
ytdw2MSwqKFbQALK13KQ68ha+UVUHMrXcZgom/lm1mNRKF/PQbvf7ZzTaREo
38AhMv6QR1SEMJRv6CC7+s+1GHNBKN/IYbWNUobGYX4o39gh+8SOfZd3ckP5
Jg4fNl/8WyvKCeWbOhj3vv3ueADGN3PQ2czCZtbHDuWbO5w4altesosDyrdw
eG/565+THhuUb+ngY16//bEeM5Rv5VA77/IesYcwvjXU/J/2EL4NVP83KN8W
yn9mDwDP73Jo
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwEFlZ5uR/XhHK53CIlFi5
YZE2jC/gYHQn5dvHPgUoX8TBilvAO48ZxpdwCO99UvDrgByUL+NQ2mSi+CVF
FspXcHgcVeYSIiED5Ss5THxekNL4UArKV3FwZO++K7BZEspXc+gJ5fK4tF4C
ytdweL1l7n2DVeJQvpZD49wL8ZIFYlC+jkPwnCnSVYaiUL6ewyy/xl+PuUSg
fAOHS/aTWMTvCkL5hg4x7ItmSbvC+EYO3Uapd2YnCED5xg5LTi4u4y7hg/JN
HGZf4/65zJQbyjd1qKr/dTB7FRuUb+YACU8mKN/cgZt5bdWryYxQvgWU/9Ee
AIXWWlg=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw2Nj9d5HaFUUon8Mh+dBO
j6XWML6Aw+LdIv7ZcxWgfBGHMFW9nz2MML6Ew4e6DzWLz8hB+TIOZ4s+MeUv
lYXyFRwYH9c9y/aQgfKVHGrV4nbf5JaG8lUcQm1upajckoTy1RyM/qdI7l8g
AeVrOIhZKRTx1IpD+VoORuLzE2PaxKB8HYd8xt9tq6xFoXw9hwPaTm/XFIlA
+QYO5aKzGfqXCUP5hg6Gu6TVH5UKQflGDrulpszd+V4Ayjd2EHwjIvZBjA/K
N3FgUtD6xb2aB8o3dYjSnuhxroIbyjdz0NnMwmbWxw7lmzu0Tcy2qpaH8S0c
fMzrtz/WY4byLR0Cewy1WVpZoHwrNL411L4/9hC+jcN7y1//nPSe2QMAAYRj
qg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwOGHv8erELUUon8Nh8ddn
C5/Yw/gCDmpXlgbfWKMA5Ys4HHGpYBGRgfElHE64/WfZpSwP5cs4/F98z05L
RA7KV3BYZJ0yf/kTGShfyWHhhusGVVekoXwVh0+SB1hLN0pB+WoOnnzOO4Im
SkL5Gg7sWtt6xLZIQPlaDhx1/dKn4sWhfB0Hs5VBsV7VYlC+nsMsha38z56L
QvkGDtr9buecTotA+YYOT7I0rf62C0P5Rg4xzcZRN14IQfnGDtzMa6teTRaE
8k0cImetXSiqIwDlmzrkOE3Yy7eQD8o3c9h73OqdxmMeKN/cQdlr2rWoFVxQ
voXDT51JNctzOKF8Swd5D19LsVWsUL6Vg495/fbHesxQvrWDce/b744HftpD
+DYOTApav7hX/4HybdHk7aDu/WgPACfGdJQ=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwWG7EUz//miKUz+GwzWQ7
4xZjGF/Agc99+ZreaQpQvojDA1txlhXX5KF8CYf/ubGlK7bKQfkyDpu/1Myp
qJKF8hUcDrU69F7Pk4HylRzCk7xOxBtLQ/kqDgyT27tmKklB+WoOxx03cD06
JAHlazisuS77YPkScShfy8Ehadv1SeViUL6Og7PO1fPMraJQvp5DX0Hpquhg
ESjfwEFThf3Jd3dhKN/QIdp9P9evDUJQvpFDwbXPhxIVYXxjh1LNKZMnbRKA
8k0cdAU1Ps66COObOiw5ubiMu4QPyjdz+Ma7s/GPKQ+Ub+7wYfPFv7WinFC+
hUNgj6E2SysLlG/p4GNev/2xHjOUb+Xw3vLXPye9b/YQvrWDce/b744HftoD
AFdVanE=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwmHBcarPeVUUon8Nhcs93
0WO2ML6AQ8PJ9g0GSxWgfBEHniktTxp+yUP5Eg78DFtDFu6Tg/JlHBInlpop
58lC+QoOX3KduAocZaB8JYepvpdt5H9LQfkqDo+VDxrP2ycJ5as5ZO6ekLn1
pgSUr+Egd+Tej0u+4lC+lsObvnOb7C+JQvk6DtVXK3kZEkSgfD2Hde7vg8p5
hKF8A4emJ0m9T9YIQvmGDuul12y/5M0P5Rs5fOPd2fjHlAfKN3b4qTOpZnkO
J5Rv4gAJLyYo39SBm3lt1avJjFC+GRrfHI1v4eBjXr/9sR4zlG/pULza2n7T
IgYo3wqq/qM9hG/t8N7y1z8nvW9Qvg2U/8weAP32cCk=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwOHs9zqTkhCKUz+FgpLQw
TcQExhdwuM5h94lvvgKUL+LAe2W5VrAEjC/h8OW37w/W+3JQvoyDbn+Cg8wc
WShfweGA6uXK+5NloHwlh23WRSnX7aWhfBUH49633x0PSEL5ag7HHTdwPTok
AeVrOFgcra+et0scytdyONZzqLxsvxiUr+PgrHP1PHOrKJSv57BO9rKS1nMR
KN/AITL+kEdUhDCUb+iQVfJjG2O4EJRv5KDomN5Z+k8Ayjd2yHGasJdvIR+U
b+KQfWLHvss7uaF8U4dvvDsb/5jyQPlmDvL/zp62+MAF5Zs7nDhqW16yiwPK
t3B4b/nrn5MeG5Rv6cDNvLbq1WRGKN8Kyv9oDwDBi2ZX
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQEf7MVCt+7emK3kABVweNXtnSR1RhHK53D4Ipq5
UFUZxhdwqGvi/vh+mgKUL+Jw/KQV59K38lC+hMM9t/yfQelyUL6Mg/Cn088D
ZGWhfAWHXDdB4S0npaF8JYeo5z7uss1SUL6Kw40PCxbvLZaE8tUcPqgfl2PN
lIDyNRzaDLfLXQ8Qh/K1HDp/XVgl+VcUytdxkLkd4SAwUQTK13PIjmAPTJ4u
DOUbOPiY129/rAfjGzoUb1zfGVAlCOUbOfi6HTv6xFYAyjd2+M8Q+D+hhB/K
N3FYcnJxGXcJH5Rv6rDC8fDRY5K8UL6Zw97jVu80HvNA+eZofAsH+X9nT1t8
4ILyLR2yT+zYd3knN5Rv5aDsNe1a1AqYvLXDh80X/9aKckL5Nmh8W4eN6/Kn
6EVzQPl2aHx7h8AeQ22WVhYo38FBZzMLm1kfO4Tf4ODQNjHbqloeymdwdGBS
0PrFvfqPPUTeERpezFB5J4fi1db2mxYxQPU7OXAzr616NZkRKu+Mym9wdgiP
MlpXpPQfYh6DCyq/wcXBuPftd8cDP6Hyrmj2u6Lax+CGZr6bw3vLX/+c9J5B
9buj8hvcoeo/2gMARqW80w==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwuGy9I/TFFUUon8NhXXLb
/ivWML6AA5ffjhaBBQpQvojDaQv52RsZYHwJh7KcXInkk3JQvowD05bIiN9z
ZaF8BYe/P7TeXOqXgfKVHBgDPnOaT5OG8lUcnm+sqfhSJQXlqznUHFt3j+uT
BJSv4XBAZDV74itxKF/LYYbl7mlvD4lB+ToOp3+96GpbKgrl6znEX98ad7lC
BMo3cFjn/j6onEcYyjd0SJ27jKl6gSCUb+Tw+d+uyCZ2ASjf2OEb787GP6Y8
UL6Jw4mjtuUluzigfFOHtonZVtXy7FC+mYO8h6+l2CpWKN/cgZt5bdWryYxQ
voXDe8tf/5z0ntlD+JZQ/jco3wouDwDrRmru
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwUBaw3zLhkiKUz+Ggsztz
T4wjjC/gYFnK+NBmowKUL+KQcOcon7ksjC/hMGfmSZYpKvJQvoyDrq1eyP5n
slC+gsPppyuT/66TgfKVHCpuBz7oKJGG8lUcrlzzvVDkLQXlqzksi3iZYW4v
CeVrOCxmmj9N1UoCytdy2CkTmXtCVRzK13Go06manfdBFMrXc7DOKpqRsEUE
yjdwOJcY8fHzTWEo39AhMv6QR1QEjG/kcCTgwOyGXUJQvrFDqeaUyZM2CUD5
Jg6rbZQyNA7zQ/mmDiscDx89JskL5Zs5nDhqW16yiwPKN3fwMa/f/liPGcq3
cAiPMlpXpPTfHsK3dOBmXlv1avJHKN/K4b3lr39Oes+gfGs4HwDzC2qF
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwOLCv9ZfnJUUon8NB/NlC
YVZTGF/AYdcVPr3amQpQvojDlHCZ2o3v5KF8CQfW71MNDT7IQfkyDprGa2ZI
7JeF8hUcxO5tn/+xSwbKV3Lgs76hMFNVGspXcbj17+zrp+ckoXw1hxJLqw7h
pRJQvoYDR12/9Kl4cShfy+HRwiuhAlJiUL6Ow72Ivvae7yJQvp5D0gmlXcYN
wlC+gUNWyY9tjOFCUL6hwzN9JeM8TUEo38iBR/hQecFLfijf2ME55I8Zqxsf
lG/icFbqw6spAlxQvqlD28Rsq2p5dijfzIGbeW3Vq8mMUL65g495/fbHesxQ
vgVU/qM9ADV8Wc0=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwmLpVLXHRJUUon8PBgVsh
4Y05jC/gYGL1XyK8RwHKF3EIEj3L8PS1PJQv4ZB44Ff0ziNyUL6Mw4sY4V9z
tslC+QoOEm5rvddNkYHylRxUsppC9ZKkoXwVh/9crUnz5KWgfDWHq28bOF4/
loDyNRxKf6mvP3lKHMrXcmjgMK77/EQMytdxaG45fGf6AVEoX8+hvepIxY85
IlC+gUNk/CGPqAhhKN/Q4fGevw3a5kJQvpHDbqkpc3e+F4DyjR0E34iIfRDj
g/JNHOT/nT1t8YELyjd1mPi4uNrpOzuUb4bGN3fwMa/f/liPGcq3cHhv+euf
k94zewBhMWFv
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVwUL/JcfPAaUUon8PBxjZN
ldsYxhdwOJ7IL7JolgKUL+Jgt3zOuzQ+GF/C4c0bm8at1+WgfBmHBX9+JSb2
yEL5Cg68166+5UqWgfKVHITi+ERPmUlD+SoOrkfzqiepSkH5ag77DRjlV/NL
QvkaDtev1p7qspGA8rUc5mx/1y3LKQ7l6zhUThC56skoBuXrOUR49As82i8C
5Rs4aKqwP/nuLgzlGzpcsp/EIn5XEMo3crAP/xLjJw3jGzvslpoyd+d7ASjf
xGHJycVl3CV8UL6pwzfenY1/THmgfDOHiY+Lq52+s0P55g5V9b8OZq9ig/It
HHQ2s7CZ9cHkLdHkrRzaJmZbVcvD5K0daudd3iP2kBnKt3FYvvu62CkZVijf
1uG95a9/Tnow/XZo8vYOxaut7TctYoDyHVD5DQ4O3Mxrq15N/mgPkXeEmvfM
HgCuLIJz
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQDQEf7MVCt+7emK3kABVwOLzOJOX6JUUon8Ph+eXA
p55GML6Ag/oHJolbDQpQvoiDo8ux1XZv5KF8CQdml4CipENyUL6MwxODa0/E
F8pC+QoO12LPaGjlykD5Sg7Onvdk3nlKQ/kqDk2rngpMDpKC8tUcPs3Vc9vB
Kwnlazh0TnVnlb8gDuVrOex9E+znv1gMytdxyO+tlBSeLArl6zksftKa5Jwm
AuUbOETGH/KIihCG8g0dtGXFJNMThaB8I4dSzSmTJ20SgPKNHXiED5UXvOSH
8k0cwqOM1hUpwfimDtd4OzJ++vFC+WYOHzZf/Fsrygnlm6PxLRyW774udkqG
Fcq3dICEPxOUb+VQvNraftMiBijf2sG49+13xwM/7SF8G4f3lr/+Oel9g/Jt
HbiZ11a9mvwRyrdD49uj8R1Q9Tc4oJnviMpvcHRgUtD6xb36D1TeCer//1B5
ND6DM5p+ZzT3ukD5z6DyLnD3AQCYUqsj
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwUBLiEPa4oAjlczjEFgge
rLaA8QUcNt11/1WwQAHKF3FYbH334m5eGF/CgfX7VEODD3JQvozDPqe5bJv3
y0L5Cg4Sa4PrdE7JQPlKDqLri8+XFUtD+SoOjrmqVpmhUlC+msNvY+N14pmS
UL6Gw1XvQ1EPFSWgfC2H9/Z5ng9ZxaF8HYfKCSJXPRnFoHw9B4XHolMXR4pC
+QYOU1X/RjLMF4byDR1KMpbv8xcTgvKNHJ7pKxnnaQpC+cYOn//timxiF4Dy
TRz81vS5pm7lhfJNHSa0MO+4H8sF5Zs5nDhqW16yiwPKN3cIjzJaV6T03x7C
t3BgUtD6xb36D5Rv6WDc+/a744GfUL4VGt8aTb2NAzfz2qpXkz9C+bYO7y1/
/XPSe2YPAAvYbxk=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVweLF1SqTjcUUon8Nh8hUP
uzMqML6AQ9+D9bnr+xSgfBGHSwcLXnK9l4fyJRysi/Pqiw7KQfkyDvdWCa3p
cpeF8hUctMUvnmH9Jg3lKzn0nH7I9+CAFJSv4tA/MVqo+YIklK/mICmdnTE9
VwLK13DYfoDLff5rMShfy8FFlU/nviCMr+NwULlFg0FJFMrXcwjQX6BUIiEC
5Rs4bC4o/hxVIQzlGzpcsp/EIn5XEMo3cvB1O3b0ia0AlG/sULo7wMbiBx+U
b+KwwvHw0WOSvFC+qUNV/a+D2avYoHwzh+W7r4udkmGF8s0dfMzrtz/WY4by
LRy4mddWvZrMCOVbOhSvtrbftIgByrdyCI8yWlek9N8ewrd2YFLQ+sW9+g+U
bwPV/9EeANwuap8=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwWG7EUz//miKUz+Gwue+P
g7sTjC/gsFsp1GbnRgUoX8RhhvO9iHBxGF/CIUJZZq/9azkoX8YhtGk6y8TN
slC+gsPXXymzNGtkoHwlh4LIo1cPqElD+SoOoTa3UlRuSUL5ag4iZ++c/PdS
AsrXcOix+pfmXC4O5Ws51OlUzc77IArl6zhcZ2u/LvtJBMrXcygXnc3Qv0wY
yjdwMHSbtdPrrBCUb+iQVfJjG2M4jG/ksEzZ65bJIQEo39hB11YvZP8zXijf
xMG49+13xwOcUL6pw8THxdVO39mhfDOHwB5DbZZWFijf3AESvkxQvoUDN/Pa
qleTGaF8S4fwKKN1RUr/7SF8KwcmBa1f3Kv/QPnWDu8tf/1z0vsG5dvA+QA5
nW0m
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwmLRio6rLOUUon8PhlM2N
TdP1YHwBB0HW/xMaZylA+SIO4TH3X11hg/ElHFRK306vfCIH5cs4NGya1j79
iiyUr+DgqrD+yOITMlC+kkNZT+l8jxnSUL6Kw9J8Q2U1dykoX81hRZ1vnoe0
JJSv4XBEpLxS4ZM4lK/lMMNy97S3h8SgfB0HrWiLo/v8RaF8PQe5ncXb2k8L
Q/kGDoa7pNUflQpB+YYOJRnL9/mLwfhGDpbndi849kAAyjd2WC+9Zvslb34o
38TBOeSPGasbH5Rv6pB9Yse+yzu5oXwzhxNHbctLdnFA+eYOtfMu7xF7yAzl
WzhAwpsJyrd04GZeW/VqMiOUbwXlf7QHAGHZZlQ=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwEFlZ5uR/XhHK53CQ6Xq1
9ZARjC/gwHXraH7rbAUoX8ThjuG0OS5f5KF8CYcqyzvfXi+Rg/JlHLL3/+Bx
bpCF8hUc7jakZK0OloHylRyObzlxslJWGspXcRC7a7+rZJoklK/m0Pnn8rWN
zhJQvobDyalrAl9riEP5Wg4uqnw69wXFoHwdh3zG322rrEWhfD2HqE+3zVT/
CkP5Bg6aKuxPvrvD+IYOM/cvLw/VEYLyjRxi2BfNknYVhPKNHXiED5UXvOSH
8k0cVjgePnpMkhfKN3VQ9pp2LWoFF5Rv5tA2MduqWp4dyjd3gIQvE5Rv4RAe
ZbSuSOm/PQAOp1yJ
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVweHhNzybwviKUz+GQ3TW3
ebYPjC/gcH5lquTx9QpQvohD4td/+TwiML6EQ4SyzF7713JQvoyDbn+Cg8wc
WShfwUExe8HktBYZKF/J4UzVqcRF4tJQvorDxAf3nCUfSUL5ag79lY7LNE5K
QPkaDpUbA39oVIlD+VoO20+Ls/5JEIPydRwyU75W6KuLQvl6Dqe3bV1ZVCAM
5Rs47D3efv9HvRCUb+iwL0b1oBw3jG/kYHlu94JjDwSgfGOHHKcJe/kW8kH5
JkD9Vu80HvNA+aYOxr1vvzse4ITyzRzaJmZbVcuzQ/nmaHwLh9p5l/eIPWSG
8i0dwqOM1hUp/beH8K2g5v2E8q0d3lv++uek98weADribDU=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwWK5VxLvlkiKUz+HAPnvL
niobGF/AYW7xigyztQpQvoiDmFFMyAcpGF/CYVL2v0pWJXkoX8ZhityCtKc3
ZaF8BYcFfy26LVploHwlh9azVhvmtktD+SoO5+5uDr7bKQXlqzmo9l9x+1ko
CeVrODzfvsbQMEQCytdykOvIWvlFVBzK13HoqosTX/NFFMrXc9hqn/ajJkcE
yjdw6O5dqrqWWRjKN3T44f2Uo9FHCMo3ckidu4ypeoEglG/sIC3x+MXESQJQ
vomD58p1q1Tn8EP5pg68RUbWl5t4oXwzh4s7rn658YMbyjd3qKr/dTB7FRuU
b+FQvNraftMiBijf0sG49+13xwM/7SF8K4f3lr/+Oel9g/KtHbiZ11a9mvzR
HgAC121T
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAmIQDQEf7MVCt+7emK3kABVwOFTjcUTtpiKUz+Fg8Py6
k6sjjC/goFs550vaSgUoX8Rh88rFGrsFYXwJh6gDl6JdmeWhfBmHD+u+thZd
kIXyFRzCEie0ey+TgfKVHPp5X81UCJOG8lUclj6q/8JVLwXlqzlMepuhUWct
CeVrOJxzj+P+KiMB5Ws5qNVcv3jYXRzK13FwUeXTuS8oBuXrOSTf3rNn+RsR
KN/AQedD37rt/cJQvqFDwbXPhxIVhaB8IwddQY2Psy4KQPnGDjlOE/byLeSD
8k0c9h63eqfxmAfKN3Vom5htVS3PDuWbOWxclz9FL5oDyjd3OHHUtrxkF4xv
gca3dIjSnuhxroIbyrdyOCv14dUUAS4o39rhw+aLf2tFOaF8G4faeZf3iD1k
hvJtHZgUtH5xr/5jD+HbOXAzr616NfkjlG/vEB5ltK5I6T+U7+CwfPd1sVMy
rBD9DQ4OOptZ2Mz6YO53dAjsMdRmaWWByjs6VNX/Opi9ig0q74Rqf4OTAyT9
MEHlnVHd0+Ds8N7y1z8nvW9Q+11Q3dPggibvCnc/ADP0qYM=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQDQEf7MVCt+7emK3kABVwmK1slNd9ThHK53AoVK7q
W2UE4ws4xE6MV5vRrwDliziotz6cFfJQHsqXcFjd+6Gopl8OypdxKPkrfja1
UBbKV3BYePiuhLaNDJSv5HD+5aP321ikoXwVB/ab51NuM0lB+WoOjBMu/XvZ
KAHlazhM688rWNUqDuVrOTxaeCVUQEoMytdxCJ4zRbrKUBTK13NIn8pUwmss
AuUbOLycVuS41l4Yyjd0SJ27jKl6gSCUb+TQbZR6Z3aCAJRv7OAc8seM1Y0P
yjdxuLjj6pcbP7ihfFM0vpnDNd6OjJ9+vFC+ucPEx8XVTt/ZoXwLB27mtVWv
JjNC+ZYOTApav7hX/7GH8K0cjHvffnc88BPKt0aTt0Hj2zqERxmtK1L6D+Xb
ocnbo/EdHIpXW9tvWsQAsb/BAU2/I6r6Bkeoez9C5Z0c3lv++uek9wwqD+N/
g8o7o8k7w/UDALPyoP4=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7MVCt+7emK3kABVwePGk0CXmriKUz+Egcd8i
0cgFxhdwYPzAGKSySgHKF3EQM13mt5EDxpdw6Kt/7WbAIA/lyzhM3cjC9vaB
LJSv4BBYMm3BlW0yUL6Sg+29GYdXLZeG8lUcPt713jatUgrKV3NQ7b/i9rNQ
EsrXcFD2LQ1riJWA8rUc2iZmW1XLi0P5Og6Ncy/ESxaIQfl6Dr/50u0PuopC
+QYOLSwnT3FMF4HyDR2EuMX3PNsjDOUbOeyLUT0oxy0E5Rs7FG9c3xlQJQjl
mzjo2uqF7H/GC+WbOmSf2LHv8k5uKN/Mwbj37XfHA5xQvrnDT51JNctzYHwL
h/eWv/456bFB+ZZofCsHH/P67Y/1mKF8awdu5rVVryYzQvk2DkwKWr+4V/+x
h/Bt0fh2DpD4ZIKqt0eTd4Da9w3Cb3CAmv8RKu8Idf9PqLwjmn4nVPUNTqjm
MTijqm9whso/g8q7wPkAWKihfQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAmIQDQEf7MVCt+7emK3kABVwMC/fZmV0QxHK53B4zet+
46QdjC/gwHXraH7rbAUoX8ShcNc335T38lC+hMOGJ4JMXxfLQfkyDgwmtTyP
y2WhfAWHC8/3Ra0wkIHylRzk/509bfFBCspXcZj44J6z5CNJKF/NYU9x5G+z
bRJQvoZDkWTu9bf14lC+loPgBD8GRyMxKF/HYenUYsGdDqJQvp7DAW2nt2uK
RKB8A4fu3qWqa5mFoXxDhxj2RbOkXQWhfCMH3hyh1x2FAlC+sUOO04S9fAv5
oHwTByYFrV/cq3mgfFOo+7mgfDOHqvpfB7NXsUH55g7Ld18XOyXDCuVbOEDC
mwnKt0STt3II7DHUZmllgfKtHYx73353PPDTHsK3ceBmXlv1avJHKN/W4b3l
r39Oet+gfDs09fYO4VFG64qU/kP5Dqj8Bgc09Y5Q857ZAwDVPIlZ
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQDQEf7MVCt+7emK3kABVwuLzQu5rjjCKUz+Fw4F7G
Qj89GF/AwUbt/7OcaQpQvohD790pblNvyUP5Eg5Vlne+vV4iB+XLOGik3Zlv
YSAL5Ss4vApQvXRBTQbKV3KoOVCnek5CGspXcQi1uZWicksSyldz0Lq2Vohj
hgSUr+FwY2pC1JoLYlC+lkM+4++2VdaiUL6Ow7vcI1+NvwlD+XoOl+wnsYjf
FYTyDRxKdwfYWPzgg/INHZxD/pixusH4Rg7feHc2/jHlgfKNHSa0MO+4H8sF
5Zs46GxmYTPrY4fyTR2q6n8dzF7FBuWbOch7+FqKrWKF8s0dIOHLBOVbOHAz
r616NZkRyrd0CI8yWlek9N8ewrdCk7d2KF5tbb9pEQOUb4PGt0Uz3w5N3t7h
veWvf05636DmO0DN/wjhNzigyTs6GPe+/e544CdU3hFVPYMTqvoGJ1T1DM5o
8mh8Bhco/5k9AHRopnc=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw8LASXqt9XhHK53Bg8OMu
aLOH8QUc6pq4P76fpgDlizh0Hcrp33VdHsqXcNCNlbo8aYEclC/j0KXSksZT
JAvlKzhwSknGN2nKQPlKDvJJjb+n2kpD+SoOuUEztytISEH5ag77DRjlV/NL
QvkaDm/bOFe1dohD+VoOnP+mcFqbiUH5Og7axyW+LnkoAuXrOaiUM042ey8M
5Rs4COgYSp/7LwjlGzrwCB8qL3jJD+UbOSw5ubiMu4QPyjd2uMbbkfHTjxfK
N3HIPrFj3+Wd3FC+qUPbxGyranl2KN/MQd7D11JsFSuUb+5QvNraftMiBijf
wiE8ymhdkdJ/ewjf0oFJQesX9+o/UL4VmnprB+Pet98dD/y0BwA6yGBK
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw+PBlXiv3VUUon8NBctMq
pcWOML6Ag9Sitaf75ytA+SIOrBN9DwX/l4fyJRwOHF379dVOOShfxmHGdvdY
3wOyUL6Cg5hFA3ObpQyUr+QgFMcnespMGspXcbiVWiKXwiIF5as5bLv+2UTo
uASUr+EgKm6qfbZJHMrXclg5/9kG7VgxKF/HYenUYsGdDqJQvp6DSjnjZLP3
wlC+gUPvZk7tffeFoHxDh+KN6zsDqgShfCOHbqPUO7MTBKB8YwfeIiPry028
UL6JwzfenY1/THmgfFMHnc0sbGZ97FC+mYO8h6+l2CpWKN/coXi1tf2mRQxQ
voWDce/b744HftpD+JYO3Mxrq15N/gjlWzm8t/z1z0nvGZRvDeV/g/Jt0Pi2
cP0AicJw9w==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwkGSI9Gy/qAjlczhstO/5
5W0B4ws49Cxcfr9isgKUL+Kg+0dm3hNGGF/CgfX7VEODD3JQvoyD1zWZ060r
ZKF8BYfsczqcRRNloHwlB5416mu086WhfBWH78kWZye8loTy1RxeRpyteFch
AeVrOHzkCz2sqS8O5Ws57JefLTGXUwzK13GwziqakbBFBMrXc/iZWPy3casw
lG/gkFXyYxtjuBCUb+gg9OLAodVBglC+kUPkrLULRXUEoHxjB781fa6pW3mh
fBM0vqlD9okd+y7v5IbyzRzOSn14NUWAC8o3d3hv+eufkx4blG/hsHz3dbFT
MqxQvqVDVf2vg9mrYPJWDrXzLu8Re8gM5Vs7GPe+/e544Kc9hG/jwM28turV
5I9Qvi0a3w7OBwBRDHj6
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVwUA6tTf90QxHK53B43KfA
c8kRxhdwkPZT+79xoQKUL+Jw57l0+uy/8lC+hIO3ofFbrRtyUL6Mg9c1mdOt
K2ShfAUHqeXB079myED5Sg7rWc96vmCVhvJVHDKuyW3YvFQSyldz4D6gYK9f
LQHlazjwfpnz0nuOOJSv5eCQtO36pHIxKF/HQSva4ug+f1EoX8/hgLbT2zVF
IlC+gYPuc+kGLhYY39DhSMCB2Q27hKB8I4dvXevEY78IQvnGDpWax3+m+gtA
+SYORz/zB0cV8kD5pg4njtqWl+zigPLNHHQ2s7CZ9bFD+eYObROzrarlYXwL
h43r8qfoRcPUWzos331d7JQMK5Rv5cCkoPWLe/Ufewjf2uG95a9/TnrfoHwb
B27mtVWvJn+E8m2h8s+gfDs0eXsH49633x0P/ITyHVDVNzigqXdE5Teg8Rmc
4PoBY/KTEQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBGIQDQEf7MVCt+7emK3kABVw+JB3rHnlGUUon8OBqZTx
zhITGF/AQSzM2rpokQKUL+JwoUPCh4EdxpdwUCl9O73yiRyUL+MwY7t7rO8B
WShfweHoZ/7gqEIZKF/J4Ufc+tQLHtJQvooDw+T2rplKUlC+mgO71rYesS0S
UL6Gw4KpHBzHL4lD+VoOigsaRRzPikH5Og6PG4U0CpJFoXw9Bw+vnlubIkWg
fAOH7t6lqmuZhaF8Q4do9/1cvzYIQflGDgmFsb9PvRCE8o0dNP2URVxzYXwT
h91SU+bufC8A5Zs68AgfKi94yQ/lmzmU7g6wsfjBB+WbO6xwPHz0mCQvlG/h
EKU90eNcBTeUb+nwYfPFv7WinFC+FRrf2mHjuvwpetEcUL4NGt/WQd7D11Js
FSuUb+fw3vLXPyc9NijfHk3ewaGq/tfB7FVQ+QYHh7aJ2VbV8uxQeUeHE0dt
y0t2Qc1vcEQzz8lh+e7rYqdkoOY1ODkE9hhqs7SyQOWdUfkNaHwGFzR5F4fi
1db2mxYxQOVdHSDpkQkq7wq1/5s9RN4Nyn8G4Te4OXAzr616NfkjVN4dTd4d
Td7Dwbj37XfHAz+h8h5w8wGNBL9Z
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwUBaw3zLhkiKUz+EQKbFy
wyJtGF/AQf0Dk8StBgUoX8Thy4HGBRwv5KF8CYfMuA0653bLQfkyDmwNIa9v
TJWF8hUcvt5/VCYeKwPlKznIOs1IKHWVhvJVHNhvnk+5zSQF5as5GCj8/Ge9
XALK13CQO3LvxyVfcShfy0Fwgh+Do5EYlK/j0F51pOLHHBEoX89BiFt8z7M9
wlC+gUPTk6TeJ2sEoXxDh2XKXrdMDglA+UYOvDlCrzsKYXxjh/8Mgf8TSvih
fBMHXVu9kP3PeKF8U4cJLcw77sdyQflmDhMfF1c7fWeH8s0ddDazsJn1wfgW
DrXzLu8Re8gM5Vs6hEcZrStS+m8P4Vs5GPe+/e544CeUbw3nAwBxQWm7
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwaPtpuODpNUUon8MhtkDw
YLUFjC/gUBTDP/XQLAUoX8Sh8mzf2d+sML6Eg1Ro0x+TR3JQvoyD05JrKyZ2
yEL5Cg7XYs9oaOXKQPlKDv28r2YqhElD+SoOwXEi3VM9pKB8NYdLJ24YrdaQ
hPI1HNxmc35cri0B5Ws5rLFecszrhRiUr+NwVSMncdl2UShfz0H3uXQDF4sI
lG/g4GNev/2xnjCUb+hwyX4Si/hdQSjfCI1v7BA5a+1CUR0BKN/EwXPlulWq
c/ihfFOHvcet3mk85oHyzdD45g5npT68miLABeVbOAT2GGqztLJA+ZYOxaut
7TctYoDyrRyMe99+dzzw0x7Ct0bj2zi8t/z1z0nvG5RvC+U/swcAkjxzdw==

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVw2LDyzs7T5xWhfA6HU7Kc
8+9pwfgCDgcXHtZln6MA5Ys4XDv6/AYjA4wv4TCZc90PQUZ5KF/Gwadpe0Pi
a1koX8HhZSTfFIfDMlC+koPMvAM3ey5KQ/kqDgvfx/O/mCgF5as5SHdarb+j
Ignlazjozdz0PvaPOJSv5bBy/rMN2rFiUL6OQ4/4hUnfCkWhfD2HqE+3zVT/
CkP5Bg4/lrDXPXEUgvINHYReHDi0OkgQyjdyeKavZJynCeMbO6yXXrP9kjc/
lG/ioGurF7L/GS+Ub+pwVurDqykCXFC+mYO8h6+l2CpWKN/cIbDHUJullQXK
t3DgZl5b9WoyI5RvCeV/tAcANophWQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwEDqwRejIXUUon8Ph8Kqk
cINIGF/AIXum9WHVgwpQvohDp7hdR68wjC/hUO7Rf34aizyUL+Og/OHBvit3
ZKF8BYd396T31HXIQPlKDjFpJ2JfxElD+SoO685XBlqZS0H5ag61K6eaR9tK
QvkaDreVsxYdV5OA8rUcbkxNiFpzQQzK13H4Xbig3jdDFMrXc4j6dNtM9a8w
lG/goKnC/uS7O4xv6PBGODL1W6cQlG/ksEzZ65bJIQEo39jBc+W6Vapz+KF8
EwcmBa1f3Kt5oHxTB53NLGxmfexQvhka39whsMdQm6WVBcq3cICENxOUb4nG
t3KonXd5j9hDZijf2oGbeW3Vq8mMUL6NQ3iU0boipf/2EL4tVP4jlG/n8N7y
1z8nvW9Qvj0a3wGuHgDB53rX
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwcPnZxhByWxHK53DY/CD/
8GUnGF/A4ebHY2a6yxWgfBGHDw/Mo/qFYHwJh6fr5S9I/JWD8mUcXjZOsFmz
ThbKV3B45/Dp7atNMlC+ksPDE6Ie76ukoXwVB0n331IqVlJQvprD5eMyzLfY
JaF8DYcDIqvZE1+JQ/laDkn7Hnz6t0UMytdxsMiyN+oVF4Xy9RyqKrWfX1MV
gfINHFxtn9Sc/yUE5Rs6ND1J6n2yRhDKN3JYpux1y+SQAJRv7LBees32S978
UL6Jw97jVu80HvNA+aYO2Sd27Lu8kxvKN3M4K/Xh1RQBLijf3GH2Ne6fy0xh
8hZo8pYO8v/Onrb4AONbOUDigwnKt3Yw7n373fHAT3sI38bhveWvf0563+wB
lV53Iw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw6Pm3d7v2dUUon8Nhcs93
0WO2ML6Aw9uqj1xZKxSgfBEH9+vbJ9znhPElHFIMuNc9+iYH5cs46D1T3Vkw
URbKV3B4vmfn/ORQGShfycH28Gmb45nSUL6Kg6T7bykVKykoX82BS7s5lvOD
BJSv4WDpfsVh03pxKF/LYc72d92ynDC+joPN14P3euJEoXw9h+qrlbwMCSJQ
voGD9+aPXoHmwlC+oUNCYezvUy8EoXwjh8//dkU2sQtA+cZofBMHXVu9kP3P
eKF8U4dvvDsb/5jyQPlmDhvX5U/Ri+aA8s0duJnXVr2azAjlWzhAwpsJyrd0
CI8yWlek9N8ewrdyMO59+93xwE8o39qBSUHrF/fqP1C+jcN7y1//nPSeQfm2
cD4AAFZ1Xg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwiNI2e+B5RRHK53D4mGfH
9t8Kxhdw2HWFT692pgKUL+KwdSGviQ0TjC/hEKEss9f+tRyUL+MwN3yD+8kt
slC+goOk+/zqwFkyUL6SQ1lP6XyPGdJQvoqD9rkXnH5+UlC+moOL+XvTKD1J
KF/D4fGdoMJGNgkoX8vhtGbeBpk/YlC+jkPlBJGrnowwvp7D8t3XxU7JiEL5
Bg6z/Bp/PeYSgfINHfYeb7//o14Iyjdy4Fr8I87tqCCUb+zwTF/JOE8Txjdx
kF3951qMOYxv6vD5367IJnYBKN/MYYXj4aPHJHmhfHOHCS3MO+7HckH5Fg7G
vW+/Ox7ghPItHeQ9fC3FVrFC+VYOxaut7TctYoDyrdH4Ng5MClq/uFf/sYfw
bR24mddWvZr8Ecq3c3hv+eufk943ewAQIXGr
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwUL79b6baJUUon8PhotAL
kxJHGF/A4SHXyaqPCxSgfBEHwwWyc5yYYXwJBxPpFesdj8hB+TIOQrHc4fpN
slC+ggNPpsxCfmkZKF/JQf7f2dMWH6SgfBWH833fep3mSkL5ag7nUzx8kldK
QPkaDhx1/dKn4sWhfC0Hna2LQ//sFoPydRxKdh5SOOwlCuXrOQhxi+95tkcY
yjdw6N3Mqb3vvhCUb+jg0lDx17BdEMo3cug2Sr0zO0EAyjd28Fy5bpXqHH4o
38QhSnuix7kKbijf1OGnzqSa5TmcUL6ZQ2CPoTZLKwuUb+5QvNraftMiBijf
Ao1v6RAeZbSuSOm/PYRvhca3djDuffvd8cBPewCEtmUJ
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQEf7MVCt+7emK3kABVwWK+deLXovCKUz+GQeMiV
L84axhdw4PLb0SKwQAHKF3HgWtl6dgcjjC/hcGpZSuaV23JQvowDT3R9wcGV
slC+gsOaDwf6kqJloHwlh5oDdarnJKShfBWHPuspmo1cUlC+msOktxkaddaS
UL6GQ3jaih+/mCWgfC2Hj3yhhzX1xaF8HQf2g8pzdN6IQvl6DpvWt8lJ3BGB
8g0c2OVYQo5cEobyDR2OBByY3bBLCMo3crAx8mnnSxCE8o0dhF4cOLQ6CMY3
cfB1O3b0ia0AlG/qsOTk4jLuEj4o38zBb02fa+pWXijf3CFKe6LHuQpuKN/C
4afOpJrlOZxQvqXDxMfF1U7f2aF8K4e2idlW1fIwvjWavI2DzmYWNrM+GN/W
4b3lr39OemxQvp1DVf2vg9mrYHx7NHkHh8AeQ22WVhYIv8EBTd7RoXbe5T1i
D5mh8o4O8h6+lmKrWKHyTg7Ld18XOyUD5Tc4oapncHaApCcmqLyzQ/Fqa/tN
ixig8i4OTApav7hX/7GHyLs4cDOvrXo1+SOEz+AKdc83qDyM/wwq74aqvsEN
Lg8AEl2xvg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw+KiVcOT6KUUon8Ph2n7T
qd26ML6AQ8jzpyd3TVaA8kUcXn6cV+v9Vh7Kl3BQfL5c48QpOShfxuGl1CtO
vUpZKF/BwUzaP53HVgbKV3KYrrvk0q5/UlC+ioNx79vvjgckoXw1hz2W7x2K
JkpA+RoOBR2zPhYWikP5Wg7q9wIXlrKKQfk6Dtr9buecTotA+XoO2RHsgcnT
haF8A4d9MaoH5biFoHxDh8hZaxeK6ghA+UYO/xkC/yeU8EP5xg7ZJ3bsu7yT
G8o3cZD/d/a0xQcuKN/UYfY17p/LTGHyZmjy5g4njtqWl+zigPItHDauy5+i
Fw3jWzq0Tcy2qpZnh/KtHGrnXd4j9pDZAQBBoWgt
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwOLCv9ZfnJUUon8OBn8uc
/6cejC/gMKcy6tHS2QpQvojDYuu7F3fzwvgSDmvjV9zLOi8H5cs46Ip9XDy9
TBbKV3A43V8qWZ8gA+UrObDsKbhhzicN5as4rNeWs3D5IAnlqzmUWFp1CC+V
gPI1HGQW5D4P2SsO5Ws53JiaELXmghiUr+PwlHXat+3TRaF8PQehtVczP9SJ
QPkGDt29S1XXMgtD+YYOLg0Vfw3bBaF8Iwf78C8xftIwvrHDf4bA/wkl/FC+
icPsa9w/l5lyQ/mmDjqbWdjM+tihfDOH8CijdUVK/+0hfHM0vgUa39KBSUHr
F/fqP1C+lcN7y1//nPSeQfnWcD4AHsVpPA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVw2G+6Skb2qiKUz+FweWbX
sShdGF/A4bk//z3mqQpQvohDfKhj010GGF/CQfH5co0Tp+SgfBkHpyXXVkzs
kIXyFRy+/kqZpVkjA+UrOXycs5ezzl8ayldx2JDgY77NVQrKV3PY5NjZ9PO/
BJSv4dCz6/2tuG5xKF/L4dHCK6ECUmJQvo6DQWzz8r0rRKB8PQe5ncXb2k8L
Q/kGDo/3/G3QNheC8g0dildb229aJADlGzn8Zwj8n1DCD+UbO3zj3dn4x5QH
yjdxOHHUtrxkFweUb+rwU2dSzfIcTijfzGHi4+Jqp+/sUL45mnoLh6r6Xwez
V7FB+ZYOy3dfFzslwwrlWzkE9hhqs7SyQPnWaOptHCDxxQTl26Lx7RyYFLR+
ca/+Yw/h2zu8t/z1z0nvmT0AywB9SA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw4BWbGyB6UxHK53DQ1T95
/oUnjC/gUL/tqq7GdgUoX8Th8L9ARQ4tGF/CYb9GxMuHkvJQvoxD8lzpDzJv
ZaF8BYfIhi02KTtkoHwlB9H1xefLiqWhfBUHhsntXTOVpKB8NYdLJ24YrdaQ
hPI1HOQX9zap+0pA+VoOc+Wm7pttJw7l6zjMUtjK/+y5KJSv5xA8Z4p0lSGM
b+AQ1+H20vaIMJRv6LBwyQnR/mtCUL6RQ9OTpN4nawShfGMHX7djR5/YCkD5
Jg7XeDsyfvrxQvmmDspe065FreCC8s0c2iZmW1XLs0P55g7Ld18XOyXDCuVb
OBSvtrbftIgByrdE41s5GPe+/e544Kc9hG/t8N7y1z8nvWdQvg2U/80eAJ+/
bgA=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwuCApsvz3KUUon8Mhji/W
ZbE+jC/g8HDutMTkVQpQvojDGd55D2VYYHwJhwmBS4XrrshB+TIO+tsddzdt
kIXyFRy23Nw2pz1EBspXcrjGUZfsLyMN5as4rNeWs3D5IAnlqzmInL1z8t9L
CShfwyHee4/DnkPiUL6Wg+AEPwZHIzEoX8dh0/o2OYk7IlC+nkNk/CGPqAhh
KN/AoSRj+T5/MSEo39DB8tzuBcceCED5Rg6f/+2KbGKH8Y0dVjgePnpMkhfK
N3H4xruz8Y8pD5Rv6nDiqG15yS4OKN/MIbDHUJullQXKN3dgUtD6xb36jz2E
b+Hw3vLXPye9Z1C+JRrfCo1v7cDNvLbq1eSPUL4NGt8Wrh4AdNd02A==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwOM9X8lDyvCKUz+FQ8n5N
d681jC/gcNAreD/vJAUoX8ThzIz9PgUf5KF8CYfsjkNhIcvloHwZh8bCNXuX
lshC+QoODUx3XvG7yED5Sg7vv/p9+aYgDeWrOBieU9nB+0MSyldzqJMVX/rp
qQSUr+GwfPWVG9/fiEP5Wg5yHVkrv4jC+DoO918vLw2fIwrl6zn0FZSuig4W
gfINHI4EHJjdsEsIyjd04GZeW/VqsiCUb+TguXLdKtU5/FC+scO2DxP0pc7y
QfkmDqttlDI0DsPkTR2u8XZk/PTjhfLNHJS9pl2LWsEF5Zs7vLf89c9Jjw3K
t3BYvvu62CkZVijf0uHEUdvykl0cUL4VmnprqPsYoXwbB+Pet98dD/y0h/Bt
oeqfQfl2cD4A06x9TQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVwePtlgkDeWUUon8NBUXKr
z1FTGF/AYdNd918FCxSgfBGHpm6HOxbCML6EQ/476yvPWeWhfBkHkYDYw+KP
ZKF8BQc7ab+LxutkoHwlhwI3l8r2NGkoX8Vhn81t88vZUlC+mkPWVVfWuYKS
UL6GwxxBe7aLP8WhfC0HnpXmgXvmi0H5Og5mb57dXcMuCuXrOczya/z1mEsE
yjdwMHSbtdPrrBCUb+ig6acs4porCOUbOTzTVzLO04TxjR3+MwT+Tyjhh/JN
HK7xdmT89OOF8k0dJrQw77gfywXlmzn81JlUszyHE8o3d5D38LUUW8UK5Vs4
BPYYarO0skD5lg6Q8GeC8q0cildb229axADlWzsY97797njgpz2Eb+PApKD1
i3v1HyjfFk3eDo1v7/De8tc/J71nUL4DlP8Nwm9wQFPv6MDNvLbq1eSPUHk0
PoMTnA8AGomPFw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw2KLqfPnPWUUon8OhTX2f
w20LGF/AIff+ilczZihA+SIO8emSk05+kIfyJRz4GbaGLNwnB+XLOPz+toJ1
WroslK/gUN2oMfGVqgyUr+QQL3DxOcN7KShfxeH0Jcv/O5MloXw1h5Jbi08I
3hCH8jUcZq086Px1rRiUr+WgUnjx5k9RGF/HQfu4xNclD0WgfD2HpBNKu4wb
hKF8A4eEwtjfp14IQvmGDoJvRMQ+iPFB+UYO2Sd27Lu8kxvKN3b4sPni31pR
TijfxOG95a9/TnpsUL6pAyT8mKB8MwcmBa1f3Kv/2EP45mh8C6j+Z1C+JRrf
Csr/BuVbo/Ft4OoBFzt5lg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVweGx7dgXfOUUon8PhT/fH
Xzx2ML6Awy33dY/uzVSA8kUcCv718r7+Iw/lSzjY3Z4ixnBLDsqXcQi81SBV
tFYWyldweHdPek9dhwyUr+Rge/i0zfFMaShfxUH6aHA+i5cUlK/mcNxxA9ej
QxJQvoaDzILc5yF7xaF8LYfbx7fcul4sBuXrOGhFWxzd5y8K5es5LH7SmuSc
JgLlGzhMVf0byTBfGMo3dNh7vP3+j3ohKN/IYZmy1y2TQwJQvrHDtg8T9KXO
8kH5Jg6zr3H/XGbKDeWbOrRNzLaqlmeH8s0cIOHJBOWbOzApaP3iXv3HHsK3
cDDuffvd8cBPKN8SjW+Fxrd2eG/565+T3jco38aBm3lt1avJH6F8W6j8M3sA
9HB8Og==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQDQEf7MVCt+7emK3kABVwqOO3m7f4rCKUz+HwPvTS
d391GF/AYcc1j1WmPQpQvoiDasgcxXOP5aF8CYcXH28x6W+Vg/JlHDSuz1jG
3CsL5Ss42Nb63PXvlIHylRwY30/+8z9eGspXcVh3vjLQylwKyldzcHctyWT+
IwHlaziIWSkU8dSKQ/laDlMbbBcLOolB+ToOCo9Fpy6OFIXy9RziOtxe2h4R
hvINHAR0DKXP/ReE8g0d7MO/xPhJw/hGDqttlDI0DvND+cYOOU4T9vIt5IPy
TRx0bfVC9j/jhfJNHa7xdmT89IPxzRy2fZigL3UWpt7cYe9xq3caj3mgfAsH
3iIj68tNMPWWaHwrh+wTO/Zd3skN5Vs7nDhqW16yiwPKt3E4K/Xh1RQBLijf
1uGnzqSa5TmcUL6dg85mFjazPnYo396heLW1/aZFDFC+gwMkvpkg/AYHByYF
rV/cq//YQ+QdHYx73353PPATwm9wdOBmXlv1avJHqLyTw3vLX/+c9J7ZAwBD
zonc
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQEf7MVCt+7emK3kABVw+Mo459DHy4pQPoeD7acV
2n/sYXwBB81UgTVHVypA+SIO+y9duBjFAeNLOGQoa09mfSIH5cs4MG2JjPg9
VxbKV3AocfSVbyuVgfKVHI4KZbdwe0tD+SoO+8KuPVH7LQnlqzlwd5tXrt0n
AeVrOFRuDPyhUSUO5Ws5XM65s/NEihiUr+Ng8/XgvZ44UShfz+FnYvHfxq3C
UL6BQ0yzcdSNF0JQvqFD6txlTNULBKF8IwfeHKHXHYUCUL6xg3PIHzNWNz4o
38Rh9jXun8tMuaF8U4dvvDsb/5jyQPlmDlHaEz3OVcDkzR10NrOwmfWxQ/kW
Dst3Xxc7JcMK5Vs6cDOvrXo1mRHKt0LjWzuERxmtK1L6bw/h2zgwKWj94l79
B8q3dTDuffvd8cBPKN/OoXi1tf2mRQxQ/fZo6h1QzWtA4zM4oqpvcIS65yNU
3snhveWvf056z6DyCD4ApiiTVA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw4L1yL6vmmiKUz+HAo3RD
R8MexhdwWOCUevvjYgUoX8Sha5XxkwQuGF/CoUurZ4/OGTkoX8aBoW+20PQp
slC+gsMjfv6XG0pkoHwlh8Kp6xe9DpaG8lUcnkw90vxCXwrKV3NQlcmIXhQo
CeVrOMgat1+VT5KA8rUc1oewsHx8Jwbl6zic/vWiq22pKJSv5xDMYHFuo6AI
lG/gEO2+n+vXBiEo39BB6MWBQ6uDBKF8IwdpiccvJk4SgPKNHY5+5g+OKuSB
8k0cLu64+uXGD24o39Rh73GrdxqPYfJmDhNamHfcj+WC8s0dJj4urnb6zg7l
Wzj4mNdvf6zHDOVbovGtHMKjjNYVKf23h/CtHbiZ11a9mvwRyrdB49ui8e0c
3lv++uek98weAK8zeJI=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVwEJ+25sSt64pQPoeDx9ds
6TInGF/AQUNwT3vAUgUoX8ThuWDT6vksML6Ew7YPE/SlzspB+TIOEr2Zero5
slC+gsNvVm2pmfIyUL6Sw7z3OitFvkpB+SoOZ8yec4XelYTy1Rz+T9uZ/Oih
BJSv4WD1+nHD+mniUL6WQ+PcC/GSBWJQvo7DOtnLSlrPRaB8PYdfP5wXlevA
+AYO0x/2MN77KATlGzoI6BhKn/svCOUbOby+o96i3yQA5Rs7MClo/eJezQPl
mzhsXJc/RS+aA8o3deBmXlv1ajIjlG/m8N7y1z8nvW/2EL65g3Hv2++OB37a
AwA9MFrf
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQEf7MVCt+7emK3kABVwmPPS7abULUUon8PhjMx3
galBML6Aw+kvSu0PtitA+SIObmWxW++IwvgSDv6bn0qkvpOD8mUcHF45XAtd
JAvlKzhIzQ4tWxovA+UrObyStri5WE4ayldx4PpvnPXmniSUr+YgXOB9MK9W
AsrXcNgpE5l7QlUcytdyWHH78NS510ShfB2HvoLSVdHBIlC+nsPJShebFDVh
KN/A4VvXOvHYL4JQvqEDj/Ch8oKX/FC+kUOU9kSPcxXcUL6xw0+dSTXLczih
fBOH95a//jnpsUH5pg7Fq63tNy1igPLNHMKjjNYVKf23BwCKCVYy
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwYLd4UPXknCKUz+GwUPrR
MxdzGF/AoSgoT3biAgUoX8QhclG12HRpGF/CQWxZs8Hvv3JQvozD5abb0TWz
ZaF8BYf9V0utDYpkoHwlhyrGbU9nBkhD+SoOjrmqVpmhUlC+mkNFg+D08osS
UL6GQ/GUdbWcB8ShfC2HsGWzjcJ5YHwdh5Xzn23QjhWD8vUc4s1s2e6eFYXy
DRycDgbLacuLQPmGDhD/C0H5Rg67pabM3fleAMo3dhB8IyL2QYwPyjdx8FvT
55q6lRfKN3WQ/3f2tMUHLijfzOGs1IdXUwRgfHOH95a//jnpsUH5FlD7mKB8
S6j8M3sAdRxfTQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVweKL/cm7LeUUon8NhR3/m
shgTGF/A4fUKI+lPCxWgfBGHf7cz5z3jhfElHHQdnBonPpaD8mUc5EVfH/LY
KwvlKzhciZSRL18pA+UrObSetdowt10ayldxcMxVtcoMlYLy1RxufFiweG+x
JJSv4XDOPY77q4wElK/l0DYx26paXhzK13HoqosTX/NFFMrXczB78+zuGnYY
38DhXGLEx883haF8Q4fu3qWqa5lhfCOHx3v+NmibC0H5xg66ghofZ10UgPJN
HJxD/pixuvFB+aYO13g7Mn768UL5Zg46m1nYzPrYoXxzqPtgfAuHiY+Lq52+
w/iWDvIevpZiq1ihfCsHH/P67Y/1mKF8awcmBa1f3Kv/2EP4Ng7czGurXk3+
aA8ATAFqRA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwcMj+JXvuoiKUz+Hg/vOi
2ltXGF/Awd20LvLDfAUoXwTIP7x2giCML+Fw80u843RueShfxiF8it/Rruuy
UL6Cg9bjQ4cbq2SgfCWHgzH/7yX6SUP5Kg7/QsVku29IQvlqDrLG7VflkySg
fA2HlKfFWzqtxaF8LYeSXyuVDK3EoHwdh76C0lXRwSJQvp7DD++nHI0+QlC+
gQM389qqV5MFoXxDh2XKXrdMDglA+UYOATlap79KwvjGDkc/8wdHFfJA+SYO
yl7TrkWt4ILyTR02rsufohfNAeWbOch7+FqKrWKF8s0dfMzrtz/WY4byLRze
W/7656T3zR7Ct4Tyn9kDAE4RYMc=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwmOGm+7LwliKUz+HwdHun
noUtjC/gcHHPn3WdKxSgfBEHHls1fn4eGF/Cwbo4r77ooByUL+NwfLESa3mz
LJSv4NB6W18zukwGyldyCNiupWjuLA3lqzhky+SbzLCWgvLVHCzLQx6z/ZKA
8jUcFkzl4Dh+SRzK13JY1MizaUmgGJSv47BpfZucxB0RKF/PQYhbfM+zPcJQ
voHDjyXsdU8chaB8QweXhoq/hu2CUL6Rw2obpQyNw/xQvrFDeJTRuiIlGN/E
4RpvR8ZPP14o39ShbWK2VbU8O5Rv5lA77/IesYfMUL65g3Hv2++OB37aQ/gW
aHxLh/eWv/456X2D8q3Q5K0dmBS0fnGv/gPl20DVP7MHAFkibGQ=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwSE/2n8h4TRHK53D43VY9
Ybc+jC/gUMk7a/2biQpQvohDHeeCVE5GGF/CQfzvJV6Xi3JQvozD5S9pO7r7
ZaF8BYevdvuF17nJQPlKDvECF58zvJeC8lUcJKQ2qjc/kITy1Ry4u80r1+6T
gPI1HIQPK+qKzxeH8rUcGl8q7n/kKQbl6zhkpnyt0FcXhfL1HKaq/o1kmC8M
5Rs4eG/+6BVoDuMbOnAt/hHndlQQyjdyUHRM7yz9JwDlGzvwCB8qL3jJD+Wb
OIRHGa0rUoLxTR2u8XZk/PTjhfLNHC7uuPrlxg9uKN/cYeLj4mqn7+xQvoVD
28Rsq2p5GN8STd7KoXbe5T1iD5mhfGsHJgWtX9yr/9hD+DYO7y1//XPS+wbl
2zpwM6+tejX5oz0AOU5wbQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwUFkQbW5xUxHK53C4+Y29
ytADxhdwuH1Bfd6MHQpQvoiD41Jhg/s6ML6Eg/QJ51PFkvJQvozDTdnXEfm/
ZaF8BYe3RX+n82yTgfKVHCpuBz7oKJGG8lUcXj2+8ENeTgrKV3PQbbwZx/1F
AsrXcGj5fyeIjRPG13L4yBd6WFNfHMrXcSj5tVLJ0EoMytdzuM7Wfl32kwiU
b+Awt+FqFf86YSjf0OGS/SQW8buCUL6RQ+SstQtFdQSgfGOH0t0BNhY/+KB8
EwfeIiPry028UL6pQ/aJHfsu7+SG8s0c3lv++uekxwblmzvIe/haiq1ihfIt
HHzM67c/1mOG8i0dildb229axADlW0H1f7OH8K2h/Gf2ACAtaTM=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVw0Oma9XrhKUUon8Ph6fZO
PQtbGF/A4XCHyLz3SxWgfBGHHgHdDVxcML6EA+v3qYYGH+SgfBmH83oBRzyX
y0L5Cg7zUkQdD3XLQPlKDumyvUUXYqWhfBUH/TAT5U9fJKF8NQdFicS/Z+9K
QPkaDqJ+aebPtotD+VoO+3YJcXyYIgbl6zhoRVsc3ecvCuXrOZxLjPj4+aYw
lG/gAPGvEJRv6KDppyzimisI5Rs58AgfKi94yQ/lGztkn9ix7/JObijfxOGn
zqSa5TmcUL6pw4fNF//WisL4Zg618y7vEXvIDOWbOyzffV3slAwrlG/h4GNe
v/2xHkze0oGbeW3Vq8kf7QG6aGDd
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw2PXkdZ/KBUUon8Ph8KuQ
mQL2ML6AQ1LDBLuNCxSgfBGH54JNq+ezwPgSDgePPG44dU0OypdxkFjw92hi
qyyUr+DgvkOnYG27DJSv5FDg5lLZniYN5as45AbN3K4gIQXlqzn8n7Yz+dFD
CShfw+HHdu5wmRPiUL6WA9sH/msTM8SgfB2H/N5KSeHJolC+nkMMh1TDDEsR
KN/AwXvzR69Ac2Eo39Ahde4ypuoFglC+kQOP8KHygpf8UL6xw5KTi8u4S/ig
fBOHa7wdGT/9eKF8U4fZ17h/LjPlhvLNHNomZltVy7ND+eYO3Mxrq15NZoTy
LdD4lg7vLX/9c9L7Zg/hW0H5z+wBNCJlQg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwmF1xLSj0tCKUz+Fwzsgp
Nl4Dxhdw2NSbsPvlVAUoX8SBZ0rLk4Zf8lC+hEPw0XVhtw7JQfkyDkz/Fu6f
Vy8L5Ss4KDHp7GCpkIHylRwOtUlHhURIQ/kqDtky+SYzrKWgfDWHkg+Ge4Uc
JaF8DYf/WckdJ56LQ/laDqwlstr1O8SgfB2HD4GX+6eaiUL5eg7BDBbnNgqK
QPkGDtsLlkXqiQpD+YYOhruk1R+VCkH5Rg7dRql3ZicIQPnGDktOLi7jLuGD
8k0cZl/j/rnMlBvKN3X4sPni31pRTijfzKF23uU9Yg+ZoXxzh+LV1vabFjFA
+RYOkPBmgvIt0fhWaHxrB27mtVWvJjNC+TZo5tk6MClo/eJe/ccewrdzeG/5
65+T3jco3x6N7+Bg3Pv2u+OBnxB+gwNU/hlU3hHVvAZHqP0f7QFs2Itl
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwcPwSEeV3TxHK53BIPOTK
F2cN4ws4WHzlbe5bpgDliziImS7z28gB40s4qGbNNcsUlofyZRw0ksUtc57I
QvkKDqEHmG0blspA+UoOX+QuT7nVIw3lqzgEcDH23k+RgvLVHBbMtFRrj5GE
8jUcrl+tPdVlIwHlazncPr7l1vViMShfx8FMinPxxwWiUL6eg0Fs8/K9K0Sg
fAOHuQ1Xq/jXCUP5hg6R8Yc8oiJgfCOH4o3rOwOqBKF8Y4fXd9Rb9JsEoHwT
h73Hrd5pPOaB8k0dlL2mXYtawQXlmznobGZhM+tjh/LNHd5b/vrnpMcG5Vs4
QMKbCcq3dAjsMdRmaWWB8q0cjHvffnc88NMewrd2YFLQ+sW9+g+Ub4Mmb+sQ
HmW0rkjpP5RvhyZvD7X/G5Tv4MDNvLbq1eSPEH4Dgg8AJY2BbQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwaLg95478bUUon8Phnm1S
3U0bGF/AwYGl+JjgEgUoX8Qh8eu/fB4RGF/CoVP2EvOjX3JQvoyD69vcTf6H
ZaF8BQfnLfHnjq2XgfKVHFJ+PJkzYZE0lK/ioLlm4qNdRVJQvpqDztIF4lo9
klC+hsPz7WsMDUMkoHwth/UhLCwf34lB+ToOE2Uz38x6LArl6zkYxDYv37tC
BMo3cGg6Hh77ywfGN3RwtX1Sc/6XEJRv5MDNvLbq1WRBKN/YYcnJxWXcJXxQ
vonDN96djX9MeaB8Uwfj3rffHQ9wQvlmDieO2paX7OKA8s0dlu++LnZKhhXK
t3CAhDcTlG/pULza2n7TIgYo3wqNb+3ApKD1i3v1H3sI3waNb4vGt4O6/6M9
AIbtd8k=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQEf7MVCt+7emK3kABVwOJ+wOaPnjiKUz+Hw5SBD
SoULjC/g4PH0vs6tGQpQvoiDX7rp/t//5KF8CYd7rP95/6+Tg/JlHJStJs/o
qJCF8hUclsn+46/JloHylRyucdQl+8tIQ/kqDtyiV0v2T5GE8tUcHvzawbC2
XgLK13DQ2czCZtYnDuVrOayc/2yDdqwYlK/jkOSnueIfjyiUr+fwM7H4b+NW
YSjfwMFwl7T6o1IhKN/Q4eQ1lS+/eQShfCOHUs0pkydtEoDyjR381vS5pm7l
hfJNHL7x7mz8Y8oD5Zs6KHtNuxa1ggvKN3M4cdS2vGQXB5RvDnUvO5Rv4VA7
7/IesYfMUL6lAyT8maB8K4fi1db2mxYxQPnWaPI2Dsa9b787HvhpD+HbovHt
0Pj2DkwKWr+4V/+B8h1QzWtwcAiPMlpXpPQfKu+Ian+DI5q8kwM389qqV5M/
QvgNTmjudYbKM0L1O6PJu6C6p8EFzb2uDu8tf/1z0vsGlXdFtY/BDSr/DCqP
xmdwh/MBLJTAjA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwyLz2uGzrWUUon8NBgfHi
FSVLGF/AYUZD0vGoNQpQvoiDl+59m3QZGF/C4aSD6+/Dn+WgfBkH0danV6UP
yUL5Cg5crHZOZzNloHwlh/AkrxPxxtJQvopDG7u9Ap+6FJSv5iCUHXKL7Z0E
lK/hoLOZhc2sTxzK13JoKLX/YqUmBuXrOCT5aa74xyMK5es5yO0s3tZ+WhjK
N3B4NNvM9PZkISjf0IFr8Y84t6OCUL6RQ/Fqa/tNiwSgfGMH3iIj68tNvFC+
iYP8v7OnLT5wQfmmDj91JtUsz+GE8s0c2iZmW1XLs0P55g618y7vEXvIDOVb
OPiY129/rAfjW0LtY4DyrRyMe99+dzzw0x7Ct3Z4b/nrn5PeMyjfBo1v68DN
vLbq1eSPUL4dVP4blG+PJu8A1w8AiKR94g==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwaJRx37/yqiKUz+GwLrlt
/xVrGF/AoeRVeuaiVQpQvojDBE8DR3U2GF/C4Z9gtpD9aTkoX8Zh672bTzYV
yUL5Cg4HPy8sllWRgfKVHFT/d0/8KSkN5as4JDh/sGr4Jgnlqzk8+LWDYW29
BJSv4TBXbuq+2XbiUL6Ww6OFV0IFpMSgfB2Hi2vOf1bJFYXy9RwC9BcolUiI
QPkGDoZus3Z6nRWC8g0dZFf/uRZjLgjlGzlUah7/meovAOUbOziH/DFjdeOD
8k0clpxcXMZdAuObOvzUmVSzPIcTyjdzeG/565+THhuUb+7Azby26tVkRijf
Asr/aA/hW0LVP4PyreB8AJOhaBE=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwSK24NOHQNUUon8Ph+eXA
p55GML6Aw9MSMzWhRQpQvoiDwGXdVx/fyEP5Eg6LM99HpS+Vg/JlHHKZaycF
2spC+QoOMZ9eCX3/Jg3lKznkFz05n7tECspXcdBZukBcq0cSyldzWOtx61kR
owSUr+Ewa+VB569rxaB8LYf7r5eXhs8RhfJ1HOR2Fm9rPy0M5es5eG/+6BVo
DuMbOMzcv7w8VEcIyjd0KF5tbb9pkQCUb+Sw2kYpQ+MwP5Rv7FC6O8DG4gcf
lG/icHHH1S83fnBD+aYOOptZ2Mz62KF8M4eq+l8Hs1exQfnmDtzMa6teTWaE
8i2g9jFA+ZYOkPBngvKtHN5b/vrnpPfMHgCZVGlQ
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw+FYnYahyShHK53BYb5+/
VcYAxhdwuLPwWJr0TAUoX8SB4bdN2AVWGF/C4cK37wsMnstB+TIOUzeysL19
IAvlKzj8LPTMcNkqA+UrOZT1lM73mCEN5as4LJNl7bscJgXlqzkoSiT+PXtX
AsrXcPifldxx4rk4lK/lsLtnwvLqjWJQvo7DVY2cxGXbRaF8PQeZ2xEOAhNF
oHwDB00V9iff3YWhfEOHaPf9XL82CEH5Rg5XUr9xauwUhPKNHQJytE5/lRSA
8k0cBN+IiH0Q44PyTR381vS5pm7lhfLNHKK0J3qcq+CG8s0dNq7Ln6IXzQHl
Wzi0Tcy2qpZnh/It0fhWDj7m9dsf6zFD+dYO4VFG64qU/ttD+DYO7y1//XPS
e2YPAJtgamQ=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwUA6tTf90QxHK53AQf7ZQ
mNUUxhdwYN/5qcVuigKUL+Jw8biWK/d3eShfwuH1ef0k2cdyUL6Mg/52x91N
G2ShfAWHptCwZdH+MlC+kkPY9QNssiLSUL6KQ2Vwl86J/5JQvprD4eVb5pjP
koDyNRwyqu+lLWISh/K1HFQKL978KSoG5es4mE0+kuEpJArl6znMbbhaxb9O
GMo3cCi49vlQoqIQlG/oYHlu94JjDwSgfCMHwTciYh/E+KB8Y4co7Yke5yq4
oXwTB+Pet98dD3BC+aZofDOHE0dty0t2cUD55g4+5vXbH+sxQ/kWDkwKWr+4
V/+xh/AtHcKjjNYVKf2H8q0cuJnXVr2a/BHKt0bj2zi8t/z1z0nvmT0A8o1u
LA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwyDziovjgsiKUz+HgU1l4
yMkBxhdwOLjwsC77HAUoX8Thr5et2iNhGF/CIXCNy0bpn3JQvozDvytTJtyc
LwvlKzi0cnD8WZsvA+UrOUj65qceEpSG8lUc9oVde6L2WxLKV3OwE1Nd8+uI
BJSv4SDql2b+bLs4lK/loLN1ceif3WJQvo5D6E3Wzo5qUShfz2Hxk9Yk5zQR
KN/AIdp9P9evDUJQvqHDM30l4zxNQSjfyGG1jVKGxmF+KN/Y4RvvzsY/pjxQ
vomDste0a1EruKB8U4cTR23LS3ZxQPlmDjqbWdjM+tihfHM0voVD28Rsq2p5
GN/SYfnu62KnZFihfCsHJgWtX9yr/9hD+NYO3Mxrq15N/gjl2zi8t/z1z0nv
G5RviyZvh8a3h/MBN8V2sw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwuFylfzr9nCKUz+GwYKWH
h7IxjC/gsK1bOHDlCgUoX8RhHSu/UBsHjC/hYHk+zr70lhyUL+Nwx4yH8+4u
WShfwaFNTOmqYZIMlK/kUKElUrw1UBrKV3Fo7ZxnK6MoBeWrOXwXshRTkJeE
8jUcMhaJq7aLSkD5Wg7zeKZvE7kiBuXrODS3HL4z/YAolK/nINBemHJ/kQiU
b+CwuaD4c1SFMJRv6HDJfhKL+F1BKN/IIcdpwl6+hXxQvrHD3uNW7zQe80D5
Jg5npT68miLABeWbOizffV3slAwrlG/mUDvv8h6xh8xQvrkDN/PaqleTGaF8
C4fwKKN1RUr/7SF8S4f3lr/+Oel9g/Kt0OStofo/Qvk2UPXP7AGBBmmP
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwMHwwZ27ncUUon8NBpOXa
5h5zGF/AwaDaT+buagUoX8ThyVbD5FfSML6EQ8mc3ozpEvJQvoxDUpXByruf
ZKF8BQfVvF3a11bLQPlKDiyd/VmrOqShfBWH3KCZ2xUkpKB8NQeFl5u33rgv
AeVrOFi6X3HYtF4cytdyqKr/dTB7lRiUr+OwfPd1sVMyolC+nkP11UpehgQR
KN/AYXNB8eeoCmEo39CBLZRx84fDQlC+kUOp5pTJkzYJQPnGDr5ux44+sYXx
TRycQ/6YsbrxQfmmDvL/zp62+MAF5Zs56GxmYTPrY4fyzR3aJmZbVcvD+BZo
fEs09VYO8h6+lmKrWKF8a4fwKKN1RUr/7SF8GzS+rQM389qqV5M/Qvl2Du8t
f/1z0ntmDwAMtXDU
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwuGy9I/TFFUUon8NhdheD
o68BjC/gIDCrim9ZswKUL+IgYWZae+qyPJQv4ZDjNGEv30I5KF/G4flN9Sae
WlkoX8FBanZo2dJ4GShfyYFlT8ENcz5pKF/F4eDmRUeYtaSgfDWH+NyN82dc
lYDyNRw46vqlT8WLQ/laDg2l9l+s1MSgfB0Hm68H7/XEiUL5eg4xHFINMyxF
oHwDh5OVLjYpasJQvqGDffiXGD9pQSjfyOE/Q+D/hBJ+KN/Y4RvvzsY/pjxQ
vomDce/b744HOKF8U4eJj4urnb6zQ/lmDtzMa6teTWaE8s2h/I/2EL4FGt/S
4b3lr39Oes/sAbS8Xq8=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwEFlZ5uR/XhHK53CYIf5Q
9rMFjC/gwO0VXXlungKUL+LwJ7+cteajPJQv4VBz4mVFwlQ5KF/GIZe5dlKg
rSyUr+DQ8zN19m9dGShfyUF48sJdK59LQfkqDi12ibr8KyWhfDWHD+rH5Vgz
JaB8DYdIJYsFN8LEoXwth666OPE1X0ShfB2HFpaTpzimi0D5eg5TVf9GMswX
hvINHLgW/4hzOyoI5Rs6rJdes/2SNz+Ub+Rwjbcj46cfL5Rv7BClPdHjXAU3
lG/ikH1ix77LO2F8Uwf5f2dPW3zggvLNHNomZltVy7ND+eYOEx8XVzt9h/Et
HKrqfx3MXsUG5Vs6LN99XeyUDCuUb4Umb40mb+NQvNraftMiBijf1uG95a9/
TnrP7CF8Oyj/G5Rv72Dc+/a744GfUL4DqnyDgwOTgtYv7tV/oPKODtzMa6te
Tf4IlXeEmw8ArSeQLw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwOLCv9ZfnJUUon8MheWq6
B4sFjC/gcGfhsTTpmQpQvohD2H7J1vKf8lC+hIM8h8LszKtyUL6Mw4I/vxIT
e2ShfAWHiwz/nf/WyED5Sg79vK9mKoRJQ/kqDvF5QlbfdaSgfDUHec+jcpPn
SUD5Gg7T+vMKVrWKQ/laDo1zL8RLFohB+ToO1llFMxK2iED5eg7bC5ZF6okK
Q/kGDgXXPh9KVBSC8g0dAnK0Tn+VFIDyjRz81vS5pm7lhfKNHfYet3qn8ZgH
yjdxWHJycRl3CR+Ub4qm3syBSUHrF/dqmHpzh6Of+YOjCmF8C4eN6/Kn6EVz
QPmWDm0Ts62q5dmhfCuH4tXW9psWMUD51g7czGurXk3+aA/h2zi8t/z1z0nv
GZRviyZvB5X/BuXbO4RHGa0rUvoP5Tugmt/gADcPAEa3gX8=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVw0N4exrrvhiKUz+GgfDL0
uZErjC/g0PTZlk98rQKUL+IQZPT3xnZhGF/CwS3xxz6v93JQvoxDaNN0lomb
ZaF8BYdDq/nUD/vIQPlKDr7WfZu3/pCC8lUc7gSXid2dKQnlqzncVs5adFxN
AsrXcGiceyFeskAMytdyqI22t9kSIgrl6zhstU/7UZMjAuXrOZzetnVlUYEw
lG/gYOg2a6fXWSEo39Dhkv0kFvG7glC+kYPs6j/XYsxhfGOH9dJrtl/y5ofy
TRz81vS5pm7lhfJNHZgUtH5xr+aB8s0cJrQw77gfywXlmztU1f86mL2KDcq3
cNDZzMJm1scO5Vs6vLf89c9JDyZv5RDYY6jN0soC5Vs71M67vEfsITOUb+PA
zby26tVkRijfFmr/H3sAH5FssA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVweMtntsX0jiKUz+Eg0nJt
c485jC/gsKrBxGDCUgUoX8RB1Wwn53YuGF/C4Y2Nxr3PV+SgfBkH0danV6UP
yUL5Cg6hB5htG5bKQPlKDmcPKLB97JOG8lUcQutvhCc7SkH5ag6fFkcekDeS
hPI1HE7Frf+0z1wCytdymHNe1ZOtSwzK13G4F9HX3vNdBMrXc/iZWPy3casw
lG/gcCTgwOyGXUJQvqGDS0PFX8N2QSjfyEFa4vGLiZMEoHxjh/Aoo3VFSvxQ
volDjtOEvXwL+aB8U4eLO65+ufGDG8o3czgr9eHVFAEuKN/cYfnu62KnZFih
fAsHeQ9fS7FVML6lAyT8maB8K6h9/+0hfGsHbua1Va8mf4TybeB8ANPSbk4=

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwEPr79OGZq4pQPofDxqxn
mi8NYXwBB/fJWox/OhWgfBGHlHuvtk18Kg/lSzhc4pXnVTgmB+XLOGTv/8Hj
3CAL5Ss4/CvPOGYRIAPlKzlsWdfcIe4kDeWrOHD9N856c08SyldzEMoOucX2
TgLK13BYMJWD4/glcShfy+Ghduohbh0YX8dB4bHo1MWRolC+nkNch9tL2yPC
UL6Bw8IlJ0T7rwlB+YYOV1K/cWrsFITyjRykJR6/mDhJAMo3duARPlRe8JIf
yjdxiNKe6HGughvKN3WYfY375zJTGN/Mwbj37XfHA5xQvrlD28Rsq2p5dijf
woGbeW3Vq8mMUL6lA5OC1i/u1X/sIXwrqP6fUL41VP1HewAyU2oc
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwKBI/lshzWRHK53D4OGWu
qIkFjC/gcOZHwP+NixWgfBGHyEXVYtOlYXwJh6YN097nfJKD8mUcuptyhev2
yUL5Cg48zdOmra2UgfKVHB561n17+18Kyldx+BcqJtt9QxLKV3MQOXvn5L+X
ElC+hsPrlE1Nn9aIQ/laDjMsd097e0gMytdxSM9+5nyAF8bXc2g7O10yQkcU
yjdw2PijD2iaCJRv6HAk4MDshl1CUL6Rw5XUb5waOwWhfGOHbR8m6Eud5YPy
TRwu7rj65cYPbijf1MG49+13xwOcUL6Zw1mpD6+mCHBB+eYOVfW/DmavYoPy
LRy4mddWvZrMCOVbQvX/tIfwrRzCo4zWFSn9twcAFr5vOQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwmNx1baXnTUUon8NBIGPN
4lceML6AQ43Vu0XdcxWgfBEHrpWtZ3cwwvgSDhozWIxmvpGD8mUcTnc8v/x8
uSyUr+CgcSqp7XaxDJSv5MBtmXbvjbk0lK/iwDC5vWumkhSUr+ZwL+xh5RFu
SShfw2Hi4+Jqp+/iUL6WQwxDsFjARDEoX8fhXkRfe893EShfz2Fuw9Uq/nXC
UL6Bw97j7fd/1AtB+YYOlud2Lzj2QADKN3IIjzJaV6TED+UbOxz9zB8cVcgD
5Zs4bFyXP0UvmgPKN0Xjmzm8t/z1z0mPDco3dwjsMdRmaWWB8i0cildb229a
xADlWzpwM6+tejX5oz2Eb4XGt0bj26DxbaH2fYPy7aD8Z1C+PRrfAc4HAMbA
hKs=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwmBjHqnb/jCKUz+Gwcv4t
/r9mML6AQ07vuZ6dMxSgfBGHxZwHn728Lw/lSzj8CMmdN7tWDsqXcTgSYjzp
Z5IslK/g0FzVWGwfJgPlKznk1/inuvpKQ/kqDrlBM7crSEhB+WoOQtkht9je
SUD5Gg5uszk/LteG8bUclv1dIa82RwzK13FYvvu62CkZUShfz6HpeHjsLx8R
KN/AYXvBskg9UWEo39AhoTD296kXglC+kcMyZa9bJocEoHxjh9LdATYWP/ig
fBOHa7wdGT/9eKF8U4eLO65+ufGDG8o3czhx1La8ZBcHlG/uIO/haym2ihXK
t3ConXd5j9hDZijf0iE8ymhdkdJ/ewjfyuG95a9/TnrP7AHEtme2
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw8Itj/3jvtiKUz+Fwwsvq
TKEDjC/gYON5z3LdPAUoX8RB92JrTCUrjC/hUCJjWXPmlRyUL+PAVjHrSshk
WShfwWHLuYcHL9TKQPlKDr92WUT/r5aG8lUcQutvhCc7SkH5ag6S/FOsFlhK
QvkaDk+ZtpdNeiQO5Ws57H0T7Oe/WAzK13HYVaDzPZhJFMrXcxDiFt/zbI8w
lG/goC0rJpmeKATlGzpo+imLuOYKQvlGDrw5Qq87CgWgfGMHz5XrVqnO4Yfy
TRxWOB4+ekySF8o3dZh9jfvnMlNuKN/M4cRR2/KSXRxQvrlDYI+hNksrC5Rv
4eBjXr/9sR4zlG/pULza2n7TIgYo38rBuPftd8cDP+0Btxlgqg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQEf7MVCt+7emK3kABVw+H+s58PX44pQPodD47xt
f9P0YHwBh6X3D32SmaAA5Ys4WAozmai8kofyJRziHKfqLFstB+XLODQWrtm7
tEQWyldw+Ma7s/GPqQyUr+QQdv0Am6yINJSv4tDGbq/Apy4F5as53NnTbvXz
uQSUr+FgGeY2v5Mbxtdy+Pzr2NE7t8SgfB2H33zp9gddRaF8PQedD33rtvcL
Q/kGDguXnBDtvyYE5Rs6nLym8uU3jyCUb+SwXnrN9kve/FC+scPe41bvNB7z
QPkmDhNamHfcj+WC8k0dsk/s2Hd5JzeUb+bwYfPFv7WinFC+ucPGdflT9KI5
oHwLB3kPX0uxVaxQvqVD8Wpr+02LGKB8Kwfj3rffHQ/8tIfwrR2YFLR+ca/+
A+XbOLy3/PXPSe8blG+LxrdD49s7cDOvrXo1+SOU7wCVfwbhN6DxGRxR1Tc4
opnnhCbvhOZeZzR5ZzTzXdDsR+MzuKLa1+CK5n831PBqcIPbBwDZO8kf
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwuKj2/N2604pQPofDl/rY
e8kWML6Aw50X96cKLlSA8kUcfE61hOiKw/gSDq8eiD/ZyiwP5cs4sP5Zrun0
WBbKV3DIF2WRuLZXBspXcnAtnPrmXqU0lK/ioGfnem9FuhSUr+bwU2dSzfIc
SShfw2Gr5LP7X+6LQ/laDsd6DpWX7ReD8nUcvm5v3fntliiUr+ewaX2bnMQd
ESjfwOG55qdKwwBhKN/Q4WSli02KGoxv5DBz//LyUB0hKN/YgTdH6HVHoQCU
b+KwXnrN9kve/FC+qYPgGxGxD2J8UL6ZA2+RkfXlJl4o39zhG+/Oxj+mPFC+
hcPsa9w/l5lyQ/mWDh82X/xbK8oJ5Vs5yHv4WoqtYoXyrR2YFLR+ca/+Yw/h
2ziERxmtK1L6D+XbOkDijwmq3g5N3h6N7+Dw3vLXPye9ZxB+A4IPAOj4hS4=

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQEf7MVCt+7emK3kABVw2M6hcy/wqiKUz+Gwue+P
g7sTjC/goBDJP4dvswKUL+Lwu6Vi+mZZGF/CISj1l5XZFzkoX8bBrijA0Wq+
LJSv4LA4X15kSZ0MlK/ksO6B7/oJbdJQvorDDyO2464uUlC+moP+f8PNr5kl
oXwNB1G/NPNn28WhfC0HxQWNIo5nxaB8HQebrwfv9cSJQvl6DtVXK3kZEkSg
fAOHpBNKu4wbhKF8Qwe3vS+zHC4KQvlGDr5ux44+sRWA8o0d9h63eqfxmAfK
N3E4K/Xh1RQBLijf1KGq/tfB7FVsUL6ZAzfz2qpXkxmhfHOH95a//jnpfbMH
AAYsWKk=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwUL+b+oTprCKUz+Fwx1Yy
RUUTxhdweMBp8frEVAUoX8Thy4HGBRwv5KF8CYc2mepYtXlyUL6MQ5dKSxpP
kSyUr+DQwHTnFb+LDJSv5LBhXk5YjLY0lK/iEMO9L2K2sBSUr+ZQMDPP/8QB
CShfw4Gjrl/6VLw4lK/l0FBq/8VKTQzK13HQPi7xdclDEShfz0FuZ/G29tPC
UL6Bw8IlJ0T7rwlB+YYOP7yfcjT6wPhGDq/vqLfoNwlA+cYOgm9ExD6I8UH5
Jg5HP/MHRxXyQPmmDnuPW73TeAzjmzmclfrwaooAF5Rv7mDc+/a74wFOKN/C
YeLj4mqn7+xQvqXDxnX5U/SiOaB8K4eq+l8Hs1exQfnWDst3Xxc7JcMK5ds4
cDOvrXo1mRHKt3WAxB8TlG/nULza2n7TIgYo3x5q/097CN/B4b3lr39Oes/s
ATy1fLE=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwyPyz/0foOUUon8PBrOF8
u6AujC/gIHyP59OV6QpQvoiD7sXWmEpWGF/CwW6Ga0jTATkoX8bhctPt6JrZ
slC+gsOctQ0Pz7nKQPlKDhI7jv44tFsKyldxON/3rddpriSUr+agdW2tEMcM
CShfwyF3SRJ7W544lK/l4DLngdDOTlEoX8fBILZ5+d4VIlC+nkPwtc6eS7LC
UL6Bg4COofS5/4JQvqGD58p1q1Tn8EP5Rg68RUbWl5t4oXxjByYFrV/cq3mg
fBOHs1IfXk0R4ILyTR2yT+zYd3knN5Rv5mDc+/a74wFOKN/cQd7D11JsFSuU
b+HgY16//bEeM5Rvica3gtr3xx7Ct0bj2ziERxmtK1L6bw8Ao25rcg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwSE/2n8h4TRHK53AQf7ZQ
mNUUxhdwWLnz3V2eeQpQvogD18rWszsYYXwJhw+q59gdrstB+TIOPNH1BQdX
ykL5Cg5z9ByuXIyQgfKVHM6/fPR+G4s0lK/isLmO9WitthSUr+ag23gzjvuL
BJSv4WBxtL563i5xKF/Lgfvyl8J/dWJQvo7D78IF9b4ZolC+nkPT8fDYXz4i
UL6BQ9IJpV3GDcJQvqHD4z1/G7TNhaB8IzS+scMzfSXjPE1BKN/EYZmy1y2T
QwJQvqnDf4bA/wkl/FC+mUOU9kSPcxXcUL65w0+dSTXLczihfAuHjevyp+hF
c0D5lg6Q8GeC8q0caudd3iP2kBnKt0aTt3Ew7n373fHAT3sAVz1uDw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwEDqwRejIXUUon8NBTImL
ycATxhdw8Jm2/0zfOgUoX8Th0odpYiUsML6Eg7eh8VutG3JQvoyD08Pp+6Ln
ykL5Cg5z9ByuXIyQgfKVHI4KZbdwe0tD+SoOZ6U+vJoiIAXlqzl8mqvntoNX
EsrXcCjbKDcp9K44lK/lYCQ+PzGmTQzK13G4/3p5afgcUShfz6H6aiUvQ4II
lG/gsM79fVA5jzCUb+jwrWudeOwXQSjfyEHoxYFDq4NgfGMHX7djR5/YCkD5
Jg68RUbWl5t4oXxThxWOh48ek4TxzRxmX+P+ucyUG8o3d9i4Ln+KXjQHlG/h
sHz3dbFTMqxQviUa38rBx7x++2M9Zijf2qF23uU9Yg9hfBsHeQ9fS7FVMPW2
aOrtHJgUtH5xr/5jD+HbO7y3/PXPSe8blO8A5T+D8BsQfAB81YAZ
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBGIQDQEf7MVCt+7emK3kABVweCsmIR51ShHK53C46mwV
v0cXxhdw4LOeW9w5UQHKF3E4ftKKc+lbeShfwuGOXovL7pVyUL6Mg8NiU8uN
tbJQvoJDU2jYsmh/GShfyeH8y0fvt7FIQ/kqDtOPnF0aslsSyldzOPuxrU6l
SALK13A4wGe+95CQOJSv5VCnUzU774MolK/jsNU+7UdNjgiUr+fwM7H4b+NW
YSjfwOFkpYtNihqMb+hQkrF8n7+YEJRv5BA5a+1CUR0BKN/Yodso9c7sBBjf
xOHzv12RTewwvqnD3uNW7zQe80D5Zg7KXtOuRa3ggvLNHSY+Lq52+s4O5Vs4
yHv4WoqtYoXyLR3eW/7656THBuVbOQT2GGqztLJA+dYOPub12x/rMUP5Ng7L
d18XOyUD02/rAIk/JijfzqF23uU9Yg9h6u3R1Dug2tfg4MCkoPWLe/Ufe4i8
o4Nx79vvjgd+QvgNjg7czGurXk1mhOp3QuU3OKH5xxnV/Q3ODsWrre03LWKA
yrug8hvQ+AyuqO5vcEWz380hPMpoXZHSf6j73NDk3VHDo8EdzX8eqPwGND6D
J5r5nmjme6GZ74Xmfm80/3lDw/sb1HwfVH6DDzy8ASJD4po=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVw0Oma9XrhKUUon8Phm4f5
nVtGML6AQ07vuZ6dMxSgfBEHR5djq+3eyEP5Eg73WP/z/l8nB+XLOPAWGVlf
bpKF8hUcnjVv6P0WLgPlKzmwzNoRN/m6FJSv4uCzw8FVc4YklK/mwH1AwV6/
WgLK13DYfoDLff5rMShfy8HsU5SG931RKF/HofpqJS9DggiUr+ew8ZPU/KoM
YSjfwGFfjOpBOW4hKN/QwaWh4q9huyCUb+Sw7cMEfamzfFC+sYNzyB8zVjcY
38SBSUHrF/dqHijf1OEb787GP6YwvpnDT51JNctzOKF8c4cTR23LS3ZxQPkW
DoE9htosrSxQvqUDN/PaqleTGaF8Kwfj3rffHQ/8tIfwraHyH6F8G4f3lr/+
Oek9g/Jt0eTt4HwAFZh0+Q==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVw4Pvywn3VCUUon8PhU2X+
wQg1GF/Awe79jSePJyhA+SIOLz/Oq/V+Kw/lSzgc9dS73twrB+XLOJQ2mSh+
SZGF8hUcgoM2ivl8lIbylRyctc7G3l0nBeWrOFTk9luUBktC+WoO/AeClzJJ
SED5Gg5thtvlrgeIQ/laDnPOq3qydYlB+ToOPeIXJn0rFIXy9RwMYpuX710h
AuUbODjpJUwpShCG8g0dot33c/3aIATlGzkI6BhKn/svCOUbO0TOWrtQVEcA
yjdxEHwjIvZBjA/KN3VgUtD6xb2aB8o3c5jQwrzjfiwXlG/uoOw17VrUChjf
wuHEUdvykl0cUL4lGt/KoW1itlW1PDuUb+3Azby26tVkRijfBmrfH3sI3xYq
/xHKt0Pj2zsY97797njgJ5TvANcPAOjseeA=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwiDN8sVblmiKUz+EQUMWT
/9AOxhdweFpipia0SAHKF3GQKba/JMgP40s4XPj2fYHBczkoX8YhtGk6y8TN
slC+gsP+q6XWBkUyUL6SQ0jHoTMlNtJQvoqD4TmVHbw/JKF8NQf9/4abXzPD
+BoOC6ZycBy/JA7lazns2yXE8WGKGJSv43D614uutqWiUL6eQ1yH20vbI8JQ
voGDk17ClKIEGN/QwXCXtPqjUiEo38iBm3lt1avJglC+sUPkrLULRXUEoHwT
h9LdATYWP/igfFOHHKcJe/kWwvhmDkc/8wdHFfJA+eYOy3dfFzslwwrlWzjU
zru8R+whM5Rv6cCkoPWLe/UfewjfCmr/R3sA+UhimQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwWOV00EjquiKUz+EQly+g
89EGxhdwOJ7IL7JolgKUL+LgsJOp999beShfwiGHrZPBYq8clC/jENNxV0R4
jyyUr+Cg9fjQ4cYqGShfyWH2Ne6fy0yloXwVh3XnKwOtzKWgfDUHLu3mWM4P
ElC+hoPezE3vY/+IQ/laDu/t8zwfssL4Og4z++ZlHSoThfL1HDy8em5tihSB
8g0cFi45Idp/TQjKN3S4ZD+JRfyuIJRv5BA5a+1CUR0BKN/YgUlB6xf3ah4o
38RB/t/Z0xYfuKB8Uwdlr2nXolbA+GYOG9flT9GL5oDyzR0Cewy1WVpZoHwL
Bx/z+u2P9ZihfEuH8CijdUVK/+0hfCuH95a//jnpfbMHAKKKYTE=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwyLz2uGzrWUUon8PhhlGG
vLsnjC/g0Lvb9zjLKgUoX8RBfM3U6xP5YXwJh776124GDPJQvowDm8G3ozUv
ZKF8BQfT1eK6kRtloHwlh2uTmTddCJKG8lUcUg5vM+zhlYLy1Ry4tJtjOT9I
QPkaDiW3Fp8QvCEO5Ws5zDmv6snWJQbl6zi4zHkgtLNTFMrXc5DbWbyt/bQw
lG/gMP1hD+O9j0JQvqFD6txlTNULBKF8I4fi1db2mxYJQPnGDs4hf8xY3fig
fBOHb7w7G/+Y8kD5pg4b1+VP0YvmgPLNHHQ2s7CZ9bFD+eYOgT2G2iytLFC+
BdR8Bijf0iE8ymhdkdJ/ewjfyuG95a9/TnrfoHxrB27mtVWvJn+0BwDiKWVJ

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwSE/2n8h4TRHK53D4aPza
180axhdw8D5tYya0WAHKF3FYrPRv/lNBGF/C4c72Q1GvbslB+TIOx0w9JebM
lIXyFRz653LtdE2XgfKVHJau7ur7pC8N5as4rH7tmO5nIgXlqzncC3tYeYRb
EsrXcFhzXfbB8iXiUL6Wg87WxaF/dotB+ToOJTsPKRz2EoXy9Rxq513eI/ZQ
GMo3cJj+sIfx3kchKN/Q4Zm+knGepiCUb+QQHmW0rkiJH8o3dri44+qXGz+4
oXwTh7NSH15NEeCC8k0dJj4urnb6zg7lm0HtY4byzaHm/beH8C0cuJnXVr2a
zAiVt3R4b/nrn5PeN3sARj5mKQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwcA2r3153RRHK53DY66JQ
tM4WxhdwSJF5u9ZggQKUL+IwwUL+li8rjC/h8OmOaezn9XJQvowDW8WsKyGT
ZaF8BQez0HUc54NkoHwlh1q1uN03uaWhfBWHW6klciksUlC+msMZuyduQWcl
oHwNhx/bucNlTohD+VoObB/4r03MEIPydRwiPPoFHu0XgfL1HJ5rfqo0DBCG
8g0cejdzau+7LwTlGzpo+imLuOYKQvlGDtISj19MnCQA5Rs7dBul3pmdAOOb
OBz9zB8cVcgD5Zs6RGlP9DhXwQ3lmzmclfrwaooAF5Rv7lBV/+tg9io2KN8C
jW/p0DYx26panh3Kt3II7DHUZmllgfKtHd5b/vrnpPfMHsK3ceBmXlv1avJH
ewD+7mj9
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVw+JB3rHnlGUUon8NhQd67
+cY2ML6Ag27lnC9pKxWgfBGHxK//8nlEYHwJh/x31lees8pD+TIOPk3bGxJf
y0L5Cg7n1fctfrhcBspXcjg15+XyWaXSUL6KA8Pk9q6ZSlJQvprD0k1HF3dc
loDyNRz8zgUcWZ4hDuVrOcw6JbRrwTpRKF/HYfGT1iTnNBEoX8+hdt7lPWIP
haF8A4fpD3sY730UgvINHTT9lEVccwWhfCOHUs0pkydtEoDyjR2WnFxcxl3C
B+WbOKxwPHz0mCQvlG/qsHFd/hS9aA4o38zhveWvf056bFC+ORrfwkHew9dS
bBUrlG/psHz3dbFTMjC+FdS9zFC+tUNgj6E2SysLlG+DJm/rwM28turVZEYo
3w6Nb+8QHmW0rkjpvz2E7+Bg3Pv2u+OBn/YAicmAiA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQEf7MVCt+7emK3kABVwiPnCf+/AOUUon8PhSeSE
N/OtYHwBB+9uK7OgRQpQvojDzw7XNWvZYXwJhzdvbBq3XpeD8mUcqthbD+hd
lYXyFRwW58uLLKmTgfKVHPi/7fL4kC0N5as4VAZ36Zz4Lwnlqzlwd5tXrt0n
AeVrOBR0zPpYWCgO5Ws5zDmv6snWJQbl6zisFnwnobZZFMrXcwhmsDi3UVAE
yjdwKLj2+VCiohCUb+jwTF/JOE9TEMo3ctj2YYK+1Fk+KN/YIfvEjn2Xd3JD
+SYOs69x/1xmCuObOlTV/zqYvYoNyjdz8DGv3/5YjxnKN3fgZl5b9WoyI5Rv
4QAJbyYo39KheLW1/aZFDFC+FZp6awcmBa1f3Kv/2EP4Ng7GvW+/Ox74CeXb
ovHtHN5b/vrnpPcNyreHmvcRyneAyj+D8Bsc4PIAjdyGvA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw+HT6zOed5xWhfA4HkSmz
X+8xgfEFHLxPCumunKMA5Ys41HEuSOVkhPElHESvfTBd+UgOypdxsP/UZOJ5
RhbKV3DQZ71wWaFLBspXclj3wHf9hDZpKF/F4YcR23FXFykoX82hokFwevlF
CShfw+Hg4aVM1yLFoXwth666OPE1X0ShfB2HTevb5CTuiED5eg6nt21dWVQg
DOUbOOyLUT0oxy0E5Rs6lGpOmTxpkwCUb+RQujvAxuIHH5Rv7OAc8seM1Q3G
N3H4qTOpZnkOJ5Rv6iDv4WsptooVyjdzYFLQ+sW9+o89hG/uwM28turV5I9Q
voXDe8tf/5z0vkH5lmh8Kyj/mT0AAx9nUg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVw+Nmd83/GRUUon8NBZMrs
13tMYHwBh+f+/PeYpypA+SIOLrsORup9kofyJRzKcnIlkk/KQfkyDqF6Iscr
FshC+QoOz5o39H4Ll4HylRwY30/+8z9eGspXcbiv5PJ4l78UlK/m8PzZUYEv
SpJQvoZDvPcehz2HxKF8LYfLOXd2nkgRg/J1HJbvvi52SkYUytdzCNBfoFQi
IQLlGzjEdbi9tD0iDOUbOrjaPqk5/0sIyjdySCiM/X3qhSCUb+ygK6jxcdZF
ASjfxCHHacJevoV8UL6pwwrHw0ePSfJC+WYO2Sd27Lu8kxvKN3eoqv91MHsV
G5Rv4SDv4WsptooVyrd0gIQ/E5Rv5RAeZbSuSOm/PYRv7eBjXr/9sR4zVN4G
jW/rUDvv8h6xhzC+ncN7y1//nPS+QfXbO3Azr616NfkjlO8A5wMAy6uCkA==

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVweNXtnSR1RhHK53DwDH/+
k8sSxhdwSA/c+2X1XAUoX8Sh4F8v7+s/8lC+hMM3Pc6ZXQvloHwZh9ImE8Uv
KbJQvoLD3pR7k81MZKB8JYepvpdt5H9LQfkqDnLFLkpXPkpC+WoOc2tl0pZO
loDyNRzUaq5fPOwuDuVrOZh9itLwvi8K5es4mFzqLVfdJQLl6zlkR7AHJk8X
hvINHAx3Sas/KhWC8g0d7MO/xPhJC0L5Rg6rbZQyNA7zQ/nGDtd4OzJ++vFC
+SYORz/zB0cV8kD5pg5R2hM9zlVwQ/lmDh82X/xbK8oJ5Zs7cDOvrXo1mRHK
t3BgUtD6xb36jz2Eb+lg3Pv2u+OBn1C+FZq8NZq8DRrf1uG95a9/TnrPoHw7
NL49lP8NyneAywMAW3eC6Q==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw8P+9k2/9OUUon8PhlCzn
/HtaML6Ag/A9nk9XpitA+SIOl6+36a34Kg/lSzjIhn+xe3heDsqXcXh+U72J
p1YWyldwuPYwcuqeFBkoX8lBMtuTacIbKShfxWHzpDq9CbMloXw1h5LEF0y7
0iSgfA2HsGWzjcJ5xKF8LYc3fec22V8ShfJ1HLT73c45nRaB8vUcJOL3XOpz
g/ENHNhCGTd/OCwE5Rs6/FjCXvfEEcY3clB0TO8s/ScA5Rs7LFP2umVyCMY3
cdj2YYK+1Fk+KN/U4RvvzsY/pjxQvpmDce/b744HOKF8cwedzSxsZn3sUL6F
g7yHr6XYKlYo39IhPMpoXZHSf3sI38rhveWvf056z+wBKP9lUg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwuHDo4ZG/1xWhfA6Hp9s7
9SxsYXwBh0v7yjMfrlKA8kUcFiv9m/9UEMaXcPA9tSLG844clC/joGm8ZobE
flkoX8Eh+5wOZ9FEGShfyUHWaUZCqas0lK/iwMTZbNGpIQXlqznck2a5z/VN
AsrXcGDN5zbOPSoO5Ws57H66Seb+MjEoX8dh+e7rYqdkRKF8PYeqSu3n11RF
oHwDh4Jrnw8lKgpB+YYOsqv/XIsxF4TyjRy6jVLvzE4QgPKNHbZ9mKAvdZYP
yjdxiNKe6HGughvKN3WY0MK8434sF5Rv5tA2MduqWp4dyjd3eG/565+THhuU
bwF1HyuUb4nGt3KAxAcTlG/tIO/haym2CiZvgyZvi8a3g9r3zR4A059zXA==

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw8Kh47mhxRRHK53BI3r2b
5acdjC/g8FKpKP3ABgUoX8Rhq94LRgM5GF/CoelEtF7kKzkoX8ah58kGqYrd
slC+gkMMT5rpgjUyUL6SQ7P/o+i95dJQvoqD9NHgfBYvKShfzcFfJmGHiawk
lK/hEJ624scvZgkoX8uhbWK2VbW8OJSv49D568Iqyb+iUL6eg3VW0YyELSJQ
voHD9Ic9jPc+CkH5hg4lGcv3+YvB+EYOvm7Hjj6xFYDyjR0iZ61dKKoD45s4
lO4OsLH4wQflmzowKWj94l7NA+WbOfzUmVSzPIcTyjd3mPi4uNrpOzuUb+Gg
s5mFzawPxrd0gIQ/E5RvBTXvjz2Eb+3w3vLXPye9Z/YAkqplSg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw+Hg4UO3mWUUon8MhkFF2
VbYxjC/gsPJf5LuLixWgfBEH1imHFHi5YXwJhxcfbzHpb5WD8mUcFnNO35Be
IwvlKzh8yXXiKnCUgfKVHOa911kp8lUKyldxiDnvybn3tiSUr+ZQMDPP/8QB
CShfw8F4suzGupniUL6Ww87TkdvCI8WgfB2HexF97T3fRaB8PYfaeZf3iD0U
hvINHCanfpgcs1wIyjd0ENAxlD73XxDKN3JYpux1y+SQAJRv7PD5367IJnYY
38SBSUHrF/dqHijf1OHijqtfbvzghvLNHIx73353PMAJ5Zs7fNh88W+tKIxv
4eBjXr/9sR4zlG/pULza2n7TIgYo38ohPMpoXZHSf3sI39qBm3lt1avJH6F8
G4f3lr/+Oek9swcAO2JxfQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwsHMRPrX9uiKUz+Hw7EWB
2RNjGF/AgZ2Ph+XcMgUoX8RhaZf1/87f8lC+hENl0CmHtuNyUL6MQ9j/JRHd
jbJQvoLD6f5SyfoEGShfyWHLuuYOcSdpKF/F4cgNr1nOTyWhfDWHw8u3zDGf
JQHlazgEG3Iw3AwWh/K1HNgPKs/ReSMK5es4/PrhvKhcRwTK13OIdt/P9WuD
EJRv4HDJfhKL+F1BKN/QoVRzyuRJmwSgfCOHHKcJe/kW8kH5xg5npT68miLA
BeWbOCzffV3slAwrlG/qUFX/62D2KjYo38yhdt7lPWIPmaF8c4fAHkNtllYW
KN/CITzKaF2R0n97CN/S4b3lr39Oet/sARRGYZQ=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVw8P92fr7TbUUon8Nhrk/l
8ll2ML6Ag8LT9FcHVylA+SIOiZ+XCZmIwvgSDg95vvjm/JOD8mUcuvt2n996
SBbKV3CIC3q15HScDJSv5HBAa/4lT1FpKF/FoUfR+vDPPZJQvppDwEYFz7Ad
ElC+hkNBx6yPhYXiUL6Ww9QG28WCTmJQvo7Ddbb267KfRKB8PYd3uUe+Gn8T
hvINHGbuX14eqiME5Rs6XLKfxCJ+VxDKN3KQlnj8YuIkASjf2IFJQesX92oe
KN/E4cRR2/KSXRxQvqnDe8tf/5z02KB8MwdIeDJB+eZofAsHH/P67Y/1mKF8
S4fi1db2mxYxQPlWUPOe2UP41g7czGurXk3+aA8AXDxsRg==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBwAWIQDQEf7MVCt+7emK3kABVwaNuxmiH4siKUz+FgpLQw
TcQExhdwMNrHLn9xiQKUL+Kgf+fnvGcCML6EQ4mMZc2ZV3JQvozD7lxb6UUX
ZaF8BYeXkXxTHA7LQPlKDhsbJF/czpKG8lUcDm5edIRZSwrKV3Pg0m6O5fwg
AeVrOPR9T/DIvSoO5Ws5sJbIatfvEIPydRzOOkdIPv0hCuXrObRXHan4MUcE
yjdwiIw/5BEVIQzlGzosXHJCtP+aEJRv5HDymsqX3zyCUL6xQ0CO1umvkgJQ
vonD53+7IpvYYXxTByYFrV/cq3mgfDOHs1IfXk0R4ILyzR02rsufohfNAeVb
OHzYfPFvrSgnlG/p0DYx26panh3Kt3KY+Li42uk7jG+Npt8GTd4WzTw7B53N
LGxmfTB5ezT1Dg4/dSbVLM+Bqm9wcJjQwrzjfizMvY4Oy3dfFzslwwqVd3Qo
Xm1tv2kRA1TeySE8ymhdkdJ/e4i8E9T/fyB8Bmc0eWcHH/P67Y/1mKH6XRxq
513eI/YQym9wQbWPwRXVvgZXVPMY3NDMd0NznzuafndU+xg8HAJ7DLVZWlmg
8h4O3Mxrq15NZoTKe6LyGzzR9HuhxlcDGp/BGzX8G7wd3lv++uekxwaV90Gz
H43P4Itmvy+avJ8DJL8yQeX90OT90cLHH2r/N2j4BaDKOwQ4GPe+/e544CdU
PRr/QACa/kC4PABO5A8I
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw2GK2N3PPRUUon8PhS33s
vWQLGF/AgZ2Ph+XcMgUoX8TBSPvlRwMxGF/CIf6ym339WzkoX8bhZeMEmzXr
ZKF8BYdlsv/4a7JloHwlh/9CTXM0fKShfBWHf6Fist03JKF8NQfubvPKtfsk
oHwNh0gliwU3wsShfC0HpU0cs476ikH5Og42Xw/e64kThfL1HPoKSldFB4tA
+QYO73KPfDX+JgzlGzpMTv0wOWa5EJRv5CAt8fjFxEkCUL6xw5KTi8u4S/ig
fBOHo5/5g6MKeaB8U4cTR23LS3ZxQPlmDhMfF1c7fWeH8s0dPmy++LdWlBPK
t3CQ9/C1FFvFCuVbOgT2GGqztLJA+VYO4VFG64qU/ttD+NYO7y1//XPSewbl
28D5AEkwbZM=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwYN76wcPhqiKUz+GQPDXd
g8UCxhdwmHM/7ob/JAUoX8RB6OnuMGteGF/CYe2pxAddN+WgfBmHfU5z2Tbv
l4XyFRyeLGM8GlotA+UrOSROCdnmoSwN5as43Jh2w17zqCSUr+YgKZ2dMT1X
AsrXcBCzUijiqRWH8rUczjpHSD79IQrl6zgE9hhqs7SKQPl6Dt6bP3oFmgtD
+QYOP7yfcjT6CEH5hg7czGurXk0WhPKNHCzP7V5w7IEAlG/ssF56zfZL3vxQ
vonD3uNW7zQe80D5pg4njtqWl+zigPLNHOQ9fC3FVrFC+eYOPub12x/rMUP5
Fg6Q8GaC8i3R5K0cildb229axADlWzsY97797njgpz2EbwN170co3xbOBwA+
d247
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwmPPS7abULUUon8MhdpFt
4Y8QGF/AwXLjYXbWowpQvoiDhXQVn7AVjC/hYKx+6Np9JXkoX8aB2/9dmO83
WShfwWGWmGZm60IZKF/JIeGS/Lb50dJQvorDq8cXfsjLSUH5ag77DRjlV/NL
QvkaDp1T3VnlL4hD+VoOe98E+/kvFoPydRzazk6XjNARhfL1HFTKGSebvReG
8g0cjgQcmN2wSwjKN3QoyVi+z18MxjdysDy3e8GxBwJQvrEDj/Ch8oKX/FC+
iYNzyB8zVjc+KN/U4ehn/uCoQh4o3wyNb+5g3Pv2u+MBTijfwmHjuvwpetEc
UL6lw3vLX/+c9NigfCsHnc0sbGZ97FC+tUNV/a+D2atg8jYOPub12x/rMUP5
tg7hUUbripT+20P4dlD7ftoDADl7cDc=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwqJy81Jb7oiKUz+Ewuee7
6DFbGF/AIcHa3Z1rrgKUL+Lg8u9Vrz4HjC/hwKUxxZrjihyUL+Mwffl1d5tZ
slC+gkPWm/ryT4EyUL6Sw/mXj95vY5GG8lUcehStD//cIwnlqzkIF3gfzKuV
gPI1HA4eXsp0LVIcytdysFLbcGNNrxiUr+NQG21vsyVEFMrXc9B9Lt3AxSIC
5Rs4sIUybv5wWAjKN3SInLV2oaiOAJRv5PCNd2fjH1MeKN/YQWczC5tZHzuU
b+LAzby26tVkRijf1IFJQesX9+o/9hC+mUN4lNG6IqX/UL65g3Hv2++OB35C
+RYO7y1//XPS+wblW6LxrdD41mh8Gyj/mT0AzPdwMA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwmH8zgoPxgiKUz+GgdWCC
6lkzGF/AgdsruvLcPAUoX8ShrsBIo48bxpdwmCAX/+n6OzkoX8ahYdO09ulX
ZKF8BQcuVjuns5kyUL6Sw8+Xf3+7PJCC8lUcjHvffnc8IAnlqzkodTuEXZ8q
AeVrOJycuibwtYY4lK/lMEthK/+z56JQvo7Ddbb267KfRKB8PYfaeZf3iD0U
hvINHHo3c2rvuy8E5Rs6uDRU/DVsF4TyjRy6jVLvzE4QgPKNHXiLjKwvN/FC
+SYOF3dc/XLjBzeUb+pwVurDqykCXFC+GdT9nFC+ucNPnUk1y3NgfAuHtonZ
VtXy7FC+pcPy3dfFTsmwQvlWDj7m9dsf6zFD+dYO4VFG64qU/ttD+DYO7y1/
/XPS+wbl20L5z+wBXU117Q==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwSAjZUatwThHK53Boqk5g
/GwE4ws4uJvWRX6YrwDlizh8eGAe1S8E40s4dMpeYn70Sw7Kl3G4Y8bDeXeX
LJSv4KDPeuGyQpcMlK/kEJu68rFdgTSUr+Kgfe4Fp5+fFJSv5uB/XTeB84cE
lK/hYPX6ccP6aeJQvpbDmceL/zpoiUH5Og4X1uztbL4mAuXrOWiqsD/57i4M
5Rs4FG9c3xlQJQjlGzrwCB8qL3jJD+UbORz9zB8cVcgD5Rs7yP87e9riAxeU
b+Jw4qhteckuDijf1OG95a9/TnpsUL6ZQ+28y3vEHjJD+eYO4VFG64qU/ttD
+BYOPub12x/rweQtHSDhzwTlWzkY97797njgJ1S9NdT8Z/YAs4xsgQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwONrL7nfkgiKUz+HAbLNX
b6sZjC/gwL7zU4vdFAUoX8TB0eXYars38lC+hEPbTkfZWdVyUL6Mw4GPRwqi
JWShfAUH0aLN8y7vkIbylRyUvaZdi1ohBeWrONz4sGDx3mJJKF/NYcbBeczt
YRJQvoZDA4dx3ecnYlC+lkPoTdbOjmpRKF/HYat92o+aHBEoX89hcuqHyTHL
haB8AwdNP2UR11xBKN/QwfLc7gXHHghA+UYOpZpTJk/aBOMbO1zj7cj46ccL
5Zs4fOPd2fjHlAfKN3WY+Li42uk7O5Rv5vDe8tc/Jz02KN/cgZt5bdWryYxQ
voUDk4LWL+7Vf+whfEuo/Ed7ALgcYoc=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQDQEf7MVCt+7emK3kABVwEOUr9PlwWxHK53B4oc3b
kG4L4ws4MDz83vlntQKUL+LA3bogdwsnjC/hULCh4MqEs3JQvoxDl0pLGk+R
LJSv4HCnY8MrMQEZKF/JYf55Hr7Jl6SgfBUHnx0OrpozJKF8NQfFkx/bLTQl
oHwNhxtTE6LWXBCD8rUcOn9dWCX5VxTK13EwiG1evneFCJSv5xDX4fbS9ogw
lG/gsL1gWaSeKIxv6CD04sCh1UGCUL6RQ3iU0boiJX4o39hhycnFZdwlfFC+
icPRz/zBUYU8UL6pwzfenY1/TGF8M4cTR23LS3ZxQPnmDlX1vw5mr2KD8i0c
Nq7Ln6IXDZO3dAjsMdRmaWWB8q2g9v+3h/CtHbiZ11a9mszoAACKHGac
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwsOe9OnXmZUUon8Nhu0Eg
s6g5jC/gwLHeNN93ngKUL+Jw32XR7aYn8lC+hEObTHWs2jw5KF/GISOE4YJ3
qSyUr+Dwm1Vbaqa8DJSv5CD/7+xpiw9SUL6Kg3Hv2++OByShfDWHD+rH5Vgz
JaB8DYceq39pzuXiUL6WA89K88A988WgfB0HZ52r55lbRaF8PQeTS73lqrtE
oHwDh+BrnT2XZIWhfEMHw13S6o9KhaB8I4emJ0m9T9YIQvnGDoqO6Z2l/wSg
fBMHXVu9kP3PeKF8U4clJxeXcZfwQflmDlHaEz3OVXBD+eYOHzZf/Fsrygnl
WzjUzru8R+whM5Rv6QAJfyYo38ohPMpoXZHSf3sI39qBm3lt1avJjFB5G2j4
/LQHAGGgaiY=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQDQEf7MVCt+7emK3kABVwOHUi2/XdSUUon8PhwL2M
hX56ML6Ag/dJId2VcxSgfBGHP/nlrDUf5aF8CQdTHhHDwFNyUL6MwzuZmx4S
BbJQvoJDh/k3AV9tGShfyeH9V78v3xSkoXwVh/+mubXthyWhfDWHgpl5/icO
SED5Gg4PtVMPceuIQ/laDl11ceJrvohC+ToOSX6aK/7xwPh6DlNV/0YyzBeG
8g0cot33c/3aIATlGzrslpoyd+d7ASjfyCFy1tqFojowvrFDlPZEj3MV3FC+
icOHzRf/1opyQvmmDvIevpZiq1ihfDMHJgWtX9yr/9gDAN/7U2g=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVwcPnZxhByWxHK53Dg2L9o
caQ3jC/gUBN7IqlluwKUL+IwP8t2p74ujC/h8KMobD6rpDyUL+Pw+FPmu11f
ZaF8BYcoJq9FjbtloHwlhxULF6c3t0pD+SoOfY8Kt8iKSkH5ag7Pnx0V+KIk
CeVrONxWzlp0XE0CytdyCJ75/3GAjDiUr+Ng9ilKw/u+KJSv5+Dx6vo+vm4R
KN/AwdX2Sc35X0JQvqFD6txlTNULBKF8I4eT11S+/OaB8Y0d/jME/k8o4Yfy
TRz81vS5pm7lhfJNHSa0MO+4H8sF5Zs5yHv4WoqtYoXyzR2YFLR+ca/+Yw/h
WzgY97797njgJ5Rv6cDNvLbq1eSP9gBkFGNP
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwMEx55Xf8rCKUz+Gw1P2o
311TGF/AoSgoT3biAgUoX8RBuPaZWycnjC/hkGLAve7RNzkoX8Yh+8uPlV8W
yUL5Cg68L0y/sxbLQPlKDn0//q+Qq5OG8lUcNiT4mG9zlYLy1Ry8PohtbEmV
hPI1HG4rZy06riYB5Ws57H0T7Oe/WAzK13Fw1rl6nrlVFMrXc/j1w3lRuY4I
lG/goKnC/uS7uzCUb+hwJODA7IZdQlC+kUPBtc+HEhVhfGOH3VJT5u58LwDl
mzhEaU/0OFfBDeWbOpw4altesosDyjdzCOwx1GZpZYHyzR2KV1vbb1rEAOVb
OHAzr616NfmjPQBUgV3g
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw+KitcX/zKUUon8Ph+eXA
p55GML6Aw+EOkXnvlypA+SIOr2SXrtRmh/ElHL789v3Bel8OypdxOFv0iSl/
qSyUr+AQ99mzLnCRDJSv5NCXJekvnigN5as4FN76I+AeLwXlqzlwaTfHcn6Q
gPI1HEqMj9mWnhWH8rUceFaaB+6ZLwbl6zisLDh7MaNPFMrXc/iZWPy3casw
lG/gAPGvEJRv6HDymsqX3zyCUL6Rw3rpNdsvefND+cYO13g7Mn768UL5Jg6z
r3H/XGbKDeWbOpw4altesosDyjdz4GZeW/VqMiOUb+7ApKD1i3v1H3sI38Lh
veWvf05636B8S6j6j1C+FZwPABfBaWg=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw8OIXPP78giKUz+Ewo+Vx
XJYljC/g4LliXezFBQpQvojDLJ2kq5P+yEP5Eg6y4V/sHp6Xg/JlHPg/dPVv
niQL5Ss4tN7W14wuk4HylRzUG5Qyw1ykoXwVh/tKLo93+UtB+WoOyyJeZpjb
S0L5Gg78X9YFvzWSgPK1HFxTH2/umSEG5es4XFxz/rNKriiUr+cgtPZq5oc6
ESjfwOFkpYtNipowlG/okDp3GVP1AkEo38ihUvP4z1R/ASjf2CE8ymhdkRI/
lG/icHHH1S83fnBD+aYOxr1vvzse4ITyzRwCewy1WVpZoHxzByYFrV/cq//Y
Q/gWDu8tf/1z0nsG5Vs6cDOvrXo1+SOUb4XGt0ZTbwPnAwD9VHIP
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwqPLJ5JK7rAjlczgsWOnh
oWwM4ws4cHtFV56bpwDlizjEpl9/kPtDHsqXcJgu/jMvd4MclC/j0KXSksZT
JAvlKzis++pRp80vA+UrOdTwsIYG7ZOC8lUcfl7OZ3cpl4Ty1Rwe/JQLbTKQ
gPI1HCJr37n2fBWD8rUc5D18LcVWiUL5Og4xHFINMyxFoHw9h6ySH9sYw4Wg
fAMHl4aKv4btglC+ocMyZa9bJocEoHwjhxynCXv5FvJB+cYO13g7Mn768UL5
Jg4fNl/8WyvKCeWbOizffV3slAwrlG/mULza2n7TIgYo39yBm3lt1avJH+0h
fAsH49633x0P/ITyLdH4Vg7vLX/9c9L7BuVbo+m3QePbovHtoPqf2QMAsfN2
aw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwiOK9zFZ6VRHK53AoVK7q
W2UE4ws48AdeuzpzsgKUL+Ig+KHyfN8FeShfwkHiQPO32GVyUL6Mw9miT0z5
S2WhfAWHg7FLFziukoHylRwOxvy/l+gnDeWrOPRZT9Fs5JKC8tUcuLSbYzk/
SED5Gg6VGwN/aFSJQ/laDgv4maT+uIpB+ToOv/nS7Q+6ikL5eg59BaWrooNF
oHwDh8j4Qx5REcJQvqGD4S5p9UelQlC+kUPq3GVM1QsEoXxjh1LNKZMnbRKA
8k0cwqOM1hUp8UP5pg5MClq/uFfzQPlmDlX1vw5mr2KD8s0daudd3iP2kBnK
t3AoXm1tv2kRA5RvCTXvvz2Eb4Umb+3w3vLXPye9b1B5Gwfj3rffHQ/8hPJt
HbiZ11a9mvzRHgC29m8N
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVwCFTPLjM8rQjlczhw1P64
t9ESxhdwuM5h94lvvgKUL+JQebbv7G9WGF/CIbVtWXbRSzkoX8aB1/CQf/0p
WShfwSGwZNqCK9tkoHwlh9azVhvmtktD+SoO0keD81m8pKB8NYesq66scwUl
oXwNh/9ZyR0nnotD+VoOS+88vHz1hxiUr+OQ31spKTxZFMrXc9i0vk1O4o4I
lG/gcC4x4uPnm8JQvqFDtPt+rl8bhKB8Iwdu5rVVryYLQvnGDsWrre03LRKA
8k0ctn2YoC91lg/KN3Uo3R1gY/EDxjdzuLjj6pcbP7ihfHMH+X9nT1t84ILy
LRw+bL74t1aUE8q3dNi4Ln+KXjQHlG/l0DYx26panh3Kt3aQ9/C1FFvFCuXb
OOhsZmEz64PJ20Ldywjl2zkY97797njgpz2Ebw+V/wjlOzi8t/z1z0nvG4Tf
gMZncITyn0HlEXwADoCRWQ==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwcA2r3153RRHK53BQYLx4
RckSxhdwOL8yVfL4egUoX8TB+b7m0wsSML6EQ/476yvPWeWhfBmHnicbpCp2
y0L5Cg5XImXky1fKQPlKDnzt9csEJklD+SoOPaIGKgV6UlC+mkN87sb5M65K
QPkaDsaTZTfWzRSH8rUckvY9+PRvixiUr+PQI35h0rdCUShfz6GvoHRVdLAI
lG/gEBl/yCMqQhjKN3Rw2/syy+GiIJRv5CC7+s+1GHMY39hhvfSa7Ze8+aF8
E4dvvDsb/5jyQPmmDsa9b787HuCE8s0c5D18LcVWsUL55g7Fq63tNy1igPIt
HN5b/vrnpPfMHgDRx12b
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwOCb5O6D5liKUz+Hwccpc
URMLGF/AoXi1tf2mRQpQvohDU7fDHQthGF/Coaxp09qer3JQvoyDloP/nNXL
ZKF8BYcSR1/5tlIZKF/Jwe76xrhN7tJQvorDuvOVgVbmUlC+msOlEzeMVmtI
QvkaDvwHgpcySUhA+VoOpzXzNsj8EYPydRze9J3bZH9JFMrXc6i+WsnLkCAC
5Rs4sIUybv5wWAjKN3SwMfJp50sQhPKNHF7fUW/RbxKA8o0dtn2YoC91lg/K
N3GI0p7oca6CG8o3dThx1La8ZBcHlG+Gxjd3aJuYbVUtzw7lWzgE9hhqs7Sy
QPmWDj7m9dsf6zFD+VYO8h6+lmKrWKF8a4fwKKN1RUr/7SF8G4f3lr/+Oel9
swcA95hnag==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw+HT6zOed5xWhfA4HjWLP
UG8bGF/A4fUKI+lPCxWgfBGHJ1sNk19Jw/gSDkfnMFY8lpGH8mUcUp53W9Sz
yEH5Cg6MB0rvpd+RgfKVHBb875/ZtVAayldx2PLj70fZxVJQvprDPMeLXX5e
klC+hsOxkokV+R4SUL6Ww/YDXO7zX4tB+ToOdTpVs/M+iEL5eg7x17fGXa4Q
gfINHLYXLIvUExWG8g0d3Pa+zHK4KAjlGzmUak6ZPGmTAJRv7PCNd2fjH1Me
KN/EgUlB6xf3ahjf1OGnzqSa5TmcUL6Zg85mFjazPnYo39xB3sPXUmwVK5Rv
4VA77/IesYfMUL4lGt/K4b3lr39Oet/sIXxrKP8ZlG8D5wMAjzZx6A==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVw+NyjrRJwQhHK53D4FPHJ
2UwPxhdwOOgVvJ93kgKUL+JgxeE52fC1PJQv4fDi4y0m/a1yUL6MQ3FlV8Ll
SlkoX8Hh+Z6d85NDZaB8JQehOD7RU2bSUL6Kw8+oLY5vWKWgfDUHoeyQW2zv
JKB8DYc112UfLF8iDuVrOezbJcTxYYoYlK/j8JR12rft00WhfD2HpuPhsb98
RKB8Awcf8/rtj/WEoXxDB8Nd0uqPSoWgfCOHhMLY36deCEL5xg66ghofZ10U
gPJNHJacXFzGXcIH5Zs6+K3pc03dygvlmzkc/cwfHFXIA+WbO2Sf2LHv8k5u
KN/CYUIL8477sVxQvqWDzmYWNrM+dijfyoGbeW3Vq8mMUL61Q3iU0boipf/2
EL4NVP6jPQCyv2vN
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw2KLqfPnPWUUon8NhaXCr
P68ZjC/gMOd+3A3/SQpQvojDDOd7EeHiML6EQ4oB97pH3+SgfBmH8Cl+R7uu
y0L5Cg6BJdMWXNkmA+UrOWxZ19wh7iQN5as43EotkUthkYLy1RxcOZj/fNko
AeVrOJSaq6VuTRWH8rUcFjXybFoSKAbl6zgs331d7JSMKJSv5xDDIdUww1IE
yjdw8DGv3/5YTxjKN3RInbuMqXqBIJRv5LBM2euWySEBKN/Y4T9D4P+EEn4o
38Qhx2nCXr6FfFC+qcNZqQ+vpghwQflmDj91JtUsz+GE8s0dAnsMtVlaWaB8
CwcmBa1f3Kv/2EP4lg7hUUbripT+Q/lWDsa9b787HvhpDwAJFGHy
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwCJM8Le5/SxHK53D4cpAh
pcIFxhdwWNQ2a3/eMgUoX8ThtIX87I0MML6Ew5LZQspNi+SgfBmHkr/iZ1ML
ZaF8BQep2aFlS+NloHwlh08xP/hdk6WhfBUHPTvXeyvSpaB8NYcFMy3V2mMk
oXwNh3C2L3fCTCWgfC2HOedVPdm6xKB8HYeJsplvZj0WhfL1HC6s2dvZfE0E
yjdweJd75KvxN2Eo39DhSMCB2Q27hKB8I4eEwtjfp14IQvnGDkIvDhxaHQTj
mzhUah7/meovAOWbOpTuDrCx+MEH5Zs5yP87e9riAxeUb+7QNjHbqlqeHcq3
cOBmXlv1ajIjlG/pEB5ltK5I6b89hG/lYNz79rvjgZ9QvrUDk4LWL+7Vf6B8
G4f3lr/+Oel9swcA2xpv5Q==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVw+H+s58PX44pQPoeDTmlW
sqA+jC/gcM0+7oPoZAUoX8SBgaX89sFz8lC+hMO1+PMhhzbLQfkyDh8Otvxl
jZSF8hUcFBXemPQYykD5Sg7qC9bc2GYnDeWrOBwPWHGpzk4Kyldz0P9vuPk1
sySUr+HA+2XOS+854lC+loNr6uPNPTPEoHwdhx7xC5O+FYpC+XoOAu2FKfcX
iUD5Bg5C3OJ7nu0RhvINHX4sYa974igE5Rs56ApqfJx1UQDKN3bY9mGCvtRZ
PijfxIFJQesX92oeKN/UYfY17p/LTLmhfDOHCS3MO+7HckH55g4fNl/8WyvK
CeVbOBj3vv3ueADGt3TQ2czCZtbHDuVbOVTV/zqYvYoNyrd2eG/565+THoxv
4wCJLyYo39ZB3sPXUmwVK5Rv58DNvLbq1WRGKN/eITzKaF2R0n97AN0eeKI=

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQDQEf7MVCt+7emK3kABVw0DD4mOJ8WhHK53B49fn7
8VoDGF/AIXhueWnDBAUoX8Sh4F8v7+s/8lC+hMM/wWwh+9NyUL6Mw47gRcz7
u2WhfAWHJ8sYj4ZWy0D5Sg7xP2ZqSeRJQ/kqDnVPVnqKqUhB+WoOFbn9FqXB
klC+hgP/l3XBb40koHwtB9YSWe36HWJQvo5DbbS9zZYQUShfz8Hj1fV9fN0i
UL6BQ2T8IY+oCGEo39CBa/GPOLejglC+kUPkrLULRXUEoHxjB781fa6pW3mh
fBMH+X9nT1t84ILyTdH4Zg5V9b8OZq9ig/LN0fgWDu8tf/1z0oPxLR0Cewy1
WVpZoHwrB27mtVWvJjNC+dZQ9d/sIXwbqPxHKN8WTd4OjW8P5T+D8h1Q9Tc4
oMk7Ohj3vv3ueOAnVN4RLg8Ar3iSZA==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7MVCt+7emK3kABVwWMPPJJ17RRHK53CIyxfQ
+WgD4ws43Hlxf6rgQgUoX8ThlezSldrsML6Ew9EVkyaGX5CD8mUcesQ+ce+Z
IwvlKziUOPrKt5XKQPlKDgHbtRTNnaWhfBUH3XbflStPS0L5ag5G/1Mk9y+Q
gPI1HAo6Zn0sLBSH8rUcZq086Px1rRiUr+Ow4vbhqXOviUL5eg5Ca69mfqgT
gfINHLIj2AOTpwtD+YYOb4QjU791CkH5Rg6afsoirrmCUL6xg+W53QuOPRCA
8k0cVjgePnpMkhfKN3WQ/3f2tMUHLijfzKGq/tfB7FVsUL65g495/fbHesxQ
voVD7bzLe8QewviWDuFRRuuKlP7bQ/hWDsa9b787HvgJ5Vuj8W0cmBS0fnGv
/mMPAG1gcAI=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQDQEf7MVCt+7emK3kABVwUBLiEPa4oAjlczjMWx06
cYEhjC/g8GiN0u+U2QpQvoiDxVkFO+e/8lC+hMOUuUG/DI7KQfkyDuf1Ao54
LpeF8hUcPGO2XGmPkoHylRx+xK1PveAhDeWrOPRZT9Fs5JKC8tUcCmbm+Z84
IAHlaziUmqulbk0Vh/K1HPbLz5aYyykG5es4WGcVzUjYIgLl6zkEM1ic2ygI
4xs4RLvv5/q1QQjKN3SYuX95eagOjG/koOiY3ln6TwDKN3bwdTt29IktjG/i
8J8h8H9CCT+Ub+qwwvHw0WOSvFC+mUP2iR37Lu/khvLNHS7uuPrlxg8Y38Lh
veWvf056bFC+pcOJo7blJbs4oHwrB53NLGxmfexQvrVD8Wpr+02LGKB8Gwdu
5rVVryYzQvm2UP5HewjfDs4HABo6c48=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQDQEf7MVCt+7emK3kABVwUEnh/JF4RhHK53DYmPVM
86UhjC/gULza2n7TIgUoX8Thee4exom8ML6EQ1DqLyuzL3JQvoyD8XzNBPmN
slC+goOhZiqj/GwZKF/JYZt1Ucp1e2koX8Vh+w+DiI/2UlC+mkPSjg2Wh25L
QPkaDq9TNjV9WiMO5Ws5JO178OnfFjEoX8dhlsJW/mfPRaF8PQeZ2xEOAhNF
oHwDh80FxZ+jKoShfEMHw13S6o9KhaB8I4emJ0m9T9YIQvnGDuFRRuuKlPih
fBMHvzV9rqlbeaF8U4cJLcw77sdyQflmDm0Ts62q5dmhfHOHwB5DbZZWFijf
wqF23uU9Yg+ZoXxLBx/z+u2P9WB8KwcmBa1f3Kv/2EP41lD7/0P5Nmh8Wwfj
3rffHQ/8hPLtHN5b/vrnpPcMyreH8wEoaHnj
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVwmF3eyvrxjCKUz+Eg0/Vq
6yEjGF/AYU5l1KOlsxWgfBGHM7zzHsqwwPgSDm/e2DRuvS4H5cs4HNI8scFi
uyyUr+Dw9VfKLM0aGShfycG1cOqbe5XSUL6Kw4QW5h33Y6WgfDUHRivtnec5
JaF8DYetks/uf7kvDuVrOayxXnLM64UYlK/joPBYdOriSFEoX88hsMdQm6VV
BMo3cCgXnc3Qv0wYyjd0mP6wh/HeRyEo38hB6MWBQ6uDBKF8Y4fXd9Rb9JsE
oHwTB+eQP2asbnxQvqnDxR1Xv9z4wQ3lm6HxzR2u8XZk/PTjhfItHOT/nT1t
8YELyrd0MO59+93xACeUb+Uw8XFxtdN3dijf2kFnMwubWR+MbwP1DwuUb+vw
3vLXPye9b/YQvh3UvJ9Qvr0Dk4LWL+7Vf6B8B6j6Z/YAppeFGw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVw4O1LDJ5wRRHK53DI+/k0
dZIRjC/gIDbRTufCfAUoX8Rh5RnmeZaf5aF8CYdoZX9l4Q45KF/GIS1moqVd
hiyUr+AgmMO2c46GDJSv5HCNoy7ZX0YayldxuPXv7Oun5yShfDWHpB0bLA/d
loDyNRwqNwb+0KgSh/K1HKzUNtxY0ysG5es4aEVbHN3nLwrl6zkIrb2a+aFO
BMo3cEg6obTLuEEYyjd0YAtl3PzhsBCUb+SQOncZU/UCQSjf2MHy3O4Fxx4I
QPkmDp//7YpsYofxTR0E34iIfRDjg/LNHLJP7Nh3eSc3lG/ucOKobXnJLg4o
38IBEt5MUL6lg3Hv2++OB37aQ/hWDu8tf/1z0ntmDwB+nmc1
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAGIQDQEf7MVCt+7emK3kABVwsHMRPrX9uiKUz+Hg9P3e
gzx7GF/Awdd0+sG3yxSgfBGH57l7GCfywvgSDrMsTxXt3yMH5cs47AhexLy/
WxbKV3D4kuvEVeAoA+UrOdTr/n/jySEN5as4rNeWs3D5IAnlqznE526cP+Oq
BJSv4ZAQGfZzerY4lK/lsDWmKiE8RwzK13HIZ/zdtspaFMrXc5iq+jeSYb4w
lG/g8EY4MvVbpxCUb+jAmyP0uqNQAMo3ctj2YYK+1Fk+KN/YwW9Nn2vqVl4o
38Rh9jXun8tMuaF8U4f3lr/+OemxQflmDpDwZILyzR2KV1vbb1rEAOVbOBj3
vv3ueOCnPQBVy13j
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwaLxsN6vtqiKUz+GwzWQ7
4xZjGF/AIdCpyeXMXAUoX8ThjuG0OS5f5KF8CQepC/1e96/KQfkyDkmmr8J/
1clC+QoOigpvTHoMZaB8JYd63f9vPDmkoXwVh83sl4794pCC8tUcXNc/aJu4
RwLK13DwOxdwZHmGOJSv5aC0iWPWUV8xKF/H4cKavZ3N10SgfD0HJ72EKUUJ
wlC+gYNLQ8Vfw3ZBKN/QYbWNUobGYX4o38hhhePho8ckeaF8Ywfj3rffHQ9w
QvkmDieO2paX7OKA8k0d3lv++uekxwblmzn4mNdvf6zHDOWbo/EtHGrnXd4j
9hDGt3SAhD8TlG8FNe+bPYRvjca3gbrnJ5Rv68DNvLbq1eSP9gBdfnaN
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEf7MVCt+7emK3kABVw2PXkdZ/KBUUon8PhmvdS
mTPGML6AA5/78jW90xSgfBGHmOscxq+ZYHwJhzvbD0W9uiUH5cs4JN96cqTx
oCyUr+DwzuHT21ebZKB8JYfY1JWP7QqkoXwVhzZ2ewU+dSkoX81hRZ1vnoe0
JJSv4XBAZDV74itxKF/Loa+svsnmnhiUr+Pgosqnc18QxtdzMLnUW666SwTK
N3BY5/4+qJxHGMo3dLAx8mnnSxCE8o0cPv/bFdnELgDlGzsc/cwfHFXIA+Wb
OGSf2LHv8k5uKN/UYeO6/Cl60RxQvpnD8t3XxU7JsEL55g4+5vXbH+sxQ/kW
DpDwZoLyLR24mddWvZr80R4ALdJggw==
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwiPitsM35hiKUz+Hwp/vj
Lx47GF/AYZ/+mZrM9QpQvojDZJkTc48yw/gSDk6XDIqeb5CD8mUcvDe1dct0
y0L5Cg4bC5++XhMpA+UrOcS+ynn0XkgayldxYL95PuU2kxSUr+aw34BRfjW/
JJSv4VA8ZV0t5wFxKF/LYQE/k9QfVzEoX8fB5uvBez1xolC+nkNM0qPHOi+E
oXwDB0O3WTu9zgpB+YYO9uFfYvykBaF8I4dtHyboS53lg/KNHS7uuPrlxg9u
KN/EoW1itlW1PDuUb+pQO+/yHrGHzFC+mUPxamv7TYsYoHxzB0j4MkH5Fmh8
SzT9Vg6BPYbaLK0sUL61A5OC1i/u1X/sIXwbh/eWv/456X2D8m3hfAArgHRP

           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAGIQDQEf7MVCt+7emK3kABVw2CIiUmF7XhHK53D4uFMi
ssAKxhdw+NSnfjB0rQKUL+LAWmMVvlocxpdwiJ2h1rv8jxyUL+PA/97c5vpj
WShfweHTJbvJocdkoHwlh7Ke0vkeM6ShfBUHa57/r2oWSEH5ag6nL1n+35ks
CeVrOHA6nXjlly0B5Ws55C5JYm/LE4fydRy4L38p/FcnBuXrOSg8Fp26OFIU
yjdwSJ/KVMJrLALlGzpoqrA/+e4uDOUbOVyyn8QiflcQyjd2eH1HvUW/SQDK
N3HgET5UXvCSH8o3dbjG25Hx048XyjdzuLjj6pcbP7ihfHOH7BM79l3eCeNb
OGxclz9FL5oDyrd0qKr/dTB7FRuUb+XAzby26tVkRijf2qF4tbX9pkUMUL6N
g3Hv2++OB37aQ/i2UPUfoXw7NL49Gt/B4b3lr39Oes/sAQwOgMo=
           "]]}, 
         {GrayLevel[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7MVCt+7emK3kABVwmD/x3sroS4pQPofD5J7v
osdsYXwBB81UgTVHVypA+SIOHx6YR/ULwfgSDs+6HEtDeeWhfBmH0G3qRywv
yUL5Cg4+tvWla1bIQPlKDraHT9scz5SG8lUcguNEuqd6SEH5ag7fhSzFFOQl
oXwNhyLJ3Otv68WhfC2H28e33LpeLAbl6zgs331d7JSMKJSv5xCT9Oixzgth
KN/AwXCXtPqjUiEo39Dhkv0kFvG7glC+kcN/hsD/CSX8UL6xw5KTi8u4S/ig
fBOHo5/5g6MKeaB8Uwdlr2nXolZwQflmDsa9b787HuCE8s0dJj4urnb6zg7l
WzhAwpsJyrd0YFLQ+sW9+o89hG/l8N7y1z8nvWf2ADQeZeA=
           
           "]]}}, {}}, {{{}, {}, 
         {Hue[0.67, 0.6, 0.6], Thickness[0.005], LineBox[CompressedData["
1:eJxd1ntUVOUaBnCUCeGoRSi3I8hAcEIgj0BCCsqDgIKaXJwRGG57BjaieEFT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           "]]}, 
         {Hue[0.9060679774997897, 0.6, 0.6], Thickness[0.005], 
          LineBox[CompressedData["
1:eJxd1XtQVHUUB/Ad00h5CMhLVgIWZVjiuQboAvGFeMp7H7C7LI8ejBpUgpLo
5HQlB0WdQhErlATBqDBIigQZ8iYBPpIJHckcG51wFMYmlkcKyiObzu+Pe3dm
Z+ez5569v/s7Z3/H/fV3VfmLJBLJ7mfv/z7/f5kiHLTtXWcKZKAv8Fy7KR43
3MkvYHohwLgvkNkah+7AU9XgRrZDeKnHHqUtsxMKZ/sUZktcyatgl5bd4/in
C9kNmuEWv9GGVWQZPnx0/r6+TEpeDdn2kcbfFM5kT5i+G5zbZb+S7IW5n10P
fH/LkewNheOJ14zlDmQfXHkysr/8lD3ZD7UdYVlVLXbkAJyZcD6xc9MKciDq
Gy/afzxkS1Ygryj76eURG/JaxHaPvoVB5pexfqCrru+uNTkIk/Pn9GVmzMH4
wVTp73zVihwi8jqkFXpf+Wclu349Gi81vGe+jcWVsPnLzsHkwBwqcpjI4bAs
VoReL7Mkv4LBjhtTN6fNyREouNjx4/VOZsDw0qH4gVIyB/ROLlcbiiwoHolM
g6KlWLac4pEojKrstqpn94vCgiR9IW8bi0dBX/NNvb0Pe55X0Rwm2+TVw+Ii
S6JhseLC9i2jLB4t2r8YWBbaPtxXROZiRPsdixL5karDbSweC5fm2SFjCKtP
HOQpHnYxb5O5OEidhkcOHWb58cL95+Lha+M1XjPI4gnYIe+fyU9l8QQcUOTf
PpbH4huE6+E2IOGrlq/XHGfPl4iU0x/F5LdTPbhE+Ib7ac7fZ/VJEtaHS4Lr
/NUr60zLKJ6MR5adu2eDqB6cyJIULHLzfmLezOIpODZkPvNFEKtvKjw2HB0y
fEm/x6WK+iFNWG+kYcbn8PtNhUvp+jT6v5H5NFF/pQvrjXRRPdKF+8Wno8v5
SG3nGNs/lbB/oBLttwpbm0Mj2k6yfBWSY/t674WzfLUwDjUuDa2eemrB6q0W
Xs+rRf2pQav09Nlriez+GlE/a4Tr4TWi/tEKDS3cIzdWlMyz9WthNDtZI42h
9fBa2I7wF5pVrD8zEM2VzgXuJSMD9/1la9+Rs/VnICJzypgiZfkZwvVIMoX9
h0zh/nKZovxMWPsESgcW2P11qMo3VRmb6LyDDpd2RIe96UnnIadDUsgHZ4f9
yLwOBTqz9Dc+YeelHtVr5vSSE2TooR6qOHjNheXrIV9tdu9xHMvXw/eBlFu2
mJ2/Bsw2LHZ/8CsZBpzb4vNYvYjOa86AU9VbbTpB5g34yWOPl0TGzvMsBDsv
bRivI+OZJwxeiXdYfha4kogppSfNAz4Lk0/6em/fYvPBiHErbY/cn+YHjHBQ
uhVb7CJzRigfDnOtR8m8EROfms8fHGPzJhtjAcrktimWn41R3dXSv0udKD8b
rgm9L1Z9TuazsbmrcnP772RJDtoiK8pmFsjIQd0SXtW/k+Ybl4Nfgh8s0/5B
5nMwrXi+PyaazcNczGft3yj/loxcVCdfD3N9SuZyYRV60+2zNTRP+VxcPj7a
VFPC5mseWu4mt1aWk93yUKHrNtYOSPEvr6Ubmw==
           "]]}, 
         {Hue[0.1421359549995791, 0.6, 0.6], Thickness[0.005], 
          LineBox[CompressedData["
1:eJxdl3lcjWkbx48GaTGydGTthGylQVSi8SvT0Yb2tJ9OnbbTNlGR8BSGeaXG
vs2QMYMiXtJYCkdkl1eRDKNDyDqyvFkmGZ+P6/rjPOfz6Y9v1/O7v/f13Pe5
z/NYKFN9VXoSiUSvw+c/CX9aJksDyiv2qweB/gHzqbGDq69ZEHdB1a2o8ONy
ZhN4rTtxqWCvjLgXdngd/HixD7MZVqnb53YaZE7cH1LjS1tv/D2AWAbXIeru
OQf7Ew/Cs6ye9vt29SMeggPZv//itLov8VDMbhlzrIdzH+Lh2HByy1dLA82I
R8IBg/XwSkpsDYP2NQYT7ZhtMK52RZbl0V7Eo3E/cYTjx6U9icfAaoC0T1xU
D+KxCNP/dVM/1+7EtjDuWZWV9rgb8Tgkufx07OttXxOPR/Xrbn4h3xsT22GX
86nqM326EtvjvfWqnJ1JBsQO+GGl2nGeuT7xBJi7TZsgLelE7IhZuydOPvCr
hHgi9GQjPxjtbpv8hSchKGTs3vRBn4idRPVvYbvi+VtnzXviyTD6qjT7yeoO
NB7wZb31vrAAkd9ZVBexxAU++WOsOi7pSHUXUX4KXkz40O5i05nqU2Bd1rGz
XQH3+51u/4KIJa6ivKuoLkf2wg8n1SVcl4v8U7Gz4ob0Qn9iQcQSN5HfTXc8
ibvueII7VjbNmufylv0euuspeODq4etvGt4ZUd0T9V2Xxb+fTusveIr2ixcy
KrwnObwjFrzQ2vVIbtt43j/TdPeTMA0hVivdaubw+NN1rxemi/bbDHR/1kva
IuXxZyB4U+k2U2sTqntjin+bXSc51eGNUU42/ice8ny9MX1PgauqnFjjjU8S
n0+K2bz/feBevLfE8mdi+GBCTUXRGS2NL4hY44OH3wyyTRnB3ydf7Bjs8ee4
KqrDF/3Mmh6tXMV5XwzY3VYfZk/Xa0R1iR+Wj1Xd3qzgvB+e3h62+Js8zovq
Gj9Mk5+pvu/EeX+8bj8anKfPeX+R3x8ZI9asXnWA8/4w3P4uQl7N8w/ANVWr
wfAjxAjAO88HXXK96PwQArDxxM6sAGtizef6b/oL7jvz+RKoe94gEGGLbEMa
HnE+EGPkm454XOZ8IA6l7Qi2MeXzKgjbfjtnWljP+SBYtxTsPVRIdSEIF/8o
L05PI9YEITiyyi1kJudn4rS3ZrNwlPMzcezs0sZ3C9kvYs1MNFV+FKzsef7B
uv0iGC42ijXpCvYHY/3d/A53XnI+WHTehsDLfuGhJhtihKAmaubL1zc5H4K4
tXqzu9rSea0JQZjyXpP1I86HwiyysrZATnWEYv6WukrpXc6H4vG6dOfSydx/
qOj+hWFFmYHV8Uaef5ho/mHYO/WFb5Yx58N0+5GE664XwtE84tXcMd6cD8f5
ud9NihnK+XAMPDLrj6UX2R+hy4jQ7U+IEPUfgb+TT//ftpXzkciea9Vcb8n9
R+qOJ0Sih1HvyoeV7I9EWdqs1yFzOK/QnZ9MIVoPhe79UChE+0uh22+RAp5l
Lz187NmnQMQy+WOn08RaBfQHdvQ/Xcv+KN31kkXp9gdRXREFP4lDzf7u1K8Q
hVHN/QTDjsRFURgdvmjnsV18v6LovDclfxQan+7MCPqZWKJEcdrlq/EFxDIl
zl9bvCTjPDGUaE9/a2lQTaxQoqibXt82V3qeEJSoS7p95FwMcZESZ/KrsjJP
EGuUsC7fHtBWQaxV0u9Nb/JHQ+j2dnHEeGJZNG596lcROpsY0Sjv87DxTSOx
IhoTjixsNLWh5x0hGtc9q0LuWhAXReNCxL5Xx+2JNdHYrrd1naUjsTYa5ttX
5A2bxs9LMZgQKN/6oxGxLAY3rs+/8J9JxIiBfLPBy51WxApRXYjBA71Dmavu
0fyKYlCc+IuZdTmxJgaFdSbLL3kQa2OwrjAlrWQJ969CvmN77JQs7l8FqaMs
3Xg+96/C8x8MSpYs4/5V6HnKYlTvrcSCCnP3+7wbns1+FVpaVQu029ivgqbX
bv2oJ+xXocD2aYc/fbj/WEidm5L2ZHL/sdDvH/PAqZD7j0V+gKFb7T7uX8RC
LEbWl/bosoHvfywMrRaFG7Tw/RexNhbfSi33fDjN/jjcrlzq+L6Z/XHw3i9z
DzzM/jiEF1pvvJPK/jjMEbqvz7rK/jiMyr0ZYfSG/XGwMIv6ePkv9sfhrPN/
De9VsT9Odz6SeOwqObrM0IKep2XxaC8ZYB/ahxjxOH9dnnzSnlgRjxOjO5jv
7kYsxEP2uKy8oZH98bgS4+YVXcz+eN1+tfH4/UD19mV17E/A/OK19qFO7E9A
7bmGsbuHsz8BxQ9tGh7NZH8CFu2p6hkQwf4EJLbllZ/OJS5KgN2H5BPH9hFr
ErBxU/b4N1uItQl4H3LQ+Vknfp9IxIXcv84YORHLEvHJcIlyizkxEpFX8sBk
tS+xIhHHJ92yr1MTC4loTJiX4zCHuOjzeB2uOA7zIdYkwm+t6/q984m1icgs
KCvKzmC/GnPGntJmhbFfjYCFDUHRzuwX1RVq6BkscvhxOPvVuNy35ckaE/ar
kXHMPHufA/vVqC7Xf1aqYL9atx9JEjwn5rj3UrI/CcVq0/ZdxexPgtMBl0c/
lbI/CedGV8zOv8x+Ub0oCTnGnQJ8j7NfdL02CT1Xbzta3Mz+ZHS02jWmSyP7
k5FtfGp7azX7k3GrLm140in2J+PF1FytXz37k3HOIWO5yf/Yn4yzU8rssg3o
/VGTjIHO7Qc9WtkvyktScMOpc6ZfG/tTkKNZYFljRnmkINq79HBrCftTUCWv
PFBTw/4UJGlXzhhaxX5RXpMCzcitte6mxNoU3HVf0Pr8E/tTEWlytVnygv2p
SM2ZoXKdxv5UmCtz/1nrRKxIxZyRvWaV+xALqbDtrRy6J5O4KBXutdKbGYvZ
n4od43zr/ylkfyqGJOYF2Cj5/ToNrt+vfXZnLrFJGjLzM7a6bSCWpcE+4Erp
+ap++BemT0qd
           "]]}}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0.},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )},
      Epilog->InsetBox[
        FormBox[
         StyleBox[
         "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False],
          TraditionalForm], 
        Scaled[{0.05, 0.95}]],
      Frame->{True, True, False, False},
      FrameLabel->{{
         FormBox["\"Number of individuals\"", TraditionalForm], None}, {
         FormBox["\"\"", TraditionalForm], None}},
      FrameTicks->{{{{0., 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {0.6931471805599453, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {Automatic, Automatic}},
      FrameTicksStyle->{
       FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
      GridLines->{None, None},
      LabelStyle->Directive[12, FontFamily -> "Helvetica"],
      Method->{},
      PlotRange->NCache[{{0, 150}, {
          Log[2], 
          Log[10000]}}, {{0, 150}, {0.6931471805599453, 9.210340371976184}}],
      PlotRangeClipping->True,
      PlotRangePadding->{{None, None}, {None, None}},
      Ticks->{Automatic, {{0., 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {9.210340371976184, 
          FormBox[
           
           TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {0.6931471805599453, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {7.600902459542082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.517193191416238, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.699514748210191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.85366542803745, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.987196820661973, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {9.104979856318357, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}}], {189., -96.24611797498106}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{{{}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 0.6931471805599453}, {5., 
           1.0986122886681098`}, {6., 1.0986122886681098`}, {7., 
           0.6931471805599453}, {8., 1.0986122886681098`}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 1.0986122886681098`}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 0.6931471805599453}, {5., 
           0.}}]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 1.0986122886681098`}, {5., 
           1.3862943611198906`}, {6., 0.6931471805599453}, {7., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 
           0.6931471805599453}, {5., 0.}, {6., 1.0986122886681098`}, {7., 
           0.6931471805599453}, {8., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 0.}, {5., 0.}, {6., 
           0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 1.0986122886681098`}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 1.6094379124341003`}, {4., 
           1.6094379124341003`}, {5., 2.0794415416798357`}, {6., 
           1.791759469228055}, {7., 1.0986122886681098`}, {8., 
           0.6931471805599453}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 0.6931471805599453}, {5., 
           0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 1.0986122886681098`}, {4., 0.}, {5., 
           0.6931471805599453}, {6., 0.}, {7., 0.}, {8., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 0.}, {5., 
           0.6931471805599453}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 
           0.6931471805599453}, {5., 0.6931471805599453}, {6., 0.}, {7., 
           0.6931471805599453}, {8., 0.}, {9., 0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 0.}, {5., 0.}, {6., 0.}, {7., 
           0.6931471805599453}, {8., 0.6931471805599453}, {9., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 1.791759469228055}, {5., 
           1.0986122886681098`}, {6., 1.0986122886681098`}, {7., 
           0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 0.}, {5., 
           0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.6931471805599453}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 0.}, {5., 0.6931471805599453}, {
           6., 0.6931471805599453}, {7., 1.0986122886681098`}, {8., 0.}, {9., 
           0.6931471805599453}, {10., 1.0986122886681098`}, {11., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 
           1.0986122886681098`}, {5., 1.3862943611198906`}, {6., 
           0.6931471805599453}, {7., 0.6931471805599453}, {8., 
           0.6931471805599453}, {9., 1.0986122886681098`}, {10., 
           1.791759469228055}, {11., 1.6094379124341003`}, {12., 
           1.6094379124341003`}, {13., 0.6931471805599453}, {14., 
           1.0986122886681098`}, {15., 1.0986122886681098`}, {16., 
           0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 0.6931471805599453}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 1.0986122886681098`}, {4., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 1.0986122886681098`}, {4., 0.}, {5., 0.}, {
           6., 1.0986122886681098`}, {7., 1.3862943611198906`}, {8., 
           1.791759469228055}, {9., 1.0986122886681098`}, {10., 
           1.3862943611198906`}, {11., 1.3862943611198906`}, {12., 
           2.0794415416798357`}, {13., 1.9459101490553132`}, {14., 
           1.3862943611198906`}, {15., 1.6094379124341003`}, {16., 
           1.0986122886681098`}, {17., 1.3862943611198906`}, {18., 
           0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 
           0.}}]}, {}, {}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 
           0.6931471805599453}, {5., 0.}}]}, {}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{2., 0.}, {3., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}, {4., 0.}, {5., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{2., 0.}, {3., 0.6931471805599453}, {4., 
           1.0986122886681098`}, {5., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 
           0.6931471805599453}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 
           0.6931471805599453}, {6., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{3., 0.}, {4., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}, {5., 0.6931471805599453}, {6., 0.}, {
           7., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.6931471805599453}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}, {5., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}, {5., 0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}, {5., 0.}, {6., 0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}, {5., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}, {5., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}, {5., 0.}, {6., 0.6931471805599453}, {
           7., 0.}, {8., 0.}, {9., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{3., 0.}, {4., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.6931471805599453}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[CompressedData["
1:eJxdlHlMHHUUx0d6YLkKFBDYVm6yi0ALCJQF5LvIfbPLsuyyHFFJ24Da0pIe
io7E1KLVcFalh7SNUksLBtO0gOhYstDDEilxrabGGhroEQUKlkI5rOn7/TEz
yWbzyXc+83vz3st4vfKmusyC47h3nvz+/396PQtOdNljImp+KT54LO4pOxE/
JHbFzvbouK4THHnrJeyJjMh3z48GryD2luS+0BlCOyq9l+l5/rBecXbfvcZn
KJej+tjIdy5/MT8Abb2/ulxZv4o4EPvry5VveVgSB0vyTVTvauIQeKRkRrmc
ZnkoJr8dXqx2XkMchsNm67mvwq2JX8Q198l7TfZWxOG4ZIrdvauH9SkCYR//
PasSmB+J8ksXvh/pZv5mmG0PbJ3LsiWOQt+g8h/5qA2xEqdU/aYBN5ZHS+6P
gW1laPRIDeNYif+S5Lw4CQOGF+pThvYQ84Bpeq3GsIP5Kur/WspVqIiv67M7
bkd5PJa53OXSXSyPh77l7HHnQHvKX0Z7jPdWeT/LJcwlwGbdxd3b77I8AdNL
PfoaS+YnwrbC8f6BHcR8IqKGelsHbrE8CVWKpsaGLpYnYUP7gtkY6UB5MhRZ
Pk6JrxPzyZC5jt6pb2B+CnIqAq7+68b8FAQ5yKdahlmeir2KwbmybJan4qPQ
spuHS1meJq6HT0Pq1x2n/Y6w90tH1plPEsvO0Xz4dATFBuf9MMbmlYHhC7/M
3HjE+p8Bj6VrVzdPsn3KxEPb7vcWwmkevIS5LFh4Bsxbt7M8S7Kf2fBJO2Q2
nKLn8dni87gc8byRg7nAhrfbKmhf+Rzx/gs5kn3LFc8buZJ55Ir7JeSi173p
aPcE659avD9QS/qtpu8B89XITBow3Y5lvkacQ4PLZt+ZxzZs3hrx/YJGsp95
6JSdOX89nZ2fJ9nnPHE9Qp5kf7RihhZeqi21VUusfi2MlidaZIlUj6CF4x3h
Yrua7Wc+Evg9iyEfECMfYxu9w95QsPrzEaebMWbJmJ8vrofTifcPOnF/eZ3E
18E+MEQ2tMzOL0Bj2WSjsc2R/AJc3psQ85r/OvIL6PtMLBSgvMAy99VPiTk9
mv0W9dwXxNBDY649eH0D8/VQ+Frenk1mvh5B4zLeaqUT+QYsnFzpNf4zMQzo
2R44q7FwJt+AL5t3OnSDWDDgR5/35Zw3MVeICPc1J6daifGEHxjk6X8yvxB8
VdyM0t+F/EJMzw+Ybv5OzBkxZaftV2x8jnwjXJSelTbVxLwRyvujfOchYsGI
B59ZLx2cIOaKMLFJmdk1w/wieKSanm885kp+Ebb11m079xuxUIQuVW3N3DIx
V4zWVYJ6cJ8b+cX4KWLcSvsHMV+MR6GrBxMT3MkvxlLhh1sU3xBzJWjOHInx
eEyMEthF3/D83E9GfgmuHLnb1lJFLJSg41ZmZ91+Yq4UtQV9xqNDMvwHEIcN
CA==
           "]]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}, {5., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}, {5., 0.}, {6., 0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}, {5., 0.6931471805599453}, {6., 0.}, {
           7., 0.6931471805599453}, {8., 0.}, {9., 0.6931471805599453}, {10., 
           0.6931471805599453}, {11., 0.6931471805599453}, {12., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}, {5., 1.0986122886681098`}, {6., 
           0.6931471805599453}, {7., 0.6931471805599453}, {8., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}}]}, {}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{3., 0.}, {4., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.}, {5., 1.0986122886681098`}, {6., 
           0.6931471805599453}, {7., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 1.0986122886681098`}}]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{3., 0.}, {4., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{3., 0.}, {4., 0.6931471805599453}, {5., 
           0.6931471805599453}, {6., 1.0986122886681098`}, {7., 
           1.0986122886681098`}, {8., 1.3862943611198906`}, {9., 
           0.6931471805599453}, {10., 0.6931471805599453}, {11., 
           0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{4., 0.}, {5., 0.6931471805599453}, {6., 
           0.6931471805599453}, {7., 1.0986122886681098`}, {8., 
           1.0986122886681098`}, {9., 1.0986122886681098`}, {10., 
           0.6931471805599453}, {11., 1.3862943611198906`}, {12., 
           1.3862943611198906`}, {13., 0.6931471805599453}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{4., 0.}, {5., 0.}}]}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{4., 0.}, {5., 0.}}]}, {}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{4., 0.}, {5., 1.0986122886681098`}, {6., 
           1.6094379124341003`}, {7., 0.6931471805599453}, {8., 
           1.3862943611198906`}, {9., 0.}, {10., 0.6931471805599453}, {11., 
           0.6931471805599453}, {12., 0.6931471805599453}, {13., 0.}, {14., 
           0.6931471805599453}, {15., 0.6931471805599453}, {16., 
           0.6931471805599453}, {17., 1.0986122886681098`}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{4., 0.}, {5., 0.6931471805599453}, {6., 0.}, {7., 
           0.}}]}, {}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{4., 0.}, {5., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{4., 0.}, {5., 0.}, {6., 0.}, {7., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{4., 0.}, {5., 0.6931471805599453}, {6., 
           0.}}]}, {}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{4., 0.}, {5., 0.}, {6., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{4., 0.}, {5., 0.6931471805599453}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{4., 0.}, {5., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{4., 0.}, {5., 0.}, {6., 0.6931471805599453}, {7., 
           0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{4., 0.}, {5., 1.0986122886681098`}, {6., 
           0.6931471805599453}, {7., 0.6931471805599453}, {8., 
           1.6094379124341003`}, {9., 1.3862943611198906`}, {10., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{5., 0.}, {6., 0.}, {7., 0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{5., 0.}, {6., 1.0986122886681098`}, {7., 
           1.0986122886681098`}, {8., 0.6931471805599453}, {9., 
           1.0986122886681098`}, {10., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{5., 0.}, {6., 0.}}]}, {}, {}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{5., 0.}, {6., 1.3862943611198906`}, {7., 
           2.1972245773362196`}, {8., 0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{5., 0.}, {6., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{5., 0.}, {6., 1.0986122886681098`}, {7., 0.}, {8., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{5., 0.}, {6., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{5., 0.}, {6., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{5., 0.}, {6., 0.}, {7., 1.0986122886681098`}, {8., 
           0.6931471805599453}, {9., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{5., 0.}, {6., 0.}, {7., 1.3862943611198906`}, {8., 
           1.3862943611198906`}, {9., 0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{5., 0.}, {6., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{5., 0.}, {6., 
           0.6931471805599453}}]}, {}, {}, {}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{5., 0.}, {6., 0.}, {7., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{5., 0.}, {6., 0.}, {7., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{5., 0.}, {6., 0.}, {7., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{5., 0.}, {6., 0.6931471805599453}, {7., 
           0.6931471805599453}, {8., 0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{5., 0.}, {6., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{5., 0.}, {6., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{5., 0.}, {6., 0.6931471805599453}, {7., 0.}, {8., 
           0.6931471805599453}, {9., 0.6931471805599453}, {10., 
           0.6931471805599453}, {11., 0.6931471805599453}, {12., 0.}, {13., 
           0.}}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{6., 0.}, {7., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{6., 0.}, {7., 0.}, {8., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{6., 0.}, {7., 0.6931471805599453}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{6., 0.}, {7., 0.}, {8., 0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{6., 0.}, {7., 1.0986122886681098`}, {8., 
           1.3862943611198906`}, {9., 1.791759469228055}, {10., 
           2.0794415416798357`}, {11., 2.1972245773362196`}, {12., 
           1.0986122886681098`}, {13., 0.6931471805599453}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{6., 0.}, {7., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{6., 0.}, {7., 0.}, {8., 0.6931471805599453}, {9., 
           1.0986122886681098`}, {10., 1.0986122886681098`}, {11., 
           0.}}]}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{6., 0.}, {7., 0.6931471805599453}, {8., 0.}, {9., 
           1.0986122886681098`}, {10., 0.6931471805599453}, {11., 
           0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{6., 0.}, {7., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{6., 0.}, {7., 0.}, {8., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{6., 0.}, {7., 1.0986122886681098`}, {8., 
           0.6931471805599453}, {9., 1.0986122886681098`}, {10., 
           0.6931471805599453}, {11., 0.6931471805599453}, {12., 
           0.6931471805599453}, {13., 1.3862943611198906`}, {14., 
           1.3862943611198906`}, {15., 1.0986122886681098`}, {16., 
           0.6931471805599453}, {17., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{6., 0.}, {7., 1.0986122886681098`}, {8., 0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{6., 0.}, {7., 0.}}]}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{6., 0.}, {7., 0.6931471805599453}, {8., 
           1.0986122886681098`}, {9., 1.3862943611198906`}, {10., 
           1.0986122886681098`}, {11., 1.3862943611198906`}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{6., 0.}, {7., 0.}, {8., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{7., 0.}, {8., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{7., 0.}, {8., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{7., 0.}, {8., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{7., 0.}, {8., 0.}, {9., 1.0986122886681098`}, {10., 
           0.6931471805599453}, {11., 0.6931471805599453}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{7., 0.}, {8., 0.}, {9., 0.6931471805599453}, {10., 
           0.}}]}, {}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{7., 0.}, {8., 0.}, {9., 0.}, {10., 0.}}]}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{7., 0.}, {8., 0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{7., 0.}, {8., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{8., 0.}, {9., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{8., 0.}, {9., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{8., 0.}, {9., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{8., 0.}, {9., 0.6931471805599453}, {10., 
           1.0986122886681098`}, {11., 1.3862943611198906`}, {12., 
           0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{8., 0.}, {9., 0.}, {10., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{8., 0.}, {9., 0.6931471805599453}, {10., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{8., 0.}, {9., 0.}, {10., 0.}, {11., 0.}, {12., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{8., 0.}, {9., 0.}, {10., 0.}, {11., 0.}, {12., 
           0.6931471805599453}, {13., 0.6931471805599453}, {14., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{8., 0.}, {9., 0.}, {10., 0.}, {11., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{9., 0.}, {10., 1.0986122886681098`}, {11., 
           1.6094379124341003`}, {12., 0.}, {13., 0.}, {14., 
           0.6931471805599453}, {15., 0.6931471805599453}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{9., 0.}, {10., 0.6931471805599453}, {11., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{9., 0.}, {10., 0.}, {11., 0.}}]}, {}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{10., 0.}, {11., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{10., 0.}, {11., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{10., 0.}, {11., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{10., 0.}, {11., 0.6931471805599453}, {12., 0.}, {13., 
           0.6931471805599453}, {14., 0.6931471805599453}, {15., 0.}, {16., 
           0.}, {17., 0.6931471805599453}, {18., 0.}, {19., 
           0.}}]}, {}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBmIQDQEaDgwoQMvhveWvf056z+whfB00vh4a38CBm3lt
1avJH6F8Q6j8NyjfCE3eGE3eBI1v6mDc+/a744GfUL4Zmrw5mnst0PiWaPZZ
oclbo/Ft0Pi2aP6zg8sDAGUjQNE=
           "]]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{12., 0.}, {13., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{13., 0.}, {14., 0.6931471805599453}, {15., 0.}, {16., 
           0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{13., 0.}, {14., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{14., 0.}, {15., 0.6931471805599453}, {16., 0.}, {17., 
           0.6931471805599453}, {18., 1.0986122886681098`}, {19., 
           0.6931471805599453}, {20., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{15., 0.}, {16., 0.6931471805599453}, {17., 0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{20., 0.}, {21., 0.}, {22., 0.6931471805599453}, {23., 
           1.0986122886681098`}, {24., 0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{26., 0.}, {27., 0.6931471805599453}, {28., 
           0.6931471805599453}, {29., 0.6931471805599453}, {30., 
           1.0986122886681098`}, {31., 0.6931471805599453}, {32., 
           1.0986122886681098`}, {33., 1.0986122886681098`}, {34., 0.}, {35., 
           0.}, {36., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{30., 0.}, {31., 0.}, {32., 0.6931471805599453}, {33., 
           1.0986122886681098`}, {34., 1.0986122886681098`}, {35., 0.}, {36., 
           1.0986122886681098`}, {37., 1.791759469228055}, {38., 
           1.9459101490553132`}, {39., 1.0986122886681098`}}]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{36., 0.}, {37., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{36., 0.}, {37., 0.}, {38., 0.}, {39., 
           1.0986122886681098`}, {40., 1.0986122886681098`}, {41., 
           1.6094379124341003`}, {42., 1.791759469228055}, {43., 
           2.0794415416798357`}, {44., 1.0986122886681098`}, {45., 
           1.0986122886681098`}, {46., 0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{37., 0.}, {38., 0.6931471805599453}, {39., 0.}, {40., 
           0.}, {41., 0.}, {42., 0.}, {43., 0.6931471805599453}, {44., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{38., 0.}, {39., 0.}, {40., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{41., 0.}, {42., 0.}, {43., 0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{45., 0.}, {46., 0.}}]}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{50., 0.}, {51., 0.}, {52., 1.3862943611198906`}, {53., 
           0.6931471805599453}, {54., 0.6931471805599453}, {55., 0.}, {56., 
           0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{52., 0.}, {53., 0.}, {54., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{53., 0.}, {54., 0.}, {55., 0.6931471805599453}, {56., 
           0.}, {57., 0.6931471805599453}, {58., 1.6094379124341003`}, {59., 
           1.0986122886681098`}, {60., 1.0986122886681098`}, {61., 
           2.302585092994046}, {62., 2.0794415416798357`}, {63., 
           2.3978952727983707`}, {64., 2.302585092994046}, {65., 
           1.0986122886681098`}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{62., 0.}, {63., 0.}, {64., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{68., 0.}, {69., 0.}, {70., 0.}, {71., 
           0.6931471805599453}}]}, {}, {}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{71., 0.}, {72., 0.}, {73., 0.6931471805599453}, {74., 
           0.6931471805599453}, {75., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{76., 0.}, {77., 0.}, {78., 0.6931471805599453}, {79., 
           0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], LineBox[{{81., 0.}, {82., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQDQYNIQ4MyOBAiMN7y1//nPS+2UMEQh24mddWvZr8
EcJ3CHVgUtD6xb36D4TfgMY/EOogFrp198ZsJqi5YQ7Fq63tNy1igPAdwhzC
o4zWFSn9h+oPczDuffvd8cBPqH40eYZwVPMd0PgN4ajqD6DJM0Sg+schAtW+
hghU9x1A4zNEQv3PCHV/JKr/GiId2iZmW1XLs0P1R0LN54Tqj3KY+Li42uk7
VN4hyqGq/tfB7FVsUP1RDvIevpZiq1ih+qMcAnsMtVlaWaD6ox1q513eI/aQ
Gao/GtV9DdGo6g+gyTPEoLk/BhoeMPtjHGZf4/65zJQbqj8GGn48UP2xDt94
dzb+MYXyHWIdBN+IiH0Q44Pqj0VVfyDW4eKOq19u/ICaxxCHpj/OYYXj4aPH
JHmh+uMcrvF2ZPz0g/IPxKHZH++w5OTiMu4SqH0O8Q6rbZQyNA7zQ/XHO/xn
CPyfUALlH4h3CMjROv1VUgCqP8GhVHPK5EmbBBwAMMjKUg==
           "]]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{84., 0.}, {85., 0.6931471805599453}, {86., 
           1.3862943611198906`}, {87., 0.}, {88., 0.}, {89., 
           1.0986122886681098`}, {90., 1.3862943611198906`}, {91., 
           1.0986122886681098`}, {92., 1.6094379124341003`}, {93., 0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{87., 0.}, {88., 0.6931471805599453}, {89., 
           0.6931471805599453}, {90., 0.}, {91., 0.}, {92., 
           0.6931471805599453}, {93., 0.}, {94., 0.6931471805599453}, {95., 
           0.}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{92., 0.}, {93., 0.}, {94., 0.6931471805599453}}]}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{108., 0.}, {109., 0.}}]}, {}, 
         {GrayLevel[0], Thickness[0.002], 
          LineBox[{{115., 0.}, {116., 0.}}]}}, {}}, {{{}, {}, 
         {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[0.005], Dashing[
          Medium], LineBox[CompressedData["
1:eJxd0mtIU3EYx/GTtzIts8vUFphCYSlChja18jcrsjB0Zzd3l8gXuagw0XLG
TmH5Il1NX5klQeDK0rCw5iX9p92j3lgaGJktsjeWZXgZohl7Bq0Dh8Pn8P8+
PBxOzMFjfIEfx3G7F+6/T8+VA+7fS8jBj1T3XGbi1wzPi1xfw+tJj4X/zHKx
tXpsSspmqJfBb/1md8itWeplUGuTWopi56mXQaRs62w1+3n2YDLIqrbEB5wL
oL14ODoHRS/XBXoMHuft5jRL9GKPBR521wlL5hSZ8cjeZn3gSvSnXu5ryBGd
dSBV1ETzBDntH0S9HKcb+rtEI95e4XseCt99BAXKrO5H5iZvr0DCvYCgFBvt
wynpewRTr8RMQk254whZUOJShb9z2LCUeiXqB0JmGpNDqFfR9wulXoXoudev
JON0XlDB/NzZ3d9O55nKdz6n9p0HNR4+S/se56J5gho3pH1PnkYto14NcaTr
m71mBfV5eFswGRzXHk59HgqLp+8vUq+kPm9hXuXwtJXM8vA4l9ULHWROg9qC
8Vq9gwwN6nocpcoEb6/xnc80+FyfkjxU6+21uCq8KwtrWUW9FmWn4kcHNqym
Xkv/C5lpweIzx24XkTkdJIUZSdURa6jXoc7WUNhbQhZ06MuaaIjpIjMdUm7y
hv0WEfV62EqsZ7d/JEOP3qqL4ddjI6jXo+1yo9QWRmZ6aGIl196ryJwBQ/Pi
Tl0xGQZUzH/gg4IjqTcg5sXPSskmMjPgk9vJNVvJnBF7lvjP/m4lw4ieL3d6
RpKjqDdi3/JdTt5OZkakd3DNO+bInAnDhy3lkpNrqTehPDRQyXeTBRPso8cP
nRkhMxNKf0mz5eli6vOxc7DVeHcveX0+rmw8OvHmghh/AGdYKXA=
           "]]}, 
         {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[0.005], 
          LineBox[CompressedData["
1:eJxdlHtMlXUYx9/wQnITEAg4GnfGIUCBADlAfCHucIBzDpdzDofLKqYOKkWZ
aDHfWFMpa1yt8BLqChOFRnMKRL3JDngJFrLImi0bDkSXgJAIcsnm8/vjfd/t
7Oyz7/t5f8/7PM9etzfeVRebcBx34Nnv///n14vgRJc1JsMXlmMDxqKfsx3x
Y2JH7G6NiO44zZG3UcKuSAs7cGk0YBWxuyT3RK4+qK3MfYWe5w3zVRf2369/
gXIfVJ4c/t7hb+b7oqX7N4frG9cQ++FgbYniPRdT4gBJvoXqXUscCJckZbjD
OZYHYeq7oaVK+3XEwTg2Yj7/dYg58asYcJ6632BtRhyCq8aovXu6WJ9CEfzJ
P3MxAvPDUHL18g/DnczfihHLw9vn0y2Jw9HTr3joM2pBrMDZmF5jnxPLIyT3
R8KyLChiuIpxlMR/TXJetIQB/Su1SYMVxDxgnFmv0e9ifgz1fz3lMSiNremx
OmVFeSxWONVK0R6Wx0LXdOGUvZ815a+jNdJ9u08vyyXMxcFiw5W9OydYHoeZ
5S5dlSnz42FZavvg8C5iPh7hg93NfXdYnoByeUN9XQfLE7CpdXHEEGZDeSLk
6R528W8T84mQOY7eq61jfhIyS31v/OvE/CT42/hMNw2xPBn75P3zxRksT8bH
QcW3jxWxPEVcD5+C5G/aznkdZ++XivTzn8YXX6T58KnwjwrI+nGMzSsNQ5d/
nb31hPU/DS7LAze2TrF9UuKxZecHiyE0D17CXDpMXH0XzFtZni7Zzwx4pBwd
0Z+l5/EZ4vO4TPG8kYl5v7r3W0ppX/lM8f4LmZJ9U4nnDZVkHipxvwQVup0b
TnROsv6pxfsDtaTfavoeMF8NZUKf8W4U8zXiHBpcG/GcfWrB5q0R3y9oJPuZ
hXbZ+Us3U9n5WZJ9zhLXI2RJ9idbzMiGW8y26vJlVn82DKanm2TxVI+QDdt7
wpVWNdvPHMTxFUuBh4iRg7HN7sHvyFn9OYjOnTWky5ifI66HyxXvH3LF/eVz
JX4urP0CZYMr7Hwt6oun6g0ttuRrcW1fXORb3hvI19L3mVjQokRrqnrzM2JO
h0avJR33JTF00IxUH7m5ifk6yD1N784lMl8H/3EZb7bajnw9Fs+sdhv/hRh6
dO30m9OY2JOvx1eNu206QSzo8ZPHhz6cOzGXh1DndWemm4nxjB/pfVL/Yn4e
+PLoWYW3A/l5mFnoM97+g5gzYNoqu1e++SXyDXBQuJZZVBLzBigejPLtR4kF
Ax59br58ZJKYy8fkFoWyY5b5+ZjQDlQ8rHAkPx8uycaX608SC/nY0V2z4+Lv
xFwBOmKqq+ZXiFGA5jWCun+/E/kF+Dl03Cz7T2KhAE+C1vbHxzmTX4jlvI+2
yb8lRiEalcORLk+J+UJYRdxy/cJLRn4hrh+faGkqJ+aK0HZH2V5zkNi1CNXa
HsOJQRn+A5eEEg0=
           "]]}}, {}}, {{{}, {}, 
         {GrayLevel[0.5], Thickness[0.005], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBWIQDQEf7MVCt+7emK3kABVwYJW6nDrtvCKUz+Hgl3/J
UV0NxhdwuDkp8nn4ZAUoX8Qh4/BDxgs/5aF8CYdLBxPebT0tB+XLOBwz9ZSY
M1MWyldw+FeeccwiQAbKV3IoiDx69YCaNJSv4vDfNLe2/bAklK/m8ODXDoa1
9RJQvoZDsCEHw81gcShfy+Hr9tad326JQvk6DpvWt8lJ3BGB8vUc4jrcXtoe
EYbyDRx+LGGve+IoBOUbOhRvXN8ZUCUI5Rs5BORonf4qKQDlGzuU7g6wsfjB
B+WbOOw9bvVO4zEPlG/qoOw17VrUCi4o38yhbWK2VbU8O5Rv7rB893WxUzKs
UL6Fw3vLX/+c9NigfEsH49633x0P/LSH8K2g8t+gfGsHbua1Va8mf4TybaDy
z6B8W6g5DAwA6nx01A==
           "]]}}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0.},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )},
      Epilog->InsetBox[
        FormBox[
         StyleBox[
         "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False],
          TraditionalForm], 
        Scaled[{0.05, 0.95}]],
      Frame->{True, True, False, False},
      FrameLabel->{{
         FormBox["\"Number of copies of allele\"", TraditionalForm], None}, {
         FormBox["\"Generation\"", TraditionalForm], None}},
      FrameTicks->{{{{0., 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {0.6931471805599453, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
           FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {7.600902459542082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.006367567650246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.294049640102028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.517193191416238, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.699514748210191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.85366542803745, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {8.987196820661973, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {9.104979856318357, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {Automatic, Automatic}},
      GridLines->{None, None},
      LabelStyle->Directive[12, FontFamily -> "Helvetica"],
      Method->{},
      PlotRange->{{0, 150}, {0., 9.210340371976184}},
      PlotRangeClipping->True,
      PlotRangePadding->{{None, None}, {None, None}},
      Ticks->{Automatic, {{0., 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {9.210340371976184, 
          FormBox[
           
           TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {0.6931471805599453, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {7.600902459542082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.517193191416238, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.699514748210191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.85366542803745, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.987196820661973, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {9.104979856318357, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}}], {189., -288.73835392494317`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->350,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.784900613460032*^9, 3.7849032459639072`*^9, 
  3.784903284338608*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Background", "Section",
 CellChangeTimes->{{3.76918614942978*^9, 3.7691861856925087`*^9}, {
  3.769187638171055*^9, 3.769187644664855*^9}, {3.782252363714937*^9, 
  3.782252365280772*^9}}],

Cell[CellGroupData[{

Cell["\<\
Distribution of mutant growth rates (equation 1)\
\>", "Subsection",
 CellChangeTimes->{{3.74387931839839*^9, 3.743879344105228*^9}, {
  3.769186239593058*^9, 3.769186241502941*^9}, {3.769187605543889*^9, 
  3.769187606951878*^9}, {3.7691877738304443`*^9, 3.769187777476553*^9}}],

Cell[TextData[{
 "In FGM, the PDF of selective effects of new mutations, s = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "-", 
    SubscriptBox["m", "wt"]}], TraditionalForm]]],
 ", is (Martin & Lenormand 2015 Evolution)"
}], "Text",
 CellChangeTimes->{{3.718636900491642*^9, 3.71863692472266*^9}, {
  3.730645683429695*^9, 3.730645691116152*^9}, {3.730739477507032*^9, 
  3.7307394807310123`*^9}, {3.730740006821928*^9, 3.730740039705467*^9}, {
  3.730740215156357*^9, 3.7307402152787123`*^9}, {3.751032207954659*^9, 
  3.7510322081364317`*^9}, {3.769188903228819*^9, 3.7691889049497843`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fs", "[", 
    RowBox[{"s_", ",", "so_", ",", "\[Lambda]_", ",", "n_"}], "]"}], ":=", 
   RowBox[{
    FractionBox["2", "\[Lambda]"], 
    RowBox[{"PDF", "[", 
     RowBox[{
      RowBox[{"NoncentralChiSquareDistribution", "[", 
       RowBox[{"n", ",", 
        FractionBox[
         RowBox[{"2", "so", " "}], "\[Lambda]"]}], "]"}], ",", 
      RowBox[{
       FractionBox["2", "\[Lambda]"], 
       RowBox[{"(", 
        RowBox[{"so", "-", "s"}], ")"}]}]}], "]"}], 
    RowBox[{"HeavisideTheta", "[", 
     RowBox[{"so", "-", "s"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.730742643008808*^9, 3.7307426435174417`*^9}, {
  3.730742676273735*^9, 3.730742676472419*^9}}],

Cell[TextData[{
 "where so = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["m", "max"], "-", 
    SubscriptBox["m", "wt"]}], TraditionalForm]]],
 " is the selection coefficient of the optimum phenotype, \[Lambda] is the \
mutational variance per trait, and n is the number of traits under \
selection."
}], "Text",
 CellChangeTimes->{{3.7307394739003077`*^9, 3.7307394840669413`*^9}, {
   3.7307395177563477`*^9, 3.730739638511516*^9}, {3.7307399351486263`*^9, 
   3.730739995318924*^9}, {3.730740048276404*^9, 3.730740104553334*^9}, 
   3.7712743201658573`*^9}],

Cell["\<\
We can translate this into the PDF of mutant growth rates (see also Anciaux \
et al 2018 Genetics)\
\>", "Text",
 CellChangeTimes->{{3.7307402027081757`*^9, 3.730740222644784*^9}, {
  3.731852235162519*^9, 3.731852243729341*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fm", "[", 
   RowBox[{"m_", ",", "mwt_", ",", "mmax_", ",", "\[Lambda]_", ",", "n_"}], 
   "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"fs", "[", 
       RowBox[{"s", ",", "so", ",", "\[Lambda]", ",", "n"}], "]"}], "/.", 
      RowBox[{"s", "\[Rule]", 
       RowBox[{"m", "-", "mwt"}]}]}], "/.", 
     RowBox[{"so", "\[Rule]", 
      RowBox[{"mmax", "-", "mwt"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mmax", ">", "m"}], ",", 
      RowBox[{"\[Lambda]", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.730739781684441*^9, 3.7307398143847857`*^9}, {
  3.730740229511654*^9, 3.730740273458096*^9}, {3.730740728295762*^9, 
  3.730740757991959*^9}, {3.730740799897637*^9, 3.730740816251461*^9}, {
  3.730740854915372*^9, 3.730740905478938*^9}, {3.7307496573820133`*^9, 
  3.7307496651915693`*^9}, {3.74389014757091*^9, 3.743890180651417*^9}}],

Cell["Simulate some mutants", "Text",
 CellChangeTimes->{{3.7342018401132097`*^9, 3.73420184330306*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "4"}], ";", 
   RowBox[{"\[Eta]", "=", 
    RowBox[{"n", "/", "2"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"phenotypic", " ", "dimensions"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Es", "=", "0.01"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"mean", " ", "mutational", " ", "selective", " ", "efffect"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Lambda]", "=", 
    RowBox[{"2", 
     RowBox[{"Es", "/", "n"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"mutational", " ", "variance"}], ",", " ", 
    RowBox[{"i", ".", "e", "."}], ",", " ", 
    RowBox[{"scaled", " ", "size"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"uo", "=", 
    RowBox[{"0", " ", 
     RowBox[{"UnitVector", "[", 
      RowBox[{"n", ",", "1"}], "]"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"mean", " ", "mutational", " ", "size"}], ";", " ", 
    RowBox[{"set", " ", "to", " ", "all", " ", "zeros"}]}], "*)"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Idn", "=", 
    RowBox[{"IdentityMatrix", "[", "n", "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "matrix", " ", "to", " ", "make", " ", "variance", " ", 
    "multidimensional"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NT", "=", 
    SuperscriptBox["10", "5"]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"number", " ", "of", " ", "mutants", " ", "to", " ", "create"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dz", "=", 
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"MultinormalDistribution", "[", 
       RowBox[{"uo", ",", 
        RowBox[{"\[Lambda]", " ", "Idn"}]}], "]"}], ",", "NT"}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "\[Lambda]", ",", "n", ",", "Es", ",", "\[Eta]", ",", "uo", ",", "Idn", ",",
    "NT"}], "]"}]}], "Input",
 CellChangeTimes->{{3.6890504744928102`*^9, 3.689050594208517*^9}, {
   3.689050893421949*^9, 3.689050898479011*^9}, 3.6890509581836147`*^9, 
   3.689058403503973*^9, 3.718654723373852*^9, {3.718654861971764*^9, 
   3.718654865994913*^9}, {3.718655832970689*^9, 3.718655833081356*^9}, {
   3.7186567107455473`*^9, 3.718656711017383*^9}, {3.721499598371749*^9, 
   3.721499600554109*^9}, {3.730656045398467*^9, 3.7306560658278627`*^9}, {
   3.730656161103064*^9, 3.7306561650184402`*^9}, {3.730741347838533*^9, 
   3.730741355156685*^9}, {3.734201861483506*^9, 3.734201882595647*^9}, {
   3.7342019218234787`*^9, 3.734201941662801*^9}, {3.734875448532668*^9, 
   3.7348754505294228`*^9}, {3.736600980326185*^9, 3.736600980439589*^9}, {
   3.7438796533604097`*^9, 3.7438796658237123`*^9}}],

Cell["\<\
Calculate selection coefficient given mutant vectors dz and vector to optimum \
zopt\
\>", "Text",
 CellChangeTimes->{{3.6890512677997637`*^9, 3.689051341569028*^9}, 
   3.689080011049065*^9, {3.734201897044272*^9, 3.7342019044349537`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ss", "[", 
    RowBox[{"dz_", ",", "zopt_"}], "]"}], ":=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"dz", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ".", "zopt"}], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"dz", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ".", 
        RowBox[{"dz", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], "2"]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "dz", "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell["Check distributions with simulated mutants:", "Text",
 CellChangeTimes->{{3.730750095013009*^9, 3.7307501082292747`*^9}, {
  3.73420190976648*^9, 3.734201912275161*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "4"}], ";", 
   RowBox[{"\[Eta]", "=", 
    RowBox[{"n", "/", "2"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"phenotypic", " ", "dimensions"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Es", "=", "0.01"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"mean", " ", "mutational", " ", "selective", " ", "efffect"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Lambda]", "=", 
    RowBox[{"2", 
     RowBox[{"Es", "/", "n"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"mutational", " ", "variance", " ", "per", " ", "trait"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mmax", "=", "0.5"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"max", " ", "growth", " ", "rate"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwts", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.3"}], ",", 
      RowBox[{"-", "0.2"}], ",", 
      RowBox[{"-", "0.1"}]}], "}"}]}], ";", 
   RowBox[{"nmwts", "=", 
    RowBox[{"Length", "[", "mwts", "]"}]}], ";"}], 
  RowBox[{"(*", "scaled", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"zis", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{"2", 
         RowBox[{"(", 
          RowBox[{"mmax", "-", 
           RowBox[{"mwts", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], ")"}]}]], 
       RowBox[{"UnitVector", "[", 
        RowBox[{"n", ",", "1"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "nmwts"}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "vector", " ", "from", " ", "wildtype", " ", "from", " ", "the", " ", 
    "optimum", " ", "along", " ", "trait", " ", "1", " ", "axis"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"color", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Darker", "[", 
       RowBox[{"Blue", ",", "0.7"}], "]"}], ",", 
      RowBox[{"Lighter", "[", "Orange", "]"}], ",", "Red"}], "}"}]}], ";"}], 
  RowBox[{"(*", "colors", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"styl", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"styles", " ", "of", " ", "axes", " ", "and", " ", "legend"}], 
   "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"legends", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"StringForm", "[", 
       RowBox[{"\"\<\!\(\*SubscriptBox[
StyleBox[\"m\",
FontSlant->\"Italic\"], \"wt\"]\) = ``\>\"", ",", 
        RowBox[{"NumberForm", "[", 
         RowBox[{
          RowBox[{"mwts", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", "3"}], "]"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "nmwts"}], "}"}]}], "]"}]}], ";", " ", 
   RowBox[{"simuls", "=", 
    RowBox[{"Histogram", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"mwts", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "+", 
         RowBox[{"ss", "[", 
          RowBox[{"dz", ",", 
           RowBox[{"zis", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "nmwts"}], "}"}]}], "]"}], ",", "500", ",", 
      "\"\<PDF\>\"", ",", 
      RowBox[{"ChartStyle", "\[Rule]", "color"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2"}], ",", "0.5"}], "}"}], ",", "All"}], "}"}]}], 
      ",", 
      RowBox[{"Axes", "\[Rule]", "False"}], ",", 
      RowBox[{"ChartLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{"legends", ",", 
         RowBox[{"{", 
          RowBox[{"0.2", ",", "0.8"}], "}"}]}], "]"}]}]}], "]"}]}], ";"}], 
  " ", 
  RowBox[{"(*", 
   RowBox[{"simulation", " ", "results"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m", ",", 
      RowBox[{"mwts", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", "mmax", ",", "\[Lambda]", ",", 
      "n"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "nmwts"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "1"}], ",", "0.5"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.7"}], ",", "0.2"}], "}"}], ",", "All"}], "}"}]}], 
      ",", 
      RowBox[{"PlotStyle", "\[Rule]", "color"}], ",", 
      RowBox[{"Frame", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
      ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", "\"\<\!\(\*
StyleBox[\"m\",
FontSlant->\"Italic\"]\)\>\"", "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"theory", ",", "simuls", ",", "theory"}], "}"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", "styl"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{",", "\"\<\!\(\*
StyleBox[\"f\",
FontSlant->\"Italic\"]\)(\!\(\*
StyleBox[\"m\",
FontSlant->\"Italic\"]\)\!\(\*
StyleBox[\" \",
FontSlant->\"Italic\"]\)| \!\(\*
StyleBox[SubscriptBox[\"m\", \"wt\"],
FontSlant->\"Italic\"]\))\>\""}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{
      RowBox[{"imagedir", "<>", "\"\<fmmwt.pdf\>\""}], ",", "%"}], "]"}], 
    ";"}], "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "\[Lambda]", ",", "n", ",", "\[Eta]", ",", "Es", ",", "mmax", ",", "mwts", 
   ",", "nmwts", ",", "zis", ",", "color", ",", "styl", ",", "legends", ",", 
   "simuls", ",", "theory"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.7307420178763027`*^9, {3.7307420919548197`*^9, 3.730742140080029*^9}, {
   3.7307422008167887`*^9, 3.730742486553404*^9}, {3.73074254252099*^9, 
   3.730742542642627*^9}, {3.730742794163145*^9, 3.730742934535372*^9}, {
   3.730743298153899*^9, 3.7307433631678457`*^9}, {3.730743401341844*^9, 
   3.730743417078063*^9}, {3.730748966693226*^9, 3.730749128539439*^9}, {
   3.73074920743021*^9, 3.730749247197057*^9}, {3.730749283260601*^9, 
   3.730749287719013*^9}, {3.730749324608781*^9, 3.730749557532645*^9}, {
   3.730749607062332*^9, 3.7307496118140507`*^9}, {3.730749696305119*^9, 
   3.7307497855057497`*^9}, {3.730749823597776*^9, 3.730749827582512*^9}, {
   3.730749898218234*^9, 3.73074989873744*^9}, {3.7307499646600657`*^9, 
   3.7307499884070253`*^9}, {3.730750031912035*^9, 3.730750078969554*^9}, {
   3.730750119330454*^9, 3.7307502945406437`*^9}, {3.7307503559230337`*^9, 
   3.730750356528187*^9}, {3.730750450656543*^9, 3.730750451401882*^9}, {
   3.7348754601204*^9, 3.734875488510385*^9}, {3.7348755208819923`*^9, 
   3.734875523114094*^9}, {3.734875560133151*^9, 3.734875561427981*^9}, {
   3.7348756385256166`*^9, 3.734875647924037*^9}, {3.7348757389675903`*^9, 
   3.7348758575465384`*^9}, {3.734875889176434*^9, 3.73487591157351*^9}, {
   3.734875949280768*^9, 3.734875950101717*^9}, {3.734876035305752*^9, 
   3.734876047580271*^9}, {3.7348761009733877`*^9, 3.734876101605463*^9}, 
   3.736600970204051*^9, {3.7438795693147993`*^9, 3.743879611828753*^9}}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      {RGBColor[0., 0., 0.30000000000000004`], LineBox[CompressedData["
1:eJwUV3c8lu8XRmbmq2ghO4TICPXe57VSqAgNfZWMkmQliYzsrCQkhJKZvfdt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        "]]}, 
      {RGBColor[1, 0.6666666666666666, 
        NCache[
         Rational[1, 3], 0.3333333333333333]], LineBox[CompressedData["
1:eJwUV3c8lu8XtimEV4QiI6OsSFa9z/0qlFERlZCvJArZq5SMzJDICAlZZWRv
jr333nvvpOz8/P56Pudz388517me65znHC4Di7tPSYiIiMjJiYj+/3zyM3Dt
8HANkoviXG426+NP7rHxXdlfA5HwjrvnVB7jqxUTdO2310DrTfxcVstjPN9o
YcPy+hpUhFcK3B81wC/STH0bmDg6Fx9Un7z4FB+p9WLw5OgapIXgn71uf4pX
jd+iVxtcg8wJgmKRrRE+7QqNc23nGtyK48390WSMtzS5rJVdtQYvZyfcHuSb
4LnyIGAV1uDOdN8XEhdTfCexcs35kjVo7jCfdb5thpf4rCcek7MGBomWOaEH
L/BbdV40/glr8HpMlPCl2xKfzIi7Xh+7BiP5KoI/71rhtf6LekkavQan6ziJ
jLqt8EV/M2Zfhq4B1UetBOEpa7wz72C5kdcaSGJjRZiYHV7UynAr1n0NrNo4
x/3a7PDjJavCI2/XgIY6hd3U2h5/TZM0UsNxDez+BFc8qnXAk7sL2RGeH/GB
v+ay++MVPq81L8Xp6RoMuegwxVk54Y3Y5CbzHq+B/Wv8tUP8a3x95r07wtpr
YBQdZOg6/wbvN+58nk3liB9jjVsl1S54vNAx/Xs31oBkI/u9qpwrftUhODTw
+hq0mE+Hm1e44tXokkkpr64B2eK+VHuzG54R6xj5LbQG2YYJP6kZPfDVPjon
Rc+vAUuNSSP/Tw+8bc+MsgnvGugPZtYV3vHE95rt5o+zr8GbwgbmimgvfEQk
T1DLiTVgX0xXOOPoi/9x8XNs/vE1YLr97pmG6nt8Uc2JzFiKI/40F/9j4/fD
D67ttNn9W4X2vaa7fL/88YvvLMb+212F6hQPh97xAPwu68yq0t9V+MNDOrTc
9wHPJt9Oy7G6Cu9IWc0jVgPxFwYU2KkWV8GMR9x/ze4jXta8WGhjZhVE6l69
tCQOwmuHJ6rUjqxClvO9D468wfjI5dc+5i2rIOhDkfgiIQSf6roRrtWwCv+l
/KqYVQ/FlzA/S75WswqIXf1WKmkYfpigUcdcugopVy00Kx3C8cs99b1Ehavw
RW69+JnsZ/y+CTa7mLMKgzkCbyhJI/BnQs6TQ+oqGBSmas8nRuKFLnw9+T15
FTgn5Nneu0Xhr8LJc8HxqxBAK/phzvALXnfh8Jpx1CrMfeM88xX7io/C97rQ
+R3h+1mieCIxFp/aqRK447UKitVCt5rE4vAlxhVfp9xXYcU2jqO5Ig4//DG1
LN9pFdpOOHmzr33DL/Nxt8Y6rMILeNuY5ReP3y8OG3lvswpUyYEyTKIJePZZ
t/3/TFeBT43YtNctES/itE2tbHzEf+DBfTeJJDxGb35a4skqTN+o7QpZSsLr
yT6UpdJZhTf+1zIjTL7jowNEHTOUV0FLMPdwMyMVn86T4BWhuArd7vHP0oPS
8GUFbGHvrq3C8acdOcgpHT86SZ6nJbsK6Yy9dqMXM47051RzTXIV0l7wnabO
yMD/o/nVLSR+5G/xCzvDpUw8h9Twb6ILq+Cp75dyViELL9KsTrrEuwpTsd3R
T7uz8NjjOlwP1yoc/B1qOjTOxuu9zxL7zroKCSdimnOjcvBfx7wt1I+tgmpU
OzEpIR+vT03V5kK+CqOMbMd9FvLx3FJeIhnEq6BD3Hq2M6wAnxjgsXJidwWW
vsg8vExahE/Hu5k2L67A71x+cSHWUrzlc+KmvdkVUO5eKs9YLsWLh7hcEJxa
AYuMLmeu2jJ87rLzgs/QCliRLh3kK5TjSyKdjG80r8Cm7JXS2+KVeOe63Vr7
+hWQ/u1LEMqrxBN+v+RLrF6B0UaVzXx8Fb5a2XGGrHQFvP9TJFzTqsY37dg+
qUxbgYPIRSLeslq8H+9m5a/vKxBxOX/fyqAOf1vdhpsrcQXMpnzY1anr8Z3J
VhNvo1fgonTMiqJpA37wgfl/+A8rELfkp91o3IyPcl8pM3u/AmTMqdq6Ei14
vZ9mHFFeK/CnIMQvgqIVP0lhOrL7dgUyKl9KFZe04RdyjXUKLFfAmJ3b8GRR
B/7HxGzRnNkKFNTzXdaS6cSb0RqxnXq+Ai3S0684Szrx64aGA3aPV+Dq0gRD
bHMXfpvx8YNLd1cgpo5hUvZML74IjecZ3D7i49Mne/uiXvxr0/+Yg5RX4MfK
5XnaR314oqpHPevXVmC7OAff+LMfT2mtrZF+aQUimXMY9wOG8PVfBrJGRFdA
LzIm6pPGMN63QQtHK7QCPWk/V4LYR/AnuB50mJ5bAfe0fvkHlaN45naNO+eZ
ViBvOkLox/kJPGsrf58pwwossCjR34ydwJ9p3tNLp10B0jPxkqfPTOK56r+Z
X6JYgfKEV4EFp6fwQuW//fFbyzAyeTz1rsIMXrSsjsnl9zLoR7zjYBuYwYuX
RH6pXFuGsbmfHd2Ws3ipgutpN+aXQcrqFN2H1Dn8tYzgZvWBZQizt94W1FrE
K6Qba37qWYZnBhKbX04s4W+mXhnu7ViG+SMtLzcs4W8lTy3pNC5DhdIp8tg7
K3itmEvURsXLMKEu//DzrXW8TjRlcHL+MqzTrJieK1vH60UNsS1lLwMt05WX
qWK/8Ibh7hcsU5fhwXDFL1LuDbxFYJfSqy9H8ckft3Be2MRbByR1lHxeBsad
nYrxnE28rZ/Tw8OQZSg7bRyjev0P/pU3z/N3AcsQV6Ac5Gv6F+/pYuMd8HYZ
zqgO2dsub+N9nG/Qdzgtw2VMosIwbAfv9/p0OKPjMuyIyJ/oU9zFf3SsSgq3
XIYckQHeouw9fJQlY13c42XYjiST+1X/D//VfO72zKNlOPFG3udJ5CE+zqy4
l1/7CI+BZHe6DBGW9OzJbOrdZaA4DL2HsRFjWfrZ5PnXlyGa1Xmq/ZAEy9Xz
8t9BR/E8bdXlXUmxAl0dpqtXj/D5vk04TUGGlWqR8lZILMOPvN8rd9jIsXo1
Dfkm3mUwNOtfMrSgxC6E4xJKuJbh6pVKVakzVJjfWAd5Ovsy1Na8f7vWQoWp
mavVBTItg0vL2u4XwnGs//0t5fvky4ALv/2BxJgWk+2iSblBfPQ9IjodaNAJ
LIqtmVrmYAkwOZdSUXY6TP+7csvpP0tw9YKyobQ9PTZfe0NtYnoJXMQXYOMF
DlM+QZnZOb4EnekSISObOCz1Xi1D9fASPJTXKwl+y4hZTst3JXYvAfG1cdrW
mJPYNvG1+2bVS6BdObcUznQK01Yizn9UvgQ0Z7QztkpPYSWB5afulCyB/WrP
LK0pC+ZyFg2I5SwBb9TXF7NdrBgV/qru1rcl+GFqU8UzfQYzebdXMv91CeqE
AmhO5rFjzU1F7IORSzCKM98d8+fAArVlxkqCl8BwMo+tn58TY3GUNHBzX4LP
Juf7nei5sVfwp9Lm7RIYVWelyQVzY8MUuTxPnZYgkqPnz3dWHiwm5NLMDZsl
oFXsO1kvdg4TyL74jPbJEsTYyjIKB/Fhvrtr9f/0lmAkKcBjU4IfW5b7eX5d
ewmaP4t74If5sYx24aXOu0tAqCjU6ZQ+j0mvXjAPv7YE/M3h334IC2ERlxdb
fbAlmB6SkjmzLYTtv/4u6iS7BNnn6lO564WxcmqBX4/El6CbQN7m81IUu3me
15aHewnQbl8cR7AYpku5ek6bYwnMcPyBT6nEMcuZvJ5AtiUYXj0US3MRx8Ji
b0r9wy3BpHGuot+rS9gsq9luP+kSPNCrHqgOuYztbkmk0BEtAcuNrmdKvJLY
id4DHcX9RSjfKj3pUCCJXQ76UJq9uQgxKz6sQotS2Lvj2S4BM4tQs/qYK+uN
LBY+7yRWM7EIa/rO9GLCV7DUWvnJvZFFaPbTdOWduIJ1ufVef967CKPkLA8n
7uMx7r0dCvm6RXjmRTJqjxEwyYHK/FdVi/AqKcUp/TsBU85//ywTFsFfvqo+
6pQcZm3D3shRsAibrm+aJ/fksIolgv9O8iI8XmfbYpi/jnU3HMMuJixC5tO4
6h0TeWw+qXPVKHYRRp7Ymor8ksfoDQ3Vuj8vgqX00PVOSkVMf9iL8afvIjz/
tUb2Qv8mZlukVj3juQh/n33j4yJSwrzDWe3OuC+CydPfy33flLCfmim9Pk6L
EPlu53j2ljL2r7n1s6HZImhlHB851n0Lw6WEKUc+WwQv3nfPCkNvY3w++nsd
hovQpK3/9obeHeyWwoYuerQI2rvAgndWw6JKmTjZbi/CmEDg5H9X72IZkaPt
asqL8OiTgd1G1l2s+mWSq5fiIrzkdLv4UkgDW7osM7WJHfHPoaqVJqCJyabr
JraJLsIltgjRjhv3sbQe+ou5gosgb3FX5fH0fYzzoLowgn8RMNzkaQGPBxiF
qnDL07OL4OgirtDcpYV1Lhz83jtxlP9jsq+FyTqYAkPWm4njiyClsfhCwUQX
K5A2oqyjWATmr78GiMQeYdFerWxB/xYAGi+lB7XqYSa8X+UEVhdgvFQez8T/
GBtR1WiiXVwA5ZyfpRHRjzE1W8p7v2cW4LHZ9RdqrAaYZJXFs7KRBVC5L8oS
x/IEI3lM+KDZsgDihMc79+SeYnbemyyyDQtQW/Q0t737KTb/MznubM0CZDTm
EEmaGWGt/+jzFksWIO4NI9P5JGMsImpi2CV1AWikP9bmqJlgtNUhRkbJCyDV
yirsTmGKuSwpravEL0DvCY/hsxWmmJFsFumpqAUgPZRnlFd4gYn3u11Ie78A
PNbh89aKlljCoWROkNcCUP/TCjDOs8RY+Jfwju4LR/O7k8bt81bYPzsN9etO
C5Bz86UqgcUaa2Q85zhgsgA49Y8PNs/YYvgr/cRgtAD7o2ancxNtsQwDv/fx
Bgtg+oPcjkHCDgvN3Iy20F6AkHaL4/sP7TGDOzU15MoL8FOp76VmjyPWY//y
zpLCAnys0S357vwSuxktPNAutwC7rq7/ngm9wkRWQpYjZRagJLrx9ucQJ2zX
14hR/PwCNN4s+nkyzhlLf2dRc4F3AZJdrnwRM3+LGTg7OvBwLQASrg8pP+uC
NVr5Dp1kXYBIGeVkjh0XLEIr/dsW1QLMf9scOmhxw27fzb+3TrYAiwUy50uV
3TES1XLKBaIj/i9RTiU0umMmqNN0cHseDCyKxOS732EyfH8vlc7PA+ODwB1S
Bi9s+ezhTO70PHRUbIjrfPfCYlipwtPH50G+Wu6yr4I3RkXLtv+1fx7OumeS
d/j4YP2/8dVu9fNQpJ0t3CLvh/mtKNo7Vc/Dbhbh/I9/fhhh7o6Abfk8cB4X
SBUr9ceSBx/7PS2YhzVbhv3cmx8wxwoPzZvJ83AXLNpf3v6ICRUHUMjFz8Pi
u2+U5fARG88JK5CJmYdvo34lg5eCsJvJ388Ihs8D2z3lb93ngrFTH1qmab3n
wXNE0HZKMARr9O4NpXg3D5sNTmNduSGYs9vYzcO382Cj//6q+PVQbNbuV+q6
wzxI5yw/DXgWhuXpMtl1Gc+DPknXY+nxz5jJfQ7+5ifz0CJDuk7lHYFxqPEP
VP83DyfCaDSJJCIxz+sy+LwH83C++29GY3gUdv/CI/LPN+ZB+bXvt4rwr9jx
c0b5H6/PQ3JWj4GueAxWxm7x3Bcd5dtI+W0wIgbjY3BtcZI6yq+xVOSLTSz2
Zys+RI9/HpZi5taJFL9h2t75YVE88zAylPXQtPAbVs7S+Hnw7Dys/0q76Sga
j/nJrH25zzIPtxKHSPN4EjBuJ5nE28fmwb5YxfGlSBLmTa2a7Ec+D+2ndKzS
C5Kw1Ui9H43E83BRZ1udUjEZKyxxT1fcnYMWVhtFM5PvmNq/ljxsaQ7kRp6K
0w6nYHkB4wWv5+YgsP4X3XPXVOzM2d9FRVNzcNltXOio0rA5xAKSw3NQ9YCu
i+Cdjjm7GtSJtBydi29wChdlYNMMdg1mDXPgdzeqmpQ9E1OK82r6UTMH+dYC
HYxumdjJqtQ2vrI5AFI8AaeRhaWQbfVx/JyDS8Un1f8y5GD0IccGdVPmYJGJ
WZ3MOwez5z0zHJE0B3r+OmfziXKxa4py48wxc6DA9cpQcTcX6/d6P3/i4xz8
/rlHUkJXgGEs0Yuq/nOQVDLWER1VgMUnZyz7+syBIrW+ToJQIWbR0LNO4TYH
CNmFPblfhFFQc+78s56D87fyHn3rLMHMIsX3rlrMgUvYqnTMq1KsU1Dh4JXp
HKQOLHy/z1eGfVE1Id56MgcxaafHrvkAJhGQc2xNcw4YPq+7F6IKLIKjjlpY
fQ5ULg4xNH6rwA7TB2hNb82BJflhE93xSqyx7R/DnMIcdM4+tDQdqcQeMyix
jUnOwZUU89e1MdUY35LinybxI74ilR/TcNdgi9Xy7QUic8CIiDKMEmswW0eC
ZxDfHPxLaemPLajFvMekNhSY5+CL0Xa1MnkDdqvwcos4bg4EfyWmKsU2YLjg
S8lnT8yBNEdXxi6hEYtSFNXbIZ8Di8G5143vm7CMNL7G1D+z8FKYoSJGvRWz
8zqX8PnXLOg0fllLpW3DZB9zu3iuzMJUQaQMf2sbVn2SQ1J/ZhYKCnjPGae3
Y31OTHGMPbNgIHhAtf6wE4u6x/iGqGP2aL/p8Tjf1InpizJorTTPgrar9cEx
1IUtTtKcqKuehbBGtp4DkW7snxLZq1c5szCn5yhjL9aLVfGQ3DPOmIWmU4WP
fhT2Yt4Hh6KaqbMQ6qMTcVyhD8Nl7s0Ix88CFiJP+vlpP8bH8lt9IngWjpU3
T1O2D2JLv9aFWj/MwpezZdY5NkNYRtMqZfH7WQg4sSojeHoYk327WPrJfRZM
MysmWu1GsFuzE+dv2sxCKW12rqTIOIYrHyO7bDEL/0TvF9oEjmO9n0fGuExn
oeuNfvLvzXFM/9ZAyJ7BLERT0rCvV09gtjntxD/vzsIdD9Wde25TmExA63Dk
7Vm4tNnFzLM9hf0zbs73Vp4Fqi6kHGc5jXmfrn9hcG0WvK2vamw+n8Gi3GCA
SXwWrGRoOJPezmGMv2vJborMwgf/Nn0l0nnM90mr6KsLs/D7SntGns885iA/
4jHKPQsLpn3Phb8uYHcp9sSSGGdBnk36gvTqElZvT/JogG4W7BVgZMRnGUNz
x7ypaY74rz+v1CywggnVs4xakM1CpKIKR73lKkbpK+kr/WcGCn1V/gsPWcec
d/G5Jr9m4JDoqb3Xr3Vs00RhPGplBlKaTisZ3vmFTapoShLPzgBVw19VOoYN
rITWerKhdwYGZ//h7qT9xqw/psnqFMxAARM9yU2NLWyBOPepf84MTMTtfr/c
tYXpW5cEQsYMnF/2ftJ4bxu7pdE0y/N9Blrrhz6dfbKDCTAtBC1/ngHvfR83
8pg9LNpjvZQjdAYijuX65EnuY0x/t+bVgmbgWUBRsVv7PkbSR4FyfWeg83YO
fSrtP2wk/NzSG6cZqL1B30upRYQ0jwkxZzjMAEPjhc9ZGUSo8eUluUmbGRi7
ymUpQk2MCrSvhSmazUDcRI9EWQ0xCjqjf53u0Qw8qnLfVLpLim7GREbGYDOw
hS+vp+2kQERTW6szsjMwe2Fc+4QyJcrn1bwmKDUDglpqjy2rKRFfCs1CrugM
NHTavvYqp0LkeW8kmzhnwD03pVOz7zgq2R7woWefAa23vi5ZT6iR7RXJkXus
M8Bd2FXUvUGNpstX3ccZZuBc52RZFCstqmz6r+MPyQw8WAu6UulLh16dKDl3
5XAarr/nXzc8RY/E1FkcXfamIbvqjxSZKT2K6W3noN6chj7lOCRxigG9nZAz
45yZhl6i4eIr73Do6hYPpUrdNLCz3h+3KmBCmzIu2oFV02BXeq3mrAAzSnk9
nNYD01BtVL319zMzYiMJ0dQvmIZUtbNvld+dQjs0FHF236dhMUppO8OWFWXc
MfhTlDANun9KfnX+ZUXPgspuEsVNw5iQnZ+dExvqP+Ww5hsxDfkOosfM/E6j
PO75qzHvp4FFXzjMrpUdmT+VD5zxmoZa3rXUjacciDc5ZurCu2nYCu8t1CQ6
iz4JP/TNfX2Ed+4ywyEHJ7KWbuxrfHGUn0yGlLQFFxK9nWr958406Lyj5Xmt
fw4pDv6OXlCZhhceewrRbeeQrtGVppEb00BlMbtIIceLfJ0beWrRNERUVL4d
uMCHZtPnu0NFp0HuDO3V9tMC6ED2IvF7wWko0KV5bhUtgE7WOQi/5Z+Ge2V5
d4t4ziO5MQpP47PTULp1oOEoeQFF0fFKSdNNAwk3QwSvsxDKjjR7IkQ9DWHM
j0LdTwmjRv6cD5yU0+B693T1TrYw2kbX56kOp0B7onDR9K8I0rB8/HlgdQrc
owidHzsuouMdX/ZetU6B33Iko17PJcT1aIbfonEKVD6keWVhEkh6QUjzSe0U
vDXtW+b4IYGMiEtSVcqm4M/yFPbM6zKqEBt8dCZ9Cm5+JZWY1pVC/aVcvvQ/
pkA3aOUCR78UWlV6nkeWOAUJKof3a+9JozMG2ydWvkzBgdUEb6CWDHIMYi4v
9Z+C2PebFx+9uYI+cOgtZ/pMAb/4+KE27VWU+COBJdFjCmobS2UuxFxFXZUS
VgFvpiC553KFdSseify+y/3fiymwl9hi+sxPQDMaH94R3ZqC4rXIG5Jb11C6
/TiRrNIUTN7iN/S7ex3ZfxZ7Y6MwBTZtc26eP68jqrEuu1n8FEikT9u5m8uj
CyYsxs0iUxBEl/7CglgRbfg9nyIXnALBoYe4HBNFVPyz6D/EPwW0V+e5B3oU
keofXa2ss0fxXalpZzJvIHOXWKVw+im4bnMwt+qqhCS/bdR00EyBAFXROuee
EjqsuX6N+thRvOvtgw72yiiQelbWmXgKktp/8xbaqKDs0AtChhuTkMA27RDs
cwttp2afuNg9Ca2nZmKLmNRReRvZ++ftk0A+8KWm8ak68tm4R/mteRIuoyuj
KF8dsUlvHzLVTEKy/xUrS727CF919dde7iRYV0ZWfSrTQBSz/i8uZ02C8JRX
uB2bJmqlGlswT58EfHNR07KDJtK/7To5kTgJQzwH7QVS95DbQE1XXdgksLFa
hXk23UfK+8xqxJ8mYbFh4Ve/xAPEePZZs2zgJJDNjersfH2A4g2P16R5T4Jb
6YpspZMWqlu7nRf8chIOXufaqShrIxqK/vD/dCahoYg8QUtZD0lYn1y98WAS
5uhfC++M6SHdUbXrFzUmodLbau+e438oJa9hhUhlEiyuVykUaekjZePia3Gy
k1DxIC9U7dtjZN21FeYrOQl8bYgXdh6jCCSxYi0+CSuONq5l6gZo8VRa2PUL
k/Di5PUpX4onyKc+enmadRLGbImpz74zRBkSQ3ItTJNQt95D2z9niPpjToXl
MkzCOaJ4MZ1bT5HAy0A5z2NH/PS+/D7KboTqz7uF8u9MQJhxQ2xBjzGieP+U
YNI/ATZc6/cYk02RyFZsyN3uCaAvy0pTETJD95+MLsq2T4AVN81cX5YZSrzy
IIS6fgIKD9A5xroXSGH55mJq/gQIXr/gEUZhicy0PFBI9gTwGFQNfLhriT5V
V3x683MCUCf55aGvlmg6ShbdTpoAr4McYlfMCr27JfRpLXQCSn+/Ckzys0ap
hc8W+oImwCFh90LvlDXq5k3AygMmgKAY/Mfjqg3i+ce+EOg5AdJb5a2uGzao
Mp0OE7efAM9fim5RVnaImP73nO29CUiy51i5UumITG6/e2qpPgE10u1bDuIv
Uacf05TprQmgKywZCox/ieKPSY8aKEyAxsUJG/uAV+gG6ZtutcsTIHPv2Yup
l69RhtyJu6piE1DmdOd0/85rxOLyte2G8ASs8Ix2zzq9QYv7FY0Y7wSscrwi
t/F0Rv5/KSqEmCaA8VXXExYdF/RXIhwTYJiAzjl+WPvmgvRszpfw0E5A5FSi
6N8VF3RxXSWfjXwCJghulnEerqhrITCN6s84yFaT5e1WuSHWEbaI6e5xyBTo
2F538UBup1NPjbePQwfPb7XdUQ+0+BAfMtQ8Di4zKf5umCcq6f0vsLN6HMaq
Nw54SbzQf+3xnuU540f/c+cirShvVH9CkqwkYxzGU9qKtyl80MVbda75qeOg
JuLKpGjjg0gaF16nx4/DkmScHbG6L0qoErGJ+jQOPU06hSlcfugESfl6WOA4
6ChZ1hlF+CF7grp5sN/RfZl9ZxImf3Sz1Oa577txuHHjE9sWXQBayiv4z9F2
HHJle0maTwQisR/XVDU1x4FytDie5k4QUn07whqiNg73aXNopkKDkJGm41yP
6jiwi0Yul44Foah/aW4PFMbhbG2PcYBtMKLQYC3UlhwHQfKKuJ0fn9Dg3hrv
Y5ajfNc6XzHeDkOb7b6/Y08e8RHvfdidFIboEnkrJunH4V1jelo3STiSV9PR
NTw2DstPkWZ0STjSVfLnbdscg/cnr5c3HVUfWaTs4VDBGJz698VH1vsLklGw
jHiUOQZ8K1KybVtfkPlawuWx72PAOdh5bfZZNOq/zmA2GTEG/zEQ/qbd+YrS
luf651+PwbmHDI9Ohseg+1hI1h/CGNwL5L7oHxOH3s833nKQGQO2rPuT/jNx
qDyIaGFbbAw03voWOwh+QxfmTM/uc4+B5plYYCj6hv59uOZHQj4Gk2xFPqmT
8ShpYu0pXcMo0HQznTl8koQiOPazVstHgYnOJZmrPAkF6FARtRaMQpxav6s/
ezKy7+GM8EsehdeBNCLqw8lIvkG99Zj3KLTfFuHce/4DjWdkS5LdGAXe6S6r
wIY01L0C7lPYKEzMGB5gV9NR3YXm9krJUXhB8rHCKSMdpcdPm7jyjcJYeeGX
rC8/0etwpq//yEfh0vkwzZaajKP6cKDcqR6BUk91hvbhLERT6q7ZXzIC7HcV
H5fwZKPDnQ+x+TkjYLofHR1mmo1mbZKv2MePwGpE+Wfef9kox3jA4rf7CPAJ
cA0vieQitTtX+leujYARtHeGVuQjeb8bvC2yI7ArmfsaWAqQVIOGdar4COi4
MAeTWRUgjutmNKbcI7CAcxJbP1eIliW/EOaJR6DI6UXOt4gi5M1xmDxZPgzu
1tTS18tL0Zg3R6hq4TBY1UhX+/KUIcnfePe8zGEIbmVO/utVhqbrXj/yjRsG
dkeDAEVNQASrXQbxd8MwdIOlyPdNOdqp+vPK9cYw7Dt/iNqRq0RqIkzPltAw
NA8VsJu+qUTJ4RL37kkPw8qvj3sehZXo/gsb0fPnh4Eq2nq29FIVymL+NdV+
fBhixJ/EPr5YjUyeL6tytg7BuGHlfL9KLaroopb1rR2CxeErgZFBtYgFE+Tf
LBsC44J3q5yDtagWZ0Jc/3MIfvfzmb8yrUPcJXO5Fh+HQIriMxYWVo+GTkxx
gOYQ3D39M2KTuQmp5gysPxoaBNVJzVeE/9qRQWbbB96uQZAo9dqN/NSOHNJr
RFYaB+HM/YgD38Z2FJecafa6aBCOL06qCEh3oO0on/mIz4MgF/bWzpWtE8V7
yIz3PRiE/EtCK8X7XajITfTt1zuDYP2ELmvsSjdqe8vLYXxjEIhT5+/8cOpG
uy8ZdP9KDkL6ZBCxzEE3UjNf6DvJPAiDayUVelS9aP/+5zb17gEgR8nT46gf
4TQ/mLM2DwD/lJcjhW8/4lf3oJ2oGgDfD+bZs9396K6KlYpl9gCIT7xlGjYb
QMlIqS4gaABcuD7JlyYMIk2BnbImtQFgt20SM786gtJ2tNIVWvrBwfiX1HH3
CSQfuf3lUk0/PDUdD6bNmUDDV8P9uUr74fHZQM83MxPouEuf2UFqP6gUP9dK
UJpEzyjuC+b69UOWdFokz6kpxM2okXxOtR9uvRK9fKduGhXlbITh5Pvho2Pg
hvbhNFK/H+RFdLUf+sJ/uQxJzSCXzx1Gw4L9QFIuu3f1xwwaOavG+4m6Hyjb
xN4HfJpF4UK34kib+sCX8cpG+9t5dLF1+eOvyj4IqOYK0Id5VGfh5zpW1Afi
lfePmx3Oo79ZTfrFP/rAJlLg0rbLAtKQUT5r49sHi0vKXWs+i+iE4o2oSaU+
4DcdrfmRvYze/ScXWlHfC72yNyeEctbRW5FNXtmKXmgn3DqvMbCOXh0k5mYV
9oJJbSx79r91ZBlJ0/PtRy/ErN65yqn8C+n09TF6+vXC3Fcii4ypX0j8jvlH
ZbVe+DLmRpXO9RtNYJF+XX09sK/c7E7T8AdhHH/cZma7weZf6Cv/8j20/da5
uni0G6xNS/nptvdQ5gQlRVBvN9xIlAxpFt1H5xLYfLDabog1IRbe+bqPjgkR
PoQlHL2v2XHxhPsB6pZ5H6lk2A2Red49tRqH6Pk9rpy0iS6YTNkx2fInJnzy
uzVjN9wJnbL1Aw4fyQmZpxdre7s7wTWjLJaQQU5o/eGZLNXSCY8fOqfQt5ET
qBrAdKe0Eyoby5eqaSgITuTiG6+/doLek4kqa28KgoEz86G7QSdgzEdzlAsl
4aLlGEvQfAeYM5WW2VseI9w6dNrdGO+AofbLKXc/HCOYBLAMawx0QJFGSCh/
+jFCfKr6V6bGjqP+1mldtHSMcGqhivdzSgdIn/r9yN7oOOHf42TxGPMOYL60
f7L3ITWhRcNKNX2zHd5C4OdPErQEM69858sr7UD8k9eCWJ2WcLz4IKNkph0i
PqsHPHhBS7jJ7cvU1NsO5h8lo0sTaAmV63GjcwXtMHGjNtWA6QShwL/bkutN
O8ioqz7/snaCEF8nFfKJvB2eO14NY1ekJ3j+3QuQ2m8DZ7pjcs/v0hOqHnn/
VlhpA+IuNt1YPXoCJhRbYtDWBsX3aKd77OkJEg2dt6OC2yA3SFhSKZGewEkq
aUN3pg3kpLm0uIgZCHomlX3stG1g5TUiw0zDQIjsuH1V6F8rqB2cjvzNzEBg
jjEmVxpvhfNV83NGQgwEGvznMLf4VkgM8qE9f5+BsG2/X/xHqBWsA9m/z8Uz
ELJIJd/BmVboJe8iZvzJQHgRaKHqQ9MKmNgTbY5CBsLk98nhM8stcONjy1pX
MwOhabj+4HpKC9RmBNNmbzAQPJ+T1NJGtkCRKkNV7x4DgfD3SkCfbwtYXTNW
7yfDEXLofnKYmrTAlSq6XzbMOEL0tRAUdL4FiKhfCFNI4whaba2UuqwtIPlR
MZSBgCMw6lK18x5rAbfI7sHtGziCt52TfuF8M7gSRCm0H+AIVsmPXceTmiHz
UdErfVscQehypNKPsGYQplhTk3fCEWYruhlsvZrhipreZRI3HEF76EYcpXEz
yPD7qlN/wBHkT4hUifA1w6HnCZ5bSTjCvwjj99tMzcBopZa5l4ojFPLHalSS
NwOth12uWxaOICJ3cvreTBOw1XIZspbiCPMtt1LP9jSB7K5GtkAljhCn7WW7
UN0Er7mqK+jqcIRTtrtkb+KbQJL7hKVhO47QSSTRovipCYbLeUs6unEEP/8X
IfTvmuBQee8s8wCOQJQ0zhv/pAnWhFmCeCZwhKJLbKsvNI78nXXQXJ7GEezK
NfKkrjfBxP260PfzOMLiQK1iE3cT+Ha7n7i1hiPEGxHRheCawAR3jshiA0fQ
+y3Tp0fSBFZPuBaN/uAILC42XwU2GgF3VSRNYhtH6KJJM96YaARf4eOC/bs4
QsDnWdGSjkYgz3VXVD/AEW7ycW57VDTC398vp74e4ggk2Q/L72Q2gtWL0dkq
YkZCCQr2Zo1thMnveZKlpIwE++ZmtanARtjvYS96T85IEHtIwZrm0ggruooP
RSkZCcszaMLeshEemDodJFExEhKtX34n6B/hseL++OcYI0H/MMvquFojDH0o
OTxFzUhg81uW6UaNUEM6f5mOhpHQzcJHEi3aCKFvH3MNHdkfEv5rND7bCOKv
yTOdaBkJ9P7QqUjfCBmyd3QXj+wg27NDvMSNkBwtLHjpBOORnt5OkW00wPMu
Pdz9I/vT9bGlqckGWKpwptQ4spkF0WZlVwPcGaAkvnBkh+G+7sdWN4Bavcbf
wSN/LLv/yFxzG+CWeNTY0yM7YkKPVj+xAah093Ibj/CcaShjQmEN8KjZzObY
kf0lg4ODw7sBdGdacNxH+XCEO/MdOB75dx79cPI4IyHm7ajI8PMGiDOWmxs/
4oPbGJMq1m4Ao+XXzF5HfH27HY0iVBogRmXvNCUFI+Gc5L8bL682wBch6i19
siP+2PXUtIQbIJNoPOkTCSNBgLxMS4qjAbyfBonGETESvi+zP2amawDbl5yB
Pv9whNTiEavu9Xpwc1GYn9k50vM3/KvsiXog1Nyf197CEX76fnEL6qwHrnbp
zu+bOELWw0fBajn1gD9Qce5ZxREk5EojRRPqYf2LkFrWEo6QK8AefyK0Hjp5
8YLPj/RYsDWc0+xQD0+1ZfieHum3LES39+aVelDquOge1oEjEN6UjPIL1UPj
z/YlhRYcocLwzBwFez00X0uqa63HEaovDW9V/6sD4zMnz1oCjtDYocMqV1kH
XPxdz3//wBFUC4u5OLPrIORBpZtDAo7QEnP6wuG3Ohjw08nq/YojtFsMyZZ6
1MG2xfkCvk84Qg+tjq6MUh18b6uXoz/qB/f/FBmyyNbBfr3RisVRv+gfZnux
daEOZvTz3qe8wBEGUwbf5NLUgSv5Bkf+fzjCuJL2V7H2WohOdFLguYYjLHs8
nDz/oBZylcTeWRAd1V+Q0e1qxVr4IPhSfvwvA2Hhq02RnmQtCHBM2p5fYSDM
FvoHBTPVwrsyXmrFAQbC2ErFtYOuGjgew+KfftRfO+9d+NauVgOXvt7XsL3H
QGg3kKIzJdRAvlPfaR8lBkKrhbwT+cUaCBh+8vgV/qjf+uhpyNLVgHCnic/v
cwyE6tIg0viWari6+tv75gY9IZ9374mDcjXk0vSSVnrSE/LEqdoZZKshWGl5
rNKRnpCDmK6mnq+GT5NTEgkm9ISMh6InJ6iqwVPfPJ7uNj3hh/+TauW6KlB2
M8E8GOkJUX+aznHIV8E1yR49D3E6gltN1Ew1vhLUe0yuYLy0hHenDzZShCsh
+sx0ewIpLcHT6hFRMHslmCfM+y1M0BB82TlOPz6ogPpj3m+pomkIQXZf1Q5K
KoBVNSS08CQNIY43rvjy1Qqwz6luCd4/TqjySPqYKFsOWRHpeJ9iKsIxP0Mn
eosS0NM8+7qCk4wQtWLFfEy9BBQG3OOj/pESRO68zSS+VAIn75V+cR0mJdzF
Rcxt/C2Gcx9E2EzDSQlR4W0aPc7FYOL28Ecj/dH9BFmhiIAisDwlYCBERkK4
W0Y/wpNeAD8tCg29fx2i6bMcjmcCC2Cu3XgiKPMQ2bsKMjJZFwC7WLBlq9Uh
ipRXVKKQLICuhtD+oY1/aLrRKXe+NB+EuJIqDLcOkH3frH9aSx603Xkv0Hp8
H0Wsl2BSKznwku07seV/24jvy7nYxOYcqOj0XOfl3kZZSn6kzKk5cHNjJVto
Zgs1xunUb5rkQH3u7qaI2Rba1dxVz5rPBsm8HVkm579Ip1DqqfB0FmylueZ0
ZW6iM25Z73mGMuDcnvNels4vlCzCthpUlAEe/t5Rmud/IYkhVzWSiAyYr209
d3drHalKqDNNaGWAuhjJs8ef1tF28xgen/YTEjG9ycSENVQYom14KT4Nwg+o
8NyVy0iWXy3zbNB3sNt5c9nEYw6ZLxXYa9z7DlHG3rrdV+fQt59cV71YvgP/
zecwtDmLaKR/165GJ8NJXGdVudEsGr0ZOlyakgSjlSq9/eozyNVkmFK3JgFi
WMWXRuWnUJ6IQssH7wToLa5SXSSfQosbaUFVKglw3igi5n3dJLrr9JZdsDMe
pKWmp/1VJ9E5P+5Lu6PfQOkjX67LowlUn/ZML3w7FmJdpA4FL4+hfasOnubi
WKAuOEVk1TCKxCRlFw6dY6F0ZWG4RW8URZRR2xqTx8KlMssPDX4jyKwt3UcS
FwOJdStNMX+GEMfkwvPvD6KA2yuW1X2nH3mZFG/Sj0aCczmnS2h0P1rf8Hvr
aBgJz15Tdn2X70eVpBdDblhFwMJe2GhDcB8y4rUvn/ENh4AKnG0lvhelPSM5
xV32CXh0Laz4oAtJyJinrip+At1zr5LXbY/2t2ODcsVtwfDNI80zTLAL1f7I
NNOcCAJvIodu28hONL6sX+lJ9hEaLCoaCR4diH/Seag3xBdO5mnEPD9sRRLu
9yksk3xAsr2umt6jFRHOiYgdK/SGd4sLwXiaVqRtNOJ5ZdgTpJONZE+fbUEB
i1fEY7jdQVJZcef9/Sa0MPOLoUvPAdLO3NSzPFaPSARijcnd7CCpSy50NaEO
nTFRK5VKsAF37Yz9sut16Ovwow7pPgsQFmhMUnKvRWYrfc5N6/rw0HjrYjpD
DdqYMFblKHiINtkC83eeVaJas55XP0L0j/aQWm0e1koUNG/fpnDHEDVI1Qa9
aKxAQuOFjq8rTdGVndvw4GIF+jn3dcZW0w59zt8rEj1WjqyWcGes2N1Q2Mp3
EugvRqEbz/K4ON0RnahERsGdYlS0U6bWyf0O/fI+f265vgiRUZl6XBLwRAEK
8lzTFYUo/FzV6h9xXxSTnapxryUflQqy+iRefo8yHvXXPbyXjybFLXgeSPuh
k5exUv2xPCQod1qrAB+AqGYkrHV2ctFYeqE+/txHtEzxq0BFPgdZZ02nhSR8
RLm+1J9ShrIRWR7d3gpfEDJ1nmgYsM1GAqVPQ6LPByPbef/z3qlZyLqJofFQ
JARdf2I79PZiJiKff36pUuYzCuYqsSRQp6HwpU8ubMWfkTLr40ec5qnowhq0
WF+NQJxC1HfGu1LQ7b9Mz3hQJDqzTdzWnfQDhZNVRr2T/4IiQve5jCyT0QWq
I2HXfEHCqfv3Ty8koVJqFqnLN6LRwYtiO13DJDSJM++YUfqKHLTNTLUNElEo
Pa37t6QY1B7KRH3JKR79FxT3/c58DErqDY6VoIxHAiel2/cEYtGL1PVB25Bv
qPjUE3bNH7GIZ9jpk19BHBrnKMwnS4tDA65xARwssei88NPlp1nxyCePR+WL
SRTqvf4YV7oajwYUzXgdWiKRm/Yj6ZOCCcjOrpFY7VIkGva6967yWwKSyH9S
1EIZgQInFc6cDUlEK8/3ZH50hiH8jtw1+45ExCy7wy+kGoYW6bBnLbRJ6E7N
i77b9aHoOl4yx8kzCUVqZjIp14egv2F8qv0Oycjmssa5hZlg9C2d21o0Jxlp
1OeKy9kEI7UajnDP9WSUXODfM00SjH5sME9LPP+OrL5lDMwKBKFHtyhff9T+
gTxcKlRrAgJRNcl8ijI+FQ0l7f5MsnmPrFinO2JfpqIFT3LFzVZfxHFxfGs7
NxVtlioM5Ar7IsdH/deTRNLQh8hKcq0/3kiwoH6IlDMdrRvPNz1N8UT9rdXE
Orrp6FrSia0ETk/0bqacPys8HT1UtRGeCPdAo7hCG32Gn6jRTPgfXdA71JDX
7aFHnIGsP/3ebElwQ5yVnSy+ZzPQFD197hMxN2Tf0p6Si89AGsUZrt7girin
mztoXmWg/AoO/ltTLug1Qw178UYGes0a3z8S4Iw6z1RlzNJnomdU+NE7zW/Q
eYGK6zjRTLTwwTmZ68Qb1IuVPn9umolekri6+0U7oYtmubmnpjORTYwUv+C6
I/ITeujaTJaF+IuWdLoJjmhheV/VlTcLvVHKtR0KcUBxL+SnF42yUPWf316x
qvaIyaILV7aQhdL+2ie/XLRB1qIOo9bHs9FmR8hFJx0b1LrG9oNfMBu1BK1Z
c7dbI29LA7mPZtmIxMKM7US1Fdq1+mVhuJaNSrTFBm8kW6D74iFXWOlzUM9y
YZpEuTnK3pCmbL2Yg9rGpLnERl8gMxuXaCnrHETKPHGjQdAMjdnStRz/k4N8
f/6XlXHsObp6OTscmHKRsLLtyzu3n6HwP/cNbSVzUcRFi2/rYcborn303ohD
LtoPWeUolzFC1Q7CFzJ3c9F75YXn+jlPEKd0x5+np/PQ0N1+i0H2J+jNtm0F
29U89DEF/bB+b4AkX5ZovXuTh6JALCfU+jH6/krF6wFRPprRibfbHNJDFFfW
7tJw5aObB8bUekuPkMFeEEeFXD46+fOktzvxI3Tm9WDuBfd8VLHIIXlPTgcF
vHk+fUBegPKDMqn8j2uhJTxtRhZfAdJwwfneVHmAbv7LcDK+UYDiSpom3ny8
j4jfbuM6vAvQxrBnZo3wPWTr4iUXT12I8vL4HMni7qJ2giDtQ6FCFGt0417V
8btImLitn/ZWIcox+jW85qCOZl2ZLR0CClGdvDEX239q6KF7QrQyQxF6tNDs
wV+sigQC9he6RYtQrOyEGgyroL/hGpf/u12EjHeixj+QqaCgdOJmm/dFKOsP
w66MkRJqHni0E0VejP5NaXE7vVBEEdM58vznilH3fIZjZIkCer5GHZh5rRjl
udM01NMrIAryIr7at8XIC6nfqq67jggXmTXXdopRtAxJBJjJoRNXXnx9yVKC
Tl3urK4cJ6ARhepFUqkSlN+t/GBQi4Be6Vi7stiWICZyvZ6f3zF006ihOS6o
BLUW2ujQZ+LRKStOFuHMEuQ/a5lSCVdRjmdrutxqCWL8WxqrsSGL3D7y7jbR
lCLzF5da2plkkXrUa4X7gqXId2IAhpEMWs28MGzyrBTp6I51LSZKIYERz2Of
Jo/Oo+0UuUsk0N+5EU0O4jIUN9V0TI1OAtVsSMQkny1D/imCYiXGl5AB1ZRk
qW4ZuqZwvrCIXxxdZJR1u+FUhraL+LfIPoihQ/aPLR2fy1DHrJHSwe5FFHUJ
Gc72lqHbhn3OU+WiyAQL/Wn5pwx9paGMe5gtgmSUVnZ3GQE9+2j6kT9dGPXq
RX6kUwdUUHrSr79YENH5bpVJNwFSsY6WVhATQKOfbh+vWgD0hsTM9Zw+P+pt
6/zBR1aOOqy0jkWH8KH4wfN/M7jL0cPKw8FIRl5Erd9z+q9YOfKP4Tes0DmH
rGdc5K7IlSOGrpLIqu88SG69z6/mv3JU4KQjmn6fGyXbuWcdtyhHZoKhPnK5
XIh+T6T/jnM5+mR604WSlQuNknvyDEaVo1fexyROj51FTqclilYHylGNK23O
UPJpNPrAD5ubP8KTdvJXUS4buvZpunJsqxytOd2+Z97Iio7ThjS1M1Wgxc5L
cU+OsyBzpZU7DecqUNGu91fxy6dQh4dCd8WlCtTfyzewZsSMwv/9Gc5SP5or
2MT49EdPon3Z249T9CtQ6E+cQyrPSfSfQ+LMN4sKZDL/0YzVghHxrd9f/eRf
gTbiH7KHncKhnIn8Q/uGCuTwJvqWhSYdYuGgf2fRX4FcJQ2zLkidQE7az6ie
zVWg/aEmsOShRde6WBgeklciUvuP781PUaNEOqsQ9ZOV6MFApu8njuPomGoD
qzJPJUowexnGJXIMtVe/5L4iV4nqDXLnnzylRBLEnYmX1CqR8K2sD2F+FCgM
f0FQ6L9KlHrNeE2kmBzp5Q1eYn9TiVz6PGc/C5Oh5aQrCocFlWhKgUhF+jEx
UpsObtiqq0Rscxz3NEuJUDbn8q313krkcbXCi+ssEXr1Oer+xOZRfJU9bv7Z
A2y0Z3NwgLQKvYk7R1zSsI/J4W7914mrQq4XuJ8r5e9hVO8PjKsuVqGRCHlH
4p87mFndveViVIVoFy5L+xVsY22k6ZY5t6uQtjlHYFvjFhb6Wu9lglkVMpPS
MtCm+ovxmoOvV3IVOs5snbw5toF5/zhF55Jfha58i3ZP4t/Almctgh1rq9Bn
wX50aPcLy/mPM+r5dBVqLubgLORdx1iiHDkNflchhtG30jq0a5hTf3u8Nkk1
Yift5+gbXMGuqbumqXBWo4/hRfx/Q5ewRP8BMXnRaiQpqWnd/24RO9YolncV
q0ZPM/81Nb1ewNqvTZYJ61Yjz2TRtXc+c5iexPV2uvBqFPvMYFiSdhqTV1ld
V02uRo66NtqZYlOYoMFnBt+CauRvvbtE/98ktv1h7S7ZQDXCbxCd5e8ax8YS
I2zkFqrRusn6DRnWcay2VOGT8041moPU8taWUSx4KbJnm7UGlUkXRA+JDmOv
SG78vXyhBp3dp6K1/DOI6bNuMNvIHs3JntJupPUDmMiNm1or2jWo6tSfYd6g
Pqw+bnNwIrIGpXB/5VJN68LSC7/ucaTWINPdAOfvLZ1YSLvyGd2SGsRyIzrR
dqsDM/gX86h3uAbR9BSX9z1tx5SYVJ0ZV2qQDbZgaavRhl0U2opWO6hBGq2M
H7GlFuzg4a3xRvZaRExmsqR5swmbttwmohKpRfSNDEXPaRqxRq9vXApYLfrt
IGJ3crQeC8/dMQC9WvSxbzh7L6kWc26Od983r0Wkj26+Ff5agz2duhMv87YW
9XX8NRqLrcbEGRJnsr/WouV3q97TdZUYi4A6xa+ftcg2gVCmsViBHWL7fCLl
tag0fCLzFXMF1mx291nyeC0aHOJJSzsJWLb7gffMei1KHkmcC4orxSIikr9z
E9chH+IvJcOEEsy4/t9iFFcdYlt1Z5pJKcRuj32nHhSrQ+k9+1xaDgWYxF9N
oVPX6pCpb+HDcLV8jORcyouPBnXI0/SLvOiFXGxe9n5Aq3UdeqZXc97sfA7W
pk78k9q9DjnQOotck8jGot4+WPf4Vod0s+/TV5pkYu6hJAxV2XVo8JNM0+uQ
DMwkLU2MqLoOdd0QI5oO/olJDZHavJquQ1zvVK9WRqViHBvpwfmbdegF3Yld
zispGNkx7ZxNsnqk8oFpsGHhO9YpmfHHnLce7bpksQrYJWEFt3SYUy/XozNP
f1N5qSViXw0ppBYU6hHN440kN5kEzCxI1/GJUT0i/XLgvCr2DdP4Tvk5xr4e
zduENeAJcZhseVbhiGc9OtlLZDr3MBajXKXae5BUj4R0v6sFan/F+H74D73N
q0ecWxdP4Wa/YIpGuJKkmnrkLuX/6pRbFOY5evrN1lQ9umMcqLM0/xlLjIh5
dPZ3PfqbLOxgkhWO1dznxW6QNKALRiyzLT5hGFmbyGEoZwOCswv6i/+FYOfe
Z4+ViTYgu8sLZZ6PPmHXb0iXz2INKCEzJqbFKBhzAzlXyUcNaJHqsEEv4iMW
51T7WM+sAd0N9O/PrwrEKqRUrnk6NSAmnhyBzJUPGFGGJmnv5wZ0PU2KyvOX
H8ZpNjB1kNyAvjgmP3T1f48hAb1q3oIGRFZ7VXBIxhdzjjH2sOttQJfPacZ1
lXth0brLT7/MNBzNFe5ZrBGeWCmLlWLNZsPRHOjnRuPqge0HvqJkYmxEu0MT
PsF27tiZW4dzV7kbUeuo0B1yNzfsyrF39YZijUjZ4YXF6GdX7JWrv0/OnUak
IT6e5NH1FovA40yG9RqRhxCnZbacM1a0E6pMZt6IbnXzBo5UvsZ2rGKoNf0a
0fZedEnV7kuMRYR32SmyEbEx9KjO/HTEpBe/N3/70YhSaAWcW2wdMEeDbP/f
9Y0owvKTGZugHRbOIW1+ur8RPdgzPsZ/2hbLHyy5fX2uEd1Zm32ixGKD/b1b
SxdM3oRC33JrmktZYcx0KutFJ5uQ/4WEDTUtS+xyU1v7JE8TKvSQ/MFAZYHZ
Xh/4KH6tCS1LSU38/W2KfTp8ZK2t3oQU6F8ovvc0wbKLJ++66Teh/qONk1Lw
ObZxaZmx07kJMf9xfmCYaITh1i03d/ybkA/G/r+Gyzuc6j+O4pJIkpIdRUjW
z8hK38/3LYrKyEpkJJsKIURZRci4KZJVVgPZyS67uPe6U6hcSTRkdUmLX3+e
55zXc57n/HcI9ZGeuEbFEkMmfwAw0TqPV6c98EC5tcwLLQMwP9E3fsXKDSeM
Xw292z8AxAw98qDzGbwqb+PJjpEB0LUL0T0W6orPCgmKbVsZgI1n2ayRDGd8
CzVrRY+HCOnSnbIc3E64auqOEVcRIhQZPoiXST2Fn9sgn1OtRYRZg5j5BPpJ
PKXjccSwEREeDN8KWCPY4RVX/nPksCFCU1HvujcuJ/CvS7qSlheIMOUtefH2
Xhs8LUXgbmssEXRtUrqr+a1xddlpYcUMIuxMftFxmdMKD7XMEuCsI8I3sbgz
tWoWuNj0+RT/LiJUV5Y0t503w1uuHOZ9QyfCqISP1e/uYzhHOZuznk2En0m/
+BqaTPDig8Ro6Q0kGJ2JFquzNcaNh4v/pAiTQMl48er4+sP4jQ02y546JCgo
Hnh7KccQ/y9PKZhmTIKZIjXB8eiDOEWTcx4/SYIg0WmK70UDXMS15rNoOAmc
AmJLGBIIb1xO9LqWSAKewviHUU4HcMdU1w/z2SSw2HXCb+rZfnxVVs/V+TEJ
amJyFe8p6+H3mwXevWoiwVdabuDxBh3cyGraQaefBGmqKtLVdtr41HT7UNEo
CegVhNgbfFq4srA/JfI3CT7KChxVrdTAyeWHzT/xkSHIzuTm67vqeKChVL+t
JBkoQ04x8cpq+PYRtnGHChniaFLRPIaqeEMAsUsVkeHOlpLT4ReVcXvuEoMc
czLUlVyL2detiP/Oi2zjdiGD9eraznKVvbhBv9IzVhQZOs6ZC3Mdlsc/uHJq
maWTIUqmjaWxKIsn/BipbrxHhhMH5pZq63bje9NqVOWryTDv2mLsmCiDD8gl
ld18QQYBSfyEQIA07t/iqrBKIcN20KxNIO3Et1rrlfi9J4MHaYDOfiuJ20VP
5xtxDoJQyZuo67bi+Irwc4lqwUHwYCk4QJMonluRdUdSdhA0JEwVZXRFcNzI
Xyhp3yBcUFtoqyEK4eMjh28uGQ3CHT1b8xvh2/GrgVJb3GwHIeB5n7nTfkF8
D89SMtljEGrqfJyn+LfhZ7VKrj2M/8c3d4bxveHHtwxErhPKGoR7f48ufJ7h
w6vP2ETFPBgE55vb8gukNuE2K0q/ZxoG4TxzVOX42Y34chpnuEPfIJiaFlVg
DG48W36U3fN6EGZDIjk67TbgB1prLmh+GoT4mJpQ64X1+IuQ6qfxXBR4breD
l+GzDhc0kGS3bKYA3VmEQ8KIA3fnS9RcFKKA7FnrD3Kuq6h+6HvgXikK3O4x
LFRz/oO4i05XuchTIKTnQoNy5C908vzAt9uqlH+/cMBwW+MKeqSnqzKgTYE9
LCWNH9t+INPBLY91jSnwzvdtcJUwG0ksU7JMLCgQPhpcZtW5iL5I3rp20o4C
nUekHO9eW0BNRieCvF0osLoZOjQc51Gin6hrmBcFfuZoRtYnzSL7myPm1/0p
EClt7NEfM4MUGnMP3AmlQIWW+5vzd7+g3g3Sos8S/uXdxHgUFKZRlsoEV18a
BUqzW9wDsj8iT5uSxaEsCvRdtN72UHYSaUV4jU8V/NtDlCNQtW8CcRXuJS8/
oMDm0v08kbHvEaPvSwt3FQUIt2a2SluNo+LZiscizyhw0D1JM8F3DBliGvE6
ff/6h50CN3mNIkH370HGgxRw0Xc7WZ41jN4nPXW1e00Bsamt//FODaHq6jAL
LxYFpGN2b1GxZqKY1/ux0GkKvF8UlT0wQkeWq78VE+YocJI/nB5xiYZ2ybeL
Zv2gwKZHdVymGlTUHmT4/SkPFRTltsXqdZFQ2l2u9z0CVPiw8jG7unIAOb/o
JTNFqVCT4L5Vvf0VUplObP24iwqZ0clyTnN96A+/admSAhUmq4V5OAx6EVGL
P3uDOhWIXIUZmyq7Ua7jYLywHhU83r6VTtHtQvqPbc5oH6FCt7/CZmrmC7SJ
Inz8sCUVJLkkqzLJ7Whk+TV2wp4K4TsrOY7ltqJHUjlKnq5UsKpWkFtOa0bh
h5zELvpQIYNziXftQSM6cnYnd3wgFXDbH6Xs8QYkmjH+/XY4FSwl6w+l6z9F
DSyPwfrEf1opmXD8UC1K4FZo6yZQwUSMq+XufDU6ofq5jJFNhRmfQqVc3yok
Z1uePXmfCjLzOb23dz5B7IjzCexHVHjN84kg/LcMdReqhXDVUOGi8ktxY87H
6NbLhTNCTVQY9L31K0r5IdIUCUVar6ggJjmudWy8GHEiPeVDVCocpb047e5d
hKjuv8RsR6jA6rlknspbiO4nt3J7vKfCo10820lJ91BgTRQ7+DMV9m7YMeKo
lo8Mhg0mri5Q4VDeqc2xHLlIYI2TcusnFZb/+h5X+5WNKs2ul9fx0oB6sMtm
2TETRQUfvdu1jQZ+An3r5tpvIfMcvut0cRr4mN22VzLIQJIdpJAPMjTQsvMe
jXtHQDPT6W7fFWng2FzuvqCYjlq3WFuu16RBubW4n8urFHRDWwjfrk+D20sL
u5mZyUjparb4vmM0uJCVn6P2OAFlXTbxbrSiwWn9byO6PPGIM3S5HjnQ4B67
/VlY3FXkH1DK2eVKg6rdEhS2WBwa9bG1POJDA6tR1wnmyxhk7La+gBTwzzee
D+6Qjka1jrVfrcNo8NNr1H/+zWWUbLH1unMCDT4t+Oq094ejZZPnjIlUGjQ8
+WPwdSUUuR303+2TSYNpmeVukyMXEVlfKvBbHg0mf/pZJDUEI30tYltQCQ08
zp0npBwMQg9UI/lWymnga+jIsp4ORIIKSg5X6miQNeLzYM00AH0WT2Rf76SB
/oC9SwjZD9lu1zXk76dBSXLGfXOSD3qxeSo9g0oDudRvsb4LXkiFO/Od6AgN
jgjkEvbqeaLsNSPl/HEa2JFXRMTvuSOun4vhuz/RYGwsUZwt64YCFwt7H87R
4GZ8dXxOtys68nHtTO0qDbw9j3ltKnZC9WOVVbrcdIjMhomwkFNIetj5bys/
HRrk29VQgD1KoW42NRSmw669JQluBDu00t+S3SdJh+NxHN/kmLbIo9tvykyO
Dh0qDuWL+jaI0iauRVOmw+Tf6t/ez63Qo+qwwbf6dAjd6iu0Q9cCCZXtkXIz
pIP6D9b2uDFTFFPM9Js+SoeVr3s69OuOopm8a43nrOhgecyk7HuNCbLP2se9
aE8Hry5S7p3Xh1F3+oRNmCsdCHc8oo/KHELqSTcL/3jTgf/IqRjXFEO08fIc
xhP2j08wmhCKABRysSA5JYoOWwhtie5/MDTubz68LYEO8k4vmB1V+sjM54/8
nVQ6ZA3n9MQT9FDjmfJgyUw6KOpK7T+aq4PkHE91FObRwY63V+sjUQsRbHkF
FEro8Ep9b9D53fuQt4l3mUYdHZ70G98r+E8d0QxEVhqa6bC1VuPK+xeqCNfv
OYx10iFt9Ij0kr0yKtsXcqvjFR2EbXv8LskoIhFV2ffGVDqEc/uptogooLg9
tP+Iw3TYyPnltLm2PJrdFXvZapwOh8nXxLkiZFGvIEvUaY4O/ooXTjn4SSPN
zWme75fpMOuhZhkhsxMVbEB1Xqt0eP5I1J9QugNtWvvKMbOBAdMRNN9HTuIo
dCXH4gI/A+qtVAteGoqiiYWjectCDOgI5LI7ZCuMLL6ufI6UZIA4W1epIXU7
2jNmF5+gzAChLdYbVc5tRYxDajKV+xgwW0pfuzTGj2LLedqYBxjwYlTzCVmB
D/0nOG7/14gB81nzvLcqN6K34Y1sOTMGLLvak6LOc6NkFoFgZsuAvzFNqc2n
uZCusa9KiBMDDIoE7w3FcKLJioMvcz0YwBFT8KiTyIEytkt4dJ1jwOFbk703
olcxg4jFtS8hDGjub/8yV/Eb+zbenyt4hQE6d4MaQ3b8xHJMinX14xmQJ/K3
1aNnGTtSGUk/k8qAYGPP2YRSNrYsZBuQlMmAT5HfvISeLWLFkSp8NfkMcLE0
WqxcmscsJ7geDpcyQGBiqbG6eRZbPfLOkKOSASfinkwzGF+xiqqnYwoNDLgn
uuSya99nzEEkLeJ4OwPc9b3ehg9OYdxXvETCehnws/ZDnFXJJFb/Aa8tIDPA
ynJdcGbFBOZ2TNSid4gB6c9SrYo+jGMCNXOfv40xIDZt0ToyeQxrFX0ZLzzN
ANrZa2piuW8wv6j7MmiOAZpbO9wEF4exHlMrh5Q1Bkjb26jynmJg0uKcN98I
MCEki4eRnUnBIqdqXypJM2HowGu7fWv92FCdO0eEOhN+3tj6K3qxB7smgeUV
6jHhw9ebG7L6ujCNWCG9VwZMuH+irFic1oGlWPQEiFkx4fIvwayy6VZM/2k+
n4EDE6C+W7uZqxmb3hH60PsME4rZ+SGtvs8ww897WA0XmMDp7Xx/br4Wmz++
FjF2iQlpRQcOW/LUYPkNr0W445jwaVysiZxbia1cTbQ4kcEEScu/L4/XPcIq
d35p+17LhDeKXHES3Pcxp/hOhx0tTCgsGhbd2JaH8c7kLBl2McE28c4lja67
mEeTqWoGnQmtijxhtMrbmITtkzx1NhPInHbynmnJWHxSYOR57SH4vuq0UJZ0
ESN3aodtQkMwHj/0wMwxGBP78yvo4aEhoEpdbJbyuIBV+Mf7vbcZAj2PHPNt
/Ocwhk2Ow4mgIeh5Dwv7Vd0wuZ3duqhqCH4HdNzh2GaBddWKsjcrvob+22Ne
6aay2Lq37ecqJIfBk/honSbnywM8W0r2nfw1AgSb0oWrpcv6gYTJa5kcb8HM
dJ2jQixl/48mB6ry5DugBjz8qVRupJc8TJDJnXkHlk0kotiKvt7OH30XNi29
g/D0+sxdZzX1DmnpCH7eMAZ7gls8xX9J6xEqBW0eKIzBuxj5IK+zv3WVigcY
0mfHIDjwyeMerwpdlxQ0LLw4Bhp9IqKnryzoLJSF7I3/NQa8SWeFK1I/6Fx7
VR7O5mRBDaXpfHY+U6ecW0Kcvp0FGU3Bp/GIJp2VmGUHgjYL1EMox99sjNLJ
uFj1ZtMlFlgf3PGRS3ZBW/72lHJELAt2lnaffXD5rXZjrdTlz0ksOJ3RjId8
6NVmzd2QfJnDAjWj9WYRJjnaKn4+zvGtLFD16ZfwtNLUfp547wm7mwW66enQ
lb1d2/rh0F93EgtucTkOJpIXtcInDxUYjrHgpnGFZ+dUqRbf+suzNVMseBCd
Mtt2PUyrQKYOl5ljwYJIQcT6TgMtTYMvaYQfLJBfnSyaV17a1+Miw1pb+8eX
WX+/6l6v+T/PVLQ1
        "]]}, 
      {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwUl3c8V/8XxxFSskcSCqHQMFLk3vdHZiWZ1VdEEpJEhCgrIntnhWQlSfY+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        "]]}}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[Opacity[-2.506]], {{}, 
       {RGBColor[0., 0., 0.30000000000000004`], Opacity[0.5], EdgeForm[
        Opacity[-2.506]], 
        RectangleBox[{-0.74, 0.}, 
         NCache[{-0.738, Rational[1, 200]}, {-0.738, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.738, 0.}, {-0.736, 0},
         RoundingRadius->0], RectangleBox[{-0.736, 0.}, {-0.734, 0},
         RoundingRadius->0], RectangleBox[{-0.734, 0.}, {-0.732, 0},
         RoundingRadius->0], RectangleBox[{-0.732, 0.}, {-0.73, 0},
         RoundingRadius->0], RectangleBox[{-0.73, 0.}, {-0.728, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.728, 0.}, 
         NCache[{-0.726, Rational[1, 200]}, {-0.726, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.726, 0.}, {-0.724, 0},
         RoundingRadius->0], RectangleBox[{-0.724, 0.}, {-0.722, 0},
         RoundingRadius->0], RectangleBox[{-0.722, 0.}, {-0.72, 0},
         RoundingRadius->0], RectangleBox[{-0.72, 0.}, {-0.718, 0},
         RoundingRadius->0], RectangleBox[{-0.718, 0.}, {-0.716, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.716, 0.}, 
         NCache[{-0.714, Rational[1, 200]}, {-0.714, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.714, 0.}, {-0.712, 0},
         RoundingRadius->0], RectangleBox[{-0.712, 0.}, {-0.71, 0},
         RoundingRadius->0], RectangleBox[{-0.71, 0.}, {-0.708, 0},
         RoundingRadius->0], RectangleBox[{-0.708, 0.}, {-0.706, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.706, 0.}, 
         NCache[{-0.704, Rational[1, 200]}, {-0.704, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.704, 0.}, 
         NCache[{-0.702, Rational[1, 100]}, {-0.702, 0.01}],
         RoundingRadius->0], RectangleBox[{-0.702, 0.}, {-0.7, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.7, 0.}, 
         NCache[{-0.698, Rational[1, 200]}, {-0.698, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.698, 0.}, {-0.696, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.696, 0.}, 
         NCache[{-0.694, Rational[1, 200]}, {-0.694, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.694, 0.}, {-0.692, 0},
         RoundingRadius->0], RectangleBox[{-0.692, 0.}, {-0.69, 0},
         RoundingRadius->0], RectangleBox[{-0.69, 0.}, {-0.688, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.688, 0.}, 
         NCache[{-0.686, Rational[1, 200]}, {-0.686, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.686, 0.}, 
         NCache[{-0.684, Rational[1, 200]}, {-0.684, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.684, 0.}, {-0.682, 0},
         RoundingRadius->0], RectangleBox[{-0.682, 0.}, {-0.68, 0},
         RoundingRadius->0], RectangleBox[{-0.68, 0.}, {-0.678, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.678, 0.}, 
         NCache[{-0.676, Rational[1, 200]}, {-0.676, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.676, 0.}, 
         NCache[{-0.674, Rational[1, 200]}, {-0.674, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.674, 0.}, 
         NCache[{-0.672, Rational[1, 200]}, {-0.672, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.672, 0.}, {-0.67, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.67, 0.}, 
         NCache[{-0.668, Rational[1, 100]}, {-0.668, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.668, 0.}, 
         NCache[{-0.666, Rational[1, 200]}, {-0.666, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.666, 0.}, {-0.664, 0},
         RoundingRadius->0], RectangleBox[{-0.664, 0.}, {-0.662, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.662, 0.}, 
         NCache[{-0.66, Rational[1, 200]}, {-0.66, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.66, 0.}, 
         NCache[{-0.658, Rational[1, 100]}, {-0.658, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.658, 0.}, 
         NCache[{-0.656, Rational[3, 200]}, {-0.656, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.656, 0.}, 
         NCache[{-0.654, Rational[1, 200]}, {-0.654, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.654, 0.}, 
         NCache[{-0.652, Rational[1, 200]}, {-0.652, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.652, 0.}, {-0.65, 0},
         RoundingRadius->0], RectangleBox[{-0.65, 0.}, {-0.648, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.648, 0.}, 
         NCache[{-0.646, Rational[1, 50]}, {-0.646, 0.02}],
         RoundingRadius->0], 
        RectangleBox[{-0.646, 0.}, 
         NCache[{-0.644, Rational[1, 200]}, {-0.644, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.644, 0.}, 
         NCache[{-0.642, Rational[7, 200]}, {-0.642, 0.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.642, 0.}, 
         NCache[{-0.64, Rational[1, 50]}, {-0.64, 0.02}],
         RoundingRadius->0], 
        RectangleBox[{-0.64, 0.}, 
         NCache[{-0.638, Rational[1, 200]}, {-0.638, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.638, 0.}, 
         NCache[{-0.636, Rational[1, 200]}, {-0.636, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.636, 0.}, 
         NCache[{-0.634, Rational[1, 100]}, {-0.634, 0.01}],
         RoundingRadius->0], RectangleBox[{-0.634, 0.}, {-0.632, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.632, 0.}, 
         NCache[{-0.63, Rational[1, 40]}, {-0.63, 0.025}],
         RoundingRadius->0], 
        RectangleBox[{-0.63, 0.}, 
         NCache[{-0.628, Rational[1, 50]}, {-0.628, 0.02}],
         RoundingRadius->0], 
        RectangleBox[{-0.628, 0.}, 
         NCache[{-0.626, Rational[1, 40]}, {-0.626, 0.025}],
         RoundingRadius->0], 
        RectangleBox[{-0.626, 0.}, 
         NCache[{-0.624, Rational[7, 200]}, {-0.624, 0.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.624, 0.}, 
         NCache[{-0.622, Rational[1, 200]}, {-0.622, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.622, 0.}, 
         NCache[{-0.62, Rational[1, 50]}, {-0.62, 0.02}],
         RoundingRadius->0], 
        RectangleBox[{-0.62, 0.}, 
         NCache[{-0.618, Rational[3, 200]}, {-0.618, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.618, 0.}, 
         NCache[{-0.616, Rational[3, 200]}, {-0.616, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.616, 0.}, 
         NCache[{-0.614, Rational[1, 40]}, {-0.614, 0.025}],
         RoundingRadius->0], 
        RectangleBox[{-0.614, 0.}, 
         NCache[{-0.612, Rational[1, 25]}, {-0.612, 0.04}],
         RoundingRadius->0], 
        RectangleBox[{-0.612, 0.}, 
         NCache[{-0.61, Rational[3, 100]}, {-0.61, 0.03}],
         RoundingRadius->0], 
        RectangleBox[{-0.61, 0.}, 
         NCache[{-0.608, Rational[7, 200]}, {-0.608, 0.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.608, 0.}, 
         NCache[{-0.606, Rational[7, 200]}, {-0.606, 0.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.606, 0.}, 
         NCache[{-0.604, Rational[3, 50]}, {-0.604, 0.06}],
         RoundingRadius->0], 
        RectangleBox[{-0.604, 0.}, 
         NCache[{-0.602, Rational[7, 200]}, {-0.602, 0.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.602, 0.}, 
         NCache[{-0.6, Rational[1, 50]}, {-0.6, 0.02}],
         RoundingRadius->0], 
        RectangleBox[{-0.6, 0.}, 
         NCache[{-0.598, Rational[1, 25]}, {-0.598, 0.04}],
         RoundingRadius->0], 
        RectangleBox[{-0.598, 0.}, 
         NCache[{-0.596, Rational[1, 25]}, {-0.596, 0.04}],
         RoundingRadius->0], 
        RectangleBox[{-0.596, 0.}, 
         NCache[{-0.594, Rational[1, 25]}, {-0.594, 0.04}],
         RoundingRadius->0], 
        RectangleBox[{-0.594, 0.}, 
         NCache[{-0.592, Rational[11, 200]}, {-0.592, 0.055}],
         RoundingRadius->0], 
        RectangleBox[{-0.592, 0.}, 
         NCache[{-0.59, Rational[1, 10]}, {-0.59, 0.1}],
         RoundingRadius->0], 
        RectangleBox[{-0.59, 0.}, 
         NCache[{-0.588, Rational[1, 20]}, {-0.588, 0.05}],
         RoundingRadius->0], 
        RectangleBox[{-0.588, 0.}, 
         NCache[{-0.586, Rational[3, 40]}, {-0.586, 0.075}],
         RoundingRadius->0], 
        RectangleBox[{-0.586, 0.}, 
         NCache[{-0.584, Rational[3, 40]}, {-0.584, 0.075}],
         RoundingRadius->0], 
        RectangleBox[{-0.584, 0.}, 
         NCache[{-0.582, Rational[11, 200]}, {-0.582, 0.055}],
         RoundingRadius->0], 
        RectangleBox[{-0.582, 0.}, 
         NCache[{-0.58, Rational[13, 200]}, {-0.58, 0.065}],
         RoundingRadius->0], 
        RectangleBox[{-0.58, 0.}, 
         NCache[{-0.578, Rational[17, 200]}, {-0.578, 0.085}],
         RoundingRadius->0], 
        RectangleBox[{-0.578, 0.}, 
         NCache[{-0.576, Rational[7, 50]}, {-0.576, 0.14}],
         RoundingRadius->0], 
        RectangleBox[{-0.576, 0.}, 
         NCache[{-0.574, Rational[9, 100]}, {-0.574, 0.09}],
         RoundingRadius->0], 
        RectangleBox[{-0.574, 0.}, 
         NCache[{-0.572, Rational[23, 200]}, {-0.572, 0.115}],
         RoundingRadius->0], 
        RectangleBox[{-0.572, 0.}, 
         NCache[{-0.57, Rational[11, 200]}, {-0.57, 0.055}],
         RoundingRadius->0], 
        RectangleBox[{-0.57, 0.}, 
         NCache[{-0.568, Rational[1, 10]}, {-0.568, 0.1}],
         RoundingRadius->0], 
        RectangleBox[{-0.568, 0.}, 
         NCache[{-0.566, Rational[27, 200]}, {-0.566, 0.135}],
         RoundingRadius->0], 
        RectangleBox[{-0.566, 0.}, 
         NCache[{-0.564, Rational[1, 10]}, {-0.564, 0.1}],
         RoundingRadius->0], 
        RectangleBox[{-0.564, 0.}, 
         NCache[{-0.562, Rational[23, 200]}, {-0.562, 0.115}],
         RoundingRadius->0], 
        RectangleBox[{-0.562, 0.}, 
         NCache[{-0.56, Rational[29, 200]}, {-0.56, 0.145}],
         RoundingRadius->0], 
        RectangleBox[{-0.56, 0.}, 
         NCache[{-0.558, Rational[11, 100]}, {-0.558, 0.11}],
         RoundingRadius->0], 
        RectangleBox[{-0.558, 0.}, 
         NCache[{-0.556, Rational[39, 200]}, {-0.556, 0.195}],
         RoundingRadius->0], 
        RectangleBox[{-0.556, 0.}, 
         NCache[{-0.554, Rational[23, 200]}, {-0.554, 0.115}],
         RoundingRadius->0], 
        RectangleBox[{-0.554, 0.}, 
         NCache[{-0.552, Rational[13, 100]}, {-0.552, 0.13}],
         RoundingRadius->0], 
        RectangleBox[{-0.552, 0.}, 
         NCache[{-0.55, Rational[4, 25]}, {-0.55, 0.16}],
         RoundingRadius->0], 
        RectangleBox[{-0.55, 0.}, 
         NCache[{-0.548, Rational[31, 200]}, {-0.548, 0.155}],
         RoundingRadius->0], 
        RectangleBox[{-0.548, 0.}, 
         NCache[{-0.546, Rational[33, 200]}, {-0.546, 0.165}],
         RoundingRadius->0], 
        RectangleBox[{-0.546, 0.}, 
         NCache[{-0.544, Rational[11, 50]}, {-0.544, 0.22}],
         RoundingRadius->0], 
        RectangleBox[{-0.544, 0.}, 
         NCache[{-0.542, Rational[1, 4]}, {-0.542, 0.25}],
         RoundingRadius->0], 
        RectangleBox[{-0.542, 0.}, 
         NCache[{-0.54, Rational[47, 200]}, {-0.54, 0.235}],
         RoundingRadius->0], 
        RectangleBox[{-0.54, 0.}, 
         NCache[{-0.538, Rational[21, 100]}, {-0.538, 0.21}],
         RoundingRadius->0], 
        RectangleBox[{-0.538, 0.}, 
         NCache[{-0.536, Rational[11, 50]}, {-0.536, 0.22}],
         RoundingRadius->0], 
        RectangleBox[{-0.536, 0.}, 
         NCache[{-0.534, Rational[1, 4]}, {-0.534, 0.25}],
         RoundingRadius->0], 
        RectangleBox[{-0.534, 0.}, 
         NCache[{-0.532, Rational[57, 200]}, {-0.532, 0.285}],
         RoundingRadius->0], 
        RectangleBox[{-0.532, 0.}, 
         NCache[{-0.53, Rational[3, 10]}, {-0.53, 0.3}],
         RoundingRadius->0], 
        RectangleBox[{-0.53, 0.}, 
         NCache[{-0.528, Rational[27, 100]}, {-0.528, 0.27}],
         RoundingRadius->0], 
        RectangleBox[{-0.528, 0.}, 
         NCache[{-0.526, Rational[7, 25]}, {-0.526, 0.28}],
         RoundingRadius->0], 
        RectangleBox[{-0.526, 0.}, 
         NCache[{-0.524, Rational[27, 100]}, {-0.524, 0.27}],
         RoundingRadius->0], 
        RectangleBox[{-0.524, 0.}, 
         NCache[{-0.522, Rational[73, 200]}, {-0.522, 0.365}],
         RoundingRadius->0], 
        RectangleBox[{-0.522, 0.}, 
         NCache[{-0.52, Rational[33, 100]}, {-0.52, 0.33}],
         RoundingRadius->0], 
        RectangleBox[{-0.52, 0.}, 
         NCache[{-0.518, Rational[57, 200]}, {-0.518, 0.285}],
         RoundingRadius->0], 
        RectangleBox[{-0.518, 0.}, 
         NCache[{-0.516, Rational[69, 200]}, {-0.516, 0.345}],
         RoundingRadius->0], 
        RectangleBox[{-0.516, 0.}, 
         NCache[{-0.514, Rational[77, 200]}, {-0.514, 0.385}],
         RoundingRadius->0], 
        RectangleBox[{-0.514, 0.}, 
         NCache[{-0.512, Rational[71, 200]}, {-0.512, 0.355}],
         RoundingRadius->0], 
        RectangleBox[{-0.512, 0.}, 
         NCache[{-0.51, Rational[9, 25]}, {-0.51, 0.36}],
         RoundingRadius->0], 
        RectangleBox[{-0.51, 0.}, 
         NCache[{-0.508, Rational[3, 8]}, {-0.508, 0.375}],
         RoundingRadius->0], 
        RectangleBox[{-0.508, 0.}, 
         NCache[{-0.506, Rational[87, 200]}, {-0.506, 0.435}],
         RoundingRadius->0], 
        RectangleBox[{-0.506, 0.}, 
         NCache[{-0.504, Rational[93, 200]}, {-0.504, 0.465}],
         RoundingRadius->0], 
        RectangleBox[{-0.504, 0.}, 
         NCache[{-0.502, Rational[107, 200]}, {-0.502, 0.535}],
         RoundingRadius->0], 
        RectangleBox[{-0.502, 0.}, 
         NCache[{-0.5, Rational[12, 25]}, {-0.5, 0.48}],
         RoundingRadius->0], 
        RectangleBox[{-0.5, 0.}, 
         NCache[{-0.498, Rational[109, 200]}, {-0.498, 0.545}],
         RoundingRadius->0], 
        RectangleBox[{-0.498, 0.}, 
         NCache[{-0.496, Rational[11, 20]}, {-0.496, 0.55}],
         RoundingRadius->0], 
        RectangleBox[{-0.496, 0.}, 
         NCache[{-0.494, Rational[131, 200]}, {-0.494, 0.655}],
         RoundingRadius->0], 
        RectangleBox[{-0.494, 0.}, 
         NCache[{-0.492, Rational[121, 200]}, {-0.492, 0.605}],
         RoundingRadius->0], 
        RectangleBox[{-0.492, 0.}, 
         NCache[{-0.49, Rational[23, 40]}, {-0.49, 0.575}],
         RoundingRadius->0], 
        RectangleBox[{-0.49, 0.}, 
         NCache[{-0.488, Rational[69, 100]}, {-0.488, 0.69}],
         RoundingRadius->0], 
        RectangleBox[{-0.488, 0.}, 
         NCache[{-0.486, Rational[29, 40]}, {-0.486, 0.725}],
         RoundingRadius->0], 
        RectangleBox[{-0.486, 0.}, 
         NCache[{-0.484, Rational[5, 8]}, {-0.484, 0.625}],
         RoundingRadius->0], 
        RectangleBox[{-0.484, 0.}, 
         NCache[{-0.482, Rational[13, 20]}, {-0.482, 0.65}],
         RoundingRadius->0], 
        RectangleBox[{-0.482, 0.}, 
         NCache[{-0.48, Rational[22, 25]}, {-0.48, 0.88}],
         RoundingRadius->0], 
        RectangleBox[{-0.48, 0.}, 
         NCache[{-0.478, Rational[149, 200]}, {-0.478, 0.745}],
         RoundingRadius->0], 
        RectangleBox[{-0.478, 0.}, 
         NCache[{-0.476, Rational[17, 20]}, {-0.476, 0.85}],
         RoundingRadius->0], 
        RectangleBox[{-0.476, 0.}, 
         NCache[{-0.474, Rational[193, 200]}, {-0.474, 0.965}],
         RoundingRadius->0], 
        RectangleBox[{-0.474, 0.}, 
         NCache[{-0.472, Rational[183, 200]}, {-0.472, 0.915}],
         RoundingRadius->0], 
        RectangleBox[{-0.472, 0.}, 
         NCache[{-0.47, Rational[81, 100]}, {-0.47, 0.81}],
         RoundingRadius->0], 
        RectangleBox[{-0.47, 0.}, 
         NCache[{-0.468, Rational[189, 200]}, {-0.468, 0.945}],
         RoundingRadius->0], 
        RectangleBox[{-0.468, 0.}, 
         NCache[{-0.466, Rational[203, 200]}, {-0.466, 1.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.466, 0.}, 
         NCache[{-0.464, Rational[181, 200]}, {-0.464, 0.905}],
         RoundingRadius->0], 
        RectangleBox[{-0.464, 0.}, 
         NCache[{-0.462, Rational[203, 200]}, {-0.462, 1.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.462, 0.}, 
         NCache[{-0.46, Rational[11, 10]}, {-0.46, 1.1}],
         RoundingRadius->0], 
        RectangleBox[{-0.46, 0.}, 
         NCache[{-0.458, Rational[223, 200]}, {-0.458, 1.115}],
         RoundingRadius->0], 
        RectangleBox[{-0.458, 0.}, 
         NCache[{-0.456, Rational[57, 50]}, {-0.456, 1.14}],
         RoundingRadius->0], 
        RectangleBox[{-0.456, 0.}, 
         NCache[{-0.454, Rational[57, 40]}, {-0.454, 1.425}],
         RoundingRadius->0], 
        RectangleBox[{-0.454, 0.}, 
         NCache[{-0.452, Rational[271, 200]}, {-0.452, 1.355}],
         RoundingRadius->0], 
        RectangleBox[{-0.452, 0.}, 
         NCache[{-0.45, Rational[123, 100]}, {-0.45, 1.23}],
         RoundingRadius->0], 
        RectangleBox[{-0.45, 0.}, 
         NCache[{-0.448, Rational[281, 200]}, {-0.448, 1.405}],
         RoundingRadius->0], 
        RectangleBox[{-0.448, 0.}, 
         NCache[{-0.446, Rational[13, 10]}, {-0.446, 1.3}],
         RoundingRadius->0], 
        RectangleBox[{-0.446, 0.}, 
         NCache[{-0.444, Rational[57, 40]}, {-0.444, 1.425}],
         RoundingRadius->0], 
        RectangleBox[{-0.444, 0.}, 
         NCache[{-0.442, Rational[151, 100]}, {-0.442, 1.51}],
         RoundingRadius->0], 
        RectangleBox[{-0.442, 0.}, 
         NCache[{-0.44, Rational[279, 200]}, {-0.44, 1.395}],
         RoundingRadius->0], 
        RectangleBox[{-0.44, 0.}, 
         NCache[{-0.438, Rational[271, 200]}, {-0.438, 1.355}],
         RoundingRadius->0], 
        RectangleBox[{-0.438, 0.}, 
         NCache[{-0.436, Rational[167, 100]}, {-0.436, 1.67}],
         RoundingRadius->0], 
        RectangleBox[{-0.436, 0.}, 
         NCache[{-0.434, Rational[41, 25]}, {-0.434, 1.64}],
         RoundingRadius->0], 
        RectangleBox[{-0.434, 0.}, 
         NCache[{-0.432, Rational[293, 200]}, {-0.432, 1.465}],
         RoundingRadius->0], 
        RectangleBox[{-0.432, 0.}, 
         NCache[{-0.43, Rational[161, 100]}, {-0.43, 1.61}],
         RoundingRadius->0], 
        RectangleBox[{-0.43, 0.}, 
         NCache[{-0.428, Rational[379, 200]}, {-0.428, 1.895}],
         RoundingRadius->0], 
        RectangleBox[{-0.428, 0.}, 
         NCache[{-0.426, Rational[341, 200]}, {-0.426, 1.705}],
         RoundingRadius->0], 
        RectangleBox[{-0.426, 0.}, 
         NCache[{-0.424, Rational[79, 40]}, {-0.424, 1.975}],
         RoundingRadius->0], 
        RectangleBox[{-0.424, 0.}, 
         NCache[{-0.422, Rational[207, 100]}, {-0.422, 2.07}],
         RoundingRadius->0], 
        RectangleBox[{-0.422, 0.}, 
         NCache[{-0.42, Rational[21, 10]}, {-0.42, 2.1}],
         RoundingRadius->0], 
        RectangleBox[{-0.42, 0.}, 
         NCache[{-0.418, Rational[213, 100]}, {-0.418, 2.13}],
         RoundingRadius->0], 
        RectangleBox[{-0.418, 0.}, 
         NCache[{-0.416, Rational[109, 50]}, {-0.416, 2.18}],
         RoundingRadius->0], 
        RectangleBox[{-0.416, 0.}, 
         NCache[{-0.414, Rational[199, 100]}, {-0.414, 1.99}],
         RoundingRadius->0], 
        RectangleBox[{-0.414, 0.}, 
         NCache[{-0.412, Rational[213, 100]}, {-0.412, 2.13}],
         RoundingRadius->0], 
        RectangleBox[{-0.412, 0.}, 
         NCache[{-0.41, Rational[427, 200]}, {-0.41, 2.135}],
         RoundingRadius->0], 
        RectangleBox[{-0.41, 0.}, 
         NCache[{-0.408, Rational[23, 10]}, {-0.408, 2.3}],
         RoundingRadius->0], 
        RectangleBox[{-0.408, 0.}, 
         NCache[{-0.406, Rational[251, 100]}, {-0.406, 2.51}],
         RoundingRadius->0], 
        RectangleBox[{-0.406, 0.}, 
         NCache[{-0.404, Rational[231, 100]}, {-0.404, 2.31}],
         RoundingRadius->0], 
        RectangleBox[{-0.404, 0.}, 
         NCache[{-0.402, Rational[99, 40]}, {-0.402, 2.475}],
         RoundingRadius->0], 
        RectangleBox[{-0.402, 0.}, 
         NCache[{-0.4, Rational[49, 20]}, {-0.4, 2.45}],
         RoundingRadius->0], 
        RectangleBox[{-0.4, 0.}, 
         NCache[{-0.398, Rational[27, 10]}, {-0.398, 2.7}],
         RoundingRadius->0], 
        RectangleBox[{-0.398, 0.}, 
         NCache[{-0.396, Rational[5, 2]}, {-0.396, 2.5}],
         RoundingRadius->0], 
        RectangleBox[{-0.396, 0.}, 
         NCache[{-0.394, Rational[133, 50]}, {-0.394, 2.66}],
         RoundingRadius->0], 
        RectangleBox[{-0.394, 0.}, 
         NCache[{-0.392, Rational[267, 100]}, {-0.392, 2.67}],
         RoundingRadius->0], 
        RectangleBox[{-0.392, 0.}, 
         NCache[{-0.39, Rational[143, 50]}, {-0.39, 2.86}],
         RoundingRadius->0], 
        RectangleBox[{-0.39, 0.}, 
         NCache[{-0.388, Rational[31, 10]}, {-0.388, 3.1}],
         RoundingRadius->0], 
        RectangleBox[{-0.388, 0.}, 
         NCache[{-0.386, Rational[557, 200]}, {-0.386, 2.785}],
         RoundingRadius->0], 
        RectangleBox[{-0.386, 0.}, 
         NCache[{-0.384, Rational[153, 50]}, {-0.384, 3.06}],
         RoundingRadius->0], 
        RectangleBox[{-0.384, 0.}, 
         NCache[{-0.382, Rational[291, 100]}, {-0.382, 2.91}],
         RoundingRadius->0], 
        RectangleBox[{-0.382, 0.}, 
         NCache[{-0.38, Rational[647, 200]}, {-0.38, 3.235}],
         RoundingRadius->0], 
        RectangleBox[{-0.38, 0.}, 
         NCache[{-0.378, Rational[25, 8]}, {-0.378, 3.125}],
         RoundingRadius->0], 
        RectangleBox[{-0.378, 0.}, 
         NCache[{-0.376, Rational[129, 40]}, {-0.376, 3.225}],
         RoundingRadius->0], 
        RectangleBox[{-0.376, 0.}, 
         NCache[{-0.374, Rational[343, 100]}, {-0.374, 3.43}],
         RoundingRadius->0], 
        RectangleBox[{-0.374, 0.}, 
         NCache[{-0.372, Rational[167, 50]}, {-0.372, 3.34}],
         RoundingRadius->0], 
        RectangleBox[{-0.372, 0.}, 
         NCache[{-0.37, Rational[83, 25]}, {-0.37, 3.32}],
         RoundingRadius->0], 
        RectangleBox[{-0.37, 0.}, 
         NCache[{-0.368, Rational[163, 50]}, {-0.368, 3.26}],
         RoundingRadius->0], 
        RectangleBox[{-0.368, 0.}, 
         NCache[{-0.366, Rational[731, 200]}, {-0.366, 3.655}],
         RoundingRadius->0], 
        RectangleBox[{-0.366, 0.}, 
         NCache[{-0.364, Rational[719, 200]}, {-0.364, 3.595}],
         RoundingRadius->0], 
        RectangleBox[{-0.364, 0.}, 
         NCache[{-0.362, Rational[151, 40]}, {-0.362, 3.775}],
         RoundingRadius->0], 
        RectangleBox[{-0.362, 0.}, 
         NCache[{-0.36, Rational[741, 200]}, {-0.36, 3.705}],
         RoundingRadius->0], 
        RectangleBox[{-0.36, 0.}, 
         NCache[{-0.358, Rational[71, 20]}, {-0.358, 3.55}],
         RoundingRadius->0], 
        RectangleBox[{-0.358, 0.}, 
         NCache[{-0.356, Rational[773, 200]}, {-0.356, 3.865}],
         RoundingRadius->0], 
        RectangleBox[{-0.356, 0.}, 
         NCache[{-0.354, Rational[751, 200]}, {-0.354, 3.755}],
         RoundingRadius->0], 
        RectangleBox[{-0.354, 0.}, 
         NCache[{-0.352, Rational[793, 200]}, {-0.352, 3.965}],
         RoundingRadius->0], 
        RectangleBox[{-0.352, 0.}, 
         NCache[{-0.35, Rational[789, 200]}, {-0.35, 3.945}],
         RoundingRadius->0], 
        RectangleBox[{-0.35, 0.}, 
         NCache[{-0.348, Rational[102, 25]}, {-0.348, 4.08}],
         RoundingRadius->0], 
        RectangleBox[{-0.348, 0.}, 
         NCache[{-0.346, Rational[153, 40]}, {-0.346, 3.825}],
         RoundingRadius->0], 
        RectangleBox[{-0.346, 0.}, 
         NCache[{-0.344, Rational[803, 200]}, {-0.344, 4.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.344, 0.}, 
         NCache[{-0.342, Rational[207, 50]}, {-0.342, 4.14}],
         RoundingRadius->0], 
        RectangleBox[{-0.342, 0.}, 
         NCache[{-0.34, Rational[401, 100]}, {-0.34, 4.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.34, 0.}, 
         NCache[{-0.338, Rational[83, 20]}, {-0.338, 4.15}],
         RoundingRadius->0], 
        RectangleBox[{-0.338, 0.}, 
         NCache[{-0.336, Rational[427, 100]}, {-0.336, 4.27}],
         RoundingRadius->0], 
        RectangleBox[{-0.336, 0.}, 
         NCache[{-0.334, Rational[393, 100]}, {-0.334, 3.93}],
         RoundingRadius->0], 
        RectangleBox[{-0.334, 0.}, 
         NCache[{-0.332, Rational[849, 200]}, {-0.332, 4.245}],
         RoundingRadius->0], 
        RectangleBox[{-0.332, 0.}, 
         NCache[{-0.33, Rational[413, 100]}, {-0.33, 4.13}],
         RoundingRadius->0], RectangleBox[{-0.33, 0.}, {-0.328, 4},
         RoundingRadius->0], 
        RectangleBox[{-0.328, 0.}, 
         NCache[{-0.326, Rational[213, 50]}, {-0.326, 4.26}],
         RoundingRadius->0], 
        RectangleBox[{-0.326, 0.}, 
         NCache[{-0.324, Rational[417, 100]}, {-0.324, 4.17}],
         RoundingRadius->0], 
        RectangleBox[{-0.324, 0.}, 
         NCache[{-0.322, Rational[881, 200]}, {-0.322, 4.405}],
         RoundingRadius->0], 
        RectangleBox[{-0.322, 0.}, 
         NCache[{-0.32, Rational[441, 100]}, {-0.32, 4.41}],
         RoundingRadius->0], 
        RectangleBox[{-0.32, 0.}, 
         NCache[{-0.318, Rational[421, 100]}, {-0.318, 4.21}],
         RoundingRadius->0], 
        RectangleBox[{-0.318, 0.}, 
         NCache[{-0.316, Rational[859, 200]}, {-0.316, 4.295}],
         RoundingRadius->0], 
        RectangleBox[{-0.316, 0.}, 
         NCache[{-0.314, Rational[907, 200]}, {-0.314, 4.535}],
         RoundingRadius->0], 
        RectangleBox[{-0.314, 0.}, 
         NCache[{-0.312, Rational[859, 200]}, {-0.312, 4.295}],
         RoundingRadius->0], 
        RectangleBox[{-0.312, 0.}, 
         NCache[{-0.31, Rational[108, 25]}, {-0.31, 4.32}],
         RoundingRadius->0], 
        RectangleBox[{-0.31, 0.}, 
         NCache[{-0.308, Rational[223, 50]}, {-0.308, 4.46}],
         RoundingRadius->0], 
        RectangleBox[{-0.308, 0.}, 
         NCache[{-0.306, Rational[867, 200]}, {-0.306, 4.335}],
         RoundingRadius->0], 
        RectangleBox[{-0.306, 0.}, 
         NCache[{-0.304, Rational[859, 200]}, {-0.304, 4.295}],
         RoundingRadius->0], 
        RectangleBox[{-0.304, 0.}, 
         NCache[{-0.302, Rational[179, 40]}, {-0.302, 4.475}],
         RoundingRadius->0], 
        RectangleBox[{-0.302, 0.}, 
         NCache[{-0.3, Rational[89, 20]}, {-0.3, 4.45}],
         RoundingRadius->0], 
        RectangleBox[{-0.3, 0.}, 
         NCache[{-0.298, Rational[859, 200]}, {-0.298, 4.295}],
         RoundingRadius->0], 
        RectangleBox[{-0.298, 0.}, 
         NCache[{-0.296, Rational[839, 200]}, {-0.296, 4.195}],
         RoundingRadius->0], 
        RectangleBox[{-0.296, 0.}, 
         NCache[{-0.294, Rational[89, 20]}, {-0.294, 4.45}],
         RoundingRadius->0], 
        RectangleBox[{-0.294, 0.}, 
         NCache[{-0.292, Rational[899, 200]}, {-0.292, 4.495}],
         RoundingRadius->0], 
        RectangleBox[{-0.292, 0.}, 
         NCache[{-0.29, Rational[233, 50]}, {-0.29, 4.66}],
         RoundingRadius->0], 
        RectangleBox[{-0.29, 0.}, 
         NCache[{-0.288, Rational[112, 25]}, {-0.288, 4.48}],
         RoundingRadius->0], 
        RectangleBox[{-0.288, 0.}, 
         NCache[{-0.286, Rational[173, 40]}, {-0.286, 4.325}],
         RoundingRadius->0], 
        RectangleBox[{-0.286, 0.}, 
         NCache[{-0.284, Rational[421, 100]}, {-0.284, 4.21}],
         RoundingRadius->0], 
        RectangleBox[{-0.284, 0.}, 
         NCache[{-0.282, Rational[171, 40]}, {-0.282, 4.275}],
         RoundingRadius->0], 
        RectangleBox[{-0.282, 0.}, 
         NCache[{-0.28, Rational[441, 100]}, {-0.28, 4.41}],
         RoundingRadius->0], 
        RectangleBox[{-0.28, 0.}, 
         NCache[{-0.278, Rational[887, 200]}, {-0.278, 4.435}],
         RoundingRadius->0], 
        RectangleBox[{-0.278, 0.}, 
         NCache[{-0.276, Rational[819, 200]}, {-0.276, 4.095}],
         RoundingRadius->0], 
        RectangleBox[{-0.276, 0.}, 
         NCache[{-0.274, Rational[106, 25]}, {-0.274, 4.24}],
         RoundingRadius->0], 
        RectangleBox[{-0.274, 0.}, 
         NCache[{-0.272, Rational[841, 200]}, {-0.272, 4.205}],
         RoundingRadius->0], 
        RectangleBox[{-0.272, 0.}, 
         NCache[{-0.27, Rational[839, 200]}, {-0.27, 4.195}],
         RoundingRadius->0], 
        RectangleBox[{-0.27, 0.}, 
         NCache[{-0.268, Rational[383, 100]}, {-0.268, 3.83}],
         RoundingRadius->0], 
        RectangleBox[{-0.268, 0.}, 
         NCache[{-0.266, Rational[97, 25]}, {-0.266, 3.88}],
         RoundingRadius->0], 
        RectangleBox[{-0.266, 0.}, 
         NCache[{-0.264, Rational[187, 50]}, {-0.264, 3.74}],
         RoundingRadius->0], 
        RectangleBox[{-0.264, 0.}, 
         NCache[{-0.262, Rational[98, 25]}, {-0.262, 3.92}],
         RoundingRadius->0], 
        RectangleBox[{-0.262, 0.}, 
         NCache[{-0.26, Rational[411, 100]}, {-0.26, 4.11}],
         RoundingRadius->0], 
        RectangleBox[{-0.26, 0.}, 
         NCache[{-0.258, Rational[41, 10]}, {-0.258, 4.1}],
         RoundingRadius->0], 
        RectangleBox[{-0.258, 0.}, 
         NCache[{-0.256, Rational[199, 50]}, {-0.256, 3.98}],
         RoundingRadius->0], 
        RectangleBox[{-0.256, 0.}, 
         NCache[{-0.254, Rational[379, 100]}, {-0.254, 3.79}],
         RoundingRadius->0], 
        RectangleBox[{-0.254, 0.}, 
         NCache[{-0.252, Rational[98, 25]}, {-0.252, 3.92}],
         RoundingRadius->0], 
        RectangleBox[{-0.252, 0.}, 
         NCache[{-0.25, Rational[371, 100]}, {-0.25, 3.71}],
         RoundingRadius->0], 
        RectangleBox[{-0.25, 0.}, 
         NCache[{-0.248, Rational[769, 200]}, {-0.248, 3.845}],
         RoundingRadius->0], 
        RectangleBox[{-0.248, 0.}, 
         NCache[{-0.246, Rational[149, 40]}, {-0.246, 3.725}],
         RoundingRadius->0], 
        RectangleBox[{-0.246, 0.}, 
         NCache[{-0.244, Rational[747, 200]}, {-0.244, 3.735}],
         RoundingRadius->0], 
        RectangleBox[{-0.244, 0.}, 
         NCache[{-0.242, Rational[77, 20]}, {-0.242, 3.85}],
         RoundingRadius->0], 
        RectangleBox[{-0.242, 0.}, 
         NCache[{-0.24, Rational[167, 50]}, {-0.24, 3.34}],
         RoundingRadius->0], 
        RectangleBox[{-0.24, 0.}, 
         NCache[{-0.238, Rational[163, 50]}, {-0.238, 3.26}],
         RoundingRadius->0], 
        RectangleBox[{-0.238, 0.}, 
         NCache[{-0.236, Rational[687, 200]}, {-0.236, 3.435}],
         RoundingRadius->0], 
        RectangleBox[{-0.236, 0.}, 
         NCache[{-0.234, Rational[611, 200]}, {-0.234, 3.055}],
         RoundingRadius->0], 
        RectangleBox[{-0.234, 0.}, 
         NCache[{-0.232, Rational[27, 8]}, {-0.232, 3.375}],
         RoundingRadius->0], 
        RectangleBox[{-0.232, 0.}, 
         NCache[{-0.23, Rational[609, 200]}, {-0.23, 3.045}],
         RoundingRadius->0], 
        RectangleBox[{-0.23, 0.}, 
         NCache[{-0.228, Rational[309, 100]}, {-0.228, 3.09}],
         RoundingRadius->0], 
        RectangleBox[{-0.228, 0.}, 
         NCache[{-0.226, Rational[79, 25]}, {-0.226, 3.16}],
         RoundingRadius->0], 
        RectangleBox[{-0.226, 0.}, 
         NCache[{-0.224, Rational[281, 100]}, {-0.224, 2.81}],
         RoundingRadius->0], 
        RectangleBox[{-0.224, 0.}, 
         NCache[{-0.222, Rational[563, 200]}, {-0.222, 2.815}],
         RoundingRadius->0], 
        RectangleBox[{-0.222, 0.}, 
         NCache[{-0.22, Rational[74, 25]}, {-0.22, 2.96}],
         RoundingRadius->0], 
        RectangleBox[{-0.22, 0.}, 
         NCache[{-0.218, Rational[139, 50]}, {-0.218, 2.78}],
         RoundingRadius->0], 
        RectangleBox[{-0.218, 0.}, 
         NCache[{-0.216, Rational[137, 50]}, {-0.216, 2.74}],
         RoundingRadius->0], 
        RectangleBox[{-0.216, 0.}, 
         NCache[{-0.214, Rational[551, 200]}, {-0.214, 2.755}],
         RoundingRadius->0], 
        RectangleBox[{-0.214, 0.}, 
         NCache[{-0.212, Rational[493, 200]}, {-0.212, 2.465}],
         RoundingRadius->0], 
        RectangleBox[{-0.212, 0.}, 
         NCache[{-0.21, Rational[493, 200]}, {-0.21, 2.465}],
         RoundingRadius->0], 
        RectangleBox[{-0.21, 0.}, 
         NCache[{-0.208, Rational[127, 50]}, {-0.208, 2.54}],
         RoundingRadius->0], 
        RectangleBox[{-0.208, 0.}, 
         NCache[{-0.206, Rational[113, 50]}, {-0.206, 2.26}],
         RoundingRadius->0], 
        RectangleBox[{-0.206, 0.}, 
         NCache[{-0.204, Rational[47, 20]}, {-0.204, 2.35}],
         RoundingRadius->0], 
        RectangleBox[{-0.204, 0.}, 
         NCache[{-0.202, Rational[463, 200]}, {-0.202, 2.315}],
         RoundingRadius->0], 
        RectangleBox[{-0.202, 0.}, 
         NCache[{-0.2, Rational[23, 10]}, {-0.2, 2.3}],
         RoundingRadius->0], 
        RectangleBox[{-0.2, 0.}, 
         NCache[{-0.198, Rational[47, 20]}, {-0.198, 2.35}],
         RoundingRadius->0], 
        RectangleBox[{-0.198, 0.}, 
         NCache[{-0.196, Rational[101, 50]}, {-0.196, 2.02}],
         RoundingRadius->0], 
        RectangleBox[{-0.196, 0.}, 
         NCache[{-0.194, Rational[48, 25]}, {-0.194, 1.92}],
         RoundingRadius->0], 
        RectangleBox[{-0.194, 0.}, 
         NCache[{-0.192, Rational[207, 100]}, {-0.192, 2.07}],
         RoundingRadius->0], 
        RectangleBox[{-0.192, 0.}, 
         NCache[{-0.19, Rational[369, 200]}, {-0.19, 1.845}],
         RoundingRadius->0], 
        RectangleBox[{-0.19, 0.}, 
         NCache[{-0.188, Rational[191, 100]}, {-0.188, 1.91}],
         RoundingRadius->0], 
        RectangleBox[{-0.188, 0.}, 
         NCache[{-0.186, Rational[49, 25]}, {-0.186, 1.96}],
         RoundingRadius->0], 
        RectangleBox[{-0.186, 0.}, 
         NCache[{-0.184, Rational[327, 200]}, {-0.184, 1.635}],
         RoundingRadius->0], 
        RectangleBox[{-0.184, 0.}, 
         NCache[{-0.182, Rational[181, 100]}, {-0.182, 1.81}],
         RoundingRadius->0], 
        RectangleBox[{-0.182, 0.}, 
         NCache[{-0.18, Rational[13, 8]}, {-0.18, 1.625}],
         RoundingRadius->0], 
        RectangleBox[{-0.18, 0.}, 
         NCache[{-0.178, Rational[31, 20]}, {-0.178, 1.55}],
         RoundingRadius->0], 
        RectangleBox[{-0.178, 0.}, 
         NCache[{-0.176, Rational[81, 50]}, {-0.176, 1.62}],
         RoundingRadius->0], 
        RectangleBox[{-0.176, 0.}, 
         NCache[{-0.174, Rational[291, 200]}, {-0.174, 1.455}],
         RoundingRadius->0], 
        RectangleBox[{-0.174, 0.}, 
         NCache[{-0.172, Rational[153, 100]}, {-0.172, 1.53}],
         RoundingRadius->0], 
        RectangleBox[{-0.172, 0.}, 
         NCache[{-0.17, Rational[267, 200]}, {-0.17, 1.335}],
         RoundingRadius->0], 
        RectangleBox[{-0.17, 0.}, 
         NCache[{-0.168, Rational[251, 200]}, {-0.168, 1.255}],
         RoundingRadius->0], 
        RectangleBox[{-0.168, 0.}, 
         NCache[{-0.166, Rational[129, 100]}, {-0.166, 1.29}],
         RoundingRadius->0], 
        RectangleBox[{-0.166, 0.}, 
         NCache[{-0.164, Rational[233, 200]}, {-0.164, 1.165}],
         RoundingRadius->0], 
        RectangleBox[{-0.164, 0.}, 
         NCache[{-0.162, Rational[233, 200]}, {-0.162, 1.165}],
         RoundingRadius->0], 
        RectangleBox[{-0.162, 0.}, 
         NCache[{-0.16, Rational[113, 100]}, {-0.16, 1.13}],
         RoundingRadius->0], 
        RectangleBox[{-0.16, 0.}, 
         NCache[{-0.158, Rational[111, 100]}, {-0.158, 1.11}],
         RoundingRadius->0], 
        RectangleBox[{-0.158, 0.}, 
         NCache[{-0.156, Rational[227, 200]}, {-0.156, 1.135}],
         RoundingRadius->0], 
        RectangleBox[{-0.156, 0.}, 
         NCache[{-0.154, Rational[191, 200]}, {-0.154, 0.955}],
         RoundingRadius->0], 
        RectangleBox[{-0.154, 0.}, 
         NCache[{-0.152, Rational[99, 100]}, {-0.152, 0.99}],
         RoundingRadius->0], 
        RectangleBox[{-0.152, 0.}, 
         NCache[{-0.15, Rational[167, 200]}, {-0.15, 0.835}],
         RoundingRadius->0], 
        RectangleBox[{-0.15, 0.}, 
         NCache[{-0.148, Rational[79, 100]}, {-0.148, 0.79}],
         RoundingRadius->0], 
        RectangleBox[{-0.148, 0.}, 
         NCache[{-0.146, Rational[191, 200]}, {-0.146, 0.955}],
         RoundingRadius->0], 
        RectangleBox[{-0.146, 0.}, 
         NCache[{-0.144, Rational[153, 200]}, {-0.144, 0.765}],
         RoundingRadius->0], 
        RectangleBox[{-0.144, 0.}, 
         NCache[{-0.142, Rational[171, 200]}, {-0.142, 0.855}],
         RoundingRadius->0], 
        RectangleBox[{-0.142, 0.}, 
         NCache[{-0.14, Rational[14, 25]}, {-0.14, 0.56}],
         RoundingRadius->0], 
        RectangleBox[{-0.14, 0.}, 
         NCache[{-0.138, Rational[27, 40]}, {-0.138, 0.675}],
         RoundingRadius->0], 
        RectangleBox[{-0.138, 0.}, 
         NCache[{-0.136, Rational[129, 200]}, {-0.136, 0.645}],
         RoundingRadius->0], 
        RectangleBox[{-0.136, 0.}, 
         NCache[{-0.134, Rational[131, 200]}, {-0.134, 0.655}],
         RoundingRadius->0], 
        RectangleBox[{-0.134, 0.}, 
         NCache[{-0.132, Rational[133, 200]}, {-0.132, 0.665}],
         RoundingRadius->0], 
        RectangleBox[{-0.132, 0.}, 
         NCache[{-0.13, Rational[99, 200]}, {-0.13, 0.495}],
         RoundingRadius->0], 
        RectangleBox[{-0.13, 0.}, 
         NCache[{-0.128, Rational[109, 200]}, {-0.128, 0.545}],
         RoundingRadius->0], 
        RectangleBox[{-0.128, 0.}, 
         NCache[{-0.126, Rational[19, 40]}, {-0.126, 0.475}],
         RoundingRadius->0], 
        RectangleBox[{-0.126, 0.}, 
         NCache[{-0.124, Rational[27, 50]}, {-0.124, 0.54}],
         RoundingRadius->0], 
        RectangleBox[{-0.124, 0.}, 
         NCache[{-0.122, Rational[43, 100]}, {-0.122, 0.43}],
         RoundingRadius->0], 
        RectangleBox[{-0.122, 0.}, 
         NCache[{-0.12, Rational[19, 50]}, {-0.12, 0.38}],
         RoundingRadius->0], 
        RectangleBox[{-0.12, 0.}, 
         NCache[{-0.118, Rational[41, 100]}, {-0.118, 0.41}],
         RoundingRadius->0], 
        RectangleBox[{-0.118, 0.}, 
         NCache[{-0.116, Rational[2, 5]}, {-0.116, 0.4}],
         RoundingRadius->0], 
        RectangleBox[{-0.116, 0.}, 
         NCache[{-0.114, Rational[19, 50]}, {-0.114, 0.38}],
         RoundingRadius->0], 
        RectangleBox[{-0.114, 0.}, 
         NCache[{-0.112, Rational[39, 100]}, {-0.112, 0.39}],
         RoundingRadius->0], 
        RectangleBox[{-0.112, 0.}, 
         NCache[{-0.11, Rational[11, 25]}, {-0.11, 0.44}],
         RoundingRadius->0], 
        RectangleBox[{-0.11, 0.}, 
         NCache[{-0.108, Rational[3, 10]}, {-0.108, 0.3}],
         RoundingRadius->0], 
        RectangleBox[{-0.108, 0.}, 
         NCache[{-0.106, Rational[31, 100]}, {-0.106, 0.31}],
         RoundingRadius->0], 
        RectangleBox[{-0.106, 0.}, 
         NCache[{-0.104, Rational[47, 200]}, {-0.104, 0.235}],
         RoundingRadius->0], 
        RectangleBox[{-0.104, 0.}, 
         NCache[{-0.102, Rational[11, 40]}, {-0.102, 0.275}],
         RoundingRadius->0], 
        RectangleBox[{-0.102, 0.}, 
         NCache[{-0.1, Rational[51, 200]}, {-0.1, 0.255}],
         RoundingRadius->0], 
        RectangleBox[{-0.1, 0.}, 
         NCache[{-0.098, Rational[39, 200]}, {-0.098, 0.195}],
         RoundingRadius->0], 
        RectangleBox[{-0.098, 0.}, 
         NCache[{-0.096, Rational[4, 25]}, {-0.096, 0.16}],
         RoundingRadius->0], 
        RectangleBox[{-0.096, 0.}, 
         NCache[{-0.094, Rational[41, 200]}, {-0.094, 0.205}],
         RoundingRadius->0], 
        RectangleBox[{-0.094, 0.}, 
         NCache[{-0.092, Rational[33, 200]}, {-0.092, 0.165}],
         RoundingRadius->0], 
        RectangleBox[{-0.092, 0.}, 
         NCache[{-0.09, Rational[43, 200]}, {-0.09, 0.215}],
         RoundingRadius->0], 
        RectangleBox[{-0.09, 0.}, 
         NCache[{-0.088, Rational[23, 100]}, {-0.088, 0.23}],
         RoundingRadius->0], 
        RectangleBox[{-0.088, 0.}, 
         NCache[{-0.086, Rational[29, 200]}, {-0.086, 0.145}],
         RoundingRadius->0], 
        RectangleBox[{-0.086, 0.}, 
         NCache[{-0.084, Rational[17, 100]}, {-0.084, 0.17}],
         RoundingRadius->0], 
        RectangleBox[{-0.084, 0.}, 
         NCache[{-0.082, Rational[4, 25]}, {-0.082, 0.16}],
         RoundingRadius->0], 
        RectangleBox[{-0.082, 0.}, 
         NCache[{-0.08, Rational[27, 200]}, {-0.08, 0.135}],
         RoundingRadius->0], 
        RectangleBox[{-0.08, 0.}, 
         NCache[{-0.078, Rational[29, 200]}, {-0.078, 0.145}],
         RoundingRadius->0], 
        RectangleBox[{-0.078, 0.}, 
         NCache[{-0.076, Rational[19, 200]}, {-0.076, 0.095}],
         RoundingRadius->0], 
        RectangleBox[{-0.076, 0.}, 
         NCache[{-0.074, Rational[19, 200]}, {-0.074, 0.095}],
         RoundingRadius->0], 
        RectangleBox[{-0.074, 0.}, 
         NCache[{-0.072, Rational[3, 20]}, {-0.072, 0.15}],
         RoundingRadius->0], 
        RectangleBox[{-0.072, 0.}, 
         NCache[{-0.07, Rational[9, 100]}, {-0.07, 0.09}],
         RoundingRadius->0], 
        RectangleBox[{-0.07, 0.}, 
         NCache[{-0.068, Rational[3, 50]}, {-0.068, 0.06}],
         RoundingRadius->0], 
        RectangleBox[{-0.068, 0.}, 
         NCache[{-0.066, Rational[9, 100]}, {-0.066, 0.09}],
         RoundingRadius->0], 
        RectangleBox[{-0.066, 0.}, 
         NCache[{-0.064, Rational[3, 40]}, {-0.064, 0.075}],
         RoundingRadius->0], 
        RectangleBox[{-0.064, 0.}, 
         NCache[{-0.062, Rational[17, 200]}, {-0.062, 0.085}],
         RoundingRadius->0], 
        RectangleBox[{-0.062, 0.}, 
         NCache[{-0.06, Rational[9, 200]}, {-0.06, 0.045}],
         RoundingRadius->0], 
        RectangleBox[{-0.06, 0.}, 
         NCache[{-0.058, Rational[21, 200]}, {-0.058, 0.105}],
         RoundingRadius->0], 
        RectangleBox[{-0.058, 0.}, 
         NCache[{-0.056, Rational[11, 200]}, {-0.056, 0.055}],
         RoundingRadius->0], 
        RectangleBox[{-0.056, 0.}, 
         NCache[{-0.054, Rational[7, 200]}, {-0.054, 0.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.054, 0.}, 
         NCache[{-0.052, Rational[9, 200]}, {-0.052, 0.045}],
         RoundingRadius->0], 
        RectangleBox[{-0.052, 0.}, 
         NCache[{-0.05, Rational[3, 100]}, {-0.05, 0.03}],
         RoundingRadius->0], 
        RectangleBox[{-0.05, 0.}, 
         NCache[{-0.048, Rational[9, 200]}, {-0.048, 0.045}],
         RoundingRadius->0], 
        RectangleBox[{-0.048, 0.}, 
         NCache[{-0.046, Rational[7, 200]}, {-0.046, 0.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.046, 0.}, 
         NCache[{-0.044, Rational[7, 100]}, {-0.044, 0.07}],
         RoundingRadius->0], 
        RectangleBox[{-0.044, 0.}, 
         NCache[{-0.042, Rational[1, 40]}, {-0.042, 0.025}],
         RoundingRadius->0], 
        RectangleBox[{-0.042, 0.}, 
         NCache[{-0.04, Rational[1, 100]}, {-0.04, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.04, 0.}, 
         NCache[{-0.038, Rational[7, 200]}, {-0.038, 0.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.038, 0.}, 
         NCache[{-0.036, Rational[1, 50]}, {-0.036, 0.02}],
         RoundingRadius->0], 
        RectangleBox[{-0.036, 0.}, 
         NCache[{-0.034, Rational[1, 100]}, {-0.034, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.034, 0.}, 
         NCache[{-0.032, Rational[3, 200]}, {-0.032, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.032, 0.}, 
         NCache[{-0.03, Rational[3, 200]}, {-0.03, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.03, 0.}, 
         NCache[{-0.028, Rational[3, 200]}, {-0.028, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.028, 0.}, 
         NCache[{-0.026, Rational[1, 200]}, {-0.026, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.026, 0.}, 
         NCache[{-0.024, Rational[3, 200]}, {-0.024, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.024, 0.}, 
         NCache[{-0.022, Rational[1, 200]}, {-0.022, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.022, 0.}, {-0.02, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.02, 0.}, 
         NCache[{-0.018, Rational[1, 200]}, {-0.018, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.018, 0.}, 
         NCache[{-0.016, Rational[1, 100]}, {-0.016, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.016, 0.}, 
         NCache[{-0.014, Rational[1, 200]}, {-0.014, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.014, 0.}, {-0.012, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.012, 0.}, 
         NCache[{-0.01, Rational[1, 200]}, {-0.01, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.01, 0.}, 
         NCache[{-0.008, Rational[1, 200]}, {-0.008, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.008, 0.}, 
         NCache[{-0.006, Rational[1, 200]}, {-0.006, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.006, 0.}, 
         NCache[{-0.004, Rational[1, 200]}, {-0.004, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.004, 0.}, 
         NCache[{-0.002, Rational[1, 200]}, {-0.002, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.002, 0.}, {0., 0},
         RoundingRadius->0], RectangleBox[{0., 0.}, {0.002, 0},
         RoundingRadius->0], RectangleBox[{0.002, 0.}, {0.004, 0},
         RoundingRadius->0], RectangleBox[{0.004, 0.}, {0.006, 0},
         RoundingRadius->0], RectangleBox[{0.006, 0.}, {0.008, 0},
         RoundingRadius->0], RectangleBox[{0.008, 0.}, {0.01, 0},
         RoundingRadius->0], RectangleBox[{0.01, 0.}, {0.012, 0},
         RoundingRadius->0], RectangleBox[{0.012, 0.}, {0.014, 0},
         RoundingRadius->0], RectangleBox[{0.014, 0.}, {0.016, 0},
         RoundingRadius->0], RectangleBox[{0.016, 0.}, {0.018, 0},
         RoundingRadius->0], RectangleBox[{0.018, 0.}, {0.02, 0},
         RoundingRadius->0], 
        RectangleBox[{0.02, 0.}, 
         NCache[{0.022, Rational[1, 200]}, {0.022, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{0.022, 0.}, 
         NCache[{0.024, Rational[1, 200]}, {0.024, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{0.024, 0.}, 
         NCache[{0.026, Rational[1, 100]}, {0.026, 0.01}],
         RoundingRadius->0], RectangleBox[{0.026, 0.}, {0.028, 0},
         RoundingRadius->0], RectangleBox[{0.028, 0.}, {0.03, 0},
         RoundingRadius->0], RectangleBox[{0.03, 0.}, {0.032, 0},
         RoundingRadius->0], RectangleBox[{0.032, 0.}, {0.034, 0},
         RoundingRadius->0], RectangleBox[{0.034, 0.}, {0.036, 0},
         RoundingRadius->0], RectangleBox[{0.036, 0.}, {0.038, 0},
         RoundingRadius->0], RectangleBox[{0.038, 0.}, {0.04, 0},
         RoundingRadius->0], RectangleBox[{0.04, 0.}, {0.042, 0},
         RoundingRadius->0], RectangleBox[{0.042, 0.}, {0.044, 0},
         RoundingRadius->0], RectangleBox[{0.044, 0.}, {0.046, 0},
         RoundingRadius->0], RectangleBox[{0.046, 0.}, {0.048, 0},
         RoundingRadius->0], RectangleBox[{0.048, 0.}, {0.05, 0},
         RoundingRadius->0], RectangleBox[{0.05, 0.}, {0.052, 0},
         RoundingRadius->0], RectangleBox[{0.052, 0.}, {0.054, 0},
         RoundingRadius->0], RectangleBox[{0.054, 0.}, {0.056, 0},
         RoundingRadius->0], RectangleBox[{0.056, 0.}, {0.058, 0},
         RoundingRadius->0], RectangleBox[{0.058, 0.}, {0.06, 0},
         RoundingRadius->0], RectangleBox[{0.06, 0.}, {0.062, 0},
         RoundingRadius->0], RectangleBox[{0.062, 0.}, {0.064, 0},
         RoundingRadius->0], RectangleBox[{0.064, 0.}, {0.066, 0},
         RoundingRadius->0], RectangleBox[{0.066, 0.}, {0.068, 0},
         RoundingRadius->0], RectangleBox[{0.068, 0.}, {0.07, 0},
         RoundingRadius->0], RectangleBox[{0.07, 0.}, {0.072, 0},
         RoundingRadius->0], RectangleBox[{0.072, 0.}, {0.074, 0},
         RoundingRadius->0], RectangleBox[{0.074, 0.}, {0.076, 0},
         RoundingRadius->0], RectangleBox[{0.076, 0.}, {0.078, 0},
         RoundingRadius->0], RectangleBox[{0.078, 0.}, {0.08, 0},
         RoundingRadius->0], RectangleBox[{0.08, 0.}, {0.082, 0},
         RoundingRadius->0], RectangleBox[{0.082, 0.}, {0.084, 0},
         RoundingRadius->0], RectangleBox[{0.084, 0.}, {0.086, 0},
         RoundingRadius->0], RectangleBox[{0.086, 0.}, {0.088, 0},
         RoundingRadius->0], RectangleBox[{0.088, 0.}, {0.09, 0},
         RoundingRadius->0], RectangleBox[{0.09, 0.}, {0.092, 0},
         RoundingRadius->0], RectangleBox[{0.092, 0.}, {0.094, 0},
         RoundingRadius->0], RectangleBox[{0.094, 0.}, {0.096, 0},
         RoundingRadius->0], RectangleBox[{0.096, 0.}, {0.098, 0},
         RoundingRadius->0], RectangleBox[{0.098, 0.}, {0.1, 0},
         RoundingRadius->0], RectangleBox[{0.1, 0.}, {0.102, 0},
         RoundingRadius->0], RectangleBox[{0.102, 0.}, {0.104, 0},
         RoundingRadius->0], RectangleBox[{0.104, 0.}, {0.106, 0},
         RoundingRadius->0], RectangleBox[{0.106, 0.}, {0.108, 0},
         RoundingRadius->0], RectangleBox[{0.108, 0.}, {0.11, 0},
         RoundingRadius->0], RectangleBox[{0.11, 0.}, {0.112, 0},
         RoundingRadius->0], RectangleBox[{0.112, 0.}, {0.114, 0},
         RoundingRadius->0], RectangleBox[{0.114, 0.}, {0.116, 0},
         RoundingRadius->0], RectangleBox[{0.116, 0.}, {0.118, 0},
         RoundingRadius->0], RectangleBox[{0.118, 0.}, {0.12, 0},
         RoundingRadius->0], RectangleBox[{0.12, 0.}, {0.122, 0},
         RoundingRadius->0], RectangleBox[{0.122, 0.}, {0.124, 0},
         RoundingRadius->0], RectangleBox[{0.124, 0.}, {0.126, 0},
         RoundingRadius->0], RectangleBox[{0.126, 0.}, {0.128, 0},
         RoundingRadius->0], RectangleBox[{0.128, 0.}, {0.13, 0},
         RoundingRadius->0], RectangleBox[{0.13, 0.}, {0.132, 0},
         RoundingRadius->0], RectangleBox[{0.132, 0.}, {0.134, 0},
         RoundingRadius->0], RectangleBox[{0.134, 0.}, {0.136, 0},
         RoundingRadius->0], RectangleBox[{0.136, 0.}, {0.138, 0},
         RoundingRadius->0], RectangleBox[{0.138, 0.}, {0.14, 0},
         RoundingRadius->0], RectangleBox[{0.14, 0.}, {0.142, 0},
         RoundingRadius->0], RectangleBox[{0.142, 0.}, {0.144, 0},
         RoundingRadius->0], RectangleBox[{0.144, 0.}, {0.146, 0},
         RoundingRadius->0], RectangleBox[{0.146, 0.}, {0.148, 0},
         RoundingRadius->0], RectangleBox[{0.148, 0.}, {0.15, 0},
         RoundingRadius->0], RectangleBox[{0.15, 0.}, {0.152, 0},
         RoundingRadius->0], RectangleBox[{0.152, 0.}, {0.154, 0},
         RoundingRadius->0], RectangleBox[{0.154, 0.}, {0.156, 0},
         RoundingRadius->0], RectangleBox[{0.156, 0.}, {0.158, 0},
         RoundingRadius->0], RectangleBox[{0.158, 0.}, {0.16, 0},
         RoundingRadius->0], RectangleBox[{0.16, 0.}, {0.162, 0},
         RoundingRadius->0], RectangleBox[{0.162, 0.}, {0.164, 0},
         RoundingRadius->0], RectangleBox[{0.164, 0.}, {0.166, 0},
         RoundingRadius->0], RectangleBox[{0.166, 0.}, {0.168, 0},
         RoundingRadius->0], RectangleBox[{0.168, 0.}, {0.17, 0},
         RoundingRadius->0], RectangleBox[{0.17, 0.}, {0.172, 0},
         RoundingRadius->0], RectangleBox[{0.172, 0.}, {0.174, 0},
         RoundingRadius->0], RectangleBox[{0.174, 0.}, {0.176, 0},
         RoundingRadius->0]}, {}, {}}, {{}, 
       {RGBColor[1, 0.6666666666666666, 
         NCache[
          Rational[1, 3], 0.3333333333333333]], Opacity[0.5], EdgeForm[
        Opacity[-2.506]], RectangleBox[{-0.74, 0.}, {-0.738, 0},
         RoundingRadius->0], RectangleBox[{-0.738, 0.}, {-0.736, 0},
         RoundingRadius->0], RectangleBox[{-0.736, 0.}, {-0.734, 0},
         RoundingRadius->0], RectangleBox[{-0.734, 0.}, {-0.732, 0},
         RoundingRadius->0], RectangleBox[{-0.732, 0.}, {-0.73, 0},
         RoundingRadius->0], RectangleBox[{-0.73, 0.}, {-0.728, 0},
         RoundingRadius->0], RectangleBox[{-0.728, 0.}, {-0.726, 0},
         RoundingRadius->0], RectangleBox[{-0.726, 0.}, {-0.724, 0},
         RoundingRadius->0], RectangleBox[{-0.724, 0.}, {-0.722, 0},
         RoundingRadius->0], RectangleBox[{-0.722, 0.}, {-0.72, 0},
         RoundingRadius->0], RectangleBox[{-0.72, 0.}, {-0.718, 0},
         RoundingRadius->0], RectangleBox[{-0.718, 0.}, {-0.716, 0},
         RoundingRadius->0], RectangleBox[{-0.716, 0.}, {-0.714, 0},
         RoundingRadius->0], RectangleBox[{-0.714, 0.}, {-0.712, 0},
         RoundingRadius->0], RectangleBox[{-0.712, 0.}, {-0.71, 0},
         RoundingRadius->0], RectangleBox[{-0.71, 0.}, {-0.708, 0},
         RoundingRadius->0], RectangleBox[{-0.708, 0.}, {-0.706, 0},
         RoundingRadius->0], RectangleBox[{-0.706, 0.}, {-0.704, 0},
         RoundingRadius->0], RectangleBox[{-0.704, 0.}, {-0.702, 0},
         RoundingRadius->0], RectangleBox[{-0.702, 0.}, {-0.7, 0},
         RoundingRadius->0], RectangleBox[{-0.7, 0.}, {-0.698, 0},
         RoundingRadius->0], RectangleBox[{-0.698, 0.}, {-0.696, 0},
         RoundingRadius->0], RectangleBox[{-0.696, 0.}, {-0.694, 0},
         RoundingRadius->0], RectangleBox[{-0.694, 0.}, {-0.692, 0},
         RoundingRadius->0], RectangleBox[{-0.692, 0.}, {-0.69, 0},
         RoundingRadius->0], RectangleBox[{-0.69, 0.}, {-0.688, 0},
         RoundingRadius->0], RectangleBox[{-0.688, 0.}, {-0.686, 0},
         RoundingRadius->0], RectangleBox[{-0.686, 0.}, {-0.684, 0},
         RoundingRadius->0], RectangleBox[{-0.684, 0.}, {-0.682, 0},
         RoundingRadius->0], RectangleBox[{-0.682, 0.}, {-0.68, 0},
         RoundingRadius->0], RectangleBox[{-0.68, 0.}, {-0.678, 0},
         RoundingRadius->0], RectangleBox[{-0.678, 0.}, {-0.676, 0},
         RoundingRadius->0], RectangleBox[{-0.676, 0.}, {-0.674, 0},
         RoundingRadius->0], RectangleBox[{-0.674, 0.}, {-0.672, 0},
         RoundingRadius->0], RectangleBox[{-0.672, 0.}, {-0.67, 0},
         RoundingRadius->0], RectangleBox[{-0.67, 0.}, {-0.668, 0},
         RoundingRadius->0], RectangleBox[{-0.668, 0.}, {-0.666, 0},
         RoundingRadius->0], RectangleBox[{-0.666, 0.}, {-0.664, 0},
         RoundingRadius->0], RectangleBox[{-0.664, 0.}, {-0.662, 0},
         RoundingRadius->0], RectangleBox[{-0.662, 0.}, {-0.66, 0},
         RoundingRadius->0], RectangleBox[{-0.66, 0.}, {-0.658, 0},
         RoundingRadius->0], RectangleBox[{-0.658, 0.}, {-0.656, 0},
         RoundingRadius->0], RectangleBox[{-0.656, 0.}, {-0.654, 0},
         RoundingRadius->0], RectangleBox[{-0.654, 0.}, {-0.652, 0},
         RoundingRadius->0], RectangleBox[{-0.652, 0.}, {-0.65, 0},
         RoundingRadius->0], RectangleBox[{-0.65, 0.}, {-0.648, 0},
         RoundingRadius->0], RectangleBox[{-0.648, 0.}, {-0.646, 0},
         RoundingRadius->0], RectangleBox[{-0.646, 0.}, {-0.644, 0},
         RoundingRadius->0], RectangleBox[{-0.644, 0.}, {-0.642, 0},
         RoundingRadius->0], RectangleBox[{-0.642, 0.}, {-0.64, 0},
         RoundingRadius->0], RectangleBox[{-0.64, 0.}, {-0.638, 0},
         RoundingRadius->0], RectangleBox[{-0.638, 0.}, {-0.636, 0},
         RoundingRadius->0], RectangleBox[{-0.636, 0.}, {-0.634, 0},
         RoundingRadius->0], RectangleBox[{-0.634, 0.}, {-0.632, 0},
         RoundingRadius->0], RectangleBox[{-0.632, 0.}, {-0.63, 0},
         RoundingRadius->0], RectangleBox[{-0.63, 0.}, {-0.628, 0},
         RoundingRadius->0], RectangleBox[{-0.628, 0.}, {-0.626, 0},
         RoundingRadius->0], RectangleBox[{-0.626, 0.}, {-0.624, 0},
         RoundingRadius->0], RectangleBox[{-0.624, 0.}, {-0.622, 0},
         RoundingRadius->0], RectangleBox[{-0.622, 0.}, {-0.62, 0},
         RoundingRadius->0], RectangleBox[{-0.62, 0.}, {-0.618, 0},
         RoundingRadius->0], RectangleBox[{-0.618, 0.}, {-0.616, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.616, 0.}, 
         NCache[{-0.614, Rational[1, 200]}, {-0.614, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.614, 0.}, {-0.612, 0},
         RoundingRadius->0], RectangleBox[{-0.612, 0.}, {-0.61, 0},
         RoundingRadius->0], RectangleBox[{-0.61, 0.}, {-0.608, 0},
         RoundingRadius->0], RectangleBox[{-0.608, 0.}, {-0.606, 0},
         RoundingRadius->0], RectangleBox[{-0.606, 0.}, {-0.604, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.604, 0.}, 
         NCache[{-0.602, Rational[1, 200]}, {-0.602, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.602, 0.}, {-0.6, 0},
         RoundingRadius->0], RectangleBox[{-0.6, 0.}, {-0.598, 0},
         RoundingRadius->0], RectangleBox[{-0.598, 0.}, {-0.596, 0},
         RoundingRadius->0], RectangleBox[{-0.596, 0.}, {-0.594, 0},
         RoundingRadius->0], RectangleBox[{-0.594, 0.}, {-0.592, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.592, 0.}, 
         NCache[{-0.59, Rational[1, 200]}, {-0.59, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.59, 0.}, {-0.588, 0},
         RoundingRadius->0], RectangleBox[{-0.588, 0.}, {-0.586, 0},
         RoundingRadius->0], RectangleBox[{-0.586, 0.}, {-0.584, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.584, 0.}, 
         NCache[{-0.582, Rational[1, 200]}, {-0.582, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.582, 0.}, {-0.58, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.58, 0.}, 
         NCache[{-0.578, Rational[1, 100]}, {-0.578, 0.01}],
         RoundingRadius->0], RectangleBox[{-0.578, 0.}, {-0.576, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.576, 0.}, 
         NCache[{-0.574, Rational[1, 100]}, {-0.574, 0.01}],
         RoundingRadius->0], RectangleBox[{-0.574, 0.}, {-0.572, 0},
         RoundingRadius->0], RectangleBox[{-0.572, 0.}, {-0.57, 0},
         RoundingRadius->0], RectangleBox[{-0.57, 0.}, {-0.568, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.568, 0.}, 
         NCache[{-0.566, Rational[1, 200]}, {-0.566, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.566, 0.}, {-0.564, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.564, 0.}, 
         NCache[{-0.562, Rational[1, 200]}, {-0.562, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.562, 0.}, {-0.56, 0},
         RoundingRadius->0], RectangleBox[{-0.56, 0.}, {-0.558, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.558, 0.}, 
         NCache[{-0.556, Rational[1, 200]}, {-0.556, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.556, 0.}, 
         NCache[{-0.554, Rational[1, 200]}, {-0.554, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.554, 0.}, {-0.552, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.552, 0.}, 
         NCache[{-0.55, Rational[1, 200]}, {-0.55, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.55, 0.}, {-0.548, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.548, 0.}, 
         NCache[{-0.546, Rational[3, 200]}, {-0.546, 0.015}],
         RoundingRadius->0], RectangleBox[{-0.546, 0.}, {-0.544, 0},
         RoundingRadius->0], RectangleBox[{-0.544, 0.}, {-0.542, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.542, 0.}, 
         NCache[{-0.54, Rational[1, 200]}, {-0.54, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.54, 0.}, 
         NCache[{-0.538, Rational[1, 200]}, {-0.538, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.538, 0.}, 
         NCache[{-0.536, Rational[3, 200]}, {-0.536, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.536, 0.}, 
         NCache[{-0.534, Rational[1, 200]}, {-0.534, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.534, 0.}, 
         NCache[{-0.532, Rational[1, 100]}, {-0.532, 0.01}],
         RoundingRadius->0], RectangleBox[{-0.532, 0.}, {-0.53, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.53, 0.}, 
         NCache[{-0.528, Rational[1, 200]}, {-0.528, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.528, 0.}, 
         NCache[{-0.526, Rational[3, 200]}, {-0.526, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.526, 0.}, 
         NCache[{-0.524, Rational[1, 200]}, {-0.524, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.524, 0.}, 
         NCache[{-0.522, Rational[7, 200]}, {-0.522, 0.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.522, 0.}, 
         NCache[{-0.52, Rational[1, 50]}, {-0.52, 0.02}],
         RoundingRadius->0], 
        RectangleBox[{-0.52, 0.}, 
         NCache[{-0.518, Rational[1, 200]}, {-0.518, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.518, 0.}, 
         NCache[{-0.516, Rational[1, 100]}, {-0.516, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.516, 0.}, 
         NCache[{-0.514, Rational[1, 200]}, {-0.514, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.514, 0.}, 
         NCache[{-0.512, Rational[1, 100]}, {-0.512, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.512, 0.}, 
         NCache[{-0.51, Rational[3, 100]}, {-0.51, 0.03}],
         RoundingRadius->0], 
        RectangleBox[{-0.51, 0.}, 
         NCache[{-0.508, Rational[3, 200]}, {-0.508, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.508, 0.}, 
         NCache[{-0.506, Rational[7, 200]}, {-0.506, 0.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.506, 0.}, 
         NCache[{-0.504, Rational[1, 50]}, {-0.504, 0.02}],
         RoundingRadius->0], 
        RectangleBox[{-0.504, 0.}, 
         NCache[{-0.502, Rational[1, 50]}, {-0.502, 0.02}],
         RoundingRadius->0], 
        RectangleBox[{-0.502, 0.}, 
         NCache[{-0.5, Rational[3, 200]}, {-0.5, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.5, 0.}, 
         NCache[{-0.498, Rational[1, 50]}, {-0.498, 0.02}],
         RoundingRadius->0], 
        RectangleBox[{-0.498, 0.}, 
         NCache[{-0.496, Rational[1, 100]}, {-0.496, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.496, 0.}, 
         NCache[{-0.494, Rational[1, 20]}, {-0.494, 0.05}],
         RoundingRadius->0], 
        RectangleBox[{-0.494, 0.}, 
         NCache[{-0.492, Rational[3, 100]}, {-0.492, 0.03}],
         RoundingRadius->0], 
        RectangleBox[{-0.492, 0.}, 
         NCache[{-0.49, Rational[1, 25]}, {-0.49, 0.04}],
         RoundingRadius->0], 
        RectangleBox[{-0.49, 0.}, 
         NCache[{-0.488, Rational[1, 20]}, {-0.488, 0.05}],
         RoundingRadius->0], 
        RectangleBox[{-0.488, 0.}, 
         NCache[{-0.486, Rational[9, 200]}, {-0.486, 0.045}],
         RoundingRadius->0], 
        RectangleBox[{-0.486, 0.}, 
         NCache[{-0.484, Rational[3, 100]}, {-0.484, 0.03}],
         RoundingRadius->0], 
        RectangleBox[{-0.484, 0.}, 
         NCache[{-0.482, Rational[1, 40]}, {-0.482, 0.025}],
         RoundingRadius->0], 
        RectangleBox[{-0.482, 0.}, 
         NCache[{-0.48, Rational[11, 200]}, {-0.48, 0.055}],
         RoundingRadius->0], 
        RectangleBox[{-0.48, 0.}, 
         NCache[{-0.478, Rational[1, 25]}, {-0.478, 0.04}],
         RoundingRadius->0], 
        RectangleBox[{-0.478, 0.}, 
         NCache[{-0.476, Rational[7, 200]}, {-0.476, 0.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.476, 0.}, 
         NCache[{-0.474, Rational[17, 200]}, {-0.474, 0.085}],
         RoundingRadius->0], 
        RectangleBox[{-0.474, 0.}, 
         NCache[{-0.472, Rational[9, 100]}, {-0.472, 0.09}],
         RoundingRadius->0], 
        RectangleBox[{-0.472, 0.}, 
         NCache[{-0.47, Rational[11, 200]}, {-0.47, 0.055}],
         RoundingRadius->0], 
        RectangleBox[{-0.47, 0.}, 
         NCache[{-0.468, Rational[9, 100]}, {-0.468, 0.09}],
         RoundingRadius->0], 
        RectangleBox[{-0.468, 0.}, 
         NCache[{-0.466, Rational[3, 50]}, {-0.466, 0.06}],
         RoundingRadius->0], 
        RectangleBox[{-0.466, 0.}, 
         NCache[{-0.464, Rational[13, 200]}, {-0.464, 0.065}],
         RoundingRadius->0], 
        RectangleBox[{-0.464, 0.}, 
         NCache[{-0.462, Rational[9, 100]}, {-0.462, 0.09}],
         RoundingRadius->0], 
        RectangleBox[{-0.462, 0.}, 
         NCache[{-0.46, Rational[3, 20]}, {-0.46, 0.15}],
         RoundingRadius->0], 
        RectangleBox[{-0.46, 0.}, 
         NCache[{-0.458, Rational[1, 8]}, {-0.458, 0.125}],
         RoundingRadius->0], 
        RectangleBox[{-0.458, 0.}, 
         NCache[{-0.456, Rational[19, 200]}, {-0.456, 0.095}],
         RoundingRadius->0], 
        RectangleBox[{-0.456, 0.}, 
         NCache[{-0.454, Rational[11, 200]}, {-0.454, 0.055}],
         RoundingRadius->0], 
        RectangleBox[{-0.454, 0.}, 
         NCache[{-0.452, Rational[11, 100]}, {-0.452, 0.11}],
         RoundingRadius->0], 
        RectangleBox[{-0.452, 0.}, 
         NCache[{-0.45, Rational[3, 20]}, {-0.45, 0.15}],
         RoundingRadius->0], 
        RectangleBox[{-0.45, 0.}, 
         NCache[{-0.448, Rational[1, 8]}, {-0.448, 0.125}],
         RoundingRadius->0], 
        RectangleBox[{-0.448, 0.}, 
         NCache[{-0.446, Rational[1, 10]}, {-0.446, 0.1}],
         RoundingRadius->0], 
        RectangleBox[{-0.446, 0.}, 
         NCache[{-0.444, Rational[27, 200]}, {-0.444, 0.135}],
         RoundingRadius->0], 
        RectangleBox[{-0.444, 0.}, 
         NCache[{-0.442, Rational[41, 200]}, {-0.442, 0.205}],
         RoundingRadius->0], 
        RectangleBox[{-0.442, 0.}, 
         NCache[{-0.44, Rational[27, 200]}, {-0.44, 0.135}],
         RoundingRadius->0], 
        RectangleBox[{-0.44, 0.}, 
         NCache[{-0.438, Rational[1, 8]}, {-0.438, 0.125}],
         RoundingRadius->0], 
        RectangleBox[{-0.438, 0.}, 
         NCache[{-0.436, Rational[31, 200]}, {-0.436, 0.155}],
         RoundingRadius->0], 
        RectangleBox[{-0.436, 0.}, 
         NCache[{-0.434, Rational[31, 200]}, {-0.434, 0.155}],
         RoundingRadius->0], 
        RectangleBox[{-0.434, 0.}, 
         NCache[{-0.432, Rational[7, 40]}, {-0.432, 0.175}],
         RoundingRadius->0], 
        RectangleBox[{-0.432, 0.}, 
         NCache[{-0.43, Rational[49, 200]}, {-0.43, 0.245}],
         RoundingRadius->0], 
        RectangleBox[{-0.43, 0.}, 
         NCache[{-0.428, Rational[1, 4]}, {-0.428, 0.25}],
         RoundingRadius->0], 
        RectangleBox[{-0.428, 0.}, 
         NCache[{-0.426, Rational[6, 25]}, {-0.426, 0.24}],
         RoundingRadius->0], 
        RectangleBox[{-0.426, 0.}, 
         NCache[{-0.424, Rational[49, 200]}, {-0.424, 0.245}],
         RoundingRadius->0], 
        RectangleBox[{-0.424, 0.}, 
         NCache[{-0.422, Rational[41, 200]}, {-0.422, 0.205}],
         RoundingRadius->0], 
        RectangleBox[{-0.422, 0.}, 
         NCache[{-0.42, Rational[31, 100]}, {-0.42, 0.31}],
         RoundingRadius->0], 
        RectangleBox[{-0.42, 0.}, 
         NCache[{-0.418, Rational[29, 100]}, {-0.418, 0.29}],
         RoundingRadius->0], 
        RectangleBox[{-0.418, 0.}, 
         NCache[{-0.416, Rational[67, 200]}, {-0.416, 0.335}],
         RoundingRadius->0], 
        RectangleBox[{-0.416, 0.}, 
         NCache[{-0.414, Rational[27, 100]}, {-0.414, 0.27}],
         RoundingRadius->0], 
        RectangleBox[{-0.414, 0.}, 
         NCache[{-0.412, Rational[27, 100]}, {-0.412, 0.27}],
         RoundingRadius->0], 
        RectangleBox[{-0.412, 0.}, 
         NCache[{-0.41, Rational[17, 50]}, {-0.41, 0.34}],
         RoundingRadius->0], 
        RectangleBox[{-0.41, 0.}, 
         NCache[{-0.408, Rational[79, 200]}, {-0.408, 0.395}],
         RoundingRadius->0], 
        RectangleBox[{-0.408, 0.}, 
         NCache[{-0.406, Rational[29, 100]}, {-0.406, 0.29}],
         RoundingRadius->0], 
        RectangleBox[{-0.406, 0.}, 
         NCache[{-0.404, Rational[73, 200]}, {-0.404, 0.365}],
         RoundingRadius->0], 
        RectangleBox[{-0.404, 0.}, 
         NCache[{-0.402, Rational[77, 200]}, {-0.402, 0.385}],
         RoundingRadius->0], 
        RectangleBox[{-0.402, 0.}, 
         NCache[{-0.4, Rational[39, 100]}, {-0.4, 0.39}],
         RoundingRadius->0], 
        RectangleBox[{-0.4, 0.}, 
         NCache[{-0.398, Rational[77, 200]}, {-0.398, 0.385}],
         RoundingRadius->0], 
        RectangleBox[{-0.398, 0.}, 
         NCache[{-0.396, Rational[39, 100]}, {-0.396, 0.39}],
         RoundingRadius->0], 
        RectangleBox[{-0.396, 0.}, 
         NCache[{-0.394, Rational[91, 200]}, {-0.394, 0.455}],
         RoundingRadius->0], 
        RectangleBox[{-0.394, 0.}, 
         NCache[{-0.392, Rational[1, 2]}, {-0.392, 0.5}],
         RoundingRadius->0], 
        RectangleBox[{-0.392, 0.}, 
         NCache[{-0.39, Rational[111, 200]}, {-0.39, 0.555}],
         RoundingRadius->0], 
        RectangleBox[{-0.39, 0.}, 
         NCache[{-0.388, Rational[53, 100]}, {-0.388, 0.53}],
         RoundingRadius->0], 
        RectangleBox[{-0.388, 0.}, 
         NCache[{-0.386, Rational[107, 200]}, {-0.386, 0.535}],
         RoundingRadius->0], 
        RectangleBox[{-0.386, 0.}, 
         NCache[{-0.384, Rational[16, 25]}, {-0.384, 0.64}],
         RoundingRadius->0], 
        RectangleBox[{-0.384, 0.}, 
         NCache[{-0.382, Rational[73, 100]}, {-0.382, 0.73}],
         RoundingRadius->0], 
        RectangleBox[{-0.382, 0.}, 
         NCache[{-0.38, Rational[123, 200]}, {-0.38, 0.615}],
         RoundingRadius->0], 
        RectangleBox[{-0.38, 0.}, 
         NCache[{-0.378, Rational[113, 200]}, {-0.378, 0.565}],
         RoundingRadius->0], 
        RectangleBox[{-0.378, 0.}, 
         NCache[{-0.376, Rational[7, 8]}, {-0.376, 0.875}],
         RoundingRadius->0], 
        RectangleBox[{-0.376, 0.}, 
         NCache[{-0.374, Rational[69, 100]}, {-0.374, 0.69}],
         RoundingRadius->0], 
        RectangleBox[{-0.374, 0.}, 
         NCache[{-0.372, Rational[33, 50]}, {-0.372, 0.66}],
         RoundingRadius->0], 
        RectangleBox[{-0.372, 0.}, 
         NCache[{-0.37, Rational[93, 100]}, {-0.37, 0.93}],
         RoundingRadius->0], 
        RectangleBox[{-0.37, 0.}, 
         NCache[{-0.368, Rational[71, 100]}, {-0.368, 0.71}],
         RoundingRadius->0], 
        RectangleBox[{-0.368, 0.}, 
         NCache[{-0.366, Rational[181, 200]}, {-0.366, 0.905}],
         RoundingRadius->0], 
        RectangleBox[{-0.366, 0.}, 
         NCache[{-0.364, Rational[207, 200]}, {-0.364, 1.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.364, 0.}, 
         NCache[{-0.362, Rational[183, 200]}, {-0.362, 0.915}],
         RoundingRadius->0], 
        RectangleBox[{-0.362, 0.}, 
         NCache[{-0.36, Rational[177, 200]}, {-0.36, 0.885}],
         RoundingRadius->0], 
        RectangleBox[{-0.36, 0.}, 
         NCache[{-0.358, Rational[201, 200]}, {-0.358, 1.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.358, 0.}, 
         NCache[{-0.356, Rational[11, 10]}, {-0.356, 1.1}],
         RoundingRadius->0], 
        RectangleBox[{-0.356, 0.}, 
         NCache[{-0.354, Rational[99, 100]}, {-0.354, 0.99}],
         RoundingRadius->0], 
        RectangleBox[{-0.354, 0.}, 
         NCache[{-0.352, Rational[209, 200]}, {-0.352, 1.045}],
         RoundingRadius->0], 
        RectangleBox[{-0.352, 0.}, 
         NCache[{-0.35, Rational[241, 200]}, {-0.35, 1.205}],
         RoundingRadius->0], 
        RectangleBox[{-0.35, 0.}, 
         NCache[{-0.348, Rational[121, 100]}, {-0.348, 1.21}],
         RoundingRadius->0], 
        RectangleBox[{-0.348, 0.}, 
         NCache[{-0.346, Rational[32, 25]}, {-0.346, 1.28}],
         RoundingRadius->0], 
        RectangleBox[{-0.346, 0.}, 
         NCache[{-0.344, Rational[309, 200]}, {-0.344, 1.545}],
         RoundingRadius->0], 
        RectangleBox[{-0.344, 0.}, 
         NCache[{-0.342, Rational[137, 100]}, {-0.342, 1.37}],
         RoundingRadius->0], 
        RectangleBox[{-0.342, 0.}, 
         NCache[{-0.34, Rational[11, 8]}, {-0.34, 1.375}],
         RoundingRadius->0], 
        RectangleBox[{-0.34, 0.}, 
         NCache[{-0.338, Rational[29, 20]}, {-0.338, 1.45}],
         RoundingRadius->0], 
        RectangleBox[{-0.338, 0.}, 
         NCache[{-0.336, Rational[38, 25]}, {-0.336, 1.52}],
         RoundingRadius->0], 
        RectangleBox[{-0.336, 0.}, 
         NCache[{-0.334, Rational[39, 25]}, {-0.334, 1.56}],
         RoundingRadius->0], 
        RectangleBox[{-0.334, 0.}, 
         NCache[{-0.332, Rational[77, 50]}, {-0.332, 1.54}],
         RoundingRadius->0], 
        RectangleBox[{-0.332, 0.}, 
         NCache[{-0.33, Rational[141, 100]}, {-0.33, 1.41}],
         RoundingRadius->0], 
        RectangleBox[{-0.33, 0.}, 
         NCache[{-0.328, Rational[343, 200]}, {-0.328, 1.715}],
         RoundingRadius->0], 
        RectangleBox[{-0.328, 0.}, 
         NCache[{-0.326, Rational[89, 50]}, {-0.326, 1.78}],
         RoundingRadius->0], 
        RectangleBox[{-0.326, 0.}, 
         NCache[{-0.324, Rational[313, 200]}, {-0.324, 1.565}],
         RoundingRadius->0], 
        RectangleBox[{-0.324, 0.}, 
         NCache[{-0.322, Rational[353, 200]}, {-0.322, 1.765}],
         RoundingRadius->0], RectangleBox[{-0.322, 0.}, {-0.32, 2},
         RoundingRadius->0], 
        RectangleBox[{-0.32, 0.}, 
         NCache[{-0.318, Rational[93, 50]}, {-0.318, 1.86}],
         RoundingRadius->0], 
        RectangleBox[{-0.318, 0.}, 
         NCache[{-0.316, Rational[211, 100]}, {-0.316, 2.11}],
         RoundingRadius->0], 
        RectangleBox[{-0.316, 0.}, 
         NCache[{-0.314, Rational[109, 50]}, {-0.314, 2.18}],
         RoundingRadius->0], 
        RectangleBox[{-0.314, 0.}, 
         NCache[{-0.312, Rational[229, 100]}, {-0.312, 2.29}],
         RoundingRadius->0], 
        RectangleBox[{-0.312, 0.}, 
         NCache[{-0.31, Rational[489, 200]}, {-0.31, 2.445}],
         RoundingRadius->0], 
        RectangleBox[{-0.31, 0.}, 
         NCache[{-0.308, Rational[417, 200]}, {-0.308, 2.085}],
         RoundingRadius->0], 
        RectangleBox[{-0.308, 0.}, 
         NCache[{-0.306, Rational[217, 100]}, {-0.306, 2.17}],
         RoundingRadius->0], 
        RectangleBox[{-0.306, 0.}, 
         NCache[{-0.304, Rational[231, 100]}, {-0.304, 2.31}],
         RoundingRadius->0], 
        RectangleBox[{-0.304, 0.}, 
         NCache[{-0.302, Rational[12, 5]}, {-0.302, 2.4}],
         RoundingRadius->0], 
        RectangleBox[{-0.302, 0.}, 
         NCache[{-0.3, Rational[267, 100]}, {-0.3, 2.67}],
         RoundingRadius->0], 
        RectangleBox[{-0.3, 0.}, 
         NCache[{-0.298, Rational[97, 40]}, {-0.298, 2.425}],
         RoundingRadius->0], 
        RectangleBox[{-0.298, 0.}, 
         NCache[{-0.296, Rational[259, 100]}, {-0.296, 2.59}],
         RoundingRadius->0], 
        RectangleBox[{-0.296, 0.}, 
         NCache[{-0.294, Rational[281, 100]}, {-0.294, 2.81}],
         RoundingRadius->0], 
        RectangleBox[{-0.294, 0.}, 
         NCache[{-0.292, Rational[14, 5]}, {-0.292, 2.8}],
         RoundingRadius->0], 
        RectangleBox[{-0.292, 0.}, 
         NCache[{-0.29, Rational[13, 5]}, {-0.29, 2.6}],
         RoundingRadius->0], 
        RectangleBox[{-0.29, 0.}, 
         NCache[{-0.288, Rational[587, 200]}, {-0.288, 2.935}],
         RoundingRadius->0], 
        RectangleBox[{-0.288, 0.}, 
         NCache[{-0.286, Rational[283, 100]}, {-0.286, 2.83}],
         RoundingRadius->0], 
        RectangleBox[{-0.286, 0.}, 
         NCache[{-0.284, Rational[639, 200]}, {-0.284, 3.195}],
         RoundingRadius->0], 
        RectangleBox[{-0.284, 0.}, 
         NCache[{-0.282, Rational[31, 10]}, {-0.282, 3.1}],
         RoundingRadius->0], 
        RectangleBox[{-0.282, 0.}, 
         NCache[{-0.28, Rational[619, 200]}, {-0.28, 3.095}],
         RoundingRadius->0], 
        RectangleBox[{-0.28, 0.}, 
         NCache[{-0.278, Rational[641, 200]}, {-0.278, 3.205}],
         RoundingRadius->0], 
        RectangleBox[{-0.278, 0.}, 
         NCache[{-0.276, Rational[663, 200]}, {-0.276, 3.315}],
         RoundingRadius->0], 
        RectangleBox[{-0.276, 0.}, 
         NCache[{-0.274, Rational[341, 100]}, {-0.274, 3.41}],
         RoundingRadius->0], 
        RectangleBox[{-0.274, 0.}, 
         NCache[{-0.272, Rational[333, 100]}, {-0.272, 3.33}],
         RoundingRadius->0], 
        RectangleBox[{-0.272, 0.}, 
         NCache[{-0.27, Rational[369, 100]}, {-0.27, 3.69}],
         RoundingRadius->0], 
        RectangleBox[{-0.27, 0.}, 
         NCache[{-0.268, Rational[709, 200]}, {-0.268, 3.545}],
         RoundingRadius->0], 
        RectangleBox[{-0.268, 0.}, 
         NCache[{-0.266, Rational[367, 100]}, {-0.266, 3.67}],
         RoundingRadius->0], 
        RectangleBox[{-0.266, 0.}, 
         NCache[{-0.264, Rational[137, 40]}, {-0.264, 3.425}],
         RoundingRadius->0], 
        RectangleBox[{-0.264, 0.}, 
         NCache[{-0.262, Rational[381, 100]}, {-0.262, 3.81}],
         RoundingRadius->0], 
        RectangleBox[{-0.262, 0.}, 
         NCache[{-0.26, Rational[779, 200]}, {-0.26, 3.895}],
         RoundingRadius->0], 
        RectangleBox[{-0.26, 0.}, 
         NCache[{-0.258, Rational[102, 25]}, {-0.258, 4.08}],
         RoundingRadius->0], 
        RectangleBox[{-0.258, 0.}, 
         NCache[{-0.256, Rational[377, 100]}, {-0.256, 3.77}],
         RoundingRadius->0], 
        RectangleBox[{-0.256, 0.}, 
         NCache[{-0.254, Rational[803, 200]}, {-0.254, 4.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.254, 0.}, 
         NCache[{-0.252, Rational[807, 200]}, {-0.252, 4.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.252, 0.}, 
         NCache[{-0.25, Rational[807, 200]}, {-0.25, 4.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.25, 0.}, 
         NCache[{-0.248, Rational[107, 25]}, {-0.248, 4.28}],
         RoundingRadius->0], 
        RectangleBox[{-0.248, 0.}, 
         NCache[{-0.246, Rational[219, 50]}, {-0.246, 4.38}],
         RoundingRadius->0], 
        RectangleBox[{-0.246, 0.}, 
         NCache[{-0.244, Rational[102, 25]}, {-0.244, 4.08}],
         RoundingRadius->0], 
        RectangleBox[{-0.244, 0.}, 
         NCache[{-0.242, Rational[429, 100]}, {-0.242, 4.29}],
         RoundingRadius->0], 
        RectangleBox[{-0.242, 0.}, 
         NCache[{-0.24, Rational[879, 200]}, {-0.24, 4.395}],
         RoundingRadius->0], 
        RectangleBox[{-0.24, 0.}, 
         NCache[{-0.238, Rational[437, 100]}, {-0.238, 4.37}],
         RoundingRadius->0], 
        RectangleBox[{-0.238, 0.}, 
         NCache[{-0.236, Rational[887, 200]}, {-0.236, 4.435}],
         RoundingRadius->0], 
        RectangleBox[{-0.236, 0.}, 
         NCache[{-0.234, Rational[89, 20]}, {-0.234, 4.45}],
         RoundingRadius->0], 
        RectangleBox[{-0.234, 0.}, 
         NCache[{-0.232, Rational[849, 200]}, {-0.232, 4.245}],
         RoundingRadius->0], 
        RectangleBox[{-0.232, 0.}, 
         NCache[{-0.23, Rational[447, 100]}, {-0.23, 4.47}],
         RoundingRadius->0], 
        RectangleBox[{-0.23, 0.}, 
         NCache[{-0.228, Rational[22, 5]}, {-0.228, 4.4}],
         RoundingRadius->0], 
        RectangleBox[{-0.228, 0.}, 
         NCache[{-0.226, Rational[43, 10]}, {-0.226, 4.3}],
         RoundingRadius->0], 
        RectangleBox[{-0.226, 0.}, 
         NCache[{-0.224, Rational[233, 50]}, {-0.224, 4.66}],
         RoundingRadius->0], 
        RectangleBox[{-0.224, 0.}, 
         NCache[{-0.222, Rational[907, 200]}, {-0.222, 4.535}],
         RoundingRadius->0], 
        RectangleBox[{-0.222, 0.}, 
         NCache[{-0.22, Rational[933, 200]}, {-0.22, 4.665}],
         RoundingRadius->0], 
        RectangleBox[{-0.22, 0.}, 
         NCache[{-0.218, Rational[913, 200]}, {-0.218, 4.565}],
         RoundingRadius->0], 
        RectangleBox[{-0.218, 0.}, 
         NCache[{-0.216, Rational[901, 200]}, {-0.216, 4.505}],
         RoundingRadius->0], 
        RectangleBox[{-0.216, 0.}, 
         NCache[{-0.214, Rational[961, 200]}, {-0.214, 4.805}],
         RoundingRadius->0], 
        RectangleBox[{-0.214, 0.}, 
         NCache[{-0.212, Rational[457, 100]}, {-0.212, 4.57}],
         RoundingRadius->0], 
        RectangleBox[{-0.212, 0.}, 
         NCache[{-0.21, Rational[947, 200]}, {-0.21, 4.735}],
         RoundingRadius->0], 
        RectangleBox[{-0.21, 0.}, 
         NCache[{-0.208, Rational[931, 200]}, {-0.208, 4.655}],
         RoundingRadius->0], 
        RectangleBox[{-0.208, 0.}, 
         NCache[{-0.206, Rational[949, 200]}, {-0.206, 4.745}],
         RoundingRadius->0], 
        RectangleBox[{-0.206, 0.}, 
         NCache[{-0.204, Rational[37, 8]}, {-0.204, 4.625}],
         RoundingRadius->0], 
        RectangleBox[{-0.204, 0.}, 
         NCache[{-0.202, Rational[118, 25]}, {-0.202, 4.72}],
         RoundingRadius->0], 
        RectangleBox[{-0.202, 0.}, 
         NCache[{-0.2, Rational[117, 25]}, {-0.2, 4.68}],
         RoundingRadius->0], 
        RectangleBox[{-0.2, 0.}, 
         NCache[{-0.198, Rational[463, 100]}, {-0.198, 4.63}],
         RoundingRadius->0], 
        RectangleBox[{-0.198, 0.}, 
         NCache[{-0.196, Rational[457, 100]}, {-0.196, 4.57}],
         RoundingRadius->0], 
        RectangleBox[{-0.196, 0.}, 
         NCache[{-0.194, Rational[121, 25]}, {-0.194, 4.84}],
         RoundingRadius->0], 
        RectangleBox[{-0.194, 0.}, 
         NCache[{-0.192, Rational[124, 25]}, {-0.192, 4.96}],
         RoundingRadius->0], 
        RectangleBox[{-0.192, 0.}, 
         NCache[{-0.19, Rational[953, 200]}, {-0.19, 4.765}],
         RoundingRadius->0], 
        RectangleBox[{-0.19, 0.}, 
         NCache[{-0.188, Rational[959, 200]}, {-0.188, 4.795}],
         RoundingRadius->0], 
        RectangleBox[{-0.188, 0.}, 
         NCache[{-0.186, Rational[437, 100]}, {-0.186, 4.37}],
         RoundingRadius->0], 
        RectangleBox[{-0.186, 0.}, 
         NCache[{-0.184, Rational[113, 25]}, {-0.184, 4.52}],
         RoundingRadius->0], 
        RectangleBox[{-0.184, 0.}, 
         NCache[{-0.182, Rational[479, 100]}, {-0.182, 4.79}],
         RoundingRadius->0], 
        RectangleBox[{-0.182, 0.}, 
         NCache[{-0.18, Rational[967, 200]}, {-0.18, 4.835}],
         RoundingRadius->0], 
        RectangleBox[{-0.18, 0.}, 
         NCache[{-0.178, Rational[871, 200]}, {-0.178, 4.355}],
         RoundingRadius->0], 
        RectangleBox[{-0.178, 0.}, 
         NCache[{-0.176, Rational[891, 200]}, {-0.176, 4.455}],
         RoundingRadius->0], 
        RectangleBox[{-0.176, 0.}, 
         NCache[{-0.174, Rational[923, 200]}, {-0.174, 4.615}],
         RoundingRadius->0], 
        RectangleBox[{-0.174, 0.}, 
         NCache[{-0.172, Rational[217, 50]}, {-0.172, 4.34}],
         RoundingRadius->0], 
        RectangleBox[{-0.172, 0.}, 
         NCache[{-0.17, Rational[827, 200]}, {-0.17, 4.135}],
         RoundingRadius->0], 
        RectangleBox[{-0.17, 0.}, 
         NCache[{-0.168, Rational[201, 50]}, {-0.168, 4.02}],
         RoundingRadius->0], 
        RectangleBox[{-0.168, 0.}, 
         NCache[{-0.166, Rational[811, 200]}, {-0.166, 4.055}],
         RoundingRadius->0], 
        RectangleBox[{-0.166, 0.}, 
         NCache[{-0.164, Rational[903, 200]}, {-0.164, 4.515}],
         RoundingRadius->0], 
        RectangleBox[{-0.164, 0.}, 
         NCache[{-0.162, Rational[21, 5]}, {-0.162, 4.2}],
         RoundingRadius->0], 
        RectangleBox[{-0.162, 0.}, 
         NCache[{-0.16, Rational[889, 200]}, {-0.16, 4.445}],
         RoundingRadius->0], 
        RectangleBox[{-0.16, 0.}, 
         NCache[{-0.158, Rational[829, 200]}, {-0.158, 4.145}],
         RoundingRadius->0], 
        RectangleBox[{-0.158, 0.}, 
         NCache[{-0.156, Rational[817, 200]}, {-0.156, 4.085}],
         RoundingRadius->0], 
        RectangleBox[{-0.156, 0.}, 
         NCache[{-0.154, Rational[793, 200]}, {-0.154, 3.965}],
         RoundingRadius->0], 
        RectangleBox[{-0.154, 0.}, 
         NCache[{-0.152, Rational[831, 200]}, {-0.152, 4.155}],
         RoundingRadius->0], 
        RectangleBox[{-0.152, 0.}, 
         NCache[{-0.15, Rational[789, 200]}, {-0.15, 3.945}],
         RoundingRadius->0], 
        RectangleBox[{-0.15, 0.}, 
         NCache[{-0.148, Rational[807, 200]}, {-0.148, 4.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.148, 0.}, 
         NCache[{-0.146, Rational[829, 200]}, {-0.146, 4.145}],
         RoundingRadius->0], 
        RectangleBox[{-0.146, 0.}, 
         NCache[{-0.144, Rational[141, 40]}, {-0.144, 3.525}],
         RoundingRadius->0], 
        RectangleBox[{-0.144, 0.}, 
         NCache[{-0.142, Rational[71, 20]}, {-0.142, 3.55}],
         RoundingRadius->0], 
        RectangleBox[{-0.142, 0.}, 
         NCache[{-0.14, Rational[141, 40]}, {-0.14, 3.525}],
         RoundingRadius->0], 
        RectangleBox[{-0.14, 0.}, 
         NCache[{-0.138, Rational[337, 100]}, {-0.138, 3.37}],
         RoundingRadius->0], 
        RectangleBox[{-0.138, 0.}, 
         NCache[{-0.136, Rational[88, 25]}, {-0.136, 3.52}],
         RoundingRadius->0], 
        RectangleBox[{-0.136, 0.}, 
         NCache[{-0.134, Rational[79, 25]}, {-0.134, 3.16}],
         RoundingRadius->0], 
        RectangleBox[{-0.134, 0.}, 
         NCache[{-0.132, Rational[691, 200]}, {-0.132, 3.455}],
         RoundingRadius->0], 
        RectangleBox[{-0.132, 0.}, 
         NCache[{-0.13, Rational[607, 200]}, {-0.13, 3.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.13, 0.}, 
         NCache[{-0.128, Rational[623, 200]}, {-0.128, 3.115}],
         RoundingRadius->0], 
        RectangleBox[{-0.128, 0.}, 
         NCache[{-0.126, Rational[641, 200]}, {-0.126, 3.205}],
         RoundingRadius->0], 
        RectangleBox[{-0.126, 0.}, 
         NCache[{-0.124, Rational[589, 200]}, {-0.124, 2.945}],
         RoundingRadius->0], 
        RectangleBox[{-0.124, 0.}, 
         NCache[{-0.122, Rational[297, 100]}, {-0.122, 2.97}],
         RoundingRadius->0], 
        RectangleBox[{-0.122, 0.}, 
         NCache[{-0.12, Rational[577, 200]}, {-0.12, 2.885}],
         RoundingRadius->0], 
        RectangleBox[{-0.12, 0.}, 
         NCache[{-0.118, Rational[521, 200]}, {-0.118, 2.605}],
         RoundingRadius->0], 
        RectangleBox[{-0.118, 0.}, 
         NCache[{-0.116, Rational[66, 25]}, {-0.116, 2.64}],
         RoundingRadius->0], 
        RectangleBox[{-0.116, 0.}, 
         NCache[{-0.114, Rational[11, 4]}, {-0.114, 2.75}],
         RoundingRadius->0], 
        RectangleBox[{-0.114, 0.}, 
         NCache[{-0.112, Rational[117, 50]}, {-0.112, 2.34}],
         RoundingRadius->0], 
        RectangleBox[{-0.112, 0.}, 
         NCache[{-0.11, Rational[517, 200]}, {-0.11, 2.585}],
         RoundingRadius->0], 
        RectangleBox[{-0.11, 0.}, 
         NCache[{-0.108, Rational[497, 200]}, {-0.108, 2.485}],
         RoundingRadius->0], 
        RectangleBox[{-0.108, 0.}, 
         NCache[{-0.106, Rational[249, 100]}, {-0.106, 2.49}],
         RoundingRadius->0], 
        RectangleBox[{-0.106, 0.}, 
         NCache[{-0.104, Rational[451, 200]}, {-0.104, 2.255}],
         RoundingRadius->0], 
        RectangleBox[{-0.104, 0.}, 
         NCache[{-0.102, Rational[427, 200]}, {-0.102, 2.135}],
         RoundingRadius->0], 
        RectangleBox[{-0.102, 0.}, 
         NCache[{-0.1, Rational[87, 40]}, {-0.1, 2.175}],
         RoundingRadius->0], 
        RectangleBox[{-0.1, 0.}, 
         NCache[{-0.098, Rational[81, 40]}, {-0.098, 2.025}],
         RoundingRadius->0], 
        RectangleBox[{-0.098, 0.}, 
         NCache[{-0.096, Rational[79, 40]}, {-0.096, 1.975}],
         RoundingRadius->0], 
        RectangleBox[{-0.096, 0.}, 
         NCache[{-0.094, Rational[217, 100]}, {-0.094, 2.17}],
         RoundingRadius->0], 
        RectangleBox[{-0.094, 0.}, 
         NCache[{-0.092, Rational[87, 50]}, {-0.092, 1.74}],
         RoundingRadius->0], 
        RectangleBox[{-0.092, 0.}, 
         NCache[{-0.09, Rational[377, 200]}, {-0.09, 1.885}],
         RoundingRadius->0], 
        RectangleBox[{-0.09, 0.}, 
         NCache[{-0.088, Rational[357, 200]}, {-0.088, 1.785}],
         RoundingRadius->0], 
        RectangleBox[{-0.088, 0.}, 
         NCache[{-0.086, Rational[169, 100]}, {-0.086, 1.69}],
         RoundingRadius->0], 
        RectangleBox[{-0.086, 0.}, 
         NCache[{-0.084, Rational[7, 4]}, {-0.084, 1.75}],
         RoundingRadius->0], 
        RectangleBox[{-0.084, 0.}, 
         NCache[{-0.082, Rational[37, 25]}, {-0.082, 1.48}],
         RoundingRadius->0], 
        RectangleBox[{-0.082, 0.}, 
         NCache[{-0.08, Rational[157, 100]}, {-0.08, 1.57}],
         RoundingRadius->0], 
        RectangleBox[{-0.08, 0.}, 
         NCache[{-0.078, Rational[277, 200]}, {-0.078, 1.385}],
         RoundingRadius->0], 
        RectangleBox[{-0.078, 0.}, 
         NCache[{-0.076, Rational[129, 100]}, {-0.076, 1.29}],
         RoundingRadius->0], 
        RectangleBox[{-0.076, 0.}, 
         NCache[{-0.074, Rational[133, 100]}, {-0.074, 1.33}],
         RoundingRadius->0], 
        RectangleBox[{-0.074, 0.}, 
         NCache[{-0.072, Rational[63, 50]}, {-0.072, 1.26}],
         RoundingRadius->0], 
        RectangleBox[{-0.072, 0.}, 
         NCache[{-0.07, Rational[257, 200]}, {-0.07, 1.285}],
         RoundingRadius->0], 
        RectangleBox[{-0.07, 0.}, 
         NCache[{-0.068, Rational[29, 25]}, {-0.068, 1.16}],
         RoundingRadius->0], 
        RectangleBox[{-0.068, 0.}, 
         NCache[{-0.066, Rational[239, 200]}, {-0.066, 1.195}],
         RoundingRadius->0], 
        RectangleBox[{-0.066, 0.}, 
         NCache[{-0.064, Rational[203, 200]}, {-0.064, 1.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.064, 0.}, 
         NCache[{-0.062, Rational[219, 200]}, {-0.062, 1.095}],
         RoundingRadius->0], 
        RectangleBox[{-0.062, 0.}, 
         NCache[{-0.06, Rational[167, 200]}, {-0.06, 0.835}],
         RoundingRadius->0], 
        RectangleBox[{-0.06, 0.}, 
         NCache[{-0.058, Rational[97, 100]}, {-0.058, 0.97}],
         RoundingRadius->0], 
        RectangleBox[{-0.058, 0.}, 
         NCache[{-0.056, Rational[187, 200]}, {-0.056, 0.935}],
         RoundingRadius->0], 
        RectangleBox[{-0.056, 0.}, 
         NCache[{-0.054, Rational[17, 20]}, {-0.054, 0.85}],
         RoundingRadius->0], 
        RectangleBox[{-0.054, 0.}, 
         NCache[{-0.052, Rational[18, 25]}, {-0.052, 0.72}],
         RoundingRadius->0], 
        RectangleBox[{-0.052, 0.}, 
         NCache[{-0.05, Rational[67, 100]}, {-0.05, 0.67}],
         RoundingRadius->0], 
        RectangleBox[{-0.05, 0.}, 
         NCache[{-0.048, Rational[69, 100]}, {-0.048, 0.69}],
         RoundingRadius->0], 
        RectangleBox[{-0.048, 0.}, 
         NCache[{-0.046, Rational[69, 100]}, {-0.046, 0.69}],
         RoundingRadius->0], 
        RectangleBox[{-0.046, 0.}, 
         NCache[{-0.044, Rational[149, 200]}, {-0.044, 0.745}],
         RoundingRadius->0], 
        RectangleBox[{-0.044, 0.}, 
         NCache[{-0.042, Rational[57, 100]}, {-0.042, 0.57}],
         RoundingRadius->0], 
        RectangleBox[{-0.042, 0.}, 
         NCache[{-0.04, Rational[113, 200]}, {-0.04, 0.565}],
         RoundingRadius->0], 
        RectangleBox[{-0.04, 0.}, 
         NCache[{-0.038, Rational[109, 200]}, {-0.038, 0.545}],
         RoundingRadius->0], 
        RectangleBox[{-0.038, 0.}, 
         NCache[{-0.036, Rational[53, 100]}, {-0.036, 0.53}],
         RoundingRadius->0], 
        RectangleBox[{-0.036, 0.}, 
         NCache[{-0.034, Rational[81, 200]}, {-0.034, 0.405}],
         RoundingRadius->0], 
        RectangleBox[{-0.034, 0.}, 
         NCache[{-0.032, Rational[11, 25]}, {-0.032, 0.44}],
         RoundingRadius->0], 
        RectangleBox[{-0.032, 0.}, 
         NCache[{-0.03, Rational[89, 200]}, {-0.03, 0.445}],
         RoundingRadius->0], 
        RectangleBox[{-0.03, 0.}, 
         NCache[{-0.028, Rational[9, 20]}, {-0.028, 0.45}],
         RoundingRadius->0], 
        RectangleBox[{-0.028, 0.}, 
         NCache[{-0.026, Rational[77, 200]}, {-0.026, 0.385}],
         RoundingRadius->0], 
        RectangleBox[{-0.026, 0.}, 
         NCache[{-0.024, Rational[91, 200]}, {-0.024, 0.455}],
         RoundingRadius->0], 
        RectangleBox[{-0.024, 0.}, 
         NCache[{-0.022, Rational[73, 200]}, {-0.022, 0.365}],
         RoundingRadius->0], 
        RectangleBox[{-0.022, 0.}, 
         NCache[{-0.02, Rational[63, 200]}, {-0.02, 0.315}],
         RoundingRadius->0], 
        RectangleBox[{-0.02, 0.}, 
         NCache[{-0.018, Rational[53, 200]}, {-0.018, 0.265}],
         RoundingRadius->0], 
        RectangleBox[{-0.018, 0.}, 
         NCache[{-0.016, Rational[57, 200]}, {-0.016, 0.285}],
         RoundingRadius->0], 
        RectangleBox[{-0.016, 0.}, 
         NCache[{-0.014, Rational[57, 200]}, {-0.014, 0.285}],
         RoundingRadius->0], 
        RectangleBox[{-0.014, 0.}, 
         NCache[{-0.012, Rational[37, 200]}, {-0.012, 0.185}],
         RoundingRadius->0], 
        RectangleBox[{-0.012, 0.}, 
         NCache[{-0.01, Rational[19, 100]}, {-0.01, 0.19}],
         RoundingRadius->0], 
        RectangleBox[{-0.01, 0.}, 
         NCache[{-0.008, Rational[6, 25]}, {-0.008, 0.24}],
         RoundingRadius->0], 
        RectangleBox[{-0.008, 0.}, 
         NCache[{-0.006, Rational[4, 25]}, {-0.006, 0.16}],
         RoundingRadius->0], 
        RectangleBox[{-0.006, 0.}, 
         NCache[{-0.004, Rational[6, 25]}, {-0.004, 0.24}],
         RoundingRadius->0], 
        RectangleBox[{-0.004, 0.}, 
         NCache[{-0.002, Rational[9, 40]}, {-0.002, 0.225}],
         RoundingRadius->0], 
        RectangleBox[{-0.002, 0.}, NCache[{0., Rational[7, 40]}, {0., 0.175}],
         
         RoundingRadius->0], 
        RectangleBox[{0., 0.}, 
         NCache[{0.002, Rational[31, 200]}, {0.002, 0.155}],
         RoundingRadius->0], 
        RectangleBox[{0.002, 0.}, 
         NCache[{0.004, Rational[17, 100]}, {0.004, 0.17}],
         RoundingRadius->0], 
        RectangleBox[{0.004, 0.}, 
         NCache[{0.006, Rational[3, 20]}, {0.006, 0.15}],
         RoundingRadius->0], 
        RectangleBox[{0.006, 0.}, 
         NCache[{0.008, Rational[17, 200]}, {0.008, 0.085}],
         RoundingRadius->0], 
        RectangleBox[{0.008, 0.}, 
         NCache[{0.01, Rational[1, 8]}, {0.01, 0.125}],
         RoundingRadius->0], 
        RectangleBox[{0.01, 0.}, 
         NCache[{0.012, Rational[3, 20]}, {0.012, 0.15}],
         RoundingRadius->0], 
        RectangleBox[{0.012, 0.}, 
         NCache[{0.014, Rational[3, 40]}, {0.014, 0.075}],
         RoundingRadius->0], 
        RectangleBox[{0.014, 0.}, 
         NCache[{0.016, Rational[3, 40]}, {0.016, 0.075}],
         RoundingRadius->0], 
        RectangleBox[{0.016, 0.}, 
         NCache[{0.018, Rational[21, 200]}, {0.018, 0.105}],
         RoundingRadius->0], 
        RectangleBox[{0.018, 0.}, 
         NCache[{0.02, Rational[17, 200]}, {0.02, 0.085}],
         RoundingRadius->0], 
        RectangleBox[{0.02, 0.}, 
         NCache[{0.022, Rational[7, 100]}, {0.022, 0.07}],
         RoundingRadius->0], 
        RectangleBox[{0.022, 0.}, 
         NCache[{0.024, Rational[17, 200]}, {0.024, 0.085}],
         RoundingRadius->0], 
        RectangleBox[{0.024, 0.}, 
         NCache[{0.026, Rational[2, 25]}, {0.026, 0.08}],
         RoundingRadius->0], 
        RectangleBox[{0.026, 0.}, 
         NCache[{0.028, Rational[1, 25]}, {0.028, 0.04}],
         RoundingRadius->0], 
        RectangleBox[{0.028, 0.}, 
         NCache[{0.03, Rational[1, 25]}, {0.03, 0.04}],
         RoundingRadius->0], 
        RectangleBox[{0.03, 0.}, 
         NCache[{0.032, Rational[1, 25]}, {0.032, 0.04}],
         RoundingRadius->0], 
        RectangleBox[{0.032, 0.}, 
         NCache[{0.034, Rational[9, 200]}, {0.034, 0.045}],
         RoundingRadius->0], 
        RectangleBox[{0.034, 0.}, 
         NCache[{0.036, Rational[1, 20]}, {0.036, 0.05}],
         RoundingRadius->0], 
        RectangleBox[{0.036, 0.}, 
         NCache[{0.038, Rational[3, 50]}, {0.038, 0.06}],
         RoundingRadius->0], 
        RectangleBox[{0.038, 0.}, 
         NCache[{0.04, Rational[1, 50]}, {0.04, 0.02}],
         RoundingRadius->0], 
        RectangleBox[{0.04, 0.}, 
         NCache[{0.042, Rational[1, 50]}, {0.042, 0.02}],
         RoundingRadius->0], 
        RectangleBox[{0.042, 0.}, 
         NCache[{0.044, Rational[1, 40]}, {0.044, 0.025}],
         RoundingRadius->0], 
        RectangleBox[{0.044, 0.}, 
         NCache[{0.046, Rational[1, 40]}, {0.046, 0.025}],
         RoundingRadius->0], 
        RectangleBox[{0.046, 0.}, 
         NCache[{0.048, Rational[3, 200]}, {0.048, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{0.048, 0.}, 
         NCache[{0.05, Rational[3, 200]}, {0.05, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{0.05, 0.}, 
         NCache[{0.052, Rational[1, 100]}, {0.052, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{0.052, 0.}, 
         NCache[{0.054, Rational[1, 100]}, {0.054, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{0.054, 0.}, 
         NCache[{0.056, Rational[1, 50]}, {0.056, 0.02}],
         RoundingRadius->0], RectangleBox[{0.056, 0.}, {0.058, 0},
         RoundingRadius->0], RectangleBox[{0.058, 0.}, {0.06, 0},
         RoundingRadius->0], 
        RectangleBox[{0.06, 0.}, 
         NCache[{0.062, Rational[1, 100]}, {0.062, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{0.062, 0.}, 
         NCache[{0.064, Rational[1, 100]}, {0.064, 0.01}],
         RoundingRadius->0], RectangleBox[{0.064, 0.}, {0.066, 0},
         RoundingRadius->0], 
        RectangleBox[{0.066, 0.}, 
         NCache[{0.068, Rational[1, 200]}, {0.068, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{0.068, 0.}, 
         NCache[{0.07, Rational[1, 200]}, {0.07, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{0.07, 0.}, 
         NCache[{0.072, Rational[1, 200]}, {0.072, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{0.072, 0.}, 
         NCache[{0.074, Rational[1, 200]}, {0.074, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{0.074, 0.}, 
         NCache[{0.076, Rational[1, 200]}, {0.076, 0.005}],
         RoundingRadius->0], RectangleBox[{0.076, 0.}, {0.078, 0},
         RoundingRadius->0], RectangleBox[{0.078, 0.}, {0.08, 0},
         RoundingRadius->0], RectangleBox[{0.08, 0.}, {0.082, 0},
         RoundingRadius->0], RectangleBox[{0.082, 0.}, {0.084, 0},
         RoundingRadius->0], RectangleBox[{0.084, 0.}, {0.086, 0},
         RoundingRadius->0], RectangleBox[{0.086, 0.}, {0.088, 0},
         RoundingRadius->0], RectangleBox[{0.088, 0.}, {0.09, 0},
         RoundingRadius->0], RectangleBox[{0.09, 0.}, {0.092, 0},
         RoundingRadius->0], RectangleBox[{0.092, 0.}, {0.094, 0},
         RoundingRadius->0], RectangleBox[{0.094, 0.}, {0.096, 0},
         RoundingRadius->0], 
        RectangleBox[{0.096, 0.}, 
         NCache[{0.098, Rational[1, 200]}, {0.098, 0.005}],
         RoundingRadius->0], RectangleBox[{0.098, 0.}, {0.1, 0},
         RoundingRadius->0], 
        RectangleBox[{0.1, 0.}, 
         NCache[{0.102, Rational[3, 200]}, {0.102, 0.015}],
         RoundingRadius->0], RectangleBox[{0.102, 0.}, {0.104, 0},
         RoundingRadius->0], RectangleBox[{0.104, 0.}, {0.106, 0},
         RoundingRadius->0], RectangleBox[{0.106, 0.}, {0.108, 0},
         RoundingRadius->0], RectangleBox[{0.108, 0.}, {0.11, 0},
         RoundingRadius->0], RectangleBox[{0.11, 0.}, {0.112, 0},
         RoundingRadius->0], RectangleBox[{0.112, 0.}, {0.114, 0},
         RoundingRadius->0], RectangleBox[{0.114, 0.}, {0.116, 0},
         RoundingRadius->0], RectangleBox[{0.116, 0.}, {0.118, 0},
         RoundingRadius->0], RectangleBox[{0.118, 0.}, {0.12, 0},
         RoundingRadius->0], RectangleBox[{0.12, 0.}, {0.122, 0},
         RoundingRadius->0], RectangleBox[{0.122, 0.}, {0.124, 0},
         RoundingRadius->0], RectangleBox[{0.124, 0.}, {0.126, 0},
         RoundingRadius->0], RectangleBox[{0.126, 0.}, {0.128, 0},
         RoundingRadius->0], RectangleBox[{0.128, 0.}, {0.13, 0},
         RoundingRadius->0], RectangleBox[{0.13, 0.}, {0.132, 0},
         RoundingRadius->0], RectangleBox[{0.132, 0.}, {0.134, 0},
         RoundingRadius->0], RectangleBox[{0.134, 0.}, {0.136, 0},
         RoundingRadius->0], RectangleBox[{0.136, 0.}, {0.138, 0},
         RoundingRadius->0], RectangleBox[{0.138, 0.}, {0.14, 0},
         RoundingRadius->0], RectangleBox[{0.14, 0.}, {0.142, 0},
         RoundingRadius->0], RectangleBox[{0.142, 0.}, {0.144, 0},
         RoundingRadius->0], RectangleBox[{0.144, 0.}, {0.146, 0},
         RoundingRadius->0], RectangleBox[{0.146, 0.}, {0.148, 0},
         RoundingRadius->0], RectangleBox[{0.148, 0.}, {0.15, 0},
         RoundingRadius->0], RectangleBox[{0.15, 0.}, {0.152, 0},
         RoundingRadius->0], RectangleBox[{0.152, 0.}, {0.154, 0},
         RoundingRadius->0], RectangleBox[{0.154, 0.}, {0.156, 0},
         RoundingRadius->0], RectangleBox[{0.156, 0.}, {0.158, 0},
         RoundingRadius->0], RectangleBox[{0.158, 0.}, {0.16, 0},
         RoundingRadius->0], RectangleBox[{0.16, 0.}, {0.162, 0},
         RoundingRadius->0], RectangleBox[{0.162, 0.}, {0.164, 0},
         RoundingRadius->0], RectangleBox[{0.164, 0.}, {0.166, 0},
         RoundingRadius->0], RectangleBox[{0.166, 0.}, {0.168, 0},
         RoundingRadius->0], RectangleBox[{0.168, 0.}, {0.17, 0},
         RoundingRadius->0], RectangleBox[{0.17, 0.}, {0.172, 0},
         RoundingRadius->0], RectangleBox[{0.172, 0.}, {0.174, 0},
         RoundingRadius->0], RectangleBox[{0.174, 0.}, {0.176, 0},
         RoundingRadius->0]}, {}, {}}, {{}, 
       {RGBColor[1, 0, 0], Opacity[0.5], EdgeForm[Opacity[-2.506]], 
        RectangleBox[{-0.74, 0.}, {-0.738, 0},
         RoundingRadius->0], RectangleBox[{-0.738, 0.}, {-0.736, 0},
         RoundingRadius->0], RectangleBox[{-0.736, 0.}, {-0.734, 0},
         RoundingRadius->0], RectangleBox[{-0.734, 0.}, {-0.732, 0},
         RoundingRadius->0], RectangleBox[{-0.732, 0.}, {-0.73, 0},
         RoundingRadius->0], RectangleBox[{-0.73, 0.}, {-0.728, 0},
         RoundingRadius->0], RectangleBox[{-0.728, 0.}, {-0.726, 0},
         RoundingRadius->0], RectangleBox[{-0.726, 0.}, {-0.724, 0},
         RoundingRadius->0], RectangleBox[{-0.724, 0.}, {-0.722, 0},
         RoundingRadius->0], RectangleBox[{-0.722, 0.}, {-0.72, 0},
         RoundingRadius->0], RectangleBox[{-0.72, 0.}, {-0.718, 0},
         RoundingRadius->0], RectangleBox[{-0.718, 0.}, {-0.716, 0},
         RoundingRadius->0], RectangleBox[{-0.716, 0.}, {-0.714, 0},
         RoundingRadius->0], RectangleBox[{-0.714, 0.}, {-0.712, 0},
         RoundingRadius->0], RectangleBox[{-0.712, 0.}, {-0.71, 0},
         RoundingRadius->0], RectangleBox[{-0.71, 0.}, {-0.708, 0},
         RoundingRadius->0], RectangleBox[{-0.708, 0.}, {-0.706, 0},
         RoundingRadius->0], RectangleBox[{-0.706, 0.}, {-0.704, 0},
         RoundingRadius->0], RectangleBox[{-0.704, 0.}, {-0.702, 0},
         RoundingRadius->0], RectangleBox[{-0.702, 0.}, {-0.7, 0},
         RoundingRadius->0], RectangleBox[{-0.7, 0.}, {-0.698, 0},
         RoundingRadius->0], RectangleBox[{-0.698, 0.}, {-0.696, 0},
         RoundingRadius->0], RectangleBox[{-0.696, 0.}, {-0.694, 0},
         RoundingRadius->0], RectangleBox[{-0.694, 0.}, {-0.692, 0},
         RoundingRadius->0], RectangleBox[{-0.692, 0.}, {-0.69, 0},
         RoundingRadius->0], RectangleBox[{-0.69, 0.}, {-0.688, 0},
         RoundingRadius->0], RectangleBox[{-0.688, 0.}, {-0.686, 0},
         RoundingRadius->0], RectangleBox[{-0.686, 0.}, {-0.684, 0},
         RoundingRadius->0], RectangleBox[{-0.684, 0.}, {-0.682, 0},
         RoundingRadius->0], RectangleBox[{-0.682, 0.}, {-0.68, 0},
         RoundingRadius->0], RectangleBox[{-0.68, 0.}, {-0.678, 0},
         RoundingRadius->0], RectangleBox[{-0.678, 0.}, {-0.676, 0},
         RoundingRadius->0], RectangleBox[{-0.676, 0.}, {-0.674, 0},
         RoundingRadius->0], RectangleBox[{-0.674, 0.}, {-0.672, 0},
         RoundingRadius->0], RectangleBox[{-0.672, 0.}, {-0.67, 0},
         RoundingRadius->0], RectangleBox[{-0.67, 0.}, {-0.668, 0},
         RoundingRadius->0], RectangleBox[{-0.668, 0.}, {-0.666, 0},
         RoundingRadius->0], RectangleBox[{-0.666, 0.}, {-0.664, 0},
         RoundingRadius->0], RectangleBox[{-0.664, 0.}, {-0.662, 0},
         RoundingRadius->0], RectangleBox[{-0.662, 0.}, {-0.66, 0},
         RoundingRadius->0], RectangleBox[{-0.66, 0.}, {-0.658, 0},
         RoundingRadius->0], RectangleBox[{-0.658, 0.}, {-0.656, 0},
         RoundingRadius->0], RectangleBox[{-0.656, 0.}, {-0.654, 0},
         RoundingRadius->0], RectangleBox[{-0.654, 0.}, {-0.652, 0},
         RoundingRadius->0], RectangleBox[{-0.652, 0.}, {-0.65, 0},
         RoundingRadius->0], RectangleBox[{-0.65, 0.}, {-0.648, 0},
         RoundingRadius->0], RectangleBox[{-0.648, 0.}, {-0.646, 0},
         RoundingRadius->0], RectangleBox[{-0.646, 0.}, {-0.644, 0},
         RoundingRadius->0], RectangleBox[{-0.644, 0.}, {-0.642, 0},
         RoundingRadius->0], RectangleBox[{-0.642, 0.}, {-0.64, 0},
         RoundingRadius->0], RectangleBox[{-0.64, 0.}, {-0.638, 0},
         RoundingRadius->0], RectangleBox[{-0.638, 0.}, {-0.636, 0},
         RoundingRadius->0], RectangleBox[{-0.636, 0.}, {-0.634, 0},
         RoundingRadius->0], RectangleBox[{-0.634, 0.}, {-0.632, 0},
         RoundingRadius->0], RectangleBox[{-0.632, 0.}, {-0.63, 0},
         RoundingRadius->0], RectangleBox[{-0.63, 0.}, {-0.628, 0},
         RoundingRadius->0], RectangleBox[{-0.628, 0.}, {-0.626, 0},
         RoundingRadius->0], RectangleBox[{-0.626, 0.}, {-0.624, 0},
         RoundingRadius->0], RectangleBox[{-0.624, 0.}, {-0.622, 0},
         RoundingRadius->0], RectangleBox[{-0.622, 0.}, {-0.62, 0},
         RoundingRadius->0], RectangleBox[{-0.62, 0.}, {-0.618, 0},
         RoundingRadius->0], RectangleBox[{-0.618, 0.}, {-0.616, 0},
         RoundingRadius->0], RectangleBox[{-0.616, 0.}, {-0.614, 0},
         RoundingRadius->0], RectangleBox[{-0.614, 0.}, {-0.612, 0},
         RoundingRadius->0], RectangleBox[{-0.612, 0.}, {-0.61, 0},
         RoundingRadius->0], RectangleBox[{-0.61, 0.}, {-0.608, 0},
         RoundingRadius->0], RectangleBox[{-0.608, 0.}, {-0.606, 0},
         RoundingRadius->0], RectangleBox[{-0.606, 0.}, {-0.604, 0},
         RoundingRadius->0], RectangleBox[{-0.604, 0.}, {-0.602, 0},
         RoundingRadius->0], RectangleBox[{-0.602, 0.}, {-0.6, 0},
         RoundingRadius->0], RectangleBox[{-0.6, 0.}, {-0.598, 0},
         RoundingRadius->0], RectangleBox[{-0.598, 0.}, {-0.596, 0},
         RoundingRadius->0], RectangleBox[{-0.596, 0.}, {-0.594, 0},
         RoundingRadius->0], RectangleBox[{-0.594, 0.}, {-0.592, 0},
         RoundingRadius->0], RectangleBox[{-0.592, 0.}, {-0.59, 0},
         RoundingRadius->0], RectangleBox[{-0.59, 0.}, {-0.588, 0},
         RoundingRadius->0], RectangleBox[{-0.588, 0.}, {-0.586, 0},
         RoundingRadius->0], RectangleBox[{-0.586, 0.}, {-0.584, 0},
         RoundingRadius->0], RectangleBox[{-0.584, 0.}, {-0.582, 0},
         RoundingRadius->0], RectangleBox[{-0.582, 0.}, {-0.58, 0},
         RoundingRadius->0], RectangleBox[{-0.58, 0.}, {-0.578, 0},
         RoundingRadius->0], RectangleBox[{-0.578, 0.}, {-0.576, 0},
         RoundingRadius->0], RectangleBox[{-0.576, 0.}, {-0.574, 0},
         RoundingRadius->0], RectangleBox[{-0.574, 0.}, {-0.572, 0},
         RoundingRadius->0], RectangleBox[{-0.572, 0.}, {-0.57, 0},
         RoundingRadius->0], RectangleBox[{-0.57, 0.}, {-0.568, 0},
         RoundingRadius->0], RectangleBox[{-0.568, 0.}, {-0.566, 0},
         RoundingRadius->0], RectangleBox[{-0.566, 0.}, {-0.564, 0},
         RoundingRadius->0], RectangleBox[{-0.564, 0.}, {-0.562, 0},
         RoundingRadius->0], RectangleBox[{-0.562, 0.}, {-0.56, 0},
         RoundingRadius->0], RectangleBox[{-0.56, 0.}, {-0.558, 0},
         RoundingRadius->0], RectangleBox[{-0.558, 0.}, {-0.556, 0},
         RoundingRadius->0], RectangleBox[{-0.556, 0.}, {-0.554, 0},
         RoundingRadius->0], RectangleBox[{-0.554, 0.}, {-0.552, 0},
         RoundingRadius->0], RectangleBox[{-0.552, 0.}, {-0.55, 0},
         RoundingRadius->0], RectangleBox[{-0.55, 0.}, {-0.548, 0},
         RoundingRadius->0], RectangleBox[{-0.548, 0.}, {-0.546, 0},
         RoundingRadius->0], RectangleBox[{-0.546, 0.}, {-0.544, 0},
         RoundingRadius->0], RectangleBox[{-0.544, 0.}, {-0.542, 0},
         RoundingRadius->0], RectangleBox[{-0.542, 0.}, {-0.54, 0},
         RoundingRadius->0], RectangleBox[{-0.54, 0.}, {-0.538, 0},
         RoundingRadius->0], RectangleBox[{-0.538, 0.}, {-0.536, 0},
         RoundingRadius->0], RectangleBox[{-0.536, 0.}, {-0.534, 0},
         RoundingRadius->0], RectangleBox[{-0.534, 0.}, {-0.532, 0},
         RoundingRadius->0], RectangleBox[{-0.532, 0.}, {-0.53, 0},
         RoundingRadius->0], RectangleBox[{-0.53, 0.}, {-0.528, 0},
         RoundingRadius->0], RectangleBox[{-0.528, 0.}, {-0.526, 0},
         RoundingRadius->0], RectangleBox[{-0.526, 0.}, {-0.524, 0},
         RoundingRadius->0], RectangleBox[{-0.524, 0.}, {-0.522, 0},
         RoundingRadius->0], RectangleBox[{-0.522, 0.}, {-0.52, 0},
         RoundingRadius->0], RectangleBox[{-0.52, 0.}, {-0.518, 0},
         RoundingRadius->0], RectangleBox[{-0.518, 0.}, {-0.516, 0},
         RoundingRadius->0], RectangleBox[{-0.516, 0.}, {-0.514, 0},
         RoundingRadius->0], RectangleBox[{-0.514, 0.}, {-0.512, 0},
         RoundingRadius->0], RectangleBox[{-0.512, 0.}, {-0.51, 0},
         RoundingRadius->0], RectangleBox[{-0.51, 0.}, {-0.508, 0},
         RoundingRadius->0], RectangleBox[{-0.508, 0.}, {-0.506, 0},
         RoundingRadius->0], RectangleBox[{-0.506, 0.}, {-0.504, 0},
         RoundingRadius->0], RectangleBox[{-0.504, 0.}, {-0.502, 0},
         RoundingRadius->0], RectangleBox[{-0.502, 0.}, {-0.5, 0},
         RoundingRadius->0], RectangleBox[{-0.5, 0.}, {-0.498, 0},
         RoundingRadius->0], RectangleBox[{-0.498, 0.}, {-0.496, 0},
         RoundingRadius->0], RectangleBox[{-0.496, 0.}, {-0.494, 0},
         RoundingRadius->0], RectangleBox[{-0.494, 0.}, {-0.492, 0},
         RoundingRadius->0], RectangleBox[{-0.492, 0.}, {-0.49, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.49, 0.}, 
         NCache[{-0.488, Rational[1, 200]}, {-0.488, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.488, 0.}, {-0.486, 0},
         RoundingRadius->0], RectangleBox[{-0.486, 0.}, {-0.484, 0},
         RoundingRadius->0], RectangleBox[{-0.484, 0.}, {-0.482, 0},
         RoundingRadius->0], RectangleBox[{-0.482, 0.}, {-0.48, 0},
         RoundingRadius->0], RectangleBox[{-0.48, 0.}, {-0.478, 0},
         RoundingRadius->0], RectangleBox[{-0.478, 0.}, {-0.476, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.476, 0.}, 
         NCache[{-0.474, Rational[1, 200]}, {-0.474, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.474, 0.}, {-0.472, 0},
         RoundingRadius->0], RectangleBox[{-0.472, 0.}, {-0.47, 0},
         RoundingRadius->0], RectangleBox[{-0.47, 0.}, {-0.468, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.468, 0.}, 
         NCache[{-0.466, Rational[1, 200]}, {-0.466, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.466, 0.}, {-0.464, 0},
         RoundingRadius->0], RectangleBox[{-0.464, 0.}, {-0.462, 0},
         RoundingRadius->0], RectangleBox[{-0.462, 0.}, {-0.46, 0},
         RoundingRadius->0], RectangleBox[{-0.46, 0.}, {-0.458, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.458, 0.}, 
         NCache[{-0.456, Rational[1, 200]}, {-0.456, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.456, 0.}, 
         NCache[{-0.454, Rational[1, 100]}, {-0.454, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.454, 0.}, 
         NCache[{-0.452, Rational[1, 200]}, {-0.452, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.452, 0.}, 
         NCache[{-0.45, Rational[1, 200]}, {-0.45, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.45, 0.}, {-0.448, 0},
         RoundingRadius->0], RectangleBox[{-0.448, 0.}, {-0.446, 0},
         RoundingRadius->0], RectangleBox[{-0.446, 0.}, {-0.444, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.444, 0.}, 
         NCache[{-0.442, Rational[1, 200]}, {-0.442, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.442, 0.}, {-0.44, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.44, 0.}, 
         NCache[{-0.438, Rational[1, 200]}, {-0.438, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.438, 0.}, {-0.436, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.436, 0.}, 
         NCache[{-0.434, Rational[1, 200]}, {-0.434, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.434, 0.}, {-0.432, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.432, 0.}, 
         NCache[{-0.43, Rational[1, 200]}, {-0.43, 0.005}],
         RoundingRadius->0], RectangleBox[{-0.43, 0.}, {-0.428, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.428, 0.}, 
         NCache[{-0.426, Rational[1, 100]}, {-0.426, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.426, 0.}, 
         NCache[{-0.424, Rational[1, 100]}, {-0.424, 0.01}],
         RoundingRadius->0], RectangleBox[{-0.424, 0.}, {-0.422, 0},
         RoundingRadius->0], RectangleBox[{-0.422, 0.}, {-0.42, 0},
         RoundingRadius->0], RectangleBox[{-0.42, 0.}, {-0.418, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.418, 0.}, 
         NCache[{-0.416, Rational[3, 200]}, {-0.416, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.416, 0.}, 
         NCache[{-0.414, Rational[1, 100]}, {-0.414, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.414, 0.}, 
         NCache[{-0.412, Rational[1, 200]}, {-0.412, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.412, 0.}, 
         NCache[{-0.41, Rational[1, 100]}, {-0.41, 0.01}],
         RoundingRadius->0], RectangleBox[{-0.41, 0.}, {-0.408, 0},
         RoundingRadius->0], 
        RectangleBox[{-0.408, 0.}, 
         NCache[{-0.406, Rational[1, 100]}, {-0.406, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.406, 0.}, 
         NCache[{-0.404, Rational[1, 100]}, {-0.404, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.404, 0.}, 
         NCache[{-0.402, Rational[3, 200]}, {-0.402, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.402, 0.}, 
         NCache[{-0.4, Rational[7, 200]}, {-0.4, 0.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.4, 0.}, 
         NCache[{-0.398, Rational[3, 200]}, {-0.398, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.398, 0.}, 
         NCache[{-0.396, Rational[1, 100]}, {-0.396, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.396, 0.}, 
         NCache[{-0.394, Rational[1, 100]}, {-0.394, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.394, 0.}, 
         NCache[{-0.392, Rational[1, 200]}, {-0.392, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.392, 0.}, 
         NCache[{-0.39, Rational[3, 100]}, {-0.39, 0.03}],
         RoundingRadius->0], 
        RectangleBox[{-0.39, 0.}, 
         NCache[{-0.388, Rational[3, 200]}, {-0.388, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.388, 0.}, 
         NCache[{-0.386, Rational[1, 40]}, {-0.386, 0.025}],
         RoundingRadius->0], 
        RectangleBox[{-0.386, 0.}, 
         NCache[{-0.384, Rational[3, 100]}, {-0.384, 0.03}],
         RoundingRadius->0], 
        RectangleBox[{-0.384, 0.}, 
         NCache[{-0.382, Rational[3, 200]}, {-0.382, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{-0.382, 0.}, 
         NCache[{-0.38, Rational[7, 200]}, {-0.38, 0.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.38, 0.}, 
         NCache[{-0.378, Rational[1, 200]}, {-0.378, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{-0.378, 0.}, 
         NCache[{-0.376, Rational[1, 40]}, {-0.376, 0.025}],
         RoundingRadius->0], 
        RectangleBox[{-0.376, 0.}, 
         NCache[{-0.374, Rational[1, 25]}, {-0.374, 0.04}],
         RoundingRadius->0], 
        RectangleBox[{-0.374, 0.}, 
         NCache[{-0.372, Rational[7, 200]}, {-0.372, 0.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.372, 0.}, 
         NCache[{-0.37, Rational[3, 50]}, {-0.37, 0.06}],
         RoundingRadius->0], 
        RectangleBox[{-0.37, 0.}, 
         NCache[{-0.368, Rational[7, 200]}, {-0.368, 0.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.368, 0.}, 
         NCache[{-0.366, Rational[9, 200]}, {-0.366, 0.045}],
         RoundingRadius->0], 
        RectangleBox[{-0.366, 0.}, 
         NCache[{-0.364, Rational[7, 200]}, {-0.364, 0.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.364, 0.}, 
         NCache[{-0.362, Rational[9, 200]}, {-0.362, 0.045}],
         RoundingRadius->0], 
        RectangleBox[{-0.362, 0.}, 
         NCache[{-0.36, Rational[11, 200]}, {-0.36, 0.055}],
         RoundingRadius->0], 
        RectangleBox[{-0.36, 0.}, 
         NCache[{-0.358, Rational[1, 25]}, {-0.358, 0.04}],
         RoundingRadius->0], 
        RectangleBox[{-0.358, 0.}, 
         NCache[{-0.356, Rational[3, 40]}, {-0.356, 0.075}],
         RoundingRadius->0], 
        RectangleBox[{-0.356, 0.}, 
         NCache[{-0.354, Rational[9, 100]}, {-0.354, 0.09}],
         RoundingRadius->0], 
        RectangleBox[{-0.354, 0.}, 
         NCache[{-0.352, Rational[7, 100]}, {-0.352, 0.07}],
         RoundingRadius->0], 
        RectangleBox[{-0.352, 0.}, 
         NCache[{-0.35, Rational[1, 10]}, {-0.35, 0.1}],
         RoundingRadius->0], 
        RectangleBox[{-0.35, 0.}, 
         NCache[{-0.348, Rational[1, 20]}, {-0.348, 0.05}],
         RoundingRadius->0], 
        RectangleBox[{-0.348, 0.}, 
         NCache[{-0.346, Rational[19, 200]}, {-0.346, 0.095}],
         RoundingRadius->0], 
        RectangleBox[{-0.346, 0.}, 
         NCache[{-0.344, Rational[11, 100]}, {-0.344, 0.11}],
         RoundingRadius->0], 
        RectangleBox[{-0.344, 0.}, 
         NCache[{-0.342, Rational[7, 50]}, {-0.342, 0.14}],
         RoundingRadius->0], 
        RectangleBox[{-0.342, 0.}, 
         NCache[{-0.34, Rational[1, 8]}, {-0.34, 0.125}],
         RoundingRadius->0], 
        RectangleBox[{-0.34, 0.}, 
         NCache[{-0.338, Rational[13, 200]}, {-0.338, 0.065}],
         RoundingRadius->0], 
        RectangleBox[{-0.338, 0.}, 
         NCache[{-0.336, Rational[23, 200]}, {-0.336, 0.115}],
         RoundingRadius->0], 
        RectangleBox[{-0.336, 0.}, 
         NCache[{-0.334, Rational[29, 200]}, {-0.334, 0.145}],
         RoundingRadius->0], 
        RectangleBox[{-0.334, 0.}, 
         NCache[{-0.332, Rational[1, 10]}, {-0.332, 0.1}],
         RoundingRadius->0], 
        RectangleBox[{-0.332, 0.}, 
         NCache[{-0.33, Rational[3, 20]}, {-0.33, 0.15}],
         RoundingRadius->0], 
        RectangleBox[{-0.33, 0.}, 
         NCache[{-0.328, Rational[27, 200]}, {-0.328, 0.135}],
         RoundingRadius->0], 
        RectangleBox[{-0.328, 0.}, 
         NCache[{-0.326, Rational[37, 200]}, {-0.326, 0.185}],
         RoundingRadius->0], 
        RectangleBox[{-0.326, 0.}, 
         NCache[{-0.324, Rational[7, 40]}, {-0.324, 0.175}],
         RoundingRadius->0], 
        RectangleBox[{-0.324, 0.}, 
         NCache[{-0.322, Rational[1, 8]}, {-0.322, 0.125}],
         RoundingRadius->0], 
        RectangleBox[{-0.322, 0.}, 
         NCache[{-0.32, Rational[17, 100]}, {-0.32, 0.17}],
         RoundingRadius->0], 
        RectangleBox[{-0.32, 0.}, 
         NCache[{-0.318, Rational[9, 50]}, {-0.318, 0.18}],
         RoundingRadius->0], 
        RectangleBox[{-0.318, 0.}, 
         NCache[{-0.316, Rational[17, 100]}, {-0.316, 0.17}],
         RoundingRadius->0], 
        RectangleBox[{-0.316, 0.}, 
         NCache[{-0.314, Rational[27, 100]}, {-0.314, 0.27}],
         RoundingRadius->0], 
        RectangleBox[{-0.314, 0.}, 
         NCache[{-0.312, Rational[3, 10]}, {-0.312, 0.3}],
         RoundingRadius->0], 
        RectangleBox[{-0.312, 0.}, 
         NCache[{-0.31, Rational[51, 200]}, {-0.31, 0.255}],
         RoundingRadius->0], 
        RectangleBox[{-0.31, 0.}, 
         NCache[{-0.308, Rational[51, 200]}, {-0.308, 0.255}],
         RoundingRadius->0], 
        RectangleBox[{-0.308, 0.}, 
         NCache[{-0.306, Rational[51, 200]}, {-0.306, 0.255}],
         RoundingRadius->0], 
        RectangleBox[{-0.306, 0.}, 
         NCache[{-0.304, Rational[29, 100]}, {-0.304, 0.29}],
         RoundingRadius->0], 
        RectangleBox[{-0.304, 0.}, 
         NCache[{-0.302, Rational[9, 25]}, {-0.302, 0.36}],
         RoundingRadius->0], 
        RectangleBox[{-0.302, 0.}, 
         NCache[{-0.3, Rational[57, 200]}, {-0.3, 0.285}],
         RoundingRadius->0], 
        RectangleBox[{-0.3, 0.}, 
         NCache[{-0.298, Rational[67, 200]}, {-0.298, 0.335}],
         RoundingRadius->0], 
        RectangleBox[{-0.298, 0.}, 
         NCache[{-0.296, Rational[37, 100]}, {-0.296, 0.37}],
         RoundingRadius->0], 
        RectangleBox[{-0.296, 0.}, 
         NCache[{-0.294, Rational[9, 25]}, {-0.294, 0.36}],
         RoundingRadius->0], 
        RectangleBox[{-0.294, 0.}, 
         NCache[{-0.292, Rational[63, 200]}, {-0.292, 0.315}],
         RoundingRadius->0], 
        RectangleBox[{-0.292, 0.}, 
         NCache[{-0.29, Rational[83, 200]}, {-0.29, 0.415}],
         RoundingRadius->0], 
        RectangleBox[{-0.29, 0.}, 
         NCache[{-0.288, Rational[23, 50]}, {-0.288, 0.46}],
         RoundingRadius->0], 
        RectangleBox[{-0.288, 0.}, 
         NCache[{-0.286, Rational[9, 25]}, {-0.286, 0.36}],
         RoundingRadius->0], 
        RectangleBox[{-0.286, 0.}, 
         NCache[{-0.284, Rational[81, 200]}, {-0.284, 0.405}],
         RoundingRadius->0], 
        RectangleBox[{-0.284, 0.}, 
         NCache[{-0.282, Rational[91, 200]}, {-0.282, 0.455}],
         RoundingRadius->0], 
        RectangleBox[{-0.282, 0.}, 
         NCache[{-0.28, Rational[53, 100]}, {-0.28, 0.53}],
         RoundingRadius->0], 
        RectangleBox[{-0.28, 0.}, 
         NCache[{-0.278, Rational[107, 200]}, {-0.278, 0.535}],
         RoundingRadius->0], 
        RectangleBox[{-0.278, 0.}, 
         NCache[{-0.276, Rational[5, 8]}, {-0.276, 0.625}],
         RoundingRadius->0], 
        RectangleBox[{-0.276, 0.}, 
         NCache[{-0.274, Rational[117, 200]}, {-0.274, 0.585}],
         RoundingRadius->0], 
        RectangleBox[{-0.274, 0.}, 
         NCache[{-0.272, Rational[123, 200]}, {-0.272, 0.615}],
         RoundingRadius->0], 
        RectangleBox[{-0.272, 0.}, 
         NCache[{-0.27, Rational[159, 200]}, {-0.27, 0.795}],
         RoundingRadius->0], 
        RectangleBox[{-0.27, 0.}, 
         NCache[{-0.268, Rational[137, 200]}, {-0.268, 0.685}],
         RoundingRadius->0], 
        RectangleBox[{-0.268, 0.}, 
         NCache[{-0.266, Rational[117, 200]}, {-0.266, 0.585}],
         RoundingRadius->0], 
        RectangleBox[{-0.266, 0.}, 
         NCache[{-0.264, Rational[189, 200]}, {-0.264, 0.945}],
         RoundingRadius->0], 
        RectangleBox[{-0.264, 0.}, 
         NCache[{-0.262, Rational[143, 200]}, {-0.262, 0.715}],
         RoundingRadius->0], 
        RectangleBox[{-0.262, 0.}, 
         NCache[{-0.26, Rational[3, 4]}, {-0.26, 0.75}],
         RoundingRadius->0], 
        RectangleBox[{-0.26, 0.}, 
         NCache[{-0.258, Rational[49, 50]}, {-0.258, 0.98}],
         RoundingRadius->0], 
        RectangleBox[{-0.258, 0.}, 
         NCache[{-0.256, Rational[33, 40]}, {-0.256, 0.825}],
         RoundingRadius->0], 
        RectangleBox[{-0.256, 0.}, 
         NCache[{-0.254, Rational[41, 40]}, {-0.254, 1.025}],
         RoundingRadius->0], 
        RectangleBox[{-0.254, 0.}, 
         NCache[{-0.252, Rational[43, 40]}, {-0.252, 1.075}],
         RoundingRadius->0], 
        RectangleBox[{-0.252, 0.}, 
         NCache[{-0.25, Rational[189, 200]}, {-0.25, 0.945}],
         RoundingRadius->0], RectangleBox[{-0.25, 0.}, {-0.248, 1},
         RoundingRadius->0], 
        RectangleBox[{-0.248, 0.}, 
         NCache[{-0.246, Rational[29, 25]}, {-0.246, 1.16}],
         RoundingRadius->0], 
        RectangleBox[{-0.246, 0.}, 
         NCache[{-0.244, Rational[231, 200]}, {-0.244, 1.155}],
         RoundingRadius->0], 
        RectangleBox[{-0.244, 0.}, 
         NCache[{-0.242, Rational[101, 100]}, {-0.242, 1.01}],
         RoundingRadius->0], 
        RectangleBox[{-0.242, 0.}, 
         NCache[{-0.24, Rational[257, 200]}, {-0.24, 1.285}],
         RoundingRadius->0], 
        RectangleBox[{-0.24, 0.}, 
         NCache[{-0.238, Rational[67, 50]}, {-0.238, 1.34}],
         RoundingRadius->0], 
        RectangleBox[{-0.238, 0.}, 
         NCache[{-0.236, Rational[139, 100]}, {-0.236, 1.39}],
         RoundingRadius->0], 
        RectangleBox[{-0.236, 0.}, 
         NCache[{-0.234, Rational[323, 200]}, {-0.234, 1.615}],
         RoundingRadius->0], 
        RectangleBox[{-0.234, 0.}, 
         NCache[{-0.232, Rational[301, 200]}, {-0.232, 1.505}],
         RoundingRadius->0], 
        RectangleBox[{-0.232, 0.}, 
         NCache[{-0.23, Rational[149, 100]}, {-0.23, 1.49}],
         RoundingRadius->0], 
        RectangleBox[{-0.23, 0.}, 
         NCache[{-0.228, Rational[309, 200]}, {-0.228, 1.545}],
         RoundingRadius->0], 
        RectangleBox[{-0.228, 0.}, 
         NCache[{-0.226, Rational[69, 40]}, {-0.226, 1.725}],
         RoundingRadius->0], 
        RectangleBox[{-0.226, 0.}, 
         NCache[{-0.224, Rational[327, 200]}, {-0.224, 1.635}],
         RoundingRadius->0], 
        RectangleBox[{-0.224, 0.}, 
         NCache[{-0.222, Rational[321, 200]}, {-0.222, 1.605}],
         RoundingRadius->0], 
        RectangleBox[{-0.222, 0.}, 
         NCache[{-0.22, Rational[331, 200]}, {-0.22, 1.655}],
         RoundingRadius->0], 
        RectangleBox[{-0.22, 0.}, 
         NCache[{-0.218, Rational[191, 100]}, {-0.218, 1.91}],
         RoundingRadius->0], 
        RectangleBox[{-0.218, 0.}, 
         NCache[{-0.216, Rational[89, 50]}, {-0.216, 1.78}],
         RoundingRadius->0], 
        RectangleBox[{-0.216, 0.}, 
         NCache[{-0.214, Rational[353, 200]}, {-0.214, 1.765}],
         RoundingRadius->0], 
        RectangleBox[{-0.214, 0.}, 
         NCache[{-0.212, Rational[43, 20]}, {-0.212, 2.15}],
         RoundingRadius->0], 
        RectangleBox[{-0.212, 0.}, 
         NCache[{-0.21, Rational[49, 25]}, {-0.21, 1.96}],
         RoundingRadius->0], 
        RectangleBox[{-0.21, 0.}, 
         NCache[{-0.208, Rational[5, 2]}, {-0.208, 2.5}],
         RoundingRadius->0], 
        RectangleBox[{-0.208, 0.}, 
         NCache[{-0.206, Rational[443, 200]}, {-0.206, 2.215}],
         RoundingRadius->0], 
        RectangleBox[{-0.206, 0.}, 
         NCache[{-0.204, Rational[517, 200]}, {-0.204, 2.585}],
         RoundingRadius->0], 
        RectangleBox[{-0.204, 0.}, 
         NCache[{-0.202, Rational[493, 200]}, {-0.202, 2.465}],
         RoundingRadius->0], 
        RectangleBox[{-0.202, 0.}, 
         NCache[{-0.2, Rational[451, 200]}, {-0.2, 2.255}],
         RoundingRadius->0], 
        RectangleBox[{-0.2, 0.}, 
         NCache[{-0.198, Rational[247, 100]}, {-0.198, 2.47}],
         RoundingRadius->0], 
        RectangleBox[{-0.198, 0.}, 
         NCache[{-0.196, Rational[489, 200]}, {-0.196, 2.445}],
         RoundingRadius->0], 
        RectangleBox[{-0.196, 0.}, 
         NCache[{-0.194, Rational[111, 40]}, {-0.194, 2.775}],
         RoundingRadius->0], 
        RectangleBox[{-0.194, 0.}, 
         NCache[{-0.192, Rational[547, 200]}, {-0.192, 2.735}],
         RoundingRadius->0], 
        RectangleBox[{-0.192, 0.}, 
         NCache[{-0.19, Rational[531, 200]}, {-0.19, 2.655}],
         RoundingRadius->0], 
        RectangleBox[{-0.19, 0.}, 
         NCache[{-0.188, Rational[609, 200]}, {-0.188, 3.045}],
         RoundingRadius->0], 
        RectangleBox[{-0.188, 0.}, 
         NCache[{-0.186, Rational[589, 200]}, {-0.186, 2.945}],
         RoundingRadius->0], 
        RectangleBox[{-0.186, 0.}, 
         NCache[{-0.184, Rational[583, 200]}, {-0.184, 2.915}],
         RoundingRadius->0], 
        RectangleBox[{-0.184, 0.}, 
         NCache[{-0.182, Rational[307, 100]}, {-0.182, 3.07}],
         RoundingRadius->0], 
        RectangleBox[{-0.182, 0.}, 
         NCache[{-0.18, Rational[123, 40]}, {-0.18, 3.075}],
         RoundingRadius->0], 
        RectangleBox[{-0.18, 0.}, 
         NCache[{-0.178, Rational[701, 200]}, {-0.178, 3.505}],
         RoundingRadius->0], 
        RectangleBox[{-0.178, 0.}, 
         NCache[{-0.176, Rational[667, 200]}, {-0.176, 3.335}],
         RoundingRadius->0], 
        RectangleBox[{-0.176, 0.}, 
         NCache[{-0.174, Rational[651, 200]}, {-0.174, 3.255}],
         RoundingRadius->0], 
        RectangleBox[{-0.174, 0.}, 
         NCache[{-0.172, Rational[351, 100]}, {-0.172, 3.51}],
         RoundingRadius->0], 
        RectangleBox[{-0.172, 0.}, 
         NCache[{-0.17, Rational[181, 50]}, {-0.17, 3.62}],
         RoundingRadius->0], 
        RectangleBox[{-0.17, 0.}, 
         NCache[{-0.168, Rational[92, 25]}, {-0.168, 3.68}],
         RoundingRadius->0], 
        RectangleBox[{-0.168, 0.}, 
         NCache[{-0.166, Rational[387, 100]}, {-0.166, 3.87}],
         RoundingRadius->0], 
        RectangleBox[{-0.166, 0.}, 
         NCache[{-0.164, Rational[757, 200]}, {-0.164, 3.785}],
         RoundingRadius->0], 
        RectangleBox[{-0.164, 0.}, 
         NCache[{-0.162, Rational[98, 25]}, {-0.162, 3.92}],
         RoundingRadius->0], 
        RectangleBox[{-0.162, 0.}, 
         NCache[{-0.16, Rational[753, 200]}, {-0.16, 3.765}],
         RoundingRadius->0], 
        RectangleBox[{-0.16, 0.}, 
         NCache[{-0.158, Rational[417, 100]}, {-0.158, 4.17}],
         RoundingRadius->0], 
        RectangleBox[{-0.158, 0.}, 
         NCache[{-0.156, Rational[104, 25]}, {-0.156, 4.16}],
         RoundingRadius->0], 
        RectangleBox[{-0.156, 0.}, 
         NCache[{-0.154, Rational[217, 50]}, {-0.154, 4.34}],
         RoundingRadius->0], 
        RectangleBox[{-0.154, 0.}, 
         NCache[{-0.152, Rational[423, 100]}, {-0.152, 4.23}],
         RoundingRadius->0], 
        RectangleBox[{-0.152, 0.}, 
         NCache[{-0.15, Rational[427, 100]}, {-0.15, 4.27}],
         RoundingRadius->0], 
        RectangleBox[{-0.15, 0.}, 
         NCache[{-0.148, Rational[879, 200]}, {-0.148, 4.395}],
         RoundingRadius->0], 
        RectangleBox[{-0.148, 0.}, 
         NCache[{-0.146, Rational[89, 20]}, {-0.146, 4.45}],
         RoundingRadius->0], 
        RectangleBox[{-0.146, 0.}, 
         NCache[{-0.144, Rational[227, 50]}, {-0.144, 4.54}],
         RoundingRadius->0], 
        RectangleBox[{-0.144, 0.}, 
         NCache[{-0.142, Rational[907, 200]}, {-0.142, 4.535}],
         RoundingRadius->0], 
        RectangleBox[{-0.142, 0.}, 
         NCache[{-0.14, Rational[907, 200]}, {-0.14, 4.535}],
         RoundingRadius->0], 
        RectangleBox[{-0.14, 0.}, 
         NCache[{-0.138, Rational[47, 10]}, {-0.138, 4.7}],
         RoundingRadius->0], 
        RectangleBox[{-0.138, 0.}, 
         NCache[{-0.136, Rational[24, 5]}, {-0.136, 4.8}],
         RoundingRadius->0], 
        RectangleBox[{-0.136, 0.}, 
         NCache[{-0.134, Rational[191, 40]}, {-0.134, 4.775}],
         RoundingRadius->0], 
        RectangleBox[{-0.134, 0.}, 
         NCache[{-0.132, Rational[47, 10]}, {-0.132, 4.7}],
         RoundingRadius->0], 
        RectangleBox[{-0.132, 0.}, 
         NCache[{-0.13, Rational[469, 100]}, {-0.13, 4.69}],
         RoundingRadius->0], 
        RectangleBox[{-0.13, 0.}, 
         NCache[{-0.128, Rational[473, 100]}, {-0.128, 4.73}],
         RoundingRadius->0], 
        RectangleBox[{-0.128, 0.}, 
         NCache[{-0.126, Rational[479, 100]}, {-0.126, 4.79}],
         RoundingRadius->0], 
        RectangleBox[{-0.126, 0.}, 
         NCache[{-0.124, Rational[957, 200]}, {-0.124, 4.785}],
         RoundingRadius->0], 
        RectangleBox[{-0.124, 0.}, 
         NCache[{-0.122, Rational[969, 200]}, {-0.122, 4.845}],
         RoundingRadius->0], 
        RectangleBox[{-0.122, 0.}, 
         NCache[{-0.12, Rational[499, 100]}, {-0.12, 4.99}],
         RoundingRadius->0], 
        RectangleBox[{-0.12, 0.}, 
         NCache[{-0.118, Rational[1029, 200]}, {-0.118, 5.145}],
         RoundingRadius->0], 
        RectangleBox[{-0.118, 0.}, 
         NCache[{-0.116, Rational[39, 8]}, {-0.116, 4.875}],
         RoundingRadius->0], 
        RectangleBox[{-0.116, 0.}, 
         NCache[{-0.114, Rational[493, 100]}, {-0.114, 4.93}],
         RoundingRadius->0], 
        RectangleBox[{-0.114, 0.}, 
         NCache[{-0.112, Rational[126, 25]}, {-0.112, 5.04}],
         RoundingRadius->0], 
        RectangleBox[{-0.112, 0.}, 
         NCache[{-0.11, Rational[1009, 200]}, {-0.11, 5.045}],
         RoundingRadius->0], 
        RectangleBox[{-0.11, 0.}, 
         NCache[{-0.108, Rational[1011, 200]}, {-0.108, 5.055}],
         RoundingRadius->0], 
        RectangleBox[{-0.108, 0.}, 
         NCache[{-0.106, Rational[1007, 200]}, {-0.106, 5.035}],
         RoundingRadius->0], 
        RectangleBox[{-0.106, 0.}, 
         NCache[{-0.104, Rational[26, 5]}, {-0.104, 5.2}],
         RoundingRadius->0], 
        RectangleBox[{-0.104, 0.}, 
         NCache[{-0.102, Rational[963, 200]}, {-0.102, 4.815}],
         RoundingRadius->0], 
        RectangleBox[{-0.102, 0.}, 
         NCache[{-0.1, Rational[131, 25]}, {-0.1, 5.24}],
         RoundingRadius->0], 
        RectangleBox[{-0.1, 0.}, 
         NCache[{-0.098, Rational[247, 50]}, {-0.098, 4.94}],
         RoundingRadius->0], 
        RectangleBox[{-0.098, 0.}, 
         NCache[{-0.096, Rational[123, 25]}, {-0.096, 4.92}],
         RoundingRadius->0], 
        RectangleBox[{-0.096, 0.}, 
         NCache[{-0.094, Rational[1077, 200]}, {-0.094, 5.385}],
         RoundingRadius->0], 
        RectangleBox[{-0.094, 0.}, 
         NCache[{-0.092, Rational[1033, 200]}, {-0.092, 5.165}],
         RoundingRadius->0], 
        RectangleBox[{-0.092, 0.}, 
         NCache[{-0.09, Rational[1037, 200]}, {-0.09, 5.185}],
         RoundingRadius->0], 
        RectangleBox[{-0.09, 0.}, 
         NCache[{-0.088, Rational[987, 200]}, {-0.088, 4.935}],
         RoundingRadius->0], 
        RectangleBox[{-0.088, 0.}, 
         NCache[{-0.086, Rational[971, 200]}, {-0.086, 4.855}],
         RoundingRadius->0], 
        RectangleBox[{-0.086, 0.}, 
         NCache[{-0.084, Rational[1043, 200]}, {-0.084, 5.215}],
         RoundingRadius->0], 
        RectangleBox[{-0.084, 0.}, 
         NCache[{-0.082, Rational[1021, 200]}, {-0.082, 5.105}],
         RoundingRadius->0], 
        RectangleBox[{-0.082, 0.}, 
         NCache[{-0.08, Rational[941, 200]}, {-0.08, 4.705}],
         RoundingRadius->0], 
        RectangleBox[{-0.08, 0.}, 
         NCache[{-0.078, Rational[121, 25]}, {-0.078, 4.84}],
         RoundingRadius->0], 
        RectangleBox[{-0.078, 0.}, 
         NCache[{-0.076, Rational[99, 20]}, {-0.076, 4.95}],
         RoundingRadius->0], 
        RectangleBox[{-0.076, 0.}, 
         NCache[{-0.074, Rational[943, 200]}, {-0.074, 4.715}],
         RoundingRadius->0], 
        RectangleBox[{-0.074, 0.}, 
         NCache[{-0.072, Rational[869, 200]}, {-0.072, 4.345}],
         RoundingRadius->0], 
        RectangleBox[{-0.072, 0.}, 
         NCache[{-0.07, Rational[87, 20]}, {-0.07, 4.35}],
         RoundingRadius->0], 
        RectangleBox[{-0.07, 0.}, 
         NCache[{-0.068, Rational[191, 40]}, {-0.068, 4.775}],
         RoundingRadius->0], 
        RectangleBox[{-0.068, 0.}, 
         NCache[{-0.066, Rational[451, 100]}, {-0.066, 4.51}],
         RoundingRadius->0], 
        RectangleBox[{-0.066, 0.}, 
         NCache[{-0.064, Rational[124, 25]}, {-0.064, 4.96}],
         RoundingRadius->0], 
        RectangleBox[{-0.064, 0.}, 
         NCache[{-0.062, Rational[35, 8]}, {-0.062, 4.375}],
         RoundingRadius->0], 
        RectangleBox[{-0.062, 0.}, 
         NCache[{-0.06, Rational[869, 200]}, {-0.06, 4.345}],
         RoundingRadius->0], 
        RectangleBox[{-0.06, 0.}, 
         NCache[{-0.058, Rational[893, 200]}, {-0.058, 4.465}],
         RoundingRadius->0], 
        RectangleBox[{-0.058, 0.}, 
         NCache[{-0.056, Rational[439, 100]}, {-0.056, 4.39}],
         RoundingRadius->0], 
        RectangleBox[{-0.056, 0.}, 
         NCache[{-0.054, Rational[437, 100]}, {-0.054, 4.37}],
         RoundingRadius->0], 
        RectangleBox[{-0.054, 0.}, 
         NCache[{-0.052, Rational[89, 20]}, {-0.052, 4.45}],
         RoundingRadius->0], 
        RectangleBox[{-0.052, 0.}, 
         NCache[{-0.05, Rational[827, 200]}, {-0.05, 4.135}],
         RoundingRadius->0], 
        RectangleBox[{-0.05, 0.}, 
         NCache[{-0.048, Rational[783, 200]}, {-0.048, 3.915}],
         RoundingRadius->0], 
        RectangleBox[{-0.048, 0.}, 
         NCache[{-0.046, Rational[397, 100]}, {-0.046, 3.97}],
         RoundingRadius->0], 
        RectangleBox[{-0.046, 0.}, 
         NCache[{-0.044, Rational[141, 40]}, {-0.044, 3.525}],
         RoundingRadius->0], 
        RectangleBox[{-0.044, 0.}, 
         NCache[{-0.042, Rational[769, 200]}, {-0.042, 3.845}],
         RoundingRadius->0], 
        RectangleBox[{-0.042, 0.}, 
         NCache[{-0.04, Rational[687, 200]}, {-0.04, 3.435}],
         RoundingRadius->0], 
        RectangleBox[{-0.04, 0.}, 
         NCache[{-0.038, Rational[387, 100]}, {-0.038, 3.87}],
         RoundingRadius->0], 
        RectangleBox[{-0.038, 0.}, 
         NCache[{-0.036, Rational[651, 200]}, {-0.036, 3.255}],
         RoundingRadius->0], 
        RectangleBox[{-0.036, 0.}, 
         NCache[{-0.034, Rational[67, 20]}, {-0.034, 3.35}],
         RoundingRadius->0], 
        RectangleBox[{-0.034, 0.}, 
         NCache[{-0.032, Rational[7, 2]}, {-0.032, 3.5}],
         RoundingRadius->0], 
        RectangleBox[{-0.032, 0.}, 
         NCache[{-0.03, Rational[82, 25]}, {-0.03, 3.28}],
         RoundingRadius->0], 
        RectangleBox[{-0.03, 0.}, 
         NCache[{-0.028, Rational[309, 100]}, {-0.028, 3.09}],
         RoundingRadius->0], 
        RectangleBox[{-0.028, 0.}, 
         NCache[{-0.026, Rational[123, 40]}, {-0.026, 3.075}],
         RoundingRadius->0], 
        RectangleBox[{-0.026, 0.}, 
         NCache[{-0.024, Rational[14, 5]}, {-0.024, 2.8}],
         RoundingRadius->0], 
        RectangleBox[{-0.024, 0.}, 
         NCache[{-0.022, Rational[591, 200]}, {-0.022, 2.955}],
         RoundingRadius->0], 
        RectangleBox[{-0.022, 0.}, 
         NCache[{-0.02, Rational[551, 200]}, {-0.02, 2.755}],
         RoundingRadius->0], 
        RectangleBox[{-0.02, 0.}, 
         NCache[{-0.018, Rational[261, 100]}, {-0.018, 2.61}],
         RoundingRadius->0], 
        RectangleBox[{-0.018, 0.}, 
         NCache[{-0.016, Rational[139, 50]}, {-0.016, 2.78}],
         RoundingRadius->0], 
        RectangleBox[{-0.016, 0.}, 
         NCache[{-0.014, Rational[539, 200]}, {-0.014, 2.695}],
         RoundingRadius->0], 
        RectangleBox[{-0.014, 0.}, 
         NCache[{-0.012, Rational[63, 25]}, {-0.012, 2.52}],
         RoundingRadius->0], 
        RectangleBox[{-0.012, 0.}, 
         NCache[{-0.01, Rational[47, 20]}, {-0.01, 2.35}],
         RoundingRadius->0], 
        RectangleBox[{-0.01, 0.}, 
         NCache[{-0.008, Rational[231, 100]}, {-0.008, 2.31}],
         RoundingRadius->0], 
        RectangleBox[{-0.008, 0.}, 
         NCache[{-0.006, Rational[43, 20]}, {-0.006, 2.15}],
         RoundingRadius->0], 
        RectangleBox[{-0.006, 0.}, 
         NCache[{-0.004, Rational[89, 40]}, {-0.004, 2.225}],
         RoundingRadius->0], 
        RectangleBox[{-0.004, 0.}, 
         NCache[{-0.002, Rational[439, 200]}, {-0.002, 2.195}],
         RoundingRadius->0], 
        RectangleBox[{-0.002, 0.}, 
         NCache[{0., Rational[199, 100]}, {0., 1.99}],
         RoundingRadius->0], 
        RectangleBox[{0., 0.}, 
         NCache[{0.002, Rational[389, 200]}, {0.002, 1.945}],
         RoundingRadius->0], RectangleBox[{0.002, 0.}, {0.004, 2},
         RoundingRadius->0], 
        RectangleBox[{0.004, 0.}, 
         NCache[{0.006, Rational[337, 200]}, {0.006, 1.685}],
         RoundingRadius->0], 
        RectangleBox[{0.006, 0.}, 
         NCache[{0.008, Rational[361, 200]}, {0.008, 1.805}],
         RoundingRadius->0], 
        RectangleBox[{0.008, 0.}, 
         NCache[{0.01, Rational[331, 200]}, {0.01, 1.655}],
         RoundingRadius->0], 
        RectangleBox[{0.01, 0.}, 
         NCache[{0.012, Rational[59, 40]}, {0.012, 1.475}],
         RoundingRadius->0], 
        RectangleBox[{0.012, 0.}, 
         NCache[{0.014, Rational[59, 40]}, {0.014, 1.475}],
         RoundingRadius->0], 
        RectangleBox[{0.014, 0.}, 
         NCache[{0.016, Rational[281, 200]}, {0.016, 1.405}],
         RoundingRadius->0], 
        RectangleBox[{0.016, 0.}, 
         NCache[{0.018, Rational[36, 25]}, {0.018, 1.44}],
         RoundingRadius->0], 
        RectangleBox[{0.018, 0.}, 
         NCache[{0.02, Rational[261, 200]}, {0.02, 1.305}],
         RoundingRadius->0], 
        RectangleBox[{0.02, 0.}, 
         NCache[{0.022, Rational[263, 200]}, {0.022, 1.315}],
         RoundingRadius->0], 
        RectangleBox[{0.022, 0.}, 
         NCache[{0.024, Rational[9, 8]}, {0.024, 1.125}],
         RoundingRadius->0], 
        RectangleBox[{0.024, 0.}, 
         NCache[{0.026, Rational[49, 40]}, {0.026, 1.225}],
         RoundingRadius->0], 
        RectangleBox[{0.026, 0.}, 
         NCache[{0.028, Rational[41, 40]}, {0.028, 1.025}],
         RoundingRadius->0], 
        RectangleBox[{0.028, 0.}, 
         NCache[{0.03, Rational[23, 25]}, {0.03, 0.92}],
         RoundingRadius->0], 
        RectangleBox[{0.03, 0.}, 
         NCache[{0.032, Rational[209, 200]}, {0.032, 1.045}],
         RoundingRadius->0], 
        RectangleBox[{0.032, 0.}, 
         NCache[{0.034, Rational[91, 100]}, {0.034, 0.91}],
         RoundingRadius->0], 
        RectangleBox[{0.034, 0.}, 
         NCache[{0.036, Rational[171, 200]}, {0.036, 0.855}],
         RoundingRadius->0], 
        RectangleBox[{0.036, 0.}, 
         NCache[{0.038, Rational[151, 200]}, {0.038, 0.755}],
         RoundingRadius->0], 
        RectangleBox[{0.038, 0.}, 
         NCache[{0.04, Rational[147, 200]}, {0.04, 0.735}],
         RoundingRadius->0], 
        RectangleBox[{0.04, 0.}, 
         NCache[{0.042, Rational[31, 40]}, {0.042, 0.775}],
         RoundingRadius->0], 
        RectangleBox[{0.042, 0.}, 
         NCache[{0.044, Rational[147, 200]}, {0.044, 0.735}],
         RoundingRadius->0], 
        RectangleBox[{0.044, 0.}, 
         NCache[{0.046, Rational[29, 50]}, {0.046, 0.58}],
         RoundingRadius->0], 
        RectangleBox[{0.046, 0.}, 
         NCache[{0.048, Rational[13, 20]}, {0.048, 0.65}],
         RoundingRadius->0], 
        RectangleBox[{0.048, 0.}, 
         NCache[{0.05, Rational[113, 200]}, {0.05, 0.565}],
         RoundingRadius->0], 
        RectangleBox[{0.05, 0.}, 
         NCache[{0.052, Rational[49, 100]}, {0.052, 0.49}],
         RoundingRadius->0], 
        RectangleBox[{0.052, 0.}, 
         NCache[{0.054, Rational[83, 200]}, {0.054, 0.415}],
         RoundingRadius->0], 
        RectangleBox[{0.054, 0.}, 
         NCache[{0.056, Rational[53, 100]}, {0.056, 0.53}],
         RoundingRadius->0], 
        RectangleBox[{0.056, 0.}, 
         NCache[{0.058, Rational[99, 200]}, {0.058, 0.495}],
         RoundingRadius->0], 
        RectangleBox[{0.058, 0.}, 
         NCache[{0.06, Rational[43, 100]}, {0.06, 0.43}],
         RoundingRadius->0], 
        RectangleBox[{0.06, 0.}, 
         NCache[{0.062, Rational[19, 40]}, {0.062, 0.475}],
         RoundingRadius->0], 
        RectangleBox[{0.062, 0.}, 
         NCache[{0.064, Rational[37, 100]}, {0.064, 0.37}],
         RoundingRadius->0], 
        RectangleBox[{0.064, 0.}, 
         NCache[{0.066, Rational[67, 200]}, {0.066, 0.335}],
         RoundingRadius->0], 
        RectangleBox[{0.066, 0.}, 
         NCache[{0.068, Rational[31, 100]}, {0.068, 0.31}],
         RoundingRadius->0], 
        RectangleBox[{0.068, 0.}, 
         NCache[{0.07, Rational[57, 200]}, {0.07, 0.285}],
         RoundingRadius->0], 
        RectangleBox[{0.07, 0.}, 
         NCache[{0.072, Rational[7, 25]}, {0.072, 0.28}],
         RoundingRadius->0], 
        RectangleBox[{0.072, 0.}, 
         NCache[{0.074, Rational[17, 100]}, {0.074, 0.17}],
         RoundingRadius->0], 
        RectangleBox[{0.074, 0.}, 
         NCache[{0.076, Rational[49, 200]}, {0.076, 0.245}],
         RoundingRadius->0], 
        RectangleBox[{0.076, 0.}, 
         NCache[{0.078, Rational[9, 50]}, {0.078, 0.18}],
         RoundingRadius->0], 
        RectangleBox[{0.078, 0.}, 
         NCache[{0.08, Rational[53, 200]}, {0.08, 0.265}],
         RoundingRadius->0], 
        RectangleBox[{0.08, 0.}, 
         NCache[{0.082, Rational[23, 100]}, {0.082, 0.23}],
         RoundingRadius->0], 
        RectangleBox[{0.082, 0.}, 
         NCache[{0.084, Rational[39, 200]}, {0.084, 0.195}],
         RoundingRadius->0], 
        RectangleBox[{0.084, 0.}, 
         NCache[{0.086, Rational[9, 50]}, {0.086, 0.18}],
         RoundingRadius->0], 
        RectangleBox[{0.086, 0.}, 
         NCache[{0.088, Rational[33, 200]}, {0.088, 0.165}],
         RoundingRadius->0], 
        RectangleBox[{0.088, 0.}, 
         NCache[{0.09, Rational[13, 100]}, {0.09, 0.13}],
         RoundingRadius->0], 
        RectangleBox[{0.09, 0.}, 
         NCache[{0.092, Rational[1, 8]}, {0.092, 0.125}],
         RoundingRadius->0], 
        RectangleBox[{0.092, 0.}, 
         NCache[{0.094, Rational[3, 20]}, {0.094, 0.15}],
         RoundingRadius->0], 
        RectangleBox[{0.094, 0.}, 
         NCache[{0.096, Rational[2, 25]}, {0.096, 0.08}],
         RoundingRadius->0], 
        RectangleBox[{0.096, 0.}, 
         NCache[{0.098, Rational[13, 100]}, {0.098, 0.13}],
         RoundingRadius->0], 
        RectangleBox[{0.098, 0.}, NCache[{0.1, Rational[2, 25]}, {0.1, 0.08}],
         
         RoundingRadius->0], 
        RectangleBox[{0.1, 0.}, 
         NCache[{0.102, Rational[19, 200]}, {0.102, 0.095}],
         RoundingRadius->0], 
        RectangleBox[{0.102, 0.}, 
         NCache[{0.104, Rational[2, 25]}, {0.104, 0.08}],
         RoundingRadius->0], 
        RectangleBox[{0.104, 0.}, 
         NCache[{0.106, Rational[19, 200]}, {0.106, 0.095}],
         RoundingRadius->0], 
        RectangleBox[{0.106, 0.}, 
         NCache[{0.108, Rational[13, 200]}, {0.108, 0.065}],
         RoundingRadius->0], 
        RectangleBox[{0.108, 0.}, 
         NCache[{0.11, Rational[3, 100]}, {0.11, 0.03}],
         RoundingRadius->0], 
        RectangleBox[{0.11, 0.}, 
         NCache[{0.112, Rational[13, 200]}, {0.112, 0.065}],
         RoundingRadius->0], 
        RectangleBox[{0.112, 0.}, 
         NCache[{0.114, Rational[9, 200]}, {0.114, 0.045}],
         RoundingRadius->0], 
        RectangleBox[{0.114, 0.}, 
         NCache[{0.116, Rational[9, 200]}, {0.116, 0.045}],
         RoundingRadius->0], 
        RectangleBox[{0.116, 0.}, 
         NCache[{0.118, Rational[13, 200]}, {0.118, 0.065}],
         RoundingRadius->0], 
        RectangleBox[{0.118, 0.}, 
         NCache[{0.12, Rational[1, 50]}, {0.12, 0.02}],
         RoundingRadius->0], 
        RectangleBox[{0.12, 0.}, 
         NCache[{0.122, Rational[3, 100]}, {0.122, 0.03}],
         RoundingRadius->0], 
        RectangleBox[{0.122, 0.}, 
         NCache[{0.124, Rational[3, 100]}, {0.124, 0.03}],
         RoundingRadius->0], 
        RectangleBox[{0.124, 0.}, 
         NCache[{0.126, Rational[1, 50]}, {0.126, 0.02}],
         RoundingRadius->0], 
        RectangleBox[{0.126, 0.}, 
         NCache[{0.128, Rational[1, 100]}, {0.128, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{0.128, 0.}, 
         NCache[{0.13, Rational[1, 50]}, {0.13, 0.02}],
         RoundingRadius->0], 
        RectangleBox[{0.13, 0.}, 
         NCache[{0.132, Rational[1, 100]}, {0.132, 0.01}],
         RoundingRadius->0], 
        RectangleBox[{0.132, 0.}, 
         NCache[{0.134, Rational[1, 50]}, {0.134, 0.02}],
         RoundingRadius->0], RectangleBox[{0.134, 0.}, {0.136, 0},
         RoundingRadius->0], RectangleBox[{0.136, 0.}, {0.138, 0},
         RoundingRadius->0], 
        RectangleBox[{0.138, 0.}, 
         NCache[{0.14, Rational[3, 200]}, {0.14, 0.015}],
         RoundingRadius->0], 
        RectangleBox[{0.14, 0.}, 
         NCache[{0.142, Rational[1, 200]}, {0.142, 0.005}],
         RoundingRadius->0], RectangleBox[{0.142, 0.}, {0.144, 0},
         RoundingRadius->0], 
        RectangleBox[{0.144, 0.}, 
         NCache[{0.146, Rational[1, 200]}, {0.146, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{0.146, 0.}, 
         NCache[{0.148, Rational[1, 200]}, {0.148, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{0.148, 0.}, 
         NCache[{0.15, Rational[1, 100]}, {0.15, 0.01}],
         RoundingRadius->0], RectangleBox[{0.15, 0.}, {0.152, 0},
         RoundingRadius->0], 
        RectangleBox[{0.152, 0.}, 
         NCache[{0.154, Rational[1, 200]}, {0.154, 0.005}],
         RoundingRadius->0], RectangleBox[{0.154, 0.}, {0.156, 0},
         RoundingRadius->0], RectangleBox[{0.156, 0.}, {0.158, 0},
         RoundingRadius->0], RectangleBox[{0.158, 0.}, {0.16, 0},
         RoundingRadius->0], RectangleBox[{0.16, 0.}, {0.162, 0},
         RoundingRadius->0], RectangleBox[{0.162, 0.}, {0.164, 0},
         RoundingRadius->0], RectangleBox[{0.164, 0.}, {0.166, 0},
         RoundingRadius->0], RectangleBox[{0.166, 0.}, {0.168, 0},
         RoundingRadius->0], RectangleBox[{0.168, 0.}, {0.17, 0},
         RoundingRadius->0], RectangleBox[{0.17, 0.}, {0.172, 0},
         RoundingRadius->0], 
        RectangleBox[{0.172, 0.}, 
         NCache[{0.174, Rational[1, 200]}, {0.174, 0.005}],
         RoundingRadius->0], 
        RectangleBox[{0.174, 0.}, 
         NCache[{0.176, Rational[3, 200]}, {0.176, 0.015}],
         RoundingRadius->0]}, {}, {}}}, {{}, {}, 
      {RGBColor[0., 0., 0.30000000000000004`], LineBox[CompressedData["
1:eJwUV3c8lu8XRmbmq2ghO4TICPXe57VSqAgNfZWMkmQliYzsrCQkhJKZvfdt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        "]]}, 
      {RGBColor[1, 0.6666666666666666, 
        NCache[
         Rational[1, 3], 0.3333333333333333]], LineBox[CompressedData["
1:eJwUV3c8lu8XtimEV4QiI6OsSFa9z/0qlFERlZCvJArZq5SMzJDICAlZZWRv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        "]]}, 
      {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwUl3c8V/8XxxFSskcSCqHQMFLk3vdHZiWZ1VdEEpJEhCgrIntnhWQlSfY+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        "]]}}}, InsetBox[
     TemplateBox[{
      InterpretationBox[
       "\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"m\\\",\\nFontSlant->\\\"Italic\\\"], \\\"wt\\\"]\\) = \
\\!\\(\\\"-0.3\\\"\\)\"", 
        StringForm[
        "\!\(\*SubscriptBox[\n StyleBox[\"m\",\nFontSlant->\"Italic\"], \
\"wt\"]\) = ``", 
         NumberForm[-0.3, 3]], Editable -> False],InterpretationBox[
       "\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"m\\\",\\nFontSlant->\\\"Italic\\\"], \\\"wt\\\"]\\) = \
\\!\\(\\\"-0.2\\\"\\)\"", 
        StringForm[
        "\!\(\*SubscriptBox[\n StyleBox[\"m\",\nFontSlant->\"Italic\"], \
\"wt\"]\) = ``", 
         NumberForm[-0.2, 3]], Editable -> False],InterpretationBox[
       "\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"m\\\",\\nFontSlant->\\\"Italic\\\"], \\\"wt\\\"]\\) = \
\\!\\(\\\"-0.1\\\"\\)\"", 
        StringForm[
        "\!\(\*SubscriptBox[\n StyleBox[\"m\",\nFontSlant->\"Italic\"], \
\"wt\"]\) = ``", 
         NumberForm[-0.1, 3]], Editable -> False]},
      "SwatchLegend",
      DisplayFunction->(StyleBox[
        StyleBox[
         PaneBox[
          TagBox[
           GridBox[{{
              TagBox[
               GridBox[{{
                  GraphicsBox[{
                    Directive[
                    Opacity[0.5], 
                    EdgeForm[
                    Opacity[-2.506]], 
                    RGBColor[0., 0., 0.30000000000000004`]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                   AspectRatio -> Full, ImageSize -> {10, 10}, 
                   PlotRangePadding -> None, ImagePadding -> 1, 
                   BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                  GraphicsBox[{
                    Directive[
                    Opacity[0.5], 
                    EdgeForm[
                    Opacity[-2.506]], 
                    RGBColor[1, 0.6666666666666666, 
                    NCache[
                    Rational[1, 3], 0.3333333333333333]]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                   AspectRatio -> Full, ImageSize -> {10, 10}, 
                   PlotRangePadding -> None, ImagePadding -> 1, 
                   BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                  GraphicsBox[{
                    Directive[
                    Opacity[0.5], 
                    EdgeForm[
                    Opacity[-2.506]], 
                    RGBColor[1, 0, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                   AspectRatio -> Full, ImageSize -> {10, 10}, 
                   PlotRangePadding -> None, ImagePadding -> 1, 
                   BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                GridBoxAlignment -> {
                 "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                AutoDelete -> False, 
                GridBoxDividers -> {
                 "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
                GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.5}}}],
                "Grid"]}}, 
            GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
            AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
           "Grid"], Alignment -> Left, AppearanceElements -> None, 
          ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"],
          LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
        Background -> Automatic, StripOnInput -> False]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"SwatchLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                   RowBox[{"EdgeForm", "[", 
                    RowBox[{"Opacity", "[", 
                    RowBox[{"-", "2.506`"}], "]"}], "]"}], ",", 
                   RowBox[{"RGBColor", "[", 
                    RowBox[{"0.`", ",", "0.`", ",", "0.30000000000000004`"}], 
                    "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                   RowBox[{"EdgeForm", "[", 
                    RowBox[{"Opacity", "[", 
                    RowBox[{"-", "2.506`"}], "]"}], "]"}], ",", 
                   RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0.6666666666666666`", ",", 
                    FractionBox["1", "3"]}], "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                   RowBox[{"EdgeForm", "[", 
                    RowBox[{"Opacity", "[", 
                    RowBox[{"-", "2.506`"}], "]"}], "]"}], ",", 
                   RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}]}], "]"}]}], 
             "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"Automatic", ",", "Automatic", ",", "Automatic"}], 
                   "}"}], ",", 
                 RowBox[{"{", 
                   
                   RowBox[{
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None", ",", "None", ",", "None", ",", 
                    "None", ",", "None"}], "}"}]}], "}"}]}]}], "]"}]& )], 
     Scaled[{0.2, 0.8}], ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesLabel->{"", 
     FormBox[
     "\"\\!\\(\\*\\nStyleBox[\\\"f\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\\!\\(\
\\*\\nStyleBox[\\\"m\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\*\\nStyleBox[\
\\\" \\\",\\nFontSlant->\\\"Italic\\\"]\\)| \
\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"wt\\\"],\\nFontSlant->\\\"Italic\\\"]\\))\"", TraditionalForm]},
   AxesOrigin->{0, 0},
   Frame->{True, True, False, False},
   FrameLabel->{{None, None}, {
      FormBox[
      "\"\\!\\(\\*\\nStyleBox[\\\"m\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"", 
       TraditionalForm], None}},
   LabelStyle->{FontFamily -> "Times", FontSize -> 10},
   Method->{},
   PlotRange->{{-0.7, 0.2}, All},
   PlotRangeClipping->True,
   PlotRangePadding->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         RGBColor[0., 0., 0.30000000000000004`], 
         Line[CompressedData["
1:eJwUV3c8lu8XRmbmq2ghO4TICPXe57VSqAgNfZWMkmQliYzsrCQkhJKZvfdt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          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         RGBColor[1, 0.6666666666666666, 
          Rational[1, 3]], 
         Line[CompressedData["
1:eJwUV3c8lu8XtimEV4QiI6OsSFa9z/0qlFERlZCvJArZq5SMzJDICAlZZWRv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          "]]}, {
         Hue[0.1421359549995791, 0.6, 0.6], 
         RGBColor[1, 0, 0], 
         Line[CompressedData["
1:eJwUl3c8V/8XxxFSskcSCqHQMFLk3vdHZiWZ1VdEEpJEhCgrIntnhWQlSfY+
svfee3zsXUYIP7+/7uM8zjmv53nde9/3vt/cBi/Un5CRkJA8oCAh+f/18Y+A
5f39ZZC4HdxBzH0pzbzDzn/t3zJ0jWQxKD6wkq5USNSx+bsMOxsMDjIU1tL8
wwV1CyvLIMN+sfSX6SvpuWMTX/rGlkE3S+N0vIudtIXp5ftZFcsgpq1Oo3DE
WdqRr7/MyGMZLqd37Wg885aOjOINaqJdBtpdsfe+U1+kUy9FfM47ugxDkid8
9uMSpAuraH9+plwGYsrps5cNEqX7l7daXu0tge1Y4YOprSRpdrlWGq6lJeCr
6O0H91TpqIU3H8ybluC1y0sBna8/pdNcfoffr1sC+poCoUMqmdLFrCYp16uW
oOZfYnjU30zpQYJGDWvJEhC8C6690c+W5gg9RwFpSyD9xk/ruUuedDTW7Uzn
swRLMnHcM9dBmnPK9Z/eswO9vsx2kupK6Ri/i3YZN5dg43JZRn5Yg/TwOEXu
faklWP9EasNY1yLNdWXwD4ngEtyUnt0OU2mXfuidKfL1xBI80OKvCGTpko4d
8XyhduTAz5QJtbJir3SSn/si7fYi6OOPhoR+DkinY67PGucWofg0f31iyIh0
zoLj7IeBRZBXnfS5RjouXRzlYKzYuAhzu9nC7e+J0pU37SbJSxZBwi55euLJ
tHTDlvXj8u+LoFsbcD4ndU5aRc2KhztpEW79fjrta7sg3Z5iOeYUswhTNut0
4o+XpPvvmeth/ovwhbw0LvzOqvTDH2Zc0R6LULi7Q0tm/1t6nPLZ0LbTItAb
Pr2jmv9H2ujh0+j/7BbBurxdp4N6XXo2x/hBvsUi2M084Vp9tSFtRmPEfvzp
ImSdKGzj/7spvWJo2Pfq0YF+zpz30ZAt6b9Mj+6JqR/Mm1ygXnhqV/rNMz3W
oJuLIH2r4ivGtC9NUqHbtXJ9Ee7GPExbCSbB3Nh1Qu5cWwS24PipmR+k2OGX
2hrpYgf87pqaH8NkmFfdfUYa4UVw+OBf58xNjtFy32t7dmYRzF1cu7+9psBY
WzXunGNZhHzdsJGSF1QYR+POw3SaRVhOjp5XoDqKcdd+MRejXISb8zauV4qo
Mf7KW475ewtwsTWlBXnRYMJlf3yxzQVwNhdTFbKlwy6W1rA4/1mAXqNDI7nS
9JhocdSn8uUFSJrIkl39RY9dyZf9rjizAPVqWsYSfQzY9YzgRrW+g7zvEHEY
Z8bk0401Q7oWQMGbPTGWyIwppV0b7G5bgGCRxC+x/izY7ZSJ+Qf1C6BGx75C
ucGKqSblWcVUL8BXvdua1T+PY+oJ3juj5QvQ9YD96isrNux+nBi1UdEC7Bgo
0T86wo49iDkcnJK3ALEk2e6kw+zYw+gB9vmsBbBf5Q+5X3ASMwx/J2iRtgDM
eMMAmTsn9iKg44b9pwU4/Ttd/EbRaeylX3JbccQCbJ+kDwiW5casfRz+2w9d
AL4u8U9nW7kxe0/ep25+B3z7v6XFGzzY2/ebK9VeCxClbmB7KJAXc3ZrsDvi
caCX3SJ55tIZ7L2zlaef0wIYPf8b5v+WD/vgqEjf5rAA5e7P6YWE+TGfNyfD
mewWQCTypOH1UX4s0K4iOdxiAc44+eqF/HcWi7Zgqol/tADHxP3vj4UKYbHm
0yqTugtA+ck+wPyVMBZvVtQtoL0An/UntP89OI8lmzyeSlNfgMaIDNst/CKW
anTFfFllAUrPtDgtcV7C0gypN0RuLcDbs3MtmnGXsEz9LIo82QUwV7bQePtT
BMt56OG7hRZg9lUYowtBFMvXecAiLb0AL3p13f51iGIl9w/x/RJfAEVJ7ckZ
KnGsVlVDroFvAS7pBn8pTJfABMMZE4u5FwCPHT6l/eoK5jPSRpHOuQBOV5rO
Z16/iqmaq9YEsCzAA1MZAevfklhmDt1ZV4YFeD26/fdulxTGvNvsaUWzABOU
jDeIcA3r9b598y7FArTR5NVSfscwqY5j3xRJF6BZ8WEiXwaORbM3UkvuzsPJ
VwpOZMUI0/96s+nk+jw0lz2ODNwkYDPViqpjxHlQ+nSFc/KJLHaT9vDP9tF5
sJ3TUKyjlcPStKoZKgfnwfd8Zt2DEjnMgijXkdQ5Dy6GQQMqwgpYuxC5eHjr
POh4H/nDvKiAiVtVhHxonIdEZztfzWxF7C/p9btmlfOQr/JInOveDUz7Bmme
btk86LrdqjkpdhMrDig7fqd4HvRiLKnsWW9hzqdQn0j2PKjkmFBrrSljVJi0
zuaXeVCLufV89YMqZuq2UzwTOw+OUotnTp5QwxobCjn7o+ZBOOMURvtdDQvQ
lhwpDp6HcV727j8T6tjvz39Ruv88dBX2qF/z0MA0Z/PiYr3noei7GL5xURNj
s5MwcH03D0ILeuTOQVqYPayXWznNA6W9yNsfynexQcoc3icO8xCrn1/ARHMP
iwsVm1S0mgc633XX25/vY2ezLpnQPJ6HyPV3k985dTCv7eXavYfzYJ1avhpL
p4styPw4t6I9D9SzL65FH3mIZbSen29XnwdD2yYyA2p9jJFt8Valyjz0usen
4KH6mLVeWlrOzXlQFAq+mc77CLu6JGgefn0ekpfLb4ypGGCRl+eaP+DzUJ2T
dHF93gD79+brRQepeUh/6X8F83uMlVGfXdUVnQfW3422JyYMMaVzfNa8PPOQ
NE6dwdNhjOkcXjqjzTUPMXwTP04FmmAWk7ldAezzQIw+x7Wh+RT7+Fnpyh7j
PGj+JTZMLZliqU4MM+J086D6xU9Wv+oZVqrbH/6Meh7yJo//sIw3w6ZOmG33
HpqHgo65ZUFLc2x7U/wbHck8gBf1Mvb4BUbbvftA4d8c1FxOSdK7YIFdDvIv
yVqbA2LJzQZ7MUvM7WiWs9/kHJA6X39t+8IKC59xEKkamwMn3RnWkCPWWFq1
3PjO0Bycpx/FTFKssQ7Xbtmn3XPQyJIkXb/2CpvSj12LbZ+D7tU2vYR4G2wb
N0nsbp6DDOG0rGYtW4xnZ4tSrmYONq357xc02mESfeV59hVzkPsg+VVLwGvs
Zp63yU+YA9VgaYsxbXvspRVnPVf+HAQ4me1mkr7Bfs0TfLdS5iDlUHisZawT
1ll3BL+UOAfmWq+fPFJ2xmaS25eMPs+Brqr5QmejM0ZvaKjaGTEHQoLXNIP6
XLAz18+TUofNwfHldIETRq7Y1dMbP2WC5mA1t3SYuOGK6Q96MP3wmoOHrO1H
W/jcMOtC1crJ93Nww0hqV6TSDfMMP/GK490cePnmDRoYu2M/NL91f3CYgyn7
s3Xlxe+xvcbmCEOzOTAmae2rTf6AMX77eDPKZA54LNICxyy8MP4P+jtthnNw
azyBm47gjd2W/62DdA/8JFpSGa76YPq8RTQ2/x3E4hetFzp8MWtSt9I0rTno
ybDZuFXih0WXsJxmV5kDVukwmZ/qAVhG1HCr6s05SA3QU5JtD8AqXye7eCjM
wR029tnvWoHY/GXJiTV8Dvr3rpG9MwnCpNJ1klouzsHnpiOPw3+FYN+76C/l
CM2BQXZd/3HLUOz0bmVBpMAcXNB2f6vKH4ZRKp9venJqDvB4m/vf4j9ir63G
7t46OQeZeWcML5mGYwuRoaOXjs+B7xC1tvjVCKx9dvfPDu0cSHVHPQyYicTk
GTLfjh2dg7a5ewb3G6Kw/KtGh2so5yBKaVTLKScai/FoZg/am4XCjD9bQ3Ex
mClfrMzZpVno6Js//ub5Z2xIWaOBZm4W0I2foeP7nzFV68NafyZnwTehgf7w
x3hMouKFSenQLDyTfv2Qv/ML9nWO9/eXvllYdL9k99I+AeNg7HX40DULaYbi
Iqf4EzGyRwR/zaZZ8CgLcrnll4S98lxjk6qbhdax68cFbiVjMz9S4k9VzULf
BU69k7QpWPMefe5c8SxoHv+kwZr8FYuMHht0TpuFaqaE7XNC3zGaylAjo5RZ
0E58zR7KlY45z99YuZUwC8pbO4OdJ35gRlKZh45Hz8JfW6T2NCQD63tk5Pvv
4yxUET8veHH9xJQ/sB8fD56FyTRSTo7vPzHRXlfB796zwG+pdZGrNxNL3JfI
DvI48Bsm8ajfOgtjE5jH7N7NgqViZ180aza290pDTdZhFuhv+jn3Ps3B6pnO
2PWZzsLUh9SxJY18DLvWSwpGs6AiHIpHcBZgGQY+3gkGs9CjLt+cvViAhf1c
i3mhPQsU+ZuD9PFF2JG+lLNadw/0iE3spe+LsTckuplS6rPw6UckT+7LEszg
TlUVxc1Z0CpwYLZ6BFiXzes78/KzsGAfbfafaBmmFHO+r1VmFnh8d6NP5Jdh
FxZDF6IkZ+Gikcwb59Zf2LaXEZPouVmQjszQqb9aiaW7vagS5JuFuo90A6KD
lZiBo50tL/cs/PEaS/jpVoXVW3oNMJ848GNBwRk8WY05Pgv2pWGZhRXDqv9u
xNRgok+iESXDLAQGWzKU6NRikffTv2xSzcKPehuloPk6TEU9T2uFfBYanviP
qRXXY2TKZYdnSWZBo3kN8w5uwExR+7P+vzNwwyXY8srdJkySf0OsZGYGZNyS
XUUiWrGFU/uTOcQZSH09/u8pVxsWd4IqPH10Bsba9L+WJbdhVDTs/2J7Z0CK
h3H9Rk07VkzJmx7eOQMk2rQ/QbcDsyAR1g9snQFHk4/TfX87sN4/WKVr7Qwk
fU7Q8MW6MJ9FBRuHyhkI2JM59nK6CyNM3zlrXTYDBcsn7waFdWMp/Y98nuTP
gP/Cru45il7M7pe7plLKDAyqiVtanh3AhIv8KGUSZsCHln9ljmQQG83+mC8Z
NwN6TsfZj4wOYkopXzmEwg/07n/3IMsaxv59zmzmDZkB0n8N4jeSRw6+H0XO
HAEzEKHgXuSuNood928i0njOgHvrftX6/TGs3rM7jNJtBjxY3tD+Gh/DHF1H
lPadZmDoU/lCucU4NvVqNW3FdgbyjtkSFiMmsFwdllcdxjPwybPQI/nMFGZ6
l0ug8fEMRO8TLBc6pjAuVYG+Sr0ZeHjtlaSn5zT2XlYSy703A6+JUn5PyWYx
Kez6crrGDMwH3Cshr53FliRufU6+MwP1nY954oPnsLuCuhQRigf5b/+OfcIW
sKNnjPICZWcgqLC2VJtjESvlfPHUCx3Un9diGiBdwvgZXJocrswApoot/Rlb
xtY3E0IfCswAW3LvmuLeKqbtmfcxmncGLEwduWhdf2NlbPUR/acO6gfMWr2O
/MF8JJc/3WWbgZL/fJcZzqxhPA6SSSpHZg7O36Laxl4bmCe1cooPxcH9f3FU
cfHCJrYU9TC1nnQGtHcj6xh6N7GC4nfpCtvTcIqGm7Pw6hamuteUi89PgzMx
s1fjyj8s1280/830NIhyvHkZQr6LcZz6U1g4MQ1ZEtsCwT272DRiA4nBaTDe
CW577r+POboY1FxomoaokzmFiYmkOJHhVZ1Z3TRwbUm5hfCR4TfiPRpSq6Yh
+ufhu8xfyXDmirQW/tJpmNRjGhEqOoR/I9/s4foxDc0bjaPxtJQ4feiRfp1v
0xAXnta2+50St+HjGIxMnoaWOObfVWqH8esKMqOscdPQ+fX5I/ZkKrzXw3uG
NnAaOPqWGMx8qHGcLWZO2XcaFFS/n6hQP4YnpGQseH2YhqKpGJOPXDT4i7qu
FUrXaUgjC2tRq6HFKalPb+29nIZPlSfo4BIDbhYluiP9YhrufHj8ljmNAW8X
kt+1fzYNdqUi/q2CjPgnZVPSzcfTQPrMInZAlAkX98s+sqw5DZZvHoVsv2DB
I7lqqM+rTYOWTMYJ/Agrvp/eR/Ps9jQ0KBl75SWx4vUtewzT8tNAjS7e/7V0
HH/EcIN9RGIatvlG2QJz2XH+eYX1BtFpaJfs/XLO/SQ+VynXmn9hGgzJDsdN
/seBW9sR3gfxT8PVW7+znFm5cEl1/JETzzTcvRPmAntc+J6QtLQZ1zSoZ+ii
scVTuOfIld/yrNNA8e2saPPKafx2weUmUcZp+KMfY6NqxY0zBoulnKKdBqpR
L70fW9x4tMLFh1sU03CpxXPIhpEXz/jOX5+2PgUj0Tyz7rZ8+CuPM4kRq1MQ
sHTvlgwHPy71iMf5/eIU1OuxPe+p4scrmbkk9CenQJv+aP2Zs2fxHgeWeKau
KbB78fSz9XkhPFqL6S1J2xQckqvau7grhOtfZLi/2DgFWaz/7RzqEMbnxo/R
1lROwZz2nfnUwAv43g1ye/vsKWhmvpbDdkkEr+Al0zLOmAJvjp9MfzJFcM/d
/YuaaVPg0RGkFycpijP+3Jk8nzAFBhEk3UR1MZyf7Y/aWPAUPFlYkNXOv4zP
r64IN/tPQfcbtVFqXQk8o2HpcJH3FPS3Vz/wpLyCSznNlYS8m4JiD2fKFyZX
8dtTY+eUrKYg2s5G8LDZNZyxbIT88ospuMzyVInzmjTeHTE0wv1sCo4GstmJ
0WO4/u2+0B2DKTiitz9O14Tj1tmtpD/UpwBKertVbsngkn7Ng1EqU3Dv3Yqv
fpMMvmfcmOd5cwrcxHOJohrXcc+Ttc8Nrk+BGemJqfemsni0K/SxiE7BQlFc
HkuDPM70p5pc6cLBPEt1zhqPFXCvx80X7QWnDvZris8T9xVwW7kh92GeKZCi
Ij2+JqeEq1PuiCQzTcFaVuPmU4pbeK0NmW4f3RTcvH7rteWvWziaPuJJfWwK
xuNs5N+6KuPCtWzDL8inYDHt7MpZZhX8sJeE19X1SVAySOPpL1bFHbexHNPV
SQh4W0k3fEkNXzOVH41enIS3rzu5NpPV8PFbmhKkU5NQR5Z3tyhWHS+meTle
1z0JvSSa3It5mriY42uaf+2T8Ljxv4hNBS08dcn56oWWSVCbfbpe36eFf2zx
9wuqmYQxmuwXItT38JeB36Ue5E/CQL++/2Tsf/gsac4T3+yDOLiX/qSqNq7/
sjgAMibhvTDp8XXyB/htjYYp3q+TcNoklZvxrQ5+lmU2aCFiEoSO8ia9SdXD
Y9xXSrjCJqGKVKI1XUYfZ9nYnFENmoS7TK8iNzP0cbIeSpTjNQn2ArmPdMMf
4UPhZ+bfOkyCs0pM8Refx7jmEWHWDNtJSOepc99lMMTrX4vJjFtNwpFCd4aO
SEM8X/v6RwWzg/na8cu3857gQRz6snS6k2Bz/EHBaS4T/IivsbnMf5OQfNOi
f/OXCe68ax5hpTUJHEI5YwymT/Hnw2+Xe25Pgn+9up5jjSmuFBcVFYdPQoS1
V7t54XOcZGJzaVJqEki1ub75OJnjeXya14WuTIJmj5DEtxsvcP5vx2ZzLh74
fVglmGNjgVPkvpVoOD0J+kJGMirXXuLFf/s+0HNOwtpFNuWsrJe49TWJIa0T
kzD9dEuI96IVTixbejfKMAlX19YGLS5a4+UNem3rZJPg8zWm4N89G9yetvjM
tX0iCK1PHluas8FF1NjsnHeI0BUzUBfoYovHdbdyUa8RIftlsaBKoR3uNCZj
dnqSCDv2eRdv6jjgEmdi4MkYEUZf05TZ073Bl4y2Gb8NEYHWKk/9bM0b/OFC
ZsHlbiK08Qp8eybniEtv8h6+VUOETyWi8zPFzviapLN2QAURvnI8vsco6IJ/
ezP4vQuIcORz+qe1CBecnSxUUz+fCJeB5vBZV1d86xhl/KuvRKD7rOuNbNzw
jDsG64WJRNDRM7rHs+OGmwSVKpHEEyHBwiRG7Z073nvcdtkrkghW/rK705/e
47k8M9Jx3kTYPd+urrrniZs/kQuY9DiYV/sc40rsB5wvJW5C0I0Iq78Mr/vJ
e+Eh5//zynlDhDzirNi5T974y6v1PfXPicBD+lj2p7MfLujAL0RvSgTLYuZQ
Nnl/fKzE1VHLiAi/3GQ0BQ8H4Kqy1/hGHxJhyWpGdqwnAL+okvZy/Q4Rkl/7
v18JD8IV+v/EzN4ignlec9wL9mBcx+haw5AiEQKKDWT0Y4NxL8d63mpEhPNK
p7h/Z4XgU+kznWEXiaAly9rw9uhHfFfqEqm3EBHIM9YzBVM/4sw1tuedBIiQ
SO9xlEElHJcZoXxvfIoI4ebxmtvxEXg0Hd+Vq3REcBVMDnztFo1nRZk9FqY+
8O8S7Ctw4xNeL5Dtf/owEezSVICMKQb/i2RnqPYnoONSWVRdbiyuYfEoom9p
Apjc80ZlP3/GTf+lVDXNTYCk6clzcuzxuLPnyuqvqQnIODgcvwiLx9PjnG6m
Dk+ATr5gYmT4F/xo26cd++YJ+J6zyplcnYhz604KvKifAOISVaf+gyT86qyw
5uPqCcgtThPd/pOEG5EWp90qnYAdlh5+EZEU/JdIvy5H+gTMVz06HT6civeW
cHvRpx7wFQNExEK/4Us3nuaSJ02AgXXHgw+qaTiHwV/axU8TYM8yNjPW9R23
C2ItK/GdgMbu4Lgn/hm4P9fDhZ8fJiDLrq5Ufz8DT0pNZEtyn4CEUO9A/OVP
vKNc3NLv7QSQ7y0OL+hn4hf+qPPoPZ+Aa+Re2VcMs3F5p0gVjacTcC5pkvHp
YjauQz1ur/hkAuZIx3y47HNwL17Ljou6E1Dr+pbTIiYXn9TwdyO5PQEl98rr
5FgK8HSbURKpGxMH64vfrvFnAW4TIfLWSn4C0LFog2PqhTjVSMerKWwC/smO
mdDEFOGCpmzGjRcm4NBodmeUUSn+2+fpBIXQBFznqcp8ygt40Y9CPSQwASYd
FiLpRMCV13XuZ56agEsssequhWW4ufPnG+H0E7AifWJl3bgcl/jyu6rt2AQc
/mmbmtdXju9XyV6nPjIBvsaqGL9KBR5APSXlSDoBcpP+PUqoEs8KExQ2/D0O
ESbRzBZy1fibAoeUT0vjAMJTdgZN1bjcYOOZnrlxWJtl3PD8rwbv5n7BeXNi
HDYUrXlLHGrxv2lZtJc6x6HypAP11Gw9XtZC7v20dRxo2LivRfo14B9+ax3+
0jgOA3w1NrxXGnH2q3/3WarGQdbBUIA2pAnHKqRXd3LGwYJKtXMateKUU77P
L2eOQym/wsn++Fa8mWpk1jx9HG6WUgWyUrXh+iou42NJB7xSo9/xfW24a19V
R83Hceg/5I77RHbgN/+xqpKGjEN3W2ulKkMnznTKpFEq4KBf4RBdm1cnnmB4
tOq75zhoulPly77vwmuWVXKDX4+Dp9ZP5uK4HjyAMU606dU4cLXHiAhc7MXv
X15Np3w5DqHVzbWdZb34nH1w8mvTcVAIet0qs9SHH6PsDdd7MA5XGPlaXa0G
cfGXzEuK98Yh+vKfmhjhIVxnWFX2ksY4uN0Mm1GeG8K/5dYtktwaB3NKQ7FW
qxH8pnHR9Xipcbhjj8a1Ho3hLzs2P3pJjIP10HJlddsYHonEF1+KjoNNoxzr
ttw4Pnf8+0dZwXHg42l2nRebwD/UxiwQT4zDCvvdxenLk3iG+IBME8s4cGQW
cN0vncR7445/zGEYBwInjwjHzSn87OsAmfdHxoE4Iti08mwarz3nGiawNQbF
6YX1Jwdm8ZXQ0nm69TGQlzIYtXWew9nIdgh/V8agfcJnsevcPG7cbzVfOzMG
jZfCIv56LuCU3k8Ipr1jcLOrdzTKYRm/sPk5VL1zDIwt+YYnuFfwu4+H56Ra
x+AfKaHdwHMFT7p2L5S6dgw6yyI9unRWcfkFpbm0vDGYLgkJE+f7g5vdd0eh
WWNgaVxCeiXmDx5S+Svk7Y8xEHZdjediX8OJ0VJIJXkMrvSG6I+zr+Nut4VD
lsPGwLbM9bnY9U08rcBktidoDB6f8P+i2bmJd/Il4mV+Y6DLRGRZfvoX593j
nA14PwYRY1HpY7FbeHk6HS5qMwbUlyVVWCT/4XPsysHsL8eg9gk1udbsP5zR
w3OGzHwM8KoK/tJPu7iBHmlwx5MxONybfsWcaR8npf8zba01Br1yQaIe7KTI
VMXtiYXaGKQa9Dfku5Kidh+WiWe3x+AJr4St6iIpSjhyddhAfgwkFHgqZ+rI
kOKht52ql8egZERvWzmeHGXI0Kori4zB7rGITelTFIjNObZF8fwYtPRw6FPF
UqC5f7/qcb4xsPdcEn6ZTIl8Nyh/CbOMgeT6G37TISq0IR6On2UYA3rlmhRq
qyPoodW5Yl6aMbhjnCvNdOwourRyK4+dYgyUBGQPfVaiRh2zAd+p1kehNutd
GHGRBkmf5REiXx2FngdNHmNxtCjBKCtlf2EUbJuPcc/co0M2E11fNoijsIJk
L0k8pUcnhtgjiZ2j8IjUh251lwG5nkw7Pto6Cm4az08NmTCiuf+w0IHGUXh+
xvzRhW5GVNytF9BeOQpnOCJdLuczIb3WhPdl2aNAcSSk4X4UC6qllSAvzhiF
PUxBfJmdFV26XeOSlzYKt300Lup8YkVk9bNv0hNGwaTM/9Lf1OMoseKCVXTI
KPDlGCbvzZ1AtGRlKx8DRkH4dkojzTt2ZENQMw/2GYWWtE85dlwnkVKJ1VMv
t1Hw7SjcSdXjQPO5+Xp21qNQ9NL0URjNKSSSel1ZU3MUBG3nyCGEByk7DZ0I
VR2F7iyvP2RbPMhI0266S3kUPPj8wu7o8aLove+u9+RH4fst+lAh0TOIUuNE
gbbEKKj+5brN8psPnT6b/T5KdBTcZ01sKo350bVdFc3BC6MQOHouoH2EH1kk
uy3rCozCDYF0L6keAdS/s8z3iG0UvNmD7fyI59Baq9efz8yjsMn+K9DTXBDR
JfH9GqcfhdBmXkX5HUEkp/pAx/DIKERr+JRLcwojnRu+fC1rI0DlHer+3e0C
Io+S2h/IHwHS4jeyepsiSFLeIlL35wjYBKvITmiJIvPlxMsjX0cg62y7kVyu
KOqVZTAbjxyBB+WvTpW/EUPfF6Z7Z96MQMEVn6AM7stoPIzT2vTVCOxSkPRy
B1xGbDIadAvPR+Cn4G5YMYkEcg0tlV9+OALp/PurH2ck0F08NHOdMAJpzO8c
GTuvIu+Z+tu2kiMgcWIpf1tTEpUFkcz+FRkB7tq3Fwx7JZHg9LNT/3hGwHJt
wnBuSgrt+V/3IaMYgf5PIwscZzCUPLb8hK5uGLoS3R1us8igSK5/mUtlw/Ds
od7hm9YyyO8BFUlz/jAoZNlkoS4ZZNN1OtInZRgo2o8+xz9dR3J1as1HPIfh
euYG8ZuCHLpK+fDkrNMwzBV2ZAXlyiEhWVOTWtthMHpsFVlzVh4xlriSeRgP
w4nKpfUbzApoNCNLglxxGCRf3mojOaKEOhfh3QQ+DIOvS4eSfJRQjWBja7nE
MNBkf7y2y3gDpScQTV34h6HJL0x3ReAmehPOErtHMQyMxhXk1tbKB+vb9vBW
5RA0RlMlW7WromMl7zR7i4eg49Wm3IXzamh/y/9zXvYQeP0dpCz6oIamrFKu
2SQMwS7vEzNzJXWUbdz34s+7ITj29GMLNqSBUhImi9sdhmDvNlXgB0VNFDW2
eiTTagg6ifsBv7M0keuDowkWj4cg/fDDo/LBWkj1zrXexetDcLE75STT83tI
zkeRr0lqCHhE9HvNZ++hK3UaL9NEh0D6jjENbnIfccmaHXvGMwSOcsaRT57/
hxYkPhFmSIeg9D0hQ+jjA+TJtZ8yXjYIGztiLIuS+mjEkytMuWAQOEWMGbY8
9ZHEH+xd7s9B+GL/RPJlnz4i1rzR9YofhLYwsYFKx0eIYLnNIOo2CEfzrrrG
DBigjwMn9qPeDALN6H21aonHaElecoHi1SA0+Ei+9Q9+jKLZ7ar7ngzCIib3
l1vdEG1VrNu7KA7CNIQvMxCfINULLCbzaBCipst0aW8boZRwcS2tq4OQz7TC
M51nhO4+t7p47twgFH58oXs72Bhlsq5OtB4dhNTsg63to6fI9OmC8unmARD/
5y0r++Q5+tVBLeVVPQD/eH8G7S4/R2y4kMBa6QDEMPlmcb81R9WMpqS1Pwbg
7cmh4JaYF4ineDrnReAA+I0Tki1JLNFr/sNf+j4MwHZ3ryalqiVqDeAPkHUd
gFdP1Gi24yyR45MnpsetBoDrju15FsWXaIB2ggs0B6BqxORncYIVEn1Nduzc
7YP+Zzrp8/tWyGuCeytIfgDeszuQftWxRlfz9TuMJAagUShhfZr9FQp5NOxB
yzYA0eqFMue/2SDl7L4V3YF+yCYZd+4+bY8Mfrb483X0Qyh3WwJ3vD2yTa+6
sFjfD8S/scxVfA4oPuWn2ZvCfqh6m3MeE3+D/kZ/mImM6IeHJrPCLC8cEW2k
k4dBYD/8QZn+cuROiPfjK37BDwd5ns3V09FOSCXwkWGBXT/opuvRHDZ1Rgnu
kqM99/qB12g4miTLBRW6XnSKvdMP8jVN95epXFGLEx+XsWI/0HWeEDfUd0Xb
rxl0NiT6wUeYWL3F9A6pms/2MLP2Q+NvZgofPzf0725Ei1pnH6SY7Ss86PFA
jJr+5ica+4BJMMNxQMkTCai504xV9MGyCNcJjWJPpH7L8pZFVh84MysbK339
gFLQjRq/oD54f/q5nEi0NyqVRkZ3vfpgnrLtmxqXD+qQvEzB5doHhwatbqbF
+6A9MW7Z75Z9cEMotEUs0xdpnt0qbVDtA3VbZuSz6I9M+ZZ1g5X6oC4En8Vl
ApATz+Q/bUIfqExcP7btE4BSOdqk5i72gY54qOits4GIhOFrLhVdH3D2+XpM
mweh71v30+WbeoGrgwHPJYQiuai/n8SqekHqxlubQ3GhaFA63Je7pBemDwk6
DJCEoaPOPWa7ab1w5PSVnes1YciE8q5Qjk8v5Kzn6Icah6P95HX2L269YOJW
fni4IxyF3Qg9GvimFz7zRbuPyUSgKp/OWTOzXlC49c5WlDcS8TBppJxR7oXn
TfPfMneiUGH274+Mcr0Q5uyw5WETjdTuBnmQSPfCzo7bsdt/opFzRJvRoFAv
1DR9dSn//QkNnVLlC6HuhesilQkMFHEoXPh2/KGGHqhsyI9JUI1Hl5oXAlfL
eyA+02ZKMTYe1bzwcRkp7AFHR3vq08vxaCOzQb8otQdiNtlKnYK+IA3Jm6es
vHqAuJd++tVMAprrn6V95NoDmwYV2ldkEpHrmw97KvY9YCA4p6oWlYgyoHZI
0LQHWIcvNsVoJCFaBcXo8Rs9YFkyo8nblYySpqe8W2V6IN+DxphfMgVhH947
lEr2wGMDeenkmBRk1lilHXmuB34Y/BOWMP+K6tTlTqgf6QFD3zOUbKe/ITc9
mbBftd0gMBX61b8jHTldWOOT+tUNi97Nb7Rv/ED2u0k5mQXdIM/4BRWX/UAW
Uce6vqR2w81ntG1C2hnoQU8P03ufbrBTUe8uvPcTid4xD7ypetAfde9635ss
dJ6Lm7tCqRui3w4lxFZlobOLHRnXZLohXDFIWJsuG3F5S7YKi3aDxD+Xz7mJ
2ehoDTkdHXM33KV/K/BgOAeN4VE+HT1dICcSZd/tko8GaVQ4lFu7IONoyyPx
gXzUPUiSVlnbBdUsNbvZlwtQo71RQ05BFzCWfW0UXCpA+bkiR8OjuqBcfeqZ
zPMiFHCh1kNHrwtO7HEIryWVIu9d++Nd97pg76ryHRJmQO8bzyffVu0C6ktj
PY9dAb0xDa7GZbpA3NrSP1akDBknPaTg5u2CQJkj5F3svxDOte46OdUJXyy/
jxDoK9BfJ8fKouFOYNLv2Fm7V4F+jh2mDOruhGsk1UWhcRXoTCL7B7y6E2jb
VZiTxSvREWGC/8fETijrkPK7Y1KFOiW9o24YdoJp1pT23/0a5BvFPHRKpxNc
DfNovt6rRQq7n7g2NDqBIHp+/UVGLSooy/gcL9sJFM871W49qUMxit3JOzyd
wBA3k+g+WI+eanFnfx/rAJ32rR2nQ82IJy91/V1fBzjFUNZNPG9Gg2ziV7Tb
OsDVa1vMu68ZqQwqFFL+6oBP8px5GdktSPyxWZleXAcgzvp1zZJWtGeR18ig
1wG5Kh13dr+0o/x2Au3M3Q6gzplJJSG2I0vx+julKh2gQebBX3qmAxE3B9tN
8Q5gKQ/89TylA9U5kvVVcHbA2mpmUEN+JwrxuT35arAdpsxEeSb3utHPk3PV
3Z3tYBW0G3hJoQc1p75PudLUDiGpf7XF/XoQVR082yppB1p6aSnT073IgUL0
95vYdvi0S0udfbsPGTiy7r8zaIfWwGb76cYB5ESTNUrUbgdfwcz4u6cHUXT0
nXJ5jXboIL2HBVsPou5CT/fDcu0wejiBzv7UELqxuU3tzdcO003HNnmchtEl
ixG2oJk2uHlbSudd1ii6ve+w/Xu0Df5pJrKtT4wiUz+2QY2+NjB4HLndwzyG
EtLUYlnq20BobaD4j+0YOj5bwRfxrQ0UqgZ3QmTH0d6jFNE48zZwSd/SOLo6
gZo0LJXT11rhdvybk+sp08jMI8/x8mIrBB/9bW83PY2OFu1mFE+2wnjeXJE9
/wxS4vFiaehuhYedlJ27iTOofCV+eDr/oD9c6Cv1t1mU79tpwf22FZrHJdW+
Nc2jhJoroSEUrXCWL3Jx8toKer+x43flXws4Pq9acHy8gip0Pf/IL7aATN+S
i673CsKFPxcbtLRAdGzS4vzAChKva1eJDm4Btbs7JGrOq+j0IQkrOo4WOCTv
/l6t+zf6a/OvaF24GUR0T4X65q2jzEMSbsDRDIdiPXo4FtbR84AXyh+ONcO9
jd/v909voPGv44McC03wYOJbb6n3BmoYrN2V/dYESOSjOc+TTRRzPRQFnWsC
J0EdvocCW0iO9kLFBf5GYDbfiuWa+Yf8E/XqjU/Vw4B/8LxWPBmB3hfaFejr
oX3pxoNXFWSEIOtTA3yk9fAm++NkGpGMECI7Mj8xXgd3bl2eNBA4RIgce0ij
n1QH4RFLbqPfDxGSOB+q3j9fB3c5RgObSskJpaE63UrXasHvVqag2yIlYcH9
v/Fz96phkZq8dcKAmjAXZKRSqVANEb5nc2w/UBNmY60KH0pUQ9i5b2xkGdSE
qQLfoGCWanDiZGbc/EdNGFn8dX23owrmZOv9b4YdI7RrCX5pVa0CmXDvc/1V
NIQ8vp3Htjcr4cJvbVl0hJ6QK0rVyiBVCYf9kv6dPElPyEYs0mnnKkFJkX15
UpiekPHfReYxqsqD/dvaV6RKT0j1fVx5s6YCeEXtIndD6QnR6w1nuOQqwJ71
vzvSnAwE16royUqsHH6m5+r5H2ckuJ3c/f3tfDmUF9R2z/MxEt5b6pIEc5ZD
TOm68FlxRoIXJ9fJR7u/gEKUoxlXZSQEvYpV3S3+BVdGzhr0vmckxPPFF12W
/gX37jo4GywyEhIcyOo4hH9BMbu7pM8WIyGpzaD7EMcv4NxgM/enYCKkvuVd
bdspg68h6jWnOZkImV0J/OZFZVD/kqbD8CYTocI9OTBJqgxif95u4P7ERKga
OBzrK1gG921ff8pLYiLUiJikWbOXgYBCowx3BhMhrEjNz30NgJ2EK8+8nImQ
/Exzq8QKwFy/2GuWyERIO87C7KMBwOthxsmyyETIqOi6oC0GoCDveJRxnYmQ
f/Ke4cbvUug8RdvkSM5MqG34r+XCy1J4LbbPz8HNTGi0ZZ/7p1YK/Wfm8+oF
mAmtvAPkDSKl0Pzmr7XSBWZCr4OOlPFqCcwPzVtlSDETBgU4tS63lcBglJJk
JIGZMNox9OLQzxLQDC0SUVdgJswI6SXGWpRAjsrDNiE1ZsJCz6my56olwEr8
Rnn7LjNh5d1o/7VLJdD3n7r3tQfMhL8Dj+h7l4vB8xVNupMhM+GfB49QUksx
6HTenew0YSaQiE/IW/8ohkTapzEbZsyEIz6GDvQvisG7/WhvjDUzIXrRkvWI
WjG8qFNYmrVlJly44/STVKwYVpqPRh92YCaUZfgobzMXw2sLIdh8y0xQZ4yc
/r1RBMdrYyQKnZkJRKtk1/neIgiwdhxXecdMsO3K5iQWFgGV35GEHHdmwtEr
5fmD0UWQ9yFJd8njgBfeotHlWAQ7TJO//3444G0PLjXpF4HHqJNSl/cB78Hc
h+rrRcBq9lDune8Br2TzDJwpgvmssCYyf2bCJBdFWR5lEWyPmDdqBDAT7JwZ
H2TMFELDxENBm8AD3vipjZT6QpigZWx/GnTAkz0f+DmtENiCTH5cCD7gJUoJ
R/oVAteu3Y/Kg7iMUqkmyKIQrqcElgmFHPBMtAy81QvBh1mq/fFBTKwz2H0n
XgjvZMS7zA5iWyGL8DeshSC+8rZI4SA+6vtW7NXfAhgdUrNbPdCLXvJqft5f
AOsrZ0me/5+nGv7UqLgAvmoVKRUczFP2M5FcL6YA/AJIb3QfzKvOlBV7z7kA
CM6XtyoO/BCty6RUDQogWrND3fXAr013U5eSXAEo2UWqMvgdPL+rAxYy/AUQ
YOS3ZOFzwIuYoZaiKoA7DpvnPnsd8HbWk0Tn8uFy1mPSeM8Dns6h60KN+XBb
M9na6v0Br5R+iDc9H5wjhtxY3A54p7jsOALygQV/Ku7pcsBzEWJieZkPl46s
v29wZCZEySncoJTIBytWXsFKuwP9JA3i3vF88N5+7/n61YH+4UdOm1t5wLps
nrhveaBX75AzU5IHl8Xt5BxND/SEP6iOxeZBt8DXYRsjZgKVX9h8n0se3Il/
a0wwYCacV/vJ3SCfB/HU+u8U/juo75ny/d6UC80Wj0ZPyx/US66dTfqRC1P/
7YzHI2ZCZCRpZUxgLsxJa7zckGQmgC7Htr9WLhy2zYphPFhvVEQ1o5dDOZCP
bd/gYT6ol9cjfQY5cCXwRpUYDTNBONks+vHnHIiLMCw5TslMUDP1aNd8kgPX
khmz720yESJXivEri9nw/dvCalEPE4H/05nPSY3ZsGXqfuVH88H36IbPIda0
bBikvmttXsVEqI9/ULtmmg0MSS2laplMhG3NbbXMmSw4JUXzOPMDE+E9qUE2
d20WaFiY8BxzYiIwptexBiZnweI9934xayaC4OGIgRdGWVDq36y5pMtEeFBw
5cl5Yib4teylHL/IRJh5ElsTXZEJm69NtWd5mAjWjIcFj33JBB2TY8+9WZkI
Ps+6l+YeZQIz6+PD13cZCcWcr+xSRn7CN8cbn1xrGQkcrpnevAMZEMHJZRx/
l5GQcoF9KagwA5qdVLISFBkJ4gMuqmSRGXDxI8ett1cZCcriaixj9zPAsCaP
MusEI+Fv4wiGff8BXuqOgdL9DISCUG1DsYTvUIUHtwlqMhCkBFR/ngr6CnY2
fFtwgZ5gPp9vo6H1FfDjFwvzOOgJX35wS3uwfYU+2rSH4UfpCceu/qleikkB
is1T9MKNdIRhpbDBkm/J4B1m2cN5lY7gYjp4WKcqEcztzFczqGgJtd9NHob/
/QwlQhdXy4OoCd9NyI7zlIZAkb7J4LwDJUFc0jxtSSEEFE3whn8alITCI/0y
RS3BQCRdkmcVpiRUp/400xwLgrendhqeDFIQRhf0y9+TB4Kf8W9Vb4yCIDDu
ONAd6gWf2J0/+ZKRE2YnVxk6HtpC6qMqR9poUgLZ2c/GFK6vQO+DYZaLDSmB
w1S15EqiFSR43uJhVCMlxA7qtl3teQEjK1ivDyUpwWyxx7FhRR/os00f/X1J
Qvg9ZqzMlf8f6lWv+HIxYQ9ZzjNyWHK6InpxA0nB/7ZR2G+TXO7T7xDt9Cue
cIZtVLhVqtrO44ZIqsyUntVvIXKqZ+5iZ98j+5RLj+WwLRR+pmJpXdQLVazy
qnUL/EUj6QX62JlAFMzAb0fNsIFeZhK/hyYGImnrtk2u1nVEnku3s8gfhOQ7
27999l9HZ0uehMacC0bv2ehtN+jW0csGhvr9C6FoL8Z9eoZlDVHMPBUrl4xA
2JHjrNeu/Ebh8yHO7EURaGx8IM5sdxUJLkPTS+lIlFsVJcZYuYpUNlhMeFEU
GjS99a9AfRWFk5dHu8l9QkT7P1OOr1ZQGD3Nuy/JcSggw/Bzw+dFdO78k4Un
mQmoJ7Mukb5kGnXLPmIsWUpA2wwZtafNppGrtu5VZqFE9DBfP2jt5DQa9NBy
K/+SiIxDd+uIb6dQwLg8x6nQJPQ0Ijao++Yk2vjIr9xrm4I2aOavGlNNoC/p
PC8vZqegOKUHjI8rxpFqFVf4+5UUtC6gqHncaRyl/mYlij/9ijJNv+Qm/h1D
urcPvwnUTkVSZyLzZNZGUSXZzLebWBo6nEhloXliGFmeILZ9fp2GcgOTHrom
DiGuS6Obf3PSUG2LgekhsSFkp9srm3zhO3q2MPJtQ20QCeXXDhw6nY7qeXVi
jWP7UV1up/tD0gykOjb/LMSmB50ub2fzOpWByp+Z399g7UE2Ta3fcrAMNPBn
dMozvxvxEBvbjtlnoMWtV4MS+13oDUMVZ9HvDCQkEqJuE9mJLpnl5Bwn/kQs
9IE1jpTtyEf4P5dG8ky0lcYfopPZhmYX/im78GWiqtOi6dZ6bSj+uRxxzigT
+SkPdigenMdYXnQwls5mIuGjqeeUaVvQy4u2wy+PZqF1BTpyitfNqHmZPVVA
KAvVv7wYTjbVhDwtDGQCzbIQnf7xI9nVjWjbcvWF4XIWYtmnkbwRX4/uioZe
O0GfjRQiPChcuOpR1u+rh5svZSPHcP7dpug6ZGblHHPlZTayYskd8Y+tRSPW
dE1H17NRe5GaDV1JNaq0PS/4czsHVXCKnV1Sr0Cnr7atPzmZi0hJhStgsRy9
/Wv9i106F3WFPIq46VWOJF4X33d7m4vivC27XtX+Ql/tb3ncI8lDdc+oFT7c
L0OU15bVj3HnofSF/2S9ScqQwU4Q1y+ZPCToknVIQhMQx5v+HMF3eagWCq9/
OlSK/N4+Je5S5KO6Wv/xGfciNI/RZGTy56NQlgmPhMVCpLSX4WCsmI+SWDj3
zt4vRKROfxnbPA/q9xWMDC8XIGtnD5kE6gI0OtSdGkiXh/57lxhzk6EQFT7j
uGwmlYXO+v2b7bxYiK4/W8v1actEG+Eal/VUCtFMS1TvR9NMFJRO2mjlfRDv
H45Si/+JGvt0t6IpilDBy1ymAIEMFEnMlhM4U4SS1jRF3SJ/oKfL1AE/rxeh
k1fWtO7MpiNKikL+aqcipCy2dHMq4DsiXGLVXN4qQrL8DGvfKb8h2mvPY1+z
FaN7Oc8nRp+loiH5yrlDV4pRHMPAcZbOr8j+wUsXNutiZORiMqb6PQVlv29O
l1kqRsUS3Vi9SxI6O/T+SMh4CWp5KiDakRKPNqaHNLlIS9FjeTG5zKvxqOq3
eFzKqVJE+SNqfKT+MzKgmpAo0SlFiz46vnvrcShaDBlOdZciBfpWHvPGGGSK
h/2wWC9FHOcWLy/RxiDJG4vb20yAOBli1y20PqHuh1GBdGqAjui7z15eikJ0
XpulVxsAwY/YYy3KEWg4ROVoxSwg+liQtP4ejrpb2lP5ycsQF7cXRyBDOEro
P7eRwVOGfhXGbqxMhCGZlR6fKr0y5OmX/5/fjxCU8upd5tEXB3nH7FVxwRBE
v3Oh947jwXuilL3fnRyMhine8/ZHlyHt4dN+Hd+CkMNJ8cKlvjIU1D/Yc6Yr
AA3f88GnZ8rQ6JOh4esmAeh6CLF8ZLMMKTvGFH3d8UdHaUIbWll+oTUjzx4l
fT8Uvrc+mKn2Cz0XvnxHQ98b/ZNSefRN/xeyOPdx89o3L6RnmzT55cUvdI3W
Ik5z+wPiX7m7FOL7C1GlZ2WVJXii7LG8fZu6X+giAwnX9YP/ABsXvduL3l/I
I+lYqFGQO3LQNqEymf6FfsDN6ydI3NH1DjaG/yjK0WPuox+GJ9+h1srXPNdk
ylE3S/ul5V4XJE7aniSmWo5sP425ftB1QR8xQSFhvXLEsjAXdmbSGT3M7Rfj
fFuOmGRZRq5sO6GF5Gvy+/nl6Pb8M6kf0W+QKjG4brOmHAUV/Lv/pt0BZZ1e
uL3SXY5y5A+d0qJxQPYR0XfH1srRj/TU+fzA14jKe9e44lIFGr7RwKTWboPM
arQWilAFIrmtIe903ga1HEq3yFapQPQx+sVEn1co7M3D14lmFcjFjfb12j1r
xGcOXh4pFUjs6beECI6XyDP1OJ1zXgUyWUjhXw2zRAtTL4LtqitQrQNZUB2z
JcrWOx39lFiBQi5dEUhlt0DX1Vy+3zpdiQouz9H/jTBDSb59InIXK5GB4/0r
GuXP0JF6kVxpvBINFXrO2q2Yotbr46XndSpRCK94U5juU/RQXLaVLrwSGT6b
CjCxNUJyt5ZWlFMq0eTuW9nloidIyCCCwSu/EqUryn08RvkE/fVfVifvq0Rd
r3X1rFIfo5GkSCuZ2UrUOfjplBX5Y1RdIh/iuFWJDv/Io7d5bICC56O6/p6o
QuejjmvvXHyE7MkUNy4LViHrrvbPUp/0kf6J36xWUlWo6bXr6gatPrqgqHR/
UbsKfd8OudC+p4tq49f6x6Kq0LdHS50D3NoovSB2hyutClV+SW4Iwf5Doa03
OXSKq9CeZfEZW/37yGAvTrd7sArNNrlnzhbeRTdYlB2ZFquQZxPdKstvLXRJ
eDNGdbcK8f65E/7lohba/e/2aD1nNTJM0E49W6KBiBZ/SaguVKMed+HaqmMa
qN7jC7c8Xo2iGi+n0Bmoo/CcLQN4WI0GrsxakXKqIVGGpMms2GpU6J8nvRd7
G7GdVaNc/VGNAtrfBFwNVEb7+D/+C2XVSMCm6/Ej71uo0UzdJGW0GiGX1nPm
ETdQ1rtdz8mVauQ9OGHenKaEIiNTvvKQ1qC+R/kVLLWKyLh2by6auwbBIzGp
JywKSGXkK3W/SA2qC85X3FSQR+IbmsLHr9egh9Rm59yc5BDZmW/PAw1qkEkt
hU8WuSyKdrq34v6lBnXvpTnAfwT0LoyMoSKrBhlp3vCftkfI9Pt3EZLKGmRH
QXaK7zaOrgwcsrIn1iA2C2uqcnppxPU7PThvrQYNi2Tv25FeQ+RHtLPXyGuR
W/nU0ewdSdQukbFuzleLHO1HbJyor6L82w9Y0y7Xoi9NNtuvT19BsYaUV2bl
a5H9Dc6iRkwCmQXp2D02qkVhN89GGwWIo8NLVDv3kmvRNyXqMmU/EcSf6jvg
lFuL9H+K0TyYu4QUjBiLk6tqUUHg2YSdW5fQ++GTbzcnapFkQLiQO34BJUXG
6Z76U4tEBfjIBLjPo6q7fLgiWR2qrjjn/5FGGJG3XNgPO12HHtSVC3wlE0Rn
vLNGSi/Wof8UgCzz6Dkkq3i1bAqvQ0VPqFj/O3kWuYKMi4RuHbI6WsT6VIsf
kWRoHuqOqEMrHtc21Pl40WmzvondlDpU/4phjeQZD0JnH1by5deha5SFrCp5
3Mgxztj9VXcdGrkxnT5jcBrF6Cw8+TRZhzRb80w+vjuFStgsFarW6hCFvmnr
qjIX+hdgf5iFqR5xXE5RHyThQBy396eleepRUWMLV8YcO7p2xK3WUKQeXeqQ
dY0dPoHsXXw/ZN+pRzdq+mRsJ46jLcs4ak2fekRTwDokcJ8ZsV3gW3CIqkeh
PKRTYx+Y0NW5r41fUg/qFXEP+QpGZGeQ5funth5VnNGj2b3FgMK5rpqf7K1H
vSqxmy2R9Civv1hFdroevUnPawwZpUMb6tV0wRQN6A8PdVKwDg1ipbu1Usjc
gMq+PTlWJHwMXW5oaR3nbUCnU41PmFFRI2vZ/zVY5eFUt0FUshRZsyUJiRZk
X3/vO7K3I2tJ0SaVLcqWIiTJZykJKZIS2RNJUahwufu9JJdUEkJ2ic/fc+bM
mZnzzDOdydpmreDsoy9J6l0Ff3SG11IjWuF2apnxmAAviI/5Tc7dagXH2Y7g
MjUe0Cqaoiveb4Vrwoe+izuvBD/lpTv+ta3gDcb2IY0rIKn32sV7La3Ay3H3
/sG3AkqyVjk3dLZCp93q6ve2XPBbQlxGbLYVmA7KHwIn/mFhStqsIX8b+F+x
SM0uXcDqt9Z3HpNqg1718Ny00L/4HO/mjFLdNsAhCu0iOnN4aMpAzta/DTgF
D0ift07hxASRe68j22DK+eUwt8Yk1tw0ILk1pQ1Wv06a0UMT+KJtmgh3RRvs
4l78NBE6jmUGzif4vG+Dz+Hyfo+ejuHay5arP9PaQJHG/8327SjmKpzkrpxs
g+cuawftyMP40c62Kwq8JHhx0cKA6j+ErdiPFhIkSeC7+G+/yKZf+CbvwemT
+iSY1879trF8AGtkbbtAtSIB5w3zTUXiD0zW5h7DziRoLS1+FB38HUsdKxuU
DibB0EpsmOPfj6un405Fx5HA3vt7Z/eVr/jwrWP9Y+kkuLvKZoXevT788JXI
l081JEi//ZSvgMnB5nYDrvotJKDPaRSfserBPwbeMHO7SBARbZzY/LEbb5f0
IYf9JYFrnQEhx92F2wst9/0UbAeRqPvJt16ysZ/ZhhYHuXaodPBLvBnOwlW+
be/VUTvUv8PdF7QZ2IUvzzRjXzsQtnlWa5Xo+G9WWB2fezvsSeDmKpCnYdOW
bS85Ee0QsvpcjjdBwf3HuHX3/tcO6kGHLl9xI+PYmc7S6gftcO2ruka1cAdu
Vb7xLLm+HTIPkYvmpluxT+0x1UVyO7iq6fkXXW/BovaGed597YAn1ahm2z5h
pysD9825O0B2j1d9Z04znpV8K1sq3gEnd8SZ2AY14cyitLtymzrgi/N0yB3n
RtzbaZk8Zd6x7Gf+JKrlO3zNb4Owp0MHxOfOBV21bcAq/FPx7Sc6IPJn3wOv
0/X4rG5e9JOYDpieH92007cOC7eGrZBI64APn+xv1nBqcanHwYir+R3gu3BP
zvnEKzydyB3s+mE5nvxSVy//JU7f3DXZxOqAyarc6GceVdjkdZm/9s8OWFJp
efZc/QWuDyx9EcNDhn6Rvcm6k+VY3FRusnYNGdyuXC0wHinDxwXjtP9IkOET
efM16kQp5ss9WuK+mQyHG4QrNPcXY+fzrSO31cnQeau/Z+3jIvzU0ECtVY8M
r4K1HqmKF+I9HcIFBlZkaBRZUorf9hTLTpPTrPeTIXxIJ+lrZz7+JZca7exE
BjHG1prSjMc4zlv62KVTZNAmN+nt2vcIuyR37rvuQwZWyfSqUJSLVaszTe5e
JEO16lzNsEkObuZVkH4ZS4a7ReNWqQ3ZOE3tK8+HRDKcP2cR/V7wPj55MO8P
M40M9iRytvr5TMyTs6V9Op8MF4izb0T80zH9w69avhIyzOVTOYfE7uJHv4sK
pF6S4X5BcWd04x1sRmjF6H8gw6ybkPHTo6lY/PhEgFUHGfZwdm5nW6bgvhsv
jjmxlvv7eXDR3iQZX2UZERcHlvVr9hVL5SZi28W/W2NHl/nKxtbncRLwxs1v
pNNmyPB0KnTPL72b+E2A2cQLfgrMnYqtvq4ahxPv8fQ1iVDAz555NLQ+Fh+p
b25nSFNgxzsvpcPnY/CC0J5nU6oU2FequOvNYhRu0xVK59WkwIyB8sl9fZE4
83BHjKQhZfl+DrV/pV3FxgUHPfRsKHArPKQ+vPUyFiBLHrC0pUDjVv8jX/jC
cec0i3B0oYAQaWbj+OFQHGzhJhPkRQHxiPfxlfsuYZuz8nwxfhQwX8HQoA4E
YemU3onbwRQY9xzQv5wWiKs4Jzoq4yhwSa9yi4B6AI7lU61rTKJATESwDFvc
HzuqDz6jp1Mgp3d+tcBqP6zsUJj+7SEFut+VrfTd4IMnQ8/HTj6lQPhIyOVV
VudwY86OQJ4yCszHqBMQ741TP457SNRQoHe3qGjcTy+sLXUR6X5a5i8KF785
chJzI8PtFhQKSE+9e5iafAJTjs/LOHRSoMmrRnjX7uP4YfxrvhN9FLBO6Ra8
IuWJ/coiJi8MLs+vgBmybuoYNmWbfr02vtyvjI+2dMtRLLLETU6do0CxSvTV
4pYjuHjv9cKK1VTYNsYauaVyCEdc2HXvvRgVZoc6lZZ/YLwvQ/A6bR0VumbC
RhZHnbBcAymwX5EKUtqVTd9CHPHwwH+eE1upcIcz41Ig64BfC9vbrtSmQmqA
mM802R7f1JPAa42pMCo8xozLtMPbrqWv09lNhX9N4k63KftxWrj16Wo7Kqy8
SJzondiLuS9OVyJXKgwq7MkZ09qDfXwfc78/RoWMmPBWo/hduMvLwdbGiwrM
dO1ky7/W2MpzZTbJlwpu4V+ulV2zwuWHy4fsL1FBNSVLWkPJEsfvF71+JJYK
oqWp5ReyzPC09Vv611tUEEuXrpgI2ok9d/ooed2hwpTht7SxY6a43XiD30gW
FWyzVuWyqjE21m2rC8ijwtDn/RaD7QTOVw8TnC1cxgenNe3nNsHiqttcL1dQ
IWyNb5GrnREeXBc3ef0dFYKHx3bJEvrYYa2BmVALFX7L5Ez303Vx/Zof/6VQ
qMC9VaQ0+JoOVuO780W6kwoCUCJ520obpy+Zb7/fSwWzseMfV27Qwjxzf4KV
flLhsID7pXxeTez3J6f5ySgVTuVp/2EsqmOb70se5YtU+Lq+90+9xTZc2VNc
YsBHg1KPDIpf6haswD7y77UQDR7+mJX4t6CCEyhr9phJ0uCG9mB/25XNeLal
Nv2DHA1eKFx96C6rjE80ev/Yq0yDSrvgfKtWJUyuW6dL3U6DaAslWY1kRfy0
9FJHtzENQrzcZLmL5bHEM5UNnmY0eDzj/8qoQA5ffcTwHthFA3c1gyj1Jlk8
nBVdfc6OBqI38r9xlmSwS5oO3x8XGjiKyM36OUvjxv++Hrx0bFlf+jhFrkUS
a95Izlk4TYMxS/VZIycJvCp8lOC/RIOG83pl9yvFcGBQdnxCBA2kj0rkrooW
xb0++9hisTRgVO0Qc2oXxnu9FjbfvUUDb5krPGk1a3C1R+EFuTs0mOIQr6I+
CGDlw4cacrJoYEx3EB2fWoWTHFaLqObRIEvzqDLLjB+ftj79TKuCBn87UkYv
a/JgqqnUbNUrGiwpCcfXk7iXDdFkSbyjwVyq0OGwqBX4mU5gasMnGmS+TjbR
3MeFpdQ39VlRaPD5u9DDMZdFFKVC1Whj02Av0/8QL15AvzdGhtv10mDz9G8F
Fet51CzOkXYbpcHZGYexM6+nkfaaxJN90zQICtLyclSeQtm8qOLUIg1sqHfS
O59MIIGlIa5hXjo0PRbp2Wb5B12czdjvL0SHs7udLDLmx9DX8V1Z0xJ0kInK
e6h6axTtH5odDJOjA41rqcnowAhS6XGKid1Oh3HtrncUq0FEt9ihWKxDhwmd
hLlauwEUWchfxzChQ4v0guv6qO9IQ7zX5Z85HcondDIQox91B1dPKu+lQ9nC
WdWHNl9RPCcpaa8DHfIw7+JwZy8ysDqjFuhGB77xAa9RIQ5KWSt74v05Olgo
NjgWuHQh09A/S78C6VBjmr12jRkbjfS2ZIpfpkP3yFTeEQcmyrB+ZGAcQwf7
DbPs9AQ6sikOo3ncokNg4eGDowNUNC3h4HvjDh28+8nUpuMU9ChMTbDsPh30
Z657e/ztQIs2X8y4iunwK0C4mcPbiopKXvSoVi3rU1l5/TL9I3KVSgw98IYO
nqdsPTZ1NCO+y6ekLjXTwcXCsCL8TyOq7Mfl2e10UHDV+BZg8h557pbe38yk
w/VIkujWJw1IpGx0cKSHDhWUAq5Z7XrkHfFQEY0u5++Rjg4wq0Uy34PrTszQ
QTQjJz15sRo17bFzTViig58q6czuwSoUUL51qoKfAc1tTo1Li5VIYR138mcR
BqwUEIxzJSpQ+5UutZUyDKAp/VcJ2WUo7Ef5x20KDBjW5icxFEsRs+I4V6gm
AxRkUihH+QtRtCyRlWPIgMcTNwsjXj1FWpEShp9MGeA7tvKJXHY+6hkYpo3Z
MGBTw8HT7sV5KGF/k6+MHQOY3un6lQO5yPjFfUFTVwZcVxEKpFvloIH1F5+c
9mBAu1YL6VzyA2Q2qMKp8mfA1FyhzI2DGWjswFJoTwgDWmHnhUn+dHS/iiXF
F8UArYM2inMjd9DuDaXl6vHL8Zfz52+uuI1mr8Xtd0xZzh+wlxnHKSj/17Ff
4RkMyJ1X3Fabm4QO2hnF5uUy4CrP76irBxMRV7WYUtszBljMfo7TyL2JiuV/
1U2UM8B1gHtMWe0Gcot557q+lgFbt//+HjQci1YPZ0yZvWdAyO7BtvSeaFRl
fyHZu5UB5sf8z3kuRqETNXvUU2gMoBeWv/hnHYnEFZQ/1XxmQF3Fjk0tvlfQ
29iFE339DLj3YPeR6jvh6NwInWv1MAOqm/hv0v+GIFmH51makwwYjQ65W5B1
CX18FWPossCAu1PB6/QuBKEgRXf6FR4mELph5j2hF5BSnL7fkzVMyFILvXa+
xB+Rfwuv6ZBggtAV1WYeIT902XHgybQcE9Bx3keaCufRttdvzeU3M+EiJ8KZ
7O2N2ErpHEt1JvTT3FZNTpxGMTf8ws7rMeHNgupW1aqTqP2d3iUBxIRs0v3u
eNJxJLMwH/DEggl5Yx7hqcKeyFOv3sdiLxM4Oj+zKEHHUJFPjHffQSYUjle3
GHC5o+knu09FHGZCuo2y21rHw8i0T8Rz/XEmuCtarO7+5oLiZRlHqr2ZcGTN
mg35z5wQ/WCGq2MAE+ql5mOHchyQ/K2jjn9CmBCiNfbnWrM98mpWtvsvkgmx
5peC70vYofKlwb1qN5hw+7HC87NiB9CCYYnNpyQm7OAbOb4F9iKrgECLU+lM
KPIjpccW7UJJhUamKx8yQbj3gIuMgzXq+rZo8vAJEwSbHZ2/aloiZflGA1TC
hAVLO5o9Nkc+zjd0uqqYICd2dLNR8E5UnbR/x6U3TDCP1ZoOewGIu2Xtdolm
Jmg97bCrbiTQ3pWdKmUkJoQV/pWolDZGaUS20n4GE2befiTFPjVAvUHH5Ye6
maDw9nnWB389tK1ki2zcNybk0tMoUT46KPDniOTm4eX9dZ5z1czQQm8UK8Te
TTDhyb0GtmPfDrTqcLDQ0b9M+JXJ7D7QrYbsb6PVC9wsUOD/+/Oo/DaUReLm
vSfAgkOrqt/vyFFFP/g+cumLs2A2TlB5yn0z0jS9tUBdx4Je86ZVp+w3odAQ
+1lfRRY0p0UsPb+oiN6XS0+u2coCnWseyR8TN6I1w92jBZos6FdL+483Ug45
bc4dsjJcrufEca99vQ49dD890A8sqLB0qjIwkUa/7qr1X7VmwbfnW1OOTksg
Xcp4z4YDLCi1SNmX+1McRQi87HrlxIIBJfO2kTVi6KN5ONPZnQVGXa9NrOuE
kfjlndTJkywIGtUQka8QRG5VfO3J51ngI+L2/uXEKpQ/2vpJI4gFo/4FvnLB
fGhsS3JTazgLBPIbjKaMeJCxp1ODVzQLtEwKrSJ0uFF05vo63gQWSBpNdYUc
5ULt9N7q3FQWvOwlK+0K+EfICOdXQiYLUlu3b3IMnic8rc+WdueygEN/42ny
aYYouqpZFPKMBVL0wG72kSliumbqiVQ5C4a1+lwqdkwQphOvHlXUsCBqWtTl
l+E4Ea929YFtwzL+rVqy/c/fBP2kZebIRxY4mRG9ejVDhPwDgbvx5GU9ESrs
2s8/CS92R4oqmwVmG96dnLT+QZSL3Uls5LBA4108V8l0P7Gw+1C8xwALEhwb
tc709RFW0RtjF3+zwIJZ9hhz9xJJdd8iM6dZ4OBE3/3iSTfRNV1w2XCRBTHy
ii8YuZ2EsqZvCIOXDZsYgZEqI0zC54xuUIAQGzxSCMfmCDpRnTvnJyLJBuWN
d2LTbKnEiu4354rk2LAxVHdoixuZSOGdfndvOxt2x5/wa9VqIZR2qK+7bswG
qU1yxnvGGolf720a/+1kQ2Wj9d2KF++IcpcTvoG72CBoEJKsXVVPmEVlNnm4
sMHV5LFoVO4rwpOxOoC4yIYQXovMFEYpEbUlWF76NhtuH5AvalR+TOyuS/10
K5MNeQliAfGkXELcviSQ5xEbYrIrevuqHhK5YT9axsvYYP5axqjDI4N43+5w
qa2DDRfPZa20dE0ieIK0yJGCnXCd5lgqnB5MtK3eFzYr3gmp3UJ8XtVBxO1s
LxVf2U7Yoaz/I1jtAqH88UG429ZOUF9xd+dh1nnCcr3wVgPrTug7RJ+3mfUg
Yht+RQ5HdcLVM4cX9wbvIviF83Sc5zuhWLD0qfsOaUJUdFDNj7sLMkzWRez9
uZaQFddQuSHQBWrStvnDEmKEhlS1TK1sF0zV99AJ2dWEg3zbP3mTLtARElOZ
6ps3ydWY/PAjrAuiajSSzrZ8MSEOWLhd/NcFk6HlH7JiH5j4JX2LvsPVDZFr
wzwaDoiZzNS4UrZ/+wI2UtufBWsUGcWzkxQzh7/A7xQfU3GePCP5mQ/+AlNf
YFFyXPmVQ5aRha6++CBvD9xsqqpdEk0wSioWP5iv2gMlia779lt7G2171EpX
ONsDVXvO1/ZkKBm5JyC25J8eyFo4Ix/jf8lw/Fnglpj5HhhecWdjb+JZw+hP
hcGT3BwYZH7v9uE/ZljIJ7uOtpYDdamei6Q5C8PZq9OuSXockKpeS9VmCxum
BJV8FgjhAN+noZm12rcMNt/+sT00kgMePOdLnouGGlSXbwgfvMGBMwLSzFcJ
pww4ozflPmZwQIS64XubBTZQ8/Y6EvOaA+mailCs1qP/Nu7B88lGDiS0qIXt
7m/Qt3/C/HecxAGLu1E1ddsf6Qd/s8g26+FAvOROz+k3bvqCK8N/l/1Y5sMk
1ysTWvrZihVYcZQDYxzL33JJi3rapr8Sk2Y4UOLEnVrpXK3X5K7IWVriwIUp
X9KNc1G6/wMTPm4b
          "]]}}}, {
       Directive[
        EdgeForm[
         Opacity[-2.506]], 
        RGBColor[
        0.798413061722744, 0.824719615472648, 0.968322270542458]], {{{{}, {
           Directive[
            Opacity[0.5], 
            Directive[
             EdgeForm[
              Opacity[-2.506]], 
             RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458]], 
            Directive[
             RGBColor[0., 0., 0.30000000000000004`]]], {{{
              Rectangle[{-0.74, 0.}, {-0.738, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.738, 0.}, {-0.736, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.736, 0.}, {-0.734, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.734, 0.}, {-0.732, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.732, 0.}, {-0.73, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.73, 0.}, {-0.728, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.728, 0.}, {-0.726, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.726, 0.}, {-0.724, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.724, 0.}, {-0.722, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.722, 0.}, {-0.72, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.72, 0.}, {-0.718, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.718, 0.}, {-0.716, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.716, 0.}, {-0.714, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.714, 0.}, {-0.712, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.712, 0.}, {-0.71, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.71, 0.}, {-0.708, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.708, 0.}, {-0.706, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.706, 0.}, {-0.704, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.704, 0.}, {-0.702, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.702, 0.}, {-0.7, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.7, 0.}, {-0.698, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.698, 0.}, {-0.696, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.696, 0.}, {-0.694, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.694, 0.}, {-0.692, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.692, 0.}, {-0.69, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.69, 0.}, {-0.688, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.688, 0.}, {-0.686, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.686, 0.}, {-0.684, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.684, 0.}, {-0.682, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.682, 0.}, {-0.68, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.68, 0.}, {-0.678, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.678, 0.}, {-0.676, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.676, 0.}, {-0.674, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.674, 0.}, {-0.672, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.672, 0.}, {-0.67, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.67, 0.}, {-0.668, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.668, 0.}, {-0.666, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.666, 0.}, {-0.664, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.664, 0.}, {-0.662, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.662, 0.}, {-0.66, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.66, 0.}, {-0.658, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.658, 0.}, {-0.656, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.656, 0.}, {-0.654, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.654, 0.}, {-0.652, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.652, 0.}, {-0.65, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.65, 0.}, {-0.648, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.648, 0.}, {-0.646, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.646, 0.}, {-0.644, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.644, 0.}, {-0.642, 
                Rational[7, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.642, 0.}, {-0.64, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.64, 0.}, {-0.638, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.638, 0.}, {-0.636, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.636, 0.}, {-0.634, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.634, 0.}, {-0.632, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.632, 0.}, {-0.63, 
                Rational[1, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.63, 0.}, {-0.628, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.628, 0.}, {-0.626, 
                Rational[1, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.626, 0.}, {-0.624, 
                Rational[7, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.624, 0.}, {-0.622, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.622, 0.}, {-0.62, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.62, 0.}, {-0.618, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.618, 0.}, {-0.616, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.616, 0.}, {-0.614, 
                Rational[1, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.614, 0.}, {-0.612, 
                Rational[1, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.612, 0.}, {-0.61, 
                Rational[3, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.61, 0.}, {-0.608, 
                Rational[7, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.608, 0.}, {-0.606, 
                Rational[7, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.606, 0.}, {-0.604, 
                Rational[3, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.604, 0.}, {-0.602, 
                Rational[7, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.602, 0.}, {-0.6, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.6, 0.}, {-0.598, 
                Rational[1, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.598, 0.}, {-0.596, 
                Rational[1, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.596, 0.}, {-0.594, 
                Rational[1, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.594, 0.}, {-0.592, 
                Rational[11, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.592, 0.}, {-0.59, 
                Rational[1, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.59, 0.}, {-0.588, 
                Rational[1, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.588, 0.}, {-0.586, 
                Rational[3, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.586, 0.}, {-0.584, 
                Rational[3, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.584, 0.}, {-0.582, 
                Rational[11, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.582, 0.}, {-0.58, 
                Rational[13, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.58, 0.}, {-0.578, 
                Rational[17, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.578, 0.}, {-0.576, 
                Rational[7, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.576, 0.}, {-0.574, 
                Rational[9, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.574, 0.}, {-0.572, 
                Rational[23, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.572, 0.}, {-0.57, 
                Rational[11, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.57, 0.}, {-0.568, 
                Rational[1, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.568, 0.}, {-0.566, 
                Rational[27, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.566, 0.}, {-0.564, 
                Rational[1, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.564, 0.}, {-0.562, 
                Rational[23, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.562, 0.}, {-0.56, 
                Rational[29, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.56, 0.}, {-0.558, 
                Rational[11, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.558, 0.}, {-0.556, 
                Rational[39, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.556, 0.}, {-0.554, 
                Rational[23, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.554, 0.}, {-0.552, 
                Rational[13, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.552, 0.}, {-0.55, 
                Rational[4, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.55, 0.}, {-0.548, 
                Rational[31, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.548, 0.}, {-0.546, 
                Rational[33, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.546, 0.}, {-0.544, 
                Rational[11, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.544, 0.}, {-0.542, 
                Rational[1, 4]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.542, 0.}, {-0.54, 
                Rational[47, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.54, 0.}, {-0.538, 
                Rational[21, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.538, 0.}, {-0.536, 
                Rational[11, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.536, 0.}, {-0.534, 
                Rational[1, 4]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.534, 0.}, {-0.532, 
                Rational[57, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.532, 0.}, {-0.53, 
                Rational[3, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.53, 0.}, {-0.528, 
                Rational[27, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.528, 0.}, {-0.526, 
                Rational[7, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.526, 0.}, {-0.524, 
                Rational[27, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.524, 0.}, {-0.522, 
                Rational[73, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.522, 0.}, {-0.52, 
                Rational[33, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.52, 0.}, {-0.518, 
                Rational[57, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.518, 0.}, {-0.516, 
                Rational[69, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.516, 0.}, {-0.514, 
                Rational[77, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.514, 0.}, {-0.512, 
                Rational[71, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.512, 0.}, {-0.51, 
                Rational[9, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.51, 0.}, {-0.508, 
                Rational[3, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.508, 0.}, {-0.506, 
                Rational[87, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.506, 0.}, {-0.504, 
                Rational[93, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.504, 0.}, {-0.502, 
                Rational[107, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.502, 0.}, {-0.5, 
                Rational[12, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.5, 0.}, {-0.498, 
                Rational[109, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.498, 0.}, {-0.496, 
                Rational[11, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.496, 0.}, {-0.494, 
                Rational[131, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.494, 0.}, {-0.492, 
                Rational[121, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.492, 0.}, {-0.49, 
                Rational[23, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.49, 0.}, {-0.488, 
                Rational[69, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.488, 0.}, {-0.486, 
                Rational[29, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.486, 0.}, {-0.484, 
                Rational[5, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.484, 0.}, {-0.482, 
                Rational[13, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.482, 0.}, {-0.48, 
                Rational[22, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.48, 0.}, {-0.478, 
                Rational[149, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.478, 0.}, {-0.476, 
                Rational[17, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.476, 0.}, {-0.474, 
                Rational[193, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.474, 0.}, {-0.472, 
                Rational[183, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.472, 0.}, {-0.47, 
                Rational[81, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.47, 0.}, {-0.468, 
                Rational[189, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.468, 0.}, {-0.466, 
                Rational[203, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.466, 0.}, {-0.464, 
                Rational[181, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.464, 0.}, {-0.462, 
                Rational[203, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.462, 0.}, {-0.46, 
                Rational[11, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.46, 0.}, {-0.458, 
                Rational[223, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.458, 0.}, {-0.456, 
                Rational[57, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.456, 0.}, {-0.454, 
                Rational[57, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.454, 0.}, {-0.452, 
                Rational[271, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.452, 0.}, {-0.45, 
                Rational[123, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.45, 0.}, {-0.448, 
                Rational[281, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.448, 0.}, {-0.446, 
                Rational[13, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.446, 0.}, {-0.444, 
                Rational[57, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.444, 0.}, {-0.442, 
                Rational[151, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.442, 0.}, {-0.44, 
                Rational[279, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.44, 0.}, {-0.438, 
                Rational[271, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.438, 0.}, {-0.436, 
                Rational[167, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.436, 0.}, {-0.434, 
                Rational[41, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.434, 0.}, {-0.432, 
                Rational[293, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.432, 0.}, {-0.43, 
                Rational[161, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.43, 0.}, {-0.428, 
                Rational[379, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.428, 0.}, {-0.426, 
                Rational[341, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.426, 0.}, {-0.424, 
                Rational[79, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.424, 0.}, {-0.422, 
                Rational[207, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.422, 0.}, {-0.42, 
                Rational[21, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.42, 0.}, {-0.418, 
                Rational[213, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.418, 0.}, {-0.416, 
                Rational[109, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.416, 0.}, {-0.414, 
                Rational[199, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.414, 0.}, {-0.412, 
                Rational[213, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.412, 0.}, {-0.41, 
                Rational[427, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.41, 0.}, {-0.408, 
                Rational[23, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.408, 0.}, {-0.406, 
                Rational[251, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.406, 0.}, {-0.404, 
                Rational[231, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.404, 0.}, {-0.402, 
                Rational[99, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.402, 0.}, {-0.4, 
                Rational[49, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.4, 0.}, {-0.398, 
                Rational[27, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.398, 0.}, {-0.396, 
                Rational[5, 2]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.396, 0.}, {-0.394, 
                Rational[133, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.394, 0.}, {-0.392, 
                Rational[267, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.392, 0.}, {-0.39, 
                Rational[143, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.39, 0.}, {-0.388, 
                Rational[31, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.388, 0.}, {-0.386, 
                Rational[557, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.386, 0.}, {-0.384, 
                Rational[153, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.384, 0.}, {-0.382, 
                Rational[291, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.382, 0.}, {-0.38, 
                Rational[647, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.38, 0.}, {-0.378, 
                Rational[25, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.378, 0.}, {-0.376, 
                Rational[129, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.376, 0.}, {-0.374, 
                Rational[343, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.374, 0.}, {-0.372, 
                Rational[167, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.372, 0.}, {-0.37, 
                Rational[83, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.37, 0.}, {-0.368, 
                Rational[163, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.368, 0.}, {-0.366, 
                Rational[731, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.366, 0.}, {-0.364, 
                Rational[719, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.364, 0.}, {-0.362, 
                Rational[151, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.362, 0.}, {-0.36, 
                Rational[741, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.36, 0.}, {-0.358, 
                Rational[71, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.358, 0.}, {-0.356, 
                Rational[773, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.356, 0.}, {-0.354, 
                Rational[751, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.354, 0.}, {-0.352, 
                Rational[793, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.352, 0.}, {-0.35, 
                Rational[789, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.35, 0.}, {-0.348, 
                Rational[102, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.348, 0.}, {-0.346, 
                Rational[153, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.346, 0.}, {-0.344, 
                Rational[803, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.344, 0.}, {-0.342, 
                Rational[207, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.342, 0.}, {-0.34, 
                Rational[401, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.34, 0.}, {-0.338, 
                Rational[83, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.338, 0.}, {-0.336, 
                Rational[427, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.336, 0.}, {-0.334, 
                Rational[393, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.334, 0.}, {-0.332, 
                Rational[849, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.332, 0.}, {-0.33, 
                Rational[413, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.33, 0.}, {-0.328, 4}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.328, 0.}, {-0.326, 
                Rational[213, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.326, 0.}, {-0.324, 
                Rational[417, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.324, 0.}, {-0.322, 
                Rational[881, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.322, 0.}, {-0.32, 
                Rational[441, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.32, 0.}, {-0.318, 
                Rational[421, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.318, 0.}, {-0.316, 
                Rational[859, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.316, 0.}, {-0.314, 
                Rational[907, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.314, 0.}, {-0.312, 
                Rational[859, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.312, 0.}, {-0.31, 
                Rational[108, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.31, 0.}, {-0.308, 
                Rational[223, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.308, 0.}, {-0.306, 
                Rational[867, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.306, 0.}, {-0.304, 
                Rational[859, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.304, 0.}, {-0.302, 
                Rational[179, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.302, 0.}, {-0.3, 
                Rational[89, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.3, 0.}, {-0.298, 
                Rational[859, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.298, 0.}, {-0.296, 
                Rational[839, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.296, 0.}, {-0.294, 
                Rational[89, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.294, 0.}, {-0.292, 
                Rational[899, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.292, 0.}, {-0.29, 
                Rational[233, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.29, 0.}, {-0.288, 
                Rational[112, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.288, 0.}, {-0.286, 
                Rational[173, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.286, 0.}, {-0.284, 
                Rational[421, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.284, 0.}, {-0.282, 
                Rational[171, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.282, 0.}, {-0.28, 
                Rational[441, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.28, 0.}, {-0.278, 
                Rational[887, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.278, 0.}, {-0.276, 
                Rational[819, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.276, 0.}, {-0.274, 
                Rational[106, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.274, 0.}, {-0.272, 
                Rational[841, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.272, 0.}, {-0.27, 
                Rational[839, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.27, 0.}, {-0.268, 
                Rational[383, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.268, 0.}, {-0.266, 
                Rational[97, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.266, 0.}, {-0.264, 
                Rational[187, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.264, 0.}, {-0.262, 
                Rational[98, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.262, 0.}, {-0.26, 
                Rational[411, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.26, 0.}, {-0.258, 
                Rational[41, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.258, 0.}, {-0.256, 
                Rational[199, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.256, 0.}, {-0.254, 
                Rational[379, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.254, 0.}, {-0.252, 
                Rational[98, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.252, 0.}, {-0.25, 
                Rational[371, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.25, 0.}, {-0.248, 
                Rational[769, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.248, 0.}, {-0.246, 
                Rational[149, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.246, 0.}, {-0.244, 
                Rational[747, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.244, 0.}, {-0.242, 
                Rational[77, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.242, 0.}, {-0.24, 
                Rational[167, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.24, 0.}, {-0.238, 
                Rational[163, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.238, 0.}, {-0.236, 
                Rational[687, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.236, 0.}, {-0.234, 
                Rational[611, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.234, 0.}, {-0.232, 
                Rational[27, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.232, 0.}, {-0.23, 
                Rational[609, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.23, 0.}, {-0.228, 
                Rational[309, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.228, 0.}, {-0.226, 
                Rational[79, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.226, 0.}, {-0.224, 
                Rational[281, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.224, 0.}, {-0.222, 
                Rational[563, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.222, 0.}, {-0.22, 
                Rational[74, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.22, 0.}, {-0.218, 
                Rational[139, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.218, 0.}, {-0.216, 
                Rational[137, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.216, 0.}, {-0.214, 
                Rational[551, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.214, 0.}, {-0.212, 
                Rational[493, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.212, 0.}, {-0.21, 
                Rational[493, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.21, 0.}, {-0.208, 
                Rational[127, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.208, 0.}, {-0.206, 
                Rational[113, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.206, 0.}, {-0.204, 
                Rational[47, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.204, 0.}, {-0.202, 
                Rational[463, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.202, 0.}, {-0.2, 
                Rational[23, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.2, 0.}, {-0.198, 
                Rational[47, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.198, 0.}, {-0.196, 
                Rational[101, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.196, 0.}, {-0.194, 
                Rational[48, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.194, 0.}, {-0.192, 
                Rational[207, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.192, 0.}, {-0.19, 
                Rational[369, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.19, 0.}, {-0.188, 
                Rational[191, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.188, 0.}, {-0.186, 
                Rational[49, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.186, 0.}, {-0.184, 
                Rational[327, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.184, 0.}, {-0.182, 
                Rational[181, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.182, 0.}, {-0.18, 
                Rational[13, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.18, 0.}, {-0.178, 
                Rational[31, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.178, 0.}, {-0.176, 
                Rational[81, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.176, 0.}, {-0.174, 
                Rational[291, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.174, 0.}, {-0.172, 
                Rational[153, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.172, 0.}, {-0.17, 
                Rational[267, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.17, 0.}, {-0.168, 
                Rational[251, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.168, 0.}, {-0.166, 
                Rational[129, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.166, 0.}, {-0.164, 
                Rational[233, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.164, 0.}, {-0.162, 
                Rational[233, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.162, 0.}, {-0.16, 
                Rational[113, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.16, 0.}, {-0.158, 
                Rational[111, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.158, 0.}, {-0.156, 
                Rational[227, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.156, 0.}, {-0.154, 
                Rational[191, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.154, 0.}, {-0.152, 
                Rational[99, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.152, 0.}, {-0.15, 
                Rational[167, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.15, 0.}, {-0.148, 
                Rational[79, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.148, 0.}, {-0.146, 
                Rational[191, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.146, 0.}, {-0.144, 
                Rational[153, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.144, 0.}, {-0.142, 
                Rational[171, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.142, 0.}, {-0.14, 
                Rational[14, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.14, 0.}, {-0.138, 
                Rational[27, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.138, 0.}, {-0.136, 
                Rational[129, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.136, 0.}, {-0.134, 
                Rational[131, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.134, 0.}, {-0.132, 
                Rational[133, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.132, 0.}, {-0.13, 
                Rational[99, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.13, 0.}, {-0.128, 
                Rational[109, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.128, 0.}, {-0.126, 
                Rational[19, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.126, 0.}, {-0.124, 
                Rational[27, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.124, 0.}, {-0.122, 
                Rational[43, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.122, 0.}, {-0.12, 
                Rational[19, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.12, 0.}, {-0.118, 
                Rational[41, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.118, 0.}, {-0.116, 
                Rational[2, 5]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.116, 0.}, {-0.114, 
                Rational[19, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.114, 0.}, {-0.112, 
                Rational[39, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.112, 0.}, {-0.11, 
                Rational[11, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.11, 0.}, {-0.108, 
                Rational[3, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.108, 0.}, {-0.106, 
                Rational[31, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.106, 0.}, {-0.104, 
                Rational[47, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.104, 0.}, {-0.102, 
                Rational[11, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.102, 0.}, {-0.1, 
                Rational[51, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.1, 0.}, {-0.098, 
                Rational[39, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.098, 0.}, {-0.096, 
                Rational[4, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.096, 0.}, {-0.094, 
                Rational[41, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.094, 0.}, {-0.092, 
                Rational[33, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.092, 0.}, {-0.09, 
                Rational[43, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.09, 0.}, {-0.088, 
                Rational[23, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.088, 0.}, {-0.086, 
                Rational[29, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.086, 0.}, {-0.084, 
                Rational[17, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.084, 0.}, {-0.082, 
                Rational[4, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.082, 0.}, {-0.08, 
                Rational[27, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.08, 0.}, {-0.078, 
                Rational[29, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.078, 0.}, {-0.076, 
                Rational[19, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.076, 0.}, {-0.074, 
                Rational[19, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.074, 0.}, {-0.072, 
                Rational[3, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.072, 0.}, {-0.07, 
                Rational[9, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.07, 0.}, {-0.068, 
                Rational[3, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.068, 0.}, {-0.066, 
                Rational[9, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.066, 0.}, {-0.064, 
                Rational[3, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.064, 0.}, {-0.062, 
                Rational[17, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.062, 0.}, {-0.06, 
                Rational[9, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.06, 0.}, {-0.058, 
                Rational[21, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.058, 0.}, {-0.056, 
                Rational[11, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.056, 0.}, {-0.054, 
                Rational[7, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.054, 0.}, {-0.052, 
                Rational[9, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.052, 0.}, {-0.05, 
                Rational[3, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.05, 0.}, {-0.048, 
                Rational[9, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.048, 0.}, {-0.046, 
                Rational[7, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.046, 0.}, {-0.044, 
                Rational[7, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.044, 0.}, {-0.042, 
                Rational[1, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.042, 0.}, {-0.04, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.04, 0.}, {-0.038, 
                Rational[7, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.038, 0.}, {-0.036, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.036, 0.}, {-0.034, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.034, 0.}, {-0.032, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.032, 0.}, {-0.03, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.03, 0.}, {-0.028, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.028, 0.}, {-0.026, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.026, 0.}, {-0.024, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.024, 0.}, {-0.022, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.022, 0.}, {-0.02, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.02, 0.}, {-0.018, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.018, 0.}, {-0.016, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.016, 0.}, {-0.014, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.014, 0.}, {-0.012, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.012, 0.}, {-0.01, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.01, 0.}, {-0.008, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.008, 0.}, {-0.006, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.006, 0.}, {-0.004, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.004, 0.}, {-0.002, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.002, 0.}, {0., 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0., 0.}, {0.002, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.002, 0.}, {0.004, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.004, 0.}, {0.006, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.006, 0.}, {0.008, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.008, 0.}, {0.01, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.01, 0.}, {0.012, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.012, 0.}, {0.014, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.014, 0.}, {0.016, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.016, 0.}, {0.018, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.018, 0.}, {0.02, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.02, 0.}, {0.022, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.022, 0.}, {0.024, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.024, 0.}, {0.026, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.026, 0.}, {0.028, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.028, 0.}, {0.03, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.03, 0.}, {0.032, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.032, 0.}, {0.034, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.034, 0.}, {0.036, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.036, 0.}, {0.038, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.038, 0.}, {0.04, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.04, 0.}, {0.042, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.042, 0.}, {0.044, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.044, 0.}, {0.046, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.046, 0.}, {0.048, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.048, 0.}, {0.05, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.05, 0.}, {0.052, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.052, 0.}, {0.054, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.054, 0.}, {0.056, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.056, 0.}, {0.058, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.058, 0.}, {0.06, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.06, 0.}, {0.062, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.062, 0.}, {0.064, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.064, 0.}, {0.066, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.066, 0.}, {0.068, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.068, 0.}, {0.07, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.07, 0.}, {0.072, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.072, 0.}, {0.074, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.074, 0.}, {0.076, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.076, 0.}, {0.078, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.078, 0.}, {0.08, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.08, 0.}, {0.082, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.082, 0.}, {0.084, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.084, 0.}, {0.086, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.086, 0.}, {0.088, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.088, 0.}, {0.09, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.09, 0.}, {0.092, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.092, 0.}, {0.094, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.094, 0.}, {0.096, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.096, 0.}, {0.098, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.098, 0.}, {0.1, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.1, 0.}, {0.102, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.102, 0.}, {0.104, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.104, 0.}, {0.106, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.106, 0.}, {0.108, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.108, 0.}, {0.11, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.11, 0.}, {0.112, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.112, 0.}, {0.114, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.114, 0.}, {0.116, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.116, 0.}, {0.118, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.118, 0.}, {0.12, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.12, 0.}, {0.122, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.122, 0.}, {0.124, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.124, 0.}, {0.126, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.126, 0.}, {0.128, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.128, 0.}, {0.13, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.13, 0.}, {0.132, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.132, 0.}, {0.134, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.134, 0.}, {0.136, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.136, 0.}, {0.138, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.138, 0.}, {0.14, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.14, 0.}, {0.142, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.142, 0.}, {0.144, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.144, 0.}, {0.146, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.146, 0.}, {0.148, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.148, 0.}, {0.15, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.15, 0.}, {0.152, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.152, 0.}, {0.154, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.154, 0.}, {0.156, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.156, 0.}, {0.158, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.158, 0.}, {0.16, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.16, 0.}, {0.162, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.162, 0.}, {0.164, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.164, 0.}, {0.166, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.166, 0.}, {0.168, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.168, 0.}, {0.17, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.17, 0.}, {0.172, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.172, 0.}, {0.174, 0}, "RoundingRadius" -> 0]}}, {{
              
              Rectangle[{0.174, 0.}, {0.176, 0}, "RoundingRadius" -> 
               0]}}}}, {}, {}}}, {{{}, {
           Directive[
            Opacity[0.5], 
            Directive[
             EdgeForm[
              Opacity[-2.506]], 
             RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458]], 
            Directive[
             RGBColor[1, 0.6666666666666666, 
              Rational[1, 3]]]], {{{
              Rectangle[{-0.74, 0.}, {-0.738, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.738, 0.}, {-0.736, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.736, 0.}, {-0.734, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.734, 0.}, {-0.732, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.732, 0.}, {-0.73, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.73, 0.}, {-0.728, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.728, 0.}, {-0.726, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.726, 0.}, {-0.724, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.724, 0.}, {-0.722, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.722, 0.}, {-0.72, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.72, 0.}, {-0.718, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.718, 0.}, {-0.716, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.716, 0.}, {-0.714, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.714, 0.}, {-0.712, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.712, 0.}, {-0.71, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.71, 0.}, {-0.708, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.708, 0.}, {-0.706, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.706, 0.}, {-0.704, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.704, 0.}, {-0.702, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.702, 0.}, {-0.7, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.7, 0.}, {-0.698, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.698, 0.}, {-0.696, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.696, 0.}, {-0.694, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.694, 0.}, {-0.692, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.692, 0.}, {-0.69, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.69, 0.}, {-0.688, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.688, 0.}, {-0.686, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.686, 0.}, {-0.684, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.684, 0.}, {-0.682, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.682, 0.}, {-0.68, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.68, 0.}, {-0.678, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.678, 0.}, {-0.676, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.676, 0.}, {-0.674, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.674, 0.}, {-0.672, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.672, 0.}, {-0.67, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.67, 0.}, {-0.668, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.668, 0.}, {-0.666, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.666, 0.}, {-0.664, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.664, 0.}, {-0.662, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.662, 0.}, {-0.66, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.66, 0.}, {-0.658, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.658, 0.}, {-0.656, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.656, 0.}, {-0.654, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.654, 0.}, {-0.652, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.652, 0.}, {-0.65, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.65, 0.}, {-0.648, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.648, 0.}, {-0.646, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.646, 0.}, {-0.644, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.644, 0.}, {-0.642, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.642, 0.}, {-0.64, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.64, 0.}, {-0.638, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.638, 0.}, {-0.636, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.636, 0.}, {-0.634, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.634, 0.}, {-0.632, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.632, 0.}, {-0.63, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.63, 0.}, {-0.628, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.628, 0.}, {-0.626, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.626, 0.}, {-0.624, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.624, 0.}, {-0.622, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.622, 0.}, {-0.62, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.62, 0.}, {-0.618, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.618, 0.}, {-0.616, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.616, 0.}, {-0.614, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.614, 0.}, {-0.612, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.612, 0.}, {-0.61, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.61, 0.}, {-0.608, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.608, 0.}, {-0.606, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.606, 0.}, {-0.604, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.604, 0.}, {-0.602, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.602, 0.}, {-0.6, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.6, 0.}, {-0.598, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.598, 0.}, {-0.596, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.596, 0.}, {-0.594, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.594, 0.}, {-0.592, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.592, 0.}, {-0.59, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.59, 0.}, {-0.588, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.588, 0.}, {-0.586, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.586, 0.}, {-0.584, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.584, 0.}, {-0.582, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.582, 0.}, {-0.58, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.58, 0.}, {-0.578, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.578, 0.}, {-0.576, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.576, 0.}, {-0.574, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.574, 0.}, {-0.572, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.572, 0.}, {-0.57, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.57, 0.}, {-0.568, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.568, 0.}, {-0.566, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.566, 0.}, {-0.564, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.564, 0.}, {-0.562, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.562, 0.}, {-0.56, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.56, 0.}, {-0.558, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.558, 0.}, {-0.556, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.556, 0.}, {-0.554, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.554, 0.}, {-0.552, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.552, 0.}, {-0.55, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.55, 0.}, {-0.548, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.548, 0.}, {-0.546, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.546, 0.}, {-0.544, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.544, 0.}, {-0.542, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.542, 0.}, {-0.54, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.54, 0.}, {-0.538, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.538, 0.}, {-0.536, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.536, 0.}, {-0.534, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.534, 0.}, {-0.532, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.532, 0.}, {-0.53, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.53, 0.}, {-0.528, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.528, 0.}, {-0.526, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.526, 0.}, {-0.524, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.524, 0.}, {-0.522, 
                Rational[7, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.522, 0.}, {-0.52, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.52, 0.}, {-0.518, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.518, 0.}, {-0.516, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.516, 0.}, {-0.514, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.514, 0.}, {-0.512, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.512, 0.}, {-0.51, 
                Rational[3, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.51, 0.}, {-0.508, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.508, 0.}, {-0.506, 
                Rational[7, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.506, 0.}, {-0.504, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.504, 0.}, {-0.502, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.502, 0.}, {-0.5, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.5, 0.}, {-0.498, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.498, 0.}, {-0.496, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.496, 0.}, {-0.494, 
                Rational[1, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.494, 0.}, {-0.492, 
                Rational[3, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.492, 0.}, {-0.49, 
                Rational[1, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.49, 0.}, {-0.488, 
                Rational[1, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.488, 0.}, {-0.486, 
                Rational[9, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.486, 0.}, {-0.484, 
                Rational[3, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.484, 0.}, {-0.482, 
                Rational[1, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.482, 0.}, {-0.48, 
                Rational[11, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.48, 0.}, {-0.478, 
                Rational[1, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.478, 0.}, {-0.476, 
                Rational[7, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.476, 0.}, {-0.474, 
                Rational[17, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.474, 0.}, {-0.472, 
                Rational[9, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.472, 0.}, {-0.47, 
                Rational[11, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.47, 0.}, {-0.468, 
                Rational[9, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.468, 0.}, {-0.466, 
                Rational[3, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.466, 0.}, {-0.464, 
                Rational[13, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.464, 0.}, {-0.462, 
                Rational[9, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.462, 0.}, {-0.46, 
                Rational[3, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.46, 0.}, {-0.458, 
                Rational[1, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.458, 0.}, {-0.456, 
                Rational[19, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.456, 0.}, {-0.454, 
                Rational[11, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.454, 0.}, {-0.452, 
                Rational[11, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.452, 0.}, {-0.45, 
                Rational[3, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.45, 0.}, {-0.448, 
                Rational[1, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.448, 0.}, {-0.446, 
                Rational[1, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.446, 0.}, {-0.444, 
                Rational[27, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.444, 0.}, {-0.442, 
                Rational[41, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.442, 0.}, {-0.44, 
                Rational[27, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.44, 0.}, {-0.438, 
                Rational[1, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.438, 0.}, {-0.436, 
                Rational[31, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.436, 0.}, {-0.434, 
                Rational[31, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.434, 0.}, {-0.432, 
                Rational[7, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.432, 0.}, {-0.43, 
                Rational[49, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.43, 0.}, {-0.428, 
                Rational[1, 4]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.428, 0.}, {-0.426, 
                Rational[6, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.426, 0.}, {-0.424, 
                Rational[49, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.424, 0.}, {-0.422, 
                Rational[41, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.422, 0.}, {-0.42, 
                Rational[31, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.42, 0.}, {-0.418, 
                Rational[29, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.418, 0.}, {-0.416, 
                Rational[67, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.416, 0.}, {-0.414, 
                Rational[27, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.414, 0.}, {-0.412, 
                Rational[27, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.412, 0.}, {-0.41, 
                Rational[17, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.41, 0.}, {-0.408, 
                Rational[79, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.408, 0.}, {-0.406, 
                Rational[29, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.406, 0.}, {-0.404, 
                Rational[73, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.404, 0.}, {-0.402, 
                Rational[77, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.402, 0.}, {-0.4, 
                Rational[39, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.4, 0.}, {-0.398, 
                Rational[77, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.398, 0.}, {-0.396, 
                Rational[39, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.396, 0.}, {-0.394, 
                Rational[91, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.394, 0.}, {-0.392, 
                Rational[1, 2]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.392, 0.}, {-0.39, 
                Rational[111, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.39, 0.}, {-0.388, 
                Rational[53, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.388, 0.}, {-0.386, 
                Rational[107, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.386, 0.}, {-0.384, 
                Rational[16, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.384, 0.}, {-0.382, 
                Rational[73, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.382, 0.}, {-0.38, 
                Rational[123, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.38, 0.}, {-0.378, 
                Rational[113, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.378, 0.}, {-0.376, 
                Rational[7, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.376, 0.}, {-0.374, 
                Rational[69, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.374, 0.}, {-0.372, 
                Rational[33, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.372, 0.}, {-0.37, 
                Rational[93, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.37, 0.}, {-0.368, 
                Rational[71, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.368, 0.}, {-0.366, 
                Rational[181, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.366, 0.}, {-0.364, 
                Rational[207, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.364, 0.}, {-0.362, 
                Rational[183, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.362, 0.}, {-0.36, 
                Rational[177, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.36, 0.}, {-0.358, 
                Rational[201, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.358, 0.}, {-0.356, 
                Rational[11, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.356, 0.}, {-0.354, 
                Rational[99, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.354, 0.}, {-0.352, 
                Rational[209, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.352, 0.}, {-0.35, 
                Rational[241, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.35, 0.}, {-0.348, 
                Rational[121, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.348, 0.}, {-0.346, 
                Rational[32, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.346, 0.}, {-0.344, 
                Rational[309, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.344, 0.}, {-0.342, 
                Rational[137, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.342, 0.}, {-0.34, 
                Rational[11, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.34, 0.}, {-0.338, 
                Rational[29, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.338, 0.}, {-0.336, 
                Rational[38, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.336, 0.}, {-0.334, 
                Rational[39, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.334, 0.}, {-0.332, 
                Rational[77, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.332, 0.}, {-0.33, 
                Rational[141, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.33, 0.}, {-0.328, 
                Rational[343, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.328, 0.}, {-0.326, 
                Rational[89, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.326, 0.}, {-0.324, 
                Rational[313, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.324, 0.}, {-0.322, 
                Rational[353, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.322, 0.}, {-0.32, 2}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.32, 0.}, {-0.318, 
                Rational[93, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.318, 0.}, {-0.316, 
                Rational[211, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.316, 0.}, {-0.314, 
                Rational[109, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.314, 0.}, {-0.312, 
                Rational[229, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.312, 0.}, {-0.31, 
                Rational[489, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.31, 0.}, {-0.308, 
                Rational[417, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.308, 0.}, {-0.306, 
                Rational[217, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.306, 0.}, {-0.304, 
                Rational[231, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.304, 0.}, {-0.302, 
                Rational[12, 5]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.302, 0.}, {-0.3, 
                Rational[267, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.3, 0.}, {-0.298, 
                Rational[97, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.298, 0.}, {-0.296, 
                Rational[259, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.296, 0.}, {-0.294, 
                Rational[281, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.294, 0.}, {-0.292, 
                Rational[14, 5]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.292, 0.}, {-0.29, 
                Rational[13, 5]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.29, 0.}, {-0.288, 
                Rational[587, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.288, 0.}, {-0.286, 
                Rational[283, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.286, 0.}, {-0.284, 
                Rational[639, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.284, 0.}, {-0.282, 
                Rational[31, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.282, 0.}, {-0.28, 
                Rational[619, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.28, 0.}, {-0.278, 
                Rational[641, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.278, 0.}, {-0.276, 
                Rational[663, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.276, 0.}, {-0.274, 
                Rational[341, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.274, 0.}, {-0.272, 
                Rational[333, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.272, 0.}, {-0.27, 
                Rational[369, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.27, 0.}, {-0.268, 
                Rational[709, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.268, 0.}, {-0.266, 
                Rational[367, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.266, 0.}, {-0.264, 
                Rational[137, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.264, 0.}, {-0.262, 
                Rational[381, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.262, 0.}, {-0.26, 
                Rational[779, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.26, 0.}, {-0.258, 
                Rational[102, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.258, 0.}, {-0.256, 
                Rational[377, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.256, 0.}, {-0.254, 
                Rational[803, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.254, 0.}, {-0.252, 
                Rational[807, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.252, 0.}, {-0.25, 
                Rational[807, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.25, 0.}, {-0.248, 
                Rational[107, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.248, 0.}, {-0.246, 
                Rational[219, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.246, 0.}, {-0.244, 
                Rational[102, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.244, 0.}, {-0.242, 
                Rational[429, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.242, 0.}, {-0.24, 
                Rational[879, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.24, 0.}, {-0.238, 
                Rational[437, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.238, 0.}, {-0.236, 
                Rational[887, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.236, 0.}, {-0.234, 
                Rational[89, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.234, 0.}, {-0.232, 
                Rational[849, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.232, 0.}, {-0.23, 
                Rational[447, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.23, 0.}, {-0.228, 
                Rational[22, 5]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.228, 0.}, {-0.226, 
                Rational[43, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.226, 0.}, {-0.224, 
                Rational[233, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.224, 0.}, {-0.222, 
                Rational[907, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.222, 0.}, {-0.22, 
                Rational[933, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.22, 0.}, {-0.218, 
                Rational[913, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.218, 0.}, {-0.216, 
                Rational[901, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.216, 0.}, {-0.214, 
                Rational[961, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.214, 0.}, {-0.212, 
                Rational[457, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.212, 0.}, {-0.21, 
                Rational[947, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.21, 0.}, {-0.208, 
                Rational[931, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.208, 0.}, {-0.206, 
                Rational[949, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.206, 0.}, {-0.204, 
                Rational[37, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.204, 0.}, {-0.202, 
                Rational[118, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.202, 0.}, {-0.2, 
                Rational[117, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.2, 0.}, {-0.198, 
                Rational[463, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.198, 0.}, {-0.196, 
                Rational[457, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.196, 0.}, {-0.194, 
                Rational[121, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.194, 0.}, {-0.192, 
                Rational[124, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.192, 0.}, {-0.19, 
                Rational[953, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.19, 0.}, {-0.188, 
                Rational[959, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.188, 0.}, {-0.186, 
                Rational[437, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.186, 0.}, {-0.184, 
                Rational[113, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.184, 0.}, {-0.182, 
                Rational[479, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.182, 0.}, {-0.18, 
                Rational[967, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.18, 0.}, {-0.178, 
                Rational[871, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.178, 0.}, {-0.176, 
                Rational[891, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.176, 0.}, {-0.174, 
                Rational[923, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.174, 0.}, {-0.172, 
                Rational[217, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.172, 0.}, {-0.17, 
                Rational[827, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.17, 0.}, {-0.168, 
                Rational[201, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.168, 0.}, {-0.166, 
                Rational[811, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.166, 0.}, {-0.164, 
                Rational[903, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.164, 0.}, {-0.162, 
                Rational[21, 5]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.162, 0.}, {-0.16, 
                Rational[889, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.16, 0.}, {-0.158, 
                Rational[829, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.158, 0.}, {-0.156, 
                Rational[817, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.156, 0.}, {-0.154, 
                Rational[793, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.154, 0.}, {-0.152, 
                Rational[831, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.152, 0.}, {-0.15, 
                Rational[789, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.15, 0.}, {-0.148, 
                Rational[807, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.148, 0.}, {-0.146, 
                Rational[829, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.146, 0.}, {-0.144, 
                Rational[141, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.144, 0.}, {-0.142, 
                Rational[71, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.142, 0.}, {-0.14, 
                Rational[141, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.14, 0.}, {-0.138, 
                Rational[337, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.138, 0.}, {-0.136, 
                Rational[88, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.136, 0.}, {-0.134, 
                Rational[79, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.134, 0.}, {-0.132, 
                Rational[691, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.132, 0.}, {-0.13, 
                Rational[607, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.13, 0.}, {-0.128, 
                Rational[623, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.128, 0.}, {-0.126, 
                Rational[641, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.126, 0.}, {-0.124, 
                Rational[589, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.124, 0.}, {-0.122, 
                Rational[297, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.122, 0.}, {-0.12, 
                Rational[577, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.12, 0.}, {-0.118, 
                Rational[521, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.118, 0.}, {-0.116, 
                Rational[66, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.116, 0.}, {-0.114, 
                Rational[11, 4]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.114, 0.}, {-0.112, 
                Rational[117, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.112, 0.}, {-0.11, 
                Rational[517, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.11, 0.}, {-0.108, 
                Rational[497, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.108, 0.}, {-0.106, 
                Rational[249, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.106, 0.}, {-0.104, 
                Rational[451, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.104, 0.}, {-0.102, 
                Rational[427, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.102, 0.}, {-0.1, 
                Rational[87, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.1, 0.}, {-0.098, 
                Rational[81, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.098, 0.}, {-0.096, 
                Rational[79, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.096, 0.}, {-0.094, 
                Rational[217, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.094, 0.}, {-0.092, 
                Rational[87, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.092, 0.}, {-0.09, 
                Rational[377, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.09, 0.}, {-0.088, 
                Rational[357, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.088, 0.}, {-0.086, 
                Rational[169, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.086, 0.}, {-0.084, 
                Rational[7, 4]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.084, 0.}, {-0.082, 
                Rational[37, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.082, 0.}, {-0.08, 
                Rational[157, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.08, 0.}, {-0.078, 
                Rational[277, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.078, 0.}, {-0.076, 
                Rational[129, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.076, 0.}, {-0.074, 
                Rational[133, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.074, 0.}, {-0.072, 
                Rational[63, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.072, 0.}, {-0.07, 
                Rational[257, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.07, 0.}, {-0.068, 
                Rational[29, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.068, 0.}, {-0.066, 
                Rational[239, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.066, 0.}, {-0.064, 
                Rational[203, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.064, 0.}, {-0.062, 
                Rational[219, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.062, 0.}, {-0.06, 
                Rational[167, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.06, 0.}, {-0.058, 
                Rational[97, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.058, 0.}, {-0.056, 
                Rational[187, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.056, 0.}, {-0.054, 
                Rational[17, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.054, 0.}, {-0.052, 
                Rational[18, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.052, 0.}, {-0.05, 
                Rational[67, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.05, 0.}, {-0.048, 
                Rational[69, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.048, 0.}, {-0.046, 
                Rational[69, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.046, 0.}, {-0.044, 
                Rational[149, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.044, 0.}, {-0.042, 
                Rational[57, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.042, 0.}, {-0.04, 
                Rational[113, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.04, 0.}, {-0.038, 
                Rational[109, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.038, 0.}, {-0.036, 
                Rational[53, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.036, 0.}, {-0.034, 
                Rational[81, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.034, 0.}, {-0.032, 
                Rational[11, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.032, 0.}, {-0.03, 
                Rational[89, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.03, 0.}, {-0.028, 
                Rational[9, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.028, 0.}, {-0.026, 
                Rational[77, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.026, 0.}, {-0.024, 
                Rational[91, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.024, 0.}, {-0.022, 
                Rational[73, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.022, 0.}, {-0.02, 
                Rational[63, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.02, 0.}, {-0.018, 
                Rational[53, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.018, 0.}, {-0.016, 
                Rational[57, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.016, 0.}, {-0.014, 
                Rational[57, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.014, 0.}, {-0.012, 
                Rational[37, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.012, 0.}, {-0.01, 
                Rational[19, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.01, 0.}, {-0.008, 
                Rational[6, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.008, 0.}, {-0.006, 
                Rational[4, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.006, 0.}, {-0.004, 
                Rational[6, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.004, 0.}, {-0.002, 
                Rational[9, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.002, 0.}, {0., 
                Rational[7, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0., 0.}, {0.002, 
                Rational[31, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.002, 0.}, {0.004, 
                Rational[17, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.004, 0.}, {0.006, 
                Rational[3, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.006, 0.}, {0.008, 
                Rational[17, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.008, 0.}, {0.01, 
                Rational[1, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.01, 0.}, {0.012, 
                Rational[3, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.012, 0.}, {0.014, 
                Rational[3, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.014, 0.}, {0.016, 
                Rational[3, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.016, 0.}, {0.018, 
                Rational[21, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.018, 0.}, {0.02, 
                Rational[17, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.02, 0.}, {0.022, 
                Rational[7, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.022, 0.}, {0.024, 
                Rational[17, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.024, 0.}, {0.026, 
                Rational[2, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.026, 0.}, {0.028, 
                Rational[1, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.028, 0.}, {0.03, 
                Rational[1, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.03, 0.}, {0.032, 
                Rational[1, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.032, 0.}, {0.034, 
                Rational[9, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.034, 0.}, {0.036, 
                Rational[1, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.036, 0.}, {0.038, 
                Rational[3, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.038, 0.}, {0.04, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.04, 0.}, {0.042, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.042, 0.}, {0.044, 
                Rational[1, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.044, 0.}, {0.046, 
                Rational[1, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.046, 0.}, {0.048, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.048, 0.}, {0.05, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.05, 0.}, {0.052, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.052, 0.}, {0.054, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.054, 0.}, {0.056, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.056, 0.}, {0.058, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.058, 0.}, {0.06, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.06, 0.}, {0.062, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.062, 0.}, {0.064, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.064, 0.}, {0.066, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.066, 0.}, {0.068, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.068, 0.}, {0.07, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.07, 0.}, {0.072, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.072, 0.}, {0.074, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.074, 0.}, {0.076, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.076, 0.}, {0.078, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.078, 0.}, {0.08, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.08, 0.}, {0.082, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.082, 0.}, {0.084, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.084, 0.}, {0.086, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.086, 0.}, {0.088, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.088, 0.}, {0.09, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.09, 0.}, {0.092, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.092, 0.}, {0.094, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.094, 0.}, {0.096, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.096, 0.}, {0.098, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.098, 0.}, {0.1, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.1, 0.}, {0.102, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.102, 0.}, {0.104, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.104, 0.}, {0.106, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.106, 0.}, {0.108, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.108, 0.}, {0.11, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.11, 0.}, {0.112, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.112, 0.}, {0.114, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.114, 0.}, {0.116, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.116, 0.}, {0.118, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.118, 0.}, {0.12, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.12, 0.}, {0.122, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.122, 0.}, {0.124, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.124, 0.}, {0.126, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.126, 0.}, {0.128, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.128, 0.}, {0.13, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.13, 0.}, {0.132, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.132, 0.}, {0.134, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.134, 0.}, {0.136, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.136, 0.}, {0.138, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.138, 0.}, {0.14, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.14, 0.}, {0.142, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.142, 0.}, {0.144, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.144, 0.}, {0.146, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.146, 0.}, {0.148, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.148, 0.}, {0.15, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.15, 0.}, {0.152, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.152, 0.}, {0.154, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.154, 0.}, {0.156, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.156, 0.}, {0.158, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.158, 0.}, {0.16, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.16, 0.}, {0.162, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.162, 0.}, {0.164, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.164, 0.}, {0.166, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.166, 0.}, {0.168, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.168, 0.}, {0.17, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.17, 0.}, {0.172, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.172, 0.}, {0.174, 0}, "RoundingRadius" -> 0]}}, {{
              
              Rectangle[{0.174, 0.}, {0.176, 0}, "RoundingRadius" -> 
               0]}}}}, {}, {}}}, {{{}, {
           Directive[
            Opacity[0.5], 
            Directive[
             EdgeForm[
              Opacity[-2.506]], 
             RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458]], 
            Directive[
             RGBColor[1, 0, 0]]], {{{
              Rectangle[{-0.74, 0.}, {-0.738, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.738, 0.}, {-0.736, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.736, 0.}, {-0.734, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.734, 0.}, {-0.732, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.732, 0.}, {-0.73, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.73, 0.}, {-0.728, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.728, 0.}, {-0.726, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.726, 0.}, {-0.724, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.724, 0.}, {-0.722, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.722, 0.}, {-0.72, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.72, 0.}, {-0.718, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.718, 0.}, {-0.716, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.716, 0.}, {-0.714, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.714, 0.}, {-0.712, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.712, 0.}, {-0.71, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.71, 0.}, {-0.708, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.708, 0.}, {-0.706, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.706, 0.}, {-0.704, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.704, 0.}, {-0.702, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.702, 0.}, {-0.7, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.7, 0.}, {-0.698, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.698, 0.}, {-0.696, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.696, 0.}, {-0.694, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.694, 0.}, {-0.692, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.692, 0.}, {-0.69, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.69, 0.}, {-0.688, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.688, 0.}, {-0.686, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.686, 0.}, {-0.684, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.684, 0.}, {-0.682, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.682, 0.}, {-0.68, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.68, 0.}, {-0.678, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.678, 0.}, {-0.676, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.676, 0.}, {-0.674, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.674, 0.}, {-0.672, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.672, 0.}, {-0.67, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.67, 0.}, {-0.668, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.668, 0.}, {-0.666, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.666, 0.}, {-0.664, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.664, 0.}, {-0.662, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.662, 0.}, {-0.66, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.66, 0.}, {-0.658, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.658, 0.}, {-0.656, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.656, 0.}, {-0.654, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.654, 0.}, {-0.652, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.652, 0.}, {-0.65, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.65, 0.}, {-0.648, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.648, 0.}, {-0.646, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.646, 0.}, {-0.644, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.644, 0.}, {-0.642, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.642, 0.}, {-0.64, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.64, 0.}, {-0.638, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.638, 0.}, {-0.636, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.636, 0.}, {-0.634, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.634, 0.}, {-0.632, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.632, 0.}, {-0.63, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.63, 0.}, {-0.628, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.628, 0.}, {-0.626, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.626, 0.}, {-0.624, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.624, 0.}, {-0.622, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.622, 0.}, {-0.62, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.62, 0.}, {-0.618, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.618, 0.}, {-0.616, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.616, 0.}, {-0.614, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.614, 0.}, {-0.612, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.612, 0.}, {-0.61, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.61, 0.}, {-0.608, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.608, 0.}, {-0.606, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.606, 0.}, {-0.604, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.604, 0.}, {-0.602, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.602, 0.}, {-0.6, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.6, 0.}, {-0.598, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.598, 0.}, {-0.596, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.596, 0.}, {-0.594, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.594, 0.}, {-0.592, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.592, 0.}, {-0.59, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.59, 0.}, {-0.588, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.588, 0.}, {-0.586, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.586, 0.}, {-0.584, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.584, 0.}, {-0.582, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.582, 0.}, {-0.58, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.58, 0.}, {-0.578, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.578, 0.}, {-0.576, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.576, 0.}, {-0.574, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.574, 0.}, {-0.572, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.572, 0.}, {-0.57, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.57, 0.}, {-0.568, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.568, 0.}, {-0.566, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.566, 0.}, {-0.564, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.564, 0.}, {-0.562, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.562, 0.}, {-0.56, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.56, 0.}, {-0.558, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.558, 0.}, {-0.556, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.556, 0.}, {-0.554, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.554, 0.}, {-0.552, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.552, 0.}, {-0.55, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.55, 0.}, {-0.548, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.548, 0.}, {-0.546, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.546, 0.}, {-0.544, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.544, 0.}, {-0.542, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.542, 0.}, {-0.54, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.54, 0.}, {-0.538, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.538, 0.}, {-0.536, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.536, 0.}, {-0.534, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.534, 0.}, {-0.532, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.532, 0.}, {-0.53, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.53, 0.}, {-0.528, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.528, 0.}, {-0.526, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.526, 0.}, {-0.524, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.524, 0.}, {-0.522, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.522, 0.}, {-0.52, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.52, 0.}, {-0.518, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.518, 0.}, {-0.516, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.516, 0.}, {-0.514, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.514, 0.}, {-0.512, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.512, 0.}, {-0.51, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.51, 0.}, {-0.508, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.508, 0.}, {-0.506, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.506, 0.}, {-0.504, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.504, 0.}, {-0.502, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.502, 0.}, {-0.5, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.5, 0.}, {-0.498, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.498, 0.}, {-0.496, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.496, 0.}, {-0.494, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.494, 0.}, {-0.492, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.492, 0.}, {-0.49, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.49, 0.}, {-0.488, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.488, 0.}, {-0.486, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.486, 0.}, {-0.484, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.484, 0.}, {-0.482, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.482, 0.}, {-0.48, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.48, 0.}, {-0.478, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.478, 0.}, {-0.476, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.476, 0.}, {-0.474, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.474, 0.}, {-0.472, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.472, 0.}, {-0.47, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.47, 0.}, {-0.468, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.468, 0.}, {-0.466, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.466, 0.}, {-0.464, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.464, 0.}, {-0.462, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.462, 0.}, {-0.46, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.46, 0.}, {-0.458, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.458, 0.}, {-0.456, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.456, 0.}, {-0.454, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.454, 0.}, {-0.452, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.452, 0.}, {-0.45, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.45, 0.}, {-0.448, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.448, 0.}, {-0.446, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.446, 0.}, {-0.444, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.444, 0.}, {-0.442, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.442, 0.}, {-0.44, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.44, 0.}, {-0.438, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.438, 0.}, {-0.436, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.436, 0.}, {-0.434, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.434, 0.}, {-0.432, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.432, 0.}, {-0.43, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.43, 0.}, {-0.428, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.428, 0.}, {-0.426, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.426, 0.}, {-0.424, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.424, 0.}, {-0.422, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.422, 0.}, {-0.42, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.42, 0.}, {-0.418, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.418, 0.}, {-0.416, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.416, 0.}, {-0.414, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.414, 0.}, {-0.412, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.412, 0.}, {-0.41, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.41, 0.}, {-0.408, 0}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.408, 0.}, {-0.406, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.406, 0.}, {-0.404, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.404, 0.}, {-0.402, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.402, 0.}, {-0.4, 
                Rational[7, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.4, 0.}, {-0.398, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.398, 0.}, {-0.396, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.396, 0.}, {-0.394, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.394, 0.}, {-0.392, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.392, 0.}, {-0.39, 
                Rational[3, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.39, 0.}, {-0.388, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.388, 0.}, {-0.386, 
                Rational[1, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.386, 0.}, {-0.384, 
                Rational[3, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.384, 0.}, {-0.382, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.382, 0.}, {-0.38, 
                Rational[7, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.38, 0.}, {-0.378, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.378, 0.}, {-0.376, 
                Rational[1, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.376, 0.}, {-0.374, 
                Rational[1, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.374, 0.}, {-0.372, 
                Rational[7, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.372, 0.}, {-0.37, 
                Rational[3, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.37, 0.}, {-0.368, 
                Rational[7, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.368, 0.}, {-0.366, 
                Rational[9, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.366, 0.}, {-0.364, 
                Rational[7, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.364, 0.}, {-0.362, 
                Rational[9, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.362, 0.}, {-0.36, 
                Rational[11, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.36, 0.}, {-0.358, 
                Rational[1, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.358, 0.}, {-0.356, 
                Rational[3, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.356, 0.}, {-0.354, 
                Rational[9, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.354, 0.}, {-0.352, 
                Rational[7, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.352, 0.}, {-0.35, 
                Rational[1, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.35, 0.}, {-0.348, 
                Rational[1, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.348, 0.}, {-0.346, 
                Rational[19, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.346, 0.}, {-0.344, 
                Rational[11, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.344, 0.}, {-0.342, 
                Rational[7, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.342, 0.}, {-0.34, 
                Rational[1, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.34, 0.}, {-0.338, 
                Rational[13, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.338, 0.}, {-0.336, 
                Rational[23, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.336, 0.}, {-0.334, 
                Rational[29, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.334, 0.}, {-0.332, 
                Rational[1, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.332, 0.}, {-0.33, 
                Rational[3, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.33, 0.}, {-0.328, 
                Rational[27, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.328, 0.}, {-0.326, 
                Rational[37, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.326, 0.}, {-0.324, 
                Rational[7, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.324, 0.}, {-0.322, 
                Rational[1, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.322, 0.}, {-0.32, 
                Rational[17, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.32, 0.}, {-0.318, 
                Rational[9, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.318, 0.}, {-0.316, 
                Rational[17, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.316, 0.}, {-0.314, 
                Rational[27, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.314, 0.}, {-0.312, 
                Rational[3, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.312, 0.}, {-0.31, 
                Rational[51, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.31, 0.}, {-0.308, 
                Rational[51, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.308, 0.}, {-0.306, 
                Rational[51, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.306, 0.}, {-0.304, 
                Rational[29, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.304, 0.}, {-0.302, 
                Rational[9, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.302, 0.}, {-0.3, 
                Rational[57, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.3, 0.}, {-0.298, 
                Rational[67, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.298, 0.}, {-0.296, 
                Rational[37, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.296, 0.}, {-0.294, 
                Rational[9, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.294, 0.}, {-0.292, 
                Rational[63, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.292, 0.}, {-0.29, 
                Rational[83, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.29, 0.}, {-0.288, 
                Rational[23, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.288, 0.}, {-0.286, 
                Rational[9, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.286, 0.}, {-0.284, 
                Rational[81, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.284, 0.}, {-0.282, 
                Rational[91, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.282, 0.}, {-0.28, 
                Rational[53, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.28, 0.}, {-0.278, 
                Rational[107, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.278, 0.}, {-0.276, 
                Rational[5, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.276, 0.}, {-0.274, 
                Rational[117, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.274, 0.}, {-0.272, 
                Rational[123, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.272, 0.}, {-0.27, 
                Rational[159, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.27, 0.}, {-0.268, 
                Rational[137, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.268, 0.}, {-0.266, 
                Rational[117, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.266, 0.}, {-0.264, 
                Rational[189, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.264, 0.}, {-0.262, 
                Rational[143, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.262, 0.}, {-0.26, 
                Rational[3, 4]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.26, 0.}, {-0.258, 
                Rational[49, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.258, 0.}, {-0.256, 
                Rational[33, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.256, 0.}, {-0.254, 
                Rational[41, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.254, 0.}, {-0.252, 
                Rational[43, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.252, 0.}, {-0.25, 
                Rational[189, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.25, 0.}, {-0.248, 1}, "RoundingRadius" -> 0]}}, {{
             
              Rectangle[{-0.248, 0.}, {-0.246, 
                Rational[29, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.246, 0.}, {-0.244, 
                Rational[231, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.244, 0.}, {-0.242, 
                Rational[101, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.242, 0.}, {-0.24, 
                Rational[257, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.24, 0.}, {-0.238, 
                Rational[67, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.238, 0.}, {-0.236, 
                Rational[139, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.236, 0.}, {-0.234, 
                Rational[323, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.234, 0.}, {-0.232, 
                Rational[301, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.232, 0.}, {-0.23, 
                Rational[149, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.23, 0.}, {-0.228, 
                Rational[309, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.228, 0.}, {-0.226, 
                Rational[69, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.226, 0.}, {-0.224, 
                Rational[327, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.224, 0.}, {-0.222, 
                Rational[321, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.222, 0.}, {-0.22, 
                Rational[331, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.22, 0.}, {-0.218, 
                Rational[191, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.218, 0.}, {-0.216, 
                Rational[89, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.216, 0.}, {-0.214, 
                Rational[353, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.214, 0.}, {-0.212, 
                Rational[43, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.212, 0.}, {-0.21, 
                Rational[49, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.21, 0.}, {-0.208, 
                Rational[5, 2]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.208, 0.}, {-0.206, 
                Rational[443, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.206, 0.}, {-0.204, 
                Rational[517, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.204, 0.}, {-0.202, 
                Rational[493, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.202, 0.}, {-0.2, 
                Rational[451, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.2, 0.}, {-0.198, 
                Rational[247, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.198, 0.}, {-0.196, 
                Rational[489, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.196, 0.}, {-0.194, 
                Rational[111, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.194, 0.}, {-0.192, 
                Rational[547, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.192, 0.}, {-0.19, 
                Rational[531, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.19, 0.}, {-0.188, 
                Rational[609, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.188, 0.}, {-0.186, 
                Rational[589, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.186, 0.}, {-0.184, 
                Rational[583, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.184, 0.}, {-0.182, 
                Rational[307, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.182, 0.}, {-0.18, 
                Rational[123, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.18, 0.}, {-0.178, 
                Rational[701, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.178, 0.}, {-0.176, 
                Rational[667, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.176, 0.}, {-0.174, 
                Rational[651, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.174, 0.}, {-0.172, 
                Rational[351, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.172, 0.}, {-0.17, 
                Rational[181, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.17, 0.}, {-0.168, 
                Rational[92, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.168, 0.}, {-0.166, 
                Rational[387, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.166, 0.}, {-0.164, 
                Rational[757, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.164, 0.}, {-0.162, 
                Rational[98, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.162, 0.}, {-0.16, 
                Rational[753, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.16, 0.}, {-0.158, 
                Rational[417, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.158, 0.}, {-0.156, 
                Rational[104, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.156, 0.}, {-0.154, 
                Rational[217, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.154, 0.}, {-0.152, 
                Rational[423, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.152, 0.}, {-0.15, 
                Rational[427, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.15, 0.}, {-0.148, 
                Rational[879, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.148, 0.}, {-0.146, 
                Rational[89, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.146, 0.}, {-0.144, 
                Rational[227, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.144, 0.}, {-0.142, 
                Rational[907, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.142, 0.}, {-0.14, 
                Rational[907, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.14, 0.}, {-0.138, 
                Rational[47, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.138, 0.}, {-0.136, 
                Rational[24, 5]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.136, 0.}, {-0.134, 
                Rational[191, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.134, 0.}, {-0.132, 
                Rational[47, 10]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.132, 0.}, {-0.13, 
                Rational[469, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.13, 0.}, {-0.128, 
                Rational[473, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.128, 0.}, {-0.126, 
                Rational[479, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.126, 0.}, {-0.124, 
                Rational[957, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.124, 0.}, {-0.122, 
                Rational[969, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.122, 0.}, {-0.12, 
                Rational[499, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.12, 0.}, {-0.118, 
                Rational[1029, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.118, 0.}, {-0.116, 
                Rational[39, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.116, 0.}, {-0.114, 
                Rational[493, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.114, 0.}, {-0.112, 
                Rational[126, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.112, 0.}, {-0.11, 
                Rational[1009, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.11, 0.}, {-0.108, 
                Rational[1011, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.108, 0.}, {-0.106, 
                Rational[1007, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.106, 0.}, {-0.104, 
                Rational[26, 5]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.104, 0.}, {-0.102, 
                Rational[963, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.102, 0.}, {-0.1, 
                Rational[131, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.1, 0.}, {-0.098, 
                Rational[247, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.098, 0.}, {-0.096, 
                Rational[123, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.096, 0.}, {-0.094, 
                Rational[1077, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.094, 0.}, {-0.092, 
                Rational[1033, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.092, 0.}, {-0.09, 
                Rational[1037, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.09, 0.}, {-0.088, 
                Rational[987, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.088, 0.}, {-0.086, 
                Rational[971, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.086, 0.}, {-0.084, 
                Rational[1043, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.084, 0.}, {-0.082, 
                Rational[1021, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.082, 0.}, {-0.08, 
                Rational[941, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.08, 0.}, {-0.078, 
                Rational[121, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.078, 0.}, {-0.076, 
                Rational[99, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.076, 0.}, {-0.074, 
                Rational[943, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.074, 0.}, {-0.072, 
                Rational[869, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.072, 0.}, {-0.07, 
                Rational[87, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.07, 0.}, {-0.068, 
                Rational[191, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.068, 0.}, {-0.066, 
                Rational[451, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.066, 0.}, {-0.064, 
                Rational[124, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.064, 0.}, {-0.062, 
                Rational[35, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.062, 0.}, {-0.06, 
                Rational[869, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.06, 0.}, {-0.058, 
                Rational[893, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.058, 0.}, {-0.056, 
                Rational[439, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.056, 0.}, {-0.054, 
                Rational[437, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.054, 0.}, {-0.052, 
                Rational[89, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.052, 0.}, {-0.05, 
                Rational[827, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.05, 0.}, {-0.048, 
                Rational[783, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.048, 0.}, {-0.046, 
                Rational[397, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.046, 0.}, {-0.044, 
                Rational[141, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.044, 0.}, {-0.042, 
                Rational[769, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.042, 0.}, {-0.04, 
                Rational[687, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.04, 0.}, {-0.038, 
                Rational[387, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.038, 0.}, {-0.036, 
                Rational[651, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.036, 0.}, {-0.034, 
                Rational[67, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.034, 0.}, {-0.032, 
                Rational[7, 2]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.032, 0.}, {-0.03, 
                Rational[82, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.03, 0.}, {-0.028, 
                Rational[309, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.028, 0.}, {-0.026, 
                Rational[123, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.026, 0.}, {-0.024, 
                Rational[14, 5]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.024, 0.}, {-0.022, 
                Rational[591, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.022, 0.}, {-0.02, 
                Rational[551, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.02, 0.}, {-0.018, 
                Rational[261, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.018, 0.}, {-0.016, 
                Rational[139, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.016, 0.}, {-0.014, 
                Rational[539, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.014, 0.}, {-0.012, 
                Rational[63, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.012, 0.}, {-0.01, 
                Rational[47, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.01, 0.}, {-0.008, 
                Rational[231, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.008, 0.}, {-0.006, 
                Rational[43, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.006, 0.}, {-0.004, 
                Rational[89, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.004, 0.}, {-0.002, 
                Rational[439, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{-0.002, 0.}, {0., 
                Rational[199, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0., 0.}, {0.002, 
                Rational[389, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.002, 0.}, {0.004, 2}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.004, 0.}, {0.006, 
                Rational[337, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.006, 0.}, {0.008, 
                Rational[361, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.008, 0.}, {0.01, 
                Rational[331, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.01, 0.}, {0.012, 
                Rational[59, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.012, 0.}, {0.014, 
                Rational[59, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.014, 0.}, {0.016, 
                Rational[281, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.016, 0.}, {0.018, 
                Rational[36, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.018, 0.}, {0.02, 
                Rational[261, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.02, 0.}, {0.022, 
                Rational[263, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.022, 0.}, {0.024, 
                Rational[9, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.024, 0.}, {0.026, 
                Rational[49, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.026, 0.}, {0.028, 
                Rational[41, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.028, 0.}, {0.03, 
                Rational[23, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.03, 0.}, {0.032, 
                Rational[209, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.032, 0.}, {0.034, 
                Rational[91, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.034, 0.}, {0.036, 
                Rational[171, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.036, 0.}, {0.038, 
                Rational[151, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.038, 0.}, {0.04, 
                Rational[147, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.04, 0.}, {0.042, 
                Rational[31, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.042, 0.}, {0.044, 
                Rational[147, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.044, 0.}, {0.046, 
                Rational[29, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.046, 0.}, {0.048, 
                Rational[13, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.048, 0.}, {0.05, 
                Rational[113, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.05, 0.}, {0.052, 
                Rational[49, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.052, 0.}, {0.054, 
                Rational[83, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.054, 0.}, {0.056, 
                Rational[53, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.056, 0.}, {0.058, 
                Rational[99, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.058, 0.}, {0.06, 
                Rational[43, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.06, 0.}, {0.062, 
                Rational[19, 40]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.062, 0.}, {0.064, 
                Rational[37, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.064, 0.}, {0.066, 
                Rational[67, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.066, 0.}, {0.068, 
                Rational[31, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.068, 0.}, {0.07, 
                Rational[57, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.07, 0.}, {0.072, 
                Rational[7, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.072, 0.}, {0.074, 
                Rational[17, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.074, 0.}, {0.076, 
                Rational[49, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.076, 0.}, {0.078, 
                Rational[9, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.078, 0.}, {0.08, 
                Rational[53, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.08, 0.}, {0.082, 
                Rational[23, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.082, 0.}, {0.084, 
                Rational[39, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.084, 0.}, {0.086, 
                Rational[9, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.086, 0.}, {0.088, 
                Rational[33, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.088, 0.}, {0.09, 
                Rational[13, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.09, 0.}, {0.092, 
                Rational[1, 8]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.092, 0.}, {0.094, 
                Rational[3, 20]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.094, 0.}, {0.096, 
                Rational[2, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.096, 0.}, {0.098, 
                Rational[13, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.098, 0.}, {0.1, 
                Rational[2, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.1, 0.}, {0.102, 
                Rational[19, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.102, 0.}, {0.104, 
                Rational[2, 25]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.104, 0.}, {0.106, 
                Rational[19, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.106, 0.}, {0.108, 
                Rational[13, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.108, 0.}, {0.11, 
                Rational[3, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.11, 0.}, {0.112, 
                Rational[13, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.112, 0.}, {0.114, 
                Rational[9, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.114, 0.}, {0.116, 
                Rational[9, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.116, 0.}, {0.118, 
                Rational[13, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.118, 0.}, {0.12, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.12, 0.}, {0.122, 
                Rational[3, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.122, 0.}, {0.124, 
                Rational[3, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.124, 0.}, {0.126, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.126, 0.}, {0.128, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.128, 0.}, {0.13, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.13, 0.}, {0.132, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.132, 0.}, {0.134, 
                Rational[1, 50]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.134, 0.}, {0.136, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.136, 0.}, {0.138, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.138, 0.}, {0.14, 
                Rational[3, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.14, 0.}, {0.142, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.142, 0.}, {0.144, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.144, 0.}, {0.146, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.146, 0.}, {0.148, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.148, 0.}, {0.15, 
                Rational[1, 100]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.15, 0.}, {0.152, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.152, 0.}, {0.154, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.154, 0.}, {0.156, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.156, 0.}, {0.158, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.158, 0.}, {0.16, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.16, 0.}, {0.162, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.162, 0.}, {0.164, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.164, 0.}, {0.166, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.166, 0.}, {0.168, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.168, 0.}, {0.17, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.17, 0.}, {0.172, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.172, 0.}, {0.174, 
                Rational[1, 200]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.174, 0.}, {0.176, 
                Rational[3, 200]}, "RoundingRadius" -> 
               0]}}}}, {}, {}}}}}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         RGBColor[0., 0., 0.30000000000000004`], 
         Line[CompressedData["
1:eJwUV3c8lu8XRmbmq2ghO4TICPXe57VSqAgNfZWMkmQliYzsrCQkhJKZvfdt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          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         RGBColor[1, 0.6666666666666666, 
          Rational[1, 3]], 
         Line[CompressedData["
1:eJwUV3c8lu8XtimEV4QiI6OsSFa9z/0qlFERlZCvJArZq5SMzJDICAlZZWRv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          "]]}, {
         Hue[0.1421359549995791, 0.6, 0.6], 
         RGBColor[1, 0, 0], 
         Line[CompressedData["
1:eJwUl3c8V/8XxxFSskcSCqHQMFLk3vdHZiWZ1VdEEpJEhCgrIntnhWQlSfY+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          "]]}}}}, {
     LabelStyle -> {FontFamily -> "Times", FontSize -> 10}, 
      AxesLabel -> {
       Null, "\!\(\*\nStyleBox[\"f\",\nFontSlant->\"Italic\"]\)(\!\(\*\n\
StyleBox[\"m\",\nFontSlant->\"Italic\"]\)\!\(\*\nStyleBox[\" \",\nFontSlant->\
\"Italic\"]\)| \!\(\*\nStyleBox[SubscriptBox[\"m\", \"wt\"],\n\
FontSlant->\"Italic\"]\))"}, AspectRatio -> GoldenRatio^(-1), Axes -> True, 
      AxesOrigin -> {0, 0}, Frame -> {True, True, False, False}, 
      FrameLabel -> {{None, None}, {
        "\!\(\*\nStyleBox[\"m\",\nFontSlant->\"Italic\"]\)", None}}, 
      Method -> {}, PlotRange -> {{-0.7, 0.2}, All}, PlotRangeClipping -> 
      True, PlotRangePadding -> {Automatic, Automatic}}], {
     Placed[
      Unevaluated[
       SwatchLegend[{
         Directive[
          Opacity[0.5], 
          EdgeForm[
           Opacity[-2.506]], 
          RGBColor[0., 0., 0.30000000000000004`]], 
         Directive[
          Opacity[0.5], 
          EdgeForm[
           Opacity[-2.506]], 
          RGBColor[1, 0.6666666666666666, 
           Rational[1, 3]]], 
         Directive[
          Opacity[0.5], 
          EdgeForm[
           Opacity[-2.506]], 
          RGBColor[1, 0, 0]]}, {
         StringForm[
         "\!\(\*SubscriptBox[\n StyleBox[\"m\",\nFontSlant->\"Italic\"], \"wt\
\"]\) = ``", 
          NumberForm[-0.3, 3]], 
         StringForm[
         "\!\(\*SubscriptBox[\n StyleBox[\"m\",\nFontSlant->\"Italic\"], \"wt\
\"]\) = ``", 
          NumberForm[-0.2, 3]], 
         StringForm[
         "\!\(\*SubscriptBox[\n StyleBox[\"m\",\nFontSlant->\"Italic\"], \"wt\
\"]\) = ``", 
          NumberForm[-0.1, 3]]}, LegendLayout -> "Column", 
        LegendMarkers -> {{Automatic, Automatic, Automatic}, {
          None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None, None, None, None, None, 
           None, None, None, None, None, None, None}}]], {0.2, 0.8}, 
      Identity], {}}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.7307420134977837`*^9, 3.73074221103153*^9, {3.730742267213263*^9, 
   3.730742299752798*^9}, {3.730742333249682*^9, 3.730742487063575*^9}, 
   3.7307425428753233`*^9, {3.7307428401319323`*^9, 3.730742939161085*^9}, {
   3.730743312022818*^9, 3.7307433680228863`*^9}, {3.730743407835232*^9, 
   3.730743422309148*^9}, {3.73074897217229*^9, 3.730749034958315*^9}, {
   3.730749089947551*^9, 3.730749146093815*^9}, 3.7307492642655563`*^9, 
   3.730749312813456*^9, 3.730749353591559*^9, 3.73074941118441*^9, {
   3.730749443985133*^9, 3.730749471929994*^9}, 3.730749503229759*^9, 
   3.730749574181099*^9, 3.73074980509839*^9, 3.730749844050253*^9, 
   3.730749912911229*^9, 3.7307500038872128`*^9, 3.730750092241996*^9, 
   3.730750306777553*^9, 3.730817941621312*^9, 3.731097457973071*^9, 
   3.731155941810268*^9, 3.731161571858304*^9, 3.731345564684024*^9, 
   3.7314132896742573`*^9, 3.731433090857141*^9, 3.7317828885500107`*^9, 
   3.7318000771269417`*^9, 3.731852271393262*^9, 3.732019824897312*^9, 
   3.732653480654578*^9, 3.7326535305993567`*^9, 3.732971276361601*^9, 
   3.733663085288289*^9, 3.7341954896701183`*^9, 3.734358660073934*^9, {
   3.734875483734264*^9, 3.7348755124271307`*^9}, {3.734875555765682*^9, 
   3.734875585264566*^9}, 3.7348756854246683`*^9, 3.73487581748116*^9, 
   3.7348758827109137`*^9, {3.73487591496452*^9, 3.734875939304426*^9}, 
   3.7348759762508802`*^9, 3.734876069764896*^9, 3.734876125330288*^9, 
   3.7362050042832947`*^9, 3.736600992400815*^9, 3.736649169599848*^9, 
   3.736650849740406*^9, 3.7438796218528433`*^9, 3.743879681353497*^9, 
   3.7438898854816093`*^9, 3.74524414239375*^9, 3.745258474183938*^9, 
   3.745496882821373*^9, 3.745587154718636*^9, 3.751032240173793*^9, 
   3.751568967111946*^9, 
   3.782251499124402*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Probability of rescue (equations 2 and 3)\
\>", "Subsection",
 CellChangeTimes->{{3.7691862045550547`*^9, 3.76918621309125*^9}, {
  3.7691875998021593`*^9, 3.769187603319888*^9}}],

Cell["\<\
Let p0 be the probability a wildtype individual has descendants that rescue \
the population. If we start with N0 wildtypes the probability of rescue is \
then\
\>", "Text",
 CellChangeTimes->{{3.76918626305441*^9, 3.769186308910027*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"prescue", "=", 
   RowBox[{"1", "-", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "p0"}], ")"}], "N0"]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.769186309719677*^9, 3.7691863201279984`*^9}, {
  3.769187897810872*^9, 3.769187899933742*^9}}],

Cell["\<\
which with small p0 and large N0 is approximately\
\>", "Text",
 CellChangeTimes->{{3.769186322102293*^9, 3.769186325654372*^9}, {
  3.769186381288115*^9, 3.769186385840198*^9}, {3.769186425193378*^9, 
  3.7691864259542627`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prescueApp", "=", 
  RowBox[{
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", "p0"}], ")"}], "N0"]}], "/.", 
       RowBox[{"p0", "\[Rule]", 
        RowBox[{"p0", " ", "\[Epsilon]"}]}]}], "/.", 
      RowBox[{"N0", "\[Rule]", 
       RowBox[{"N0", " ", "/", "\[Epsilon]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]", ",", "0", ",", "0"}], "}"}]}], "]"}], "//", 
   "Normal"}]}]], "Input",
 CellChangeTimes->{{3.7691863306413183`*^9, 3.769186416003811*^9}, 
   3.769186519513324*^9, {3.769187883587554*^9, 3.769187923248152*^9}}],

Cell[BoxData[
 RowBox[{"1", "-", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "N0"}], " ", "p0"}]]}]], "Output",
 CellChangeTimes->{
  3.769186338557124*^9, 3.769186374985783*^9, {3.769186413718672*^9, 
   3.769186416890667*^9}, 3.769186520353306*^9, 3.769187887594172*^9, {
   3.769187918872073*^9, 3.769187923684445*^9}, 3.7822515142012787`*^9}]
}, Closed]],

Cell[TextData[{
 "Let there be X[t,m] individuals in a lineage time t after it arose, given \
growth rate m. Then the total number of individuals in the lineage is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     SuperscriptBox[
      SubscriptBox["\[Integral]", "0"], "\[Tau]"],
     TraditionalForm], 
    RowBox[{
     RowBox[{"X", "[", 
      RowBox[{"t", ",", "m"}], "]"}], " ", "dt", " "}]}], TraditionalForm]]],
 " , where \[Tau] is the time of extinction. The distribution of the random \
variable Y[m] = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     SubscriptBox["\[Integral]", "0"], "\[Tau]"], 
    RowBox[{
     RowBox[{"X", "[", 
      RowBox[{"t", ",", "m"}], "]"}], " ", "dt"}]}], TraditionalForm]]],
 " is known (see Martin et al 2013 Phil Trans B sup mat); its MGF is"
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQbbD68Bf9F68dOzKOfQPRHkt8f4PoZSd2MxkA6SCe
ongQ7fX3QhKIlnscnw6iM2YcrgDRm+afqwXR7IcnNoLoNTWbZoHoeRwtc0H0
NgP5ZSD6VpTLfhC9UOj/cRDNV/XsJIiedpFlVe+n144+s+LXgGi2uh2XQTTP
1agbILrt8clPIDrAeusfEP1qmiZzH5DOEHMC048+nksH0VIZlzNAdHGTU8uO
z68d1Zoh9GStc1rqom8cl91dqw+ijTuPW4Do3iObbEF0RWyhC4h+plPgDaJF
7u3LB6t7J18Ioi/bp5SCaM/P3mUg2itloZ0GkN72OckJRAMAyqaotw==
  "]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MomentGeneratingFunction", "[", 
  RowBox[{
   RowBox[{"InverseGaussianDistribution", "[", 
    RowBox[{
     RowBox[{"Abs", "[", 
      RowBox[{"1", "/", "m"}], "]"}], ",", "1"}], "]"}], ",", "z"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.745613308161525*^9, 3.745613362260069*^9}, 
   3.751046869520893*^9, 3.769186918507279*^9}],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"2", " ", "z"}], 
        SuperscriptBox[
         RowBox[{"Abs", "[", "m", "]"}], "2"]]}]]}], ")"}], " ", 
   RowBox[{"Abs", "[", "m", "]"}]}]]], "Output",
 CellChangeTimes->{{3.745613357067486*^9, 3.745613362491045*^9}, 
   3.751046514834819*^9, 3.751046870662919*^9, 3.7691869191623363`*^9, 
   3.7822515143135977`*^9}]
}, Closed]],

Cell[TextData[{
 "Let an individual with growth rate m produce rescue mutants at rate \
\[CapitalLambda](m). The probability its lineage rescues the population is \
then ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"1", "-", 
    RowBox[{
     SubscriptBox["\[DoubleStruckCapitalE]", "Y"], "[", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "Y"}], 
       RowBox[{"(", "m", ")"}], "\[CapitalLambda]", 
       RowBox[{"(", "m", ")"}]}]], "]"}]}], " ", "=", " ", 
   RowBox[{"1", "-", 
    RowBox[{
     SubscriptBox["M", "Y"], "[", 
     RowBox[{
      RowBox[{"-", "\[CapitalLambda]"}], 
      RowBox[{"(", "m", ")"}]}], "]"}]}]}]], "Text",
  CellChangeTimes->{
   3.742200615101766*^9, {3.7422006969164457`*^9, 3.7422007024887643`*^9}, {
    3.742200751651576*^9, 3.7422007559168205`*^9}, {3.7422007978792205`*^9, 
    3.7422008823520517`*^9}, {3.743252220523651*^9, 3.743252255349643*^9}},
  ExpressionUUID -> "2a9cf130-b2dd-4ac1-9f64-287cc98b08a5"],
 " where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["M", "Y"], TraditionalForm]]],
 "is the MGF of Y. Thus evaluating our MGF above at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", 
    RowBox[{"-", 
     RowBox[{"\[CapitalLambda]", "(", "m", ")"}]}]}], TraditionalForm]]],
 " we have the probability of rescue from a genotype with growth rate m"
}], "Text",
 CellChangeTimes->{{3.745613495110363*^9, 3.745613530768385*^9}, {
  3.751046663187553*^9, 3.751046667064456*^9}, {3.7510471720754633`*^9, 
  3.751047301760498*^9}, {3.7510475083000803`*^9, 3.7510477383262587`*^9}, {
  3.7510480146132174`*^9, 3.7510480310161133`*^9}, {3.7510501558644342`*^9, 
  3.7510501560306177`*^9}, {3.769187129772047*^9, 3.769187188683228*^9}, {
  3.7691872644060183`*^9, 3.7691872673495693`*^9}, {3.769187321759412*^9, 
  3.7691874100215607`*^9}, {3.769187442669016*^9, 3.769187524853341*^9}, {
  3.771274353022891*^9, 3.771274355878693*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"prescuem", "[", 
   RowBox[{"m_", ",", "\[CapitalLambda]_"}], "]"}], ":=", 
  RowBox[{"1", "-", 
   RowBox[{"MomentGeneratingFunction", "[", 
    RowBox[{
     RowBox[{"InverseGaussianDistribution", "[", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"1", "/", "m"}], "]"}], ",", "1"}], "]"}], ",", 
     RowBox[{"-", "\[CapitalLambda]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.769187528824133*^9, 3.769187538400679*^9}, {
  3.769195316461226*^9, 3.7691953554369373`*^9}, {3.769195601372223*^9, 
  3.7691956015802107`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Probability of establishment (equation 4)\
\>", "Subsection",
 CellChangeTimes->{
  3.7691876586549397`*^9, {3.769187694060711*^9, 3.7691876984507027`*^9}, 
   3.769190677208246*^9, 3.7717616685806313`*^9}],

Cell["\<\
Using the Feller diffusion approximation (see Martin et al 2013 Phil Trans B \
sup mat for details), the probability a mutant establishes is\
\>", "Text",
 CellChangeTimes->{{3.7318062510241423`*^9, 3.731806271008039*^9}, {
  3.731806302328012*^9, 3.731806358811297*^9}, {3.731806399636548*^9, 
  3.73180643631704*^9}, {3.7318065451610193`*^9, 3.73180656729745*^9}, {
  3.7318066161232347`*^9, 3.731806621219161*^9}, {3.731806917109435*^9, 
  3.731806917523879*^9}, {3.731806956584903*^9, 3.731806958061137*^9}, {
  3.731851425909443*^9, 3.7318514362803307`*^9}, {3.7361750832706633`*^9, 
  3.736175125228904*^9}, {3.7361752466747913`*^9, 3.736175269321965*^9}, {
  3.73617530033097*^9, 3.736175333283865*^9}, {3.736175394573423*^9, 
  3.736175433903061*^9}, {3.743879766274952*^9, 3.74387978902208*^9}, {
  3.7510322518706923`*^9, 3.7510322521440773`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"1", "-", 
  RowBox[{"Exp", "[", 
   RowBox[{
    RowBox[{"-", "2"}], 
    RowBox[{"r", "/", "\[Sigma]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.731806997338668*^9, 3.7318070548101053`*^9}, {
  3.731851344877049*^9, 3.7318513450533524`*^9}, {3.73617545215352*^9, 
  3.7361754540898647`*^9}, {3.743889928958219*^9, 3.743889949497045*^9}, {
  3.75103225428955*^9, 3.751032254967402*^9}}],

Cell[BoxData[
 RowBox[{"1", "-", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", "r"}], "\[Sigma]"]}]]}]], "Output",
 CellChangeTimes->{
  3.731807017262866*^9, 3.731807055267614*^9, 3.731851345651087*^9, 
   3.73201979757052*^9, 3.7329712511851873`*^9, 3.733663060896833*^9, 
   3.734195455950302*^9, 3.73435863236553*^9, 3.736175478539021*^9, 
   3.736204968338955*^9, 3.736206700529932*^9, 3.736253197391204*^9, 
   3.736649183212421*^9, 3.737679862507299*^9, 3.7377487673192263`*^9, {
   3.743889930209424*^9, 3.743889951168633*^9}, 3.7452584743741207`*^9, 
   3.745496882973082*^9, 3.745587154944154*^9, 3.751032255400313*^9, 
   3.751568967233416*^9, 3.782251519766135*^9}]
}, Closed]],

Cell["\<\
where r is the infinitesimal mean and \[Sigma] is the infinitesimal variance \
in mutant growth rate.\
\>", "Text",
 CellChangeTimes->{{3.7361754429036016`*^9, 3.7361755112732277`*^9}, {
  3.736175601363908*^9, 3.736175603387994*^9}, {3.743889933016163*^9, 
  3.743889934335598*^9}, {3.7510322634866447`*^9, 3.7510322758499537`*^9}}],

Cell["In our discrete generation Poisson process, r is", "Text",
 CellChangeTimes->{{3.736175605595255*^9, 3.736175621612309*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expectation", "[", 
  RowBox[{
   RowBox[{"X", "-", "1"}], ",", 
   RowBox[{"X", "\[Distributed]", 
    RowBox[{"PoissonDistribution", "[", 
     RowBox[{"Exp", "[", "m", "]"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7361756293412733`*^9, 3.736175673272748*^9}, {
  3.73617573086765*^9, 3.736175769898988*^9}, {3.7361759203796577`*^9, 
  3.736175920530437*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "+", 
  SuperscriptBox["\[ExponentialE]", "m"]}]], "Output",
 CellChangeTimes->{
  3.736175674611669*^9, {3.736175731578887*^9, 3.736175750153163*^9}, 
   3.7361759208659554`*^9, 3.736204968415001*^9, 3.736206700600947*^9, 
   3.736253197456996*^9, 3.736649183250062*^9, 3.73767986256153*^9, 
   3.737748767375065*^9, 3.7452584744576893`*^9, 3.7454968830261183`*^9, 
   3.745587155027569*^9, 3.751032279800706*^9, 3.751568967272031*^9, 
   3.7822515200006533`*^9}]
}, Closed]],

Cell["and \[Sigma] is", "Text",
 CellChangeTimes->{{3.736175759096653*^9, 3.7361757616997347`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Expectation", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"X", "-", "1"}], ")"}], "2"], ",", 
      RowBox[{"X", "\[Distributed]", 
       RowBox[{"PoissonDistribution", "[", 
        RowBox[{"Exp", "[", "m", "]"}], "]"}]}]}], "]"}], "-", 
    SuperscriptBox[
     RowBox[{"Expectation", "[", 
      RowBox[{
       RowBox[{"X", "-", "1"}], ",", 
       RowBox[{"X", "\[Distributed]", 
        RowBox[{"PoissonDistribution", "[", 
         RowBox[{"Exp", "[", "m", "]"}], "]"}]}]}], "]"}], "2"]}], "//", 
   "Simplify"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.736175764958815*^9, 3.736175785742318*^9}, {
  3.736175926892623*^9, 3.7361759285319853`*^9}, {3.736175962189981*^9, 
  3.7361759737416973`*^9}}],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", "m"]], "Output",
 CellChangeTimes->{{3.7361757728490477`*^9, 3.736175786025072*^9}, 
   3.736175929133161*^9, {3.736175962520149*^9, 3.7361759742764072`*^9}, 
   3.736204968505226*^9, 3.7362067007080793`*^9, 3.7362531975246677`*^9, 
   3.736649183300025*^9, 3.737679862629497*^9, 3.737748767421419*^9, 
   3.745258474538467*^9, 3.7454968830740232`*^9, 3.745587155111023*^9, 
   3.751032288969514*^9, 3.751568967316944*^9, 3.7822515201193323`*^9}]
}, Closed]],

Cell["When m is small these are roughly", "Text",
 CellChangeTimes->{{3.736175831710297*^9, 3.736175837965008*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Exp", "[", "m", "]"}], "-", "1"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
  "Normal"}]], "Input",
 CellChangeTimes->{{3.7361758406708593`*^9, 3.736175851597575*^9}, {
  3.736175943867435*^9, 3.736175944011057*^9}}],

Cell[BoxData["m"], "Output",
 CellChangeTimes->{{3.736175847121023*^9, 3.736175851906414*^9}, 
   3.7361759443737392`*^9, 3.736204968543108*^9, 3.736206700746086*^9, 
   3.736253197590746*^9, 3.736649183345602*^9, 3.737679862678361*^9, 
   3.737748767475355*^9, 3.745258474622423*^9, 3.745496883125084*^9, 
   3.745587155194027*^9, 3.751032293417788*^9, 3.751568967355029*^9, 
   3.782251520230768*^9}]
}, Closed]],

Cell["and", "Text",
 CellChangeTimes->{{3.736175948538364*^9, 3.736175950640627*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"Exp", "[", "m", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "0", ",", "0"}], "}"}]}], "]"}], "//", 
  "Normal"}]], "Input",
 CellChangeTimes->{{3.7361759547011747`*^9, 3.736175980196295*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.736175957332983*^9, 3.736175980398512*^9}, 
   3.73620496858873*^9, 3.7362067007802067`*^9, 3.736253197658133*^9, 
   3.736649183395351*^9, 3.737679862946064*^9, 3.737748767527164*^9, 
   3.745258474709997*^9, 3.745496883174934*^9, 3.7455871552780933`*^9, 
   3.751032295352467*^9, 3.7515689674012337`*^9, 3.782251520345284*^9}]
}, Closed]],

Cell["\<\
Then the probability of establishment for m>0 is roughly\
\>", "Text",
 CellChangeTimes->{{3.736175990443315*^9, 3.736175997418153*^9}, {
   3.736176290522808*^9, 3.736176297627796*^9}, {3.743879848463765*^9, 
   3.743879850040016*^9}, 3.769966065402596*^9, {3.769966217491971*^9, 
   3.7699662190909843`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"1", "-", 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"-", "2"}], 
      RowBox[{"r", "/", "\[Sigma]"}]}], "]"}]}], "/.", 
   RowBox[{"r", "\[Rule]", "m"}]}], "/.", 
  RowBox[{"\[Sigma]", "\[Rule]", "1"}]}]], "Input",
 CellChangeTimes->{{3.736176006526086*^9, 3.736176011900745*^9}, {
   3.74387982341026*^9, 3.743879836347107*^9}, {3.769187979989911*^9, 
   3.769187980157436*^9}, {3.7699660880772142`*^9, 3.769966098754032*^9}, {
   3.769966221845594*^9, 3.7699662260932693`*^9}, 3.769967236036171*^9}],

Cell[BoxData[
 RowBox[{"1", "-", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "2"}], " ", "m"}]]}]], "Output",
 CellChangeTimes->{3.7822515204302473`*^9}]
}, Closed]],

Cell["and this is zero when m<0.", "Text",
 CellChangeTimes->{{3.769966228379047*^9, 3.7699662378114357`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"pest", "[", "m_", "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "2"}], "m"}], "]"}]}], ")"}], 
   RowBox[{"HeavisideTheta", "[", "m", "]"}]}]}]], "Input"],

Cell["\<\
Note that this reduces to both Haldane\[CloseCurlyQuote]s (1927 Mathematical \
Proceedings of the Cambridge Philosophical Society) constant population size \
result and Otto & Whitlock\[CloseCurlyQuote]s (1997 Genetics) changing \
population size result when m is small\
\>", "Text",
 CellChangeTimes->{{3.736176016571143*^9, 3.736176020282577*^9}, {
  3.736176055111812*^9, 3.7361761325260763`*^9}, {3.736176222635826*^9, 
  3.7361762654343987`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"1", "-", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "2"}], "m"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/.", 
   RowBox[{"m", "\[Rule]", 
    RowBox[{
     SubscriptBox["m", "wt"], "+", "s"}]}]}], "/.", 
  RowBox[{
   SubscriptBox["m", "wt"], "\[Rule]", "0"}]}]], "Input",
 CellChangeTimes->{{3.736176023400778*^9, 3.736176036498975*^9}, {
  3.7361761240406637`*^9, 3.7361761719948387`*^9}, {3.769187995447186*^9, 
  3.769187997103549*^9}, {3.769967242646741*^9, 3.769967247286146*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", "s"}]], "Output",
 CellChangeTimes->{{3.736176032116023*^9, 3.736176036807475*^9}, {
   3.736176134501277*^9, 3.736176141310431*^9}, 3.736176172507451*^9, 
   3.736204968654736*^9, 3.736206700864208*^9, 3.7362531977911167`*^9, 
   3.73664918350091*^9, 3.737679863048938*^9, 3.737748767621071*^9, 
   3.745258474874626*^9, 3.745496883275339*^9, 3.7455871554461527`*^9, 
   3.751032339020014*^9, 3.7515689674670553`*^9, 3.769188004019663*^9, 
   3.782251520538745*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Normal", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"1", "-", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "2"}], "m"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/.", 
  RowBox[{"m", "\[Rule]", 
   RowBox[{
    SubscriptBox["m", "wt"], "+", "s"}]}]}]], "Input",
 CellChangeTimes->{{3.736176150210821*^9, 3.7361761589701757`*^9}, 
   3.769188001866201*^9, {3.769967244558551*^9, 3.7699672494362583`*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{"s", "+", 
    SubscriptBox["m", "wt"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.736176159375937*^9, 3.736204968706249*^9, 
  3.7362067009129333`*^9, 3.7362531978577127`*^9, 3.7366491835498333`*^9, 
  3.737679863098127*^9, 3.737748767670937*^9, 3.7452584749566193`*^9, 
  3.745496883324545*^9, 3.7455871556292257`*^9, 3.751032340837665*^9, 
  3.7515689674992437`*^9, 3.769188002785204*^9, 3.782251520635449*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mutant lineage dynamics", "Subsection",
 CellChangeTimes->{{3.771168517132803*^9, 3.771168525102826*^9}, {
   3.77116858521865*^9, 3.771168596257203*^9}, 3.771169483025339*^9}],

Cell[CellGroupData[{

Cell["\<\
Probability generating function\
\>", "Subsubsection",
 CellChangeTimes->{{3.7711694892501717`*^9, 3.7711694940876417`*^9}}],

Cell["\<\
Here we use a continuous time birth (\[Lambda]) death (\[Mu]) process to \
approximate the dynamics of our discrete time Poisson process (nonoverlapping \
generations with expected offspring exp(m)). To align these two approaches we \
need m = \[Lambda] - \[Mu] and, as discussed in Uecker & Hermisson 2016 \
Genetics and Uecker et al 2014 Am Nat, \[Lambda] + \[Mu] = 1. The latter \
requirement ensures both processes have the same amount of drift. We follow \
these studies in equally distributing m between \[Lambda] and \[Mu], such \
that \[Lambda] = (1 + m)/2 and \[Mu] = (1 - m)/2. Note that this is only \
valid for |m|<1.\
\>", "Text",
 CellChangeTimes->{{3.73625641214262*^9, 3.736256484007242*^9}, {
  3.736256701549982*^9, 3.7362567065339003`*^9}, {3.7362569175259113`*^9, 
  3.7362570068551073`*^9}, {3.736257076110777*^9, 3.736257078703267*^9}, {
  3.736257116789352*^9, 3.736257178285912*^9}, {3.7366010448205833`*^9, 
  3.736601062013575*^9}}],

Cell[TextData[{
 "For a continuous-time birth death process starting from N0 individuals ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"F", "[", 
      RowBox[{"s", ",", "0"}], "]"}], "\[Equal]", 
     SuperscriptBox["s", "N0"]}]}], TraditionalForm]]],
 ") the PGF for the number of individuals at time t can be solved for \
explicitly"
}], "Text",
 CellChangeTimes->{{3.682332914730015*^9, 3.6823329437554283`*^9}, {
  3.682413451216722*^9, 3.682413483930725*^9}, {3.682681310190462*^9, 
  3.682681317478837*^9}, {3.7318057368168087`*^9, 3.731805746673211*^9}, {
  3.7362571926700573`*^9, 3.7362571945341673`*^9}, {3.736261359422262*^9, 
  3.736261370057955*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fst", "=", 
  RowBox[{
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"F", "[", 
           RowBox[{"s", ",", "t"}], "]"}], ",", "t"}], "]"}], "==", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"F", "[", 
            RowBox[{"s", ",", "t"}], "]"}], ",", "s"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Lambda]", " ", 
            SuperscriptBox["s", "2"]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Lambda]", "+", "\[Mu]"}], ")"}], "s"}], "+", 
           "\[Mu]"}], ")"}]}]}], ",", 
       RowBox[{
        RowBox[{"F", "[", 
         RowBox[{"s", ",", "0"}], "]"}], "\[Equal]", 
        SuperscriptBox["s", "N0"]}]}], "}"}], ",", 
     RowBox[{"F", "[", 
      RowBox[{"s", ",", "t"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "t"}], "}"}]}], "]"}], "//", "Flatten"}]}]], "Input",
 CellChangeTimes->{{3.682331823761627*^9, 3.682331953449193*^9}, {
   3.682332007211029*^9, 3.6823320898183537`*^9}, {3.682332465426484*^9, 
   3.682332475715043*^9}, {3.682332529308484*^9, 3.6823325540311527`*^9}, {
   3.682332600689569*^9, 3.682332723911749*^9}, {3.6824134064258213`*^9, 
   3.682413416747098*^9}, {3.682658972586132*^9, 3.682658973851983*^9}, 
   3.682659041567869*^9, {3.682681321317177*^9, 3.682681322049942*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"F", "[", 
    RowBox[{"s", ",", "t"}], "]"}], "\[Rule]", 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"t", " ", "\[Lambda]"}], "-", 
            RowBox[{"t", " ", "\[Mu]"}], "+", 
            RowBox[{"Log", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "s"}], "]"}], "-", 
            RowBox[{"Log", "[", 
             RowBox[{
              RowBox[{"s", " ", "\[Lambda]"}], "-", "\[Mu]"}], "]"}]}], 
           ")"}]}], 
         RowBox[{"\[Lambda]", "-", "\[Mu]"}]]], "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"t", " ", "\[Lambda]"}], "-", 
             RowBox[{"t", " ", "\[Mu]"}], "+", 
             RowBox[{"Log", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "s"}], "]"}], "-", 
             RowBox[{"Log", "[", 
              RowBox[{
               RowBox[{"s", " ", "\[Lambda]"}], "-", "\[Mu]"}], "]"}]}], 
            ")"}]}], 
          RowBox[{"\[Lambda]", "-", "\[Mu]"}]]], " ", "\[Mu]"}]}], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"t", " ", "\[Lambda]"}], "-", 
            RowBox[{"t", " ", "\[Mu]"}], "+", 
            RowBox[{"Log", "[", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "s"}], "]"}], "-", 
            RowBox[{"Log", "[", 
             RowBox[{
              RowBox[{"s", " ", "\[Lambda]"}], "-", "\[Mu]"}], "]"}]}], 
           ")"}]}], 
         RowBox[{"\[Lambda]", "-", "\[Mu]"}]]], "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"\[Lambda]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"t", " ", "\[Lambda]"}], "-", 
             RowBox[{"t", " ", "\[Mu]"}], "+", 
             RowBox[{"Log", "[", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "s"}], "]"}], "-", 
             RowBox[{"Log", "[", 
              RowBox[{
               RowBox[{"s", " ", "\[Lambda]"}], "-", "\[Mu]"}], "]"}]}], 
            ")"}]}], 
          RowBox[{"\[Lambda]", "-", "\[Mu]"}]]], " ", "\[Lambda]"}]}]], ")"}],
     "N0"]}], "}"}]], "Output",
 CellChangeTimes->{{3.68233190308508*^9, 3.682331960104352*^9}, {
   3.6823320086201687`*^9, 3.682332091871525*^9}, {3.6823324662667303`*^9, 
   3.682332476468315*^9}, {3.6823326098558483`*^9, 3.682332654790593*^9}, {
   3.682332707145697*^9, 3.682332724315588*^9}, {3.6824134083627157`*^9, 
   3.682413418676931*^9}, {3.682658953133478*^9, 3.6826589741559687`*^9}, 
   3.682659041909783*^9, 3.682681323726219*^9, {3.68274085661263*^9, 
   3.6827408727029057`*^9}, 3.682757236159814*^9, 3.6827671832596283`*^9, 
   3.68291094044261*^9, 3.682912156744175*^9, 3.6829130281149883`*^9, 
   3.682913338034842*^9, 3.6829139520574293`*^9, 3.6841502408986588`*^9, 
   3.684150326458926*^9, 3.684150580920081*^9, 3.684207401808552*^9, 
   3.684208942532284*^9, 3.684225310429503*^9, 3.684421628477981*^9, 
   3.684552954636365*^9, 3.684744243359426*^9, 3.684744475337654*^9, 
   3.685678719223233*^9, 3.685691604575479*^9, 3.687150184654582*^9, 
   3.6871770901887074`*^9, 3.687252191162676*^9, 3.687258920039982*^9, 
   3.687504448608039*^9, 3.687691396248274*^9, 3.6893191919205313`*^9, 
   3.6955596461245127`*^9, 3.695578578852669*^9, 3.6955863488855133`*^9, 
   3.69661093329478*^9, 3.700413473806239*^9, 3.718461372538356*^9, 
   3.718714638706936*^9, 3.7252892671327057`*^9, 3.725289411431072*^9, 
   3.7306439857715893`*^9, 3.73073186850982*^9, 3.7308177439788094`*^9, 
   3.731097318844776*^9, 3.731155812947096*^9, 3.731161444350708*^9, 
   3.731345439335938*^9, 3.731413111818552*^9, 3.7314329637859697`*^9, 
   3.7314335716123877`*^9, 3.7314412722068157`*^9, 3.7317826547717876`*^9, 
   3.7317999436066093`*^9, 3.731849460522706*^9, 3.731876710112838*^9, 
   3.732019784970578*^9, 3.7326533242966433`*^9, 3.7329712427412243`*^9, 
   3.7336630525261374`*^9, 3.734195444570438*^9, 3.734358618702093*^9, 
   3.7345272593418207`*^9, 3.734980872795949*^9, 3.735052657095439*^9, 
   3.736204961781444*^9, {3.7362066885872717`*^9, 3.736206697396392*^9}, 
   3.736253191379449*^9, 3.736519835793461*^9, 3.73660108345927*^9, 
   3.736649175425378*^9, 3.736772484059499*^9, 3.771168563969927*^9, 
   3.782251527765246*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Probability of persistence", "Subsubsection",
 CellChangeTimes->{{3.771169056317178*^9, 3.77116906093187*^9}}],

Cell["\<\
The probability of extinction at time t can be obtained from the PGF\
\>", "Text",
 CellChangeTimes->{{3.682659160570601*^9, 3.682659167004808*^9}, {
  3.7362580789255543`*^9, 3.7362580849100943`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pextt", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{"s", ",", "t"}], "]"}], "/.", "fst"}], "/.", 
     RowBox[{"s", "\[Rule]", "0"}]}], "//", "Factor"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.682658958198617*^9, 3.682658994507291*^9}, {
  3.682659034020277*^9, 3.682659056070386*^9}, {3.6826640380196323`*^9, 
  3.682664039707939*^9}, {3.736257043846539*^9, 3.736257066414221*^9}}],

Cell[BoxData[
 SuperscriptBox[
  RowBox[{"(", 
   RowBox[{"1", "+", 
    FractionBox[
     RowBox[{
      RowBox[{"-", "\[Lambda]"}], "+", "\[Mu]"}], 
     RowBox[{"\[Lambda]", "-", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"t", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "\[Lambda]"}], "+", "\[Mu]"}], ")"}]}]], " ", 
       "\[Mu]"}]}]]}], ")"}], "N0"]], "Output",
 CellChangeTimes->{{3.682658966768631*^9, 3.682658995101892*^9}, {
   3.6826590353215637`*^9, 3.6826590566698017`*^9}, {3.682664034307967*^9, 
   3.6826640402374973`*^9}, 3.682681327959464*^9, {3.682740857588459*^9, 
   3.682740873611541*^9}, 3.682757237040559*^9, 3.6827671842045813`*^9, 
   3.682910941513433*^9, 3.6829121579671717`*^9, 3.682913029023435*^9, 
   3.682913338983617*^9, 3.68291395300317*^9, 3.6841502418929367`*^9, 
   3.684150327545774*^9, 3.684150581948227*^9, 3.684207402801579*^9, 
   3.684208943577532*^9, 3.6842253113624487`*^9, 3.684421629498559*^9, 
   3.684552955646471*^9, 3.6847442444274597`*^9, 3.6847444765152082`*^9, 
   3.6856787201538343`*^9, 3.685691605704816*^9, 3.6871501855995913`*^9, 
   3.68717709296686*^9, 3.687252192234001*^9, 3.687258921333008*^9, 
   3.687504449692416*^9, 3.687691397196989*^9, 3.689319193138299*^9, 
   3.695559649017932*^9, 3.695578579625558*^9, 3.695586349763138*^9, 
   3.6966109366042747`*^9, 3.700413474576735*^9, 3.718461373562242*^9, 
   3.718714639740646*^9, 3.725289269359544*^9, 3.725289412261754*^9, 
   3.730644024555751*^9, 3.730731869428174*^9, 3.7308177450317097`*^9, 
   3.731097320373826*^9, 3.731155813855308*^9, 3.731161445282201*^9, 
   3.731345440257494*^9, 3.731413112770355*^9, 3.7314329647733183`*^9, 
   3.731433572654031*^9, 3.7314412733085527`*^9, 3.7317826556843433`*^9, 
   3.731799944646019*^9, 3.7318494614476633`*^9, 3.731876711043974*^9, 
   3.732019785954081*^9, 3.732653325355214*^9, 3.732971243672611*^9, 
   3.733663053435463*^9, 3.734195446002049*^9, 3.73435861956872*^9, 
   3.734527260401753*^9, 3.73498087396737*^9, 3.7350526584244413`*^9, 
   3.736204962885848*^9, {3.736206689759*^9, 3.736206698484483*^9}, 
   3.7362531923850203`*^9, {3.736257045938446*^9, 3.736257067166934*^9}, 
   3.736519836693557*^9, 3.736601084297387*^9, 3.7366491764999866`*^9, 
   3.736772484850204*^9, 3.771168604500102*^9, 3.782251532662395*^9}]
}, Closed]],

Cell["\<\
Evaluating at s=0 as t goes to infinity gives the probabilty the lineage ever \
goes extinct. When birth rate is greater than death rate, \[Lambda]>\[Mu] ie \
m>0, we have\
\>", "Text",
 CellChangeTimes->{{3.682332947884575*^9, 3.6823329763906517`*^9}, {
   3.682333818181336*^9, 3.682333827919465*^9}, {3.6826592096868267`*^9, 
   3.682659229874874*^9}, {3.682681346634392*^9, 3.6826813747529593`*^9}, 
   3.6841493258643703`*^9, {3.6955596662293663`*^9, 3.695559666935213*^9}, 
   3.69661257630578*^9, {3.7306440361674433`*^9, 3.730644036773409*^9}, {
   3.7306570671830683`*^9, 3.7306570774952707`*^9}, {3.736257320529872*^9, 
   3.736257332034378*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"pextinction", "=", 
  RowBox[{"Limit", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{"s", ",", "t"}], "]"}], "/.", "fst"}], "/.", 
     RowBox[{"s", "\[Rule]", "0"}]}], ",", 
    RowBox[{"t", "\[Rule]", "\[Infinity]"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Lambda]", ">", "\[Mu]"}], ",", 
       RowBox[{"\[Mu]", ">", "0"}]}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"1", "-", "%"}], "/.", 
     RowBox[{"\[Lambda]", "\[Rule]", 
      FractionBox[
       RowBox[{"1", "+", "m"}], "2"]}]}], "/.", 
    RowBox[{"\[Mu]", "\[Rule]", 
     FractionBox[
      RowBox[{"1", "-", "m"}], "2"]}]}], "/.", 
   RowBox[{"N0", "\[Rule]", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"m", ",", "0", ",", "1"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.682332726024107*^9, 3.6823327821660137`*^9}, {
   3.682332901449705*^9, 3.682332904923052*^9}, {3.682413601662385*^9, 
   3.682413631825924*^9}, {3.682681356648881*^9, 3.6826813651439743`*^9}, {
   3.736257212918721*^9, 3.736257269294301*^9}, 3.736257349175228*^9, {
   3.7362573831291447`*^9, 3.736257383560511*^9}, {3.736257421312731*^9, 
   3.736257421477483*^9}}],

Cell[BoxData[
 SuperscriptBox[
  RowBox[{"(", 
   FractionBox["\[Mu]", "\[Lambda]"], ")"}], "N0"]], "Output",
 CellChangeTimes->{{3.682332728362124*^9, 3.682332783172077*^9}, 
   3.6823329056659517`*^9, 3.682413499264751*^9, 3.682413606995298*^9, 
   3.6826589787313223`*^9, 3.682659186232942*^9, 3.682675778882359*^9, 
   3.6826813588937273`*^9, {3.682740858452972*^9, 3.6827408737158823`*^9}, 
   3.682757238007535*^9, 3.6827671850484667`*^9, 3.682910942609147*^9, 
   3.6829121588159933`*^9, 3.6829130297587137`*^9, 3.682913339874617*^9, 
   3.682913953760215*^9, 3.684150242843616*^9, 3.684150328433429*^9, 
   3.684150582798278*^9, 3.684207403579948*^9, 3.684208944622508*^9, 
   3.684225312158441*^9, 3.6844216303079576`*^9, 3.6845529565562067`*^9, 
   3.6847442454961653`*^9, 3.68474447741066*^9, 3.685678721005582*^9, 
   3.6856916066008253`*^9, 3.6871501863873*^9, 3.687177093923608*^9, 
   3.6872521931427927`*^9, 3.6872589224678907`*^9, 3.6875044506096077`*^9, 
   3.687691397998685*^9, 3.689319194044167*^9, 3.695559670513132*^9, 
   3.6955785802621*^9, 3.695586350562612*^9, 3.6966109399465027`*^9, 
   3.7004134752245007`*^9, 3.718461374313863*^9, 3.718714640494672*^9, 
   3.725289313506199*^9, 3.725289413004938*^9, 3.7306440394819927`*^9, 
   3.7307318704324913`*^9, 3.7308177458100986`*^9, 3.731097321651518*^9, 
   3.73115581507446*^9, 3.731161446108095*^9, 3.731345440968924*^9, 
   3.731413113582963*^9, 3.731432965402196*^9, 3.731433573504628*^9, 
   3.731441274238315*^9, 3.73178265652002*^9, 3.731799945506975*^9, 
   3.731849462231258*^9, 3.7318767117781363`*^9, 3.732019786681293*^9, 
   3.732653326172781*^9, 3.7329712443879633`*^9, 3.733663054131176*^9, 
   3.7341954469417553`*^9, 3.734358620294745*^9, 3.734527261225884*^9, 
   3.734980875177533*^9, 3.735052659593856*^9, 3.736204963815112*^9, {
   3.736206690585045*^9, 3.736206698537464*^9}, 3.7362531930304947`*^9, {
   3.7362572190752287`*^9, 3.736257269878519*^9}, 3.73625734937096*^9, 
   3.736257384310898*^9, 3.7362574342966003`*^9, 3.736519837390903*^9, 
   3.73660108489254*^9, 3.7366491775981083`*^9, 3.736772485562353*^9, 
   3.771168613802775*^9, 3.782251533557002*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"2", " ", "m"}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "m", "]"}], "2"],
    SeriesData[$CellContext`m, 0, {}, 1, 2, 1],
    Editable->False]}],
  SeriesData[$CellContext`m, 0, {2}, 1, 2, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.682332728362124*^9, 3.682332783172077*^9}, 
   3.6823329056659517`*^9, 3.682413499264751*^9, 3.682413606995298*^9, 
   3.6826589787313223`*^9, 3.682659186232942*^9, 3.682675778882359*^9, 
   3.6826813588937273`*^9, {3.682740858452972*^9, 3.6827408737158823`*^9}, 
   3.682757238007535*^9, 3.6827671850484667`*^9, 3.682910942609147*^9, 
   3.6829121588159933`*^9, 3.6829130297587137`*^9, 3.682913339874617*^9, 
   3.682913953760215*^9, 3.684150242843616*^9, 3.684150328433429*^9, 
   3.684150582798278*^9, 3.684207403579948*^9, 3.684208944622508*^9, 
   3.684225312158441*^9, 3.6844216303079576`*^9, 3.6845529565562067`*^9, 
   3.6847442454961653`*^9, 3.68474447741066*^9, 3.685678721005582*^9, 
   3.6856916066008253`*^9, 3.6871501863873*^9, 3.687177093923608*^9, 
   3.6872521931427927`*^9, 3.6872589224678907`*^9, 3.6875044506096077`*^9, 
   3.687691397998685*^9, 3.689319194044167*^9, 3.695559670513132*^9, 
   3.6955785802621*^9, 3.695586350562612*^9, 3.6966109399465027`*^9, 
   3.7004134752245007`*^9, 3.718461374313863*^9, 3.718714640494672*^9, 
   3.725289313506199*^9, 3.725289413004938*^9, 3.7306440394819927`*^9, 
   3.7307318704324913`*^9, 3.7308177458100986`*^9, 3.731097321651518*^9, 
   3.73115581507446*^9, 3.731161446108095*^9, 3.731345440968924*^9, 
   3.731413113582963*^9, 3.731432965402196*^9, 3.731433573504628*^9, 
   3.731441274238315*^9, 3.73178265652002*^9, 3.731799945506975*^9, 
   3.731849462231258*^9, 3.7318767117781363`*^9, 3.732019786681293*^9, 
   3.732653326172781*^9, 3.7329712443879633`*^9, 3.733663054131176*^9, 
   3.7341954469417553`*^9, 3.734358620294745*^9, 3.734527261225884*^9, 
   3.734980875177533*^9, 3.735052659593856*^9, 3.736204963815112*^9, {
   3.736206690585045*^9, 3.736206698537464*^9}, 3.7362531930304947`*^9, {
   3.7362572190752287`*^9, 3.736257269878519*^9}, 3.73625734937096*^9, 
   3.736257384310898*^9, 3.7362574342966003`*^9, 3.736519837390903*^9, 
   3.73660108489254*^9, 3.7366491775981083`*^9, 3.736772485562353*^9, 
   3.771168613802775*^9, 3.782251533560198*^9}]
}, Closed]],

Cell["\<\
(giving Haldane\[CloseCurlyQuote]s classic 2m approximation for the \
probability of establishment)\
\>", "Text",
 CellChangeTimes->{{3.736257297017623*^9, 3.7362573695473633`*^9}}],

Cell["and when death rate is greater than birth rate we have ", "Text",
 CellChangeTimes->{{3.696612578271688*^9, 3.696612580647723*^9}, {
  3.730644053631586*^9, 3.7306440697827263`*^9}, {3.730657062294464*^9, 
  3.7306570926475973`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", 
      RowBox[{"s", ",", "t"}], "]"}], "/.", "fst"}], "/.", 
    RowBox[{"s", "\[Rule]", "0"}]}], ",", 
   RowBox[{"t", "\[Rule]", "\[Infinity]"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Lambda]", "<", "\[Mu]"}], ",", 
      RowBox[{"\[Mu]", ">", "0"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.6823329838158197`*^9, {3.682413501589802*^9, 3.6824135021833773`*^9}, {
   3.682413618246366*^9, 3.682413637357992*^9}, 3.6826757763333673`*^9}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{
  3.682332985437059*^9, 3.6824135048677883`*^9, {3.6824136206045094`*^9, 
   3.6824136397998867`*^9}, 3.68265898112002*^9, 3.682659189126513*^9, 
   3.682675777737543*^9, 3.682681382692317*^9, {3.682740860914093*^9, 
   3.682740873761108*^9}, 3.682757240528722*^9, 3.6827671876738377`*^9, 
   3.6829109475728188`*^9, 3.6829121613178587`*^9, 3.682913032129899*^9, 
   3.682913342602604*^9, 3.682913956586443*^9, 3.684150245341138*^9, 
   3.684150331057838*^9, 3.684150585313719*^9, 3.684207406104306*^9, 
   3.684208947275619*^9, 3.68422531462908*^9, 3.68442163290071*^9, 
   3.684552958966813*^9, 3.684744248180223*^9, 3.68474448004178*^9, 
   3.685678723658206*^9, 3.68569160941849*^9, 3.68715018887223*^9, 
   3.687177097069025*^9, 3.687252195703393*^9, 3.6872589262169323`*^9, 
   3.6875044534186573`*^9, 3.687691400716147*^9, 3.689319196781994*^9, 
   3.695559675123693*^9, 3.695578582391271*^9, 3.695586352948324*^9, 
   3.700413477547723*^9, 3.718461376449731*^9, 3.7187146436850367`*^9, 
   3.7252893679434*^9, 3.72528941507819*^9, 3.7306440521425962`*^9, 
   3.730731872570883*^9, 3.730817747977089*^9, 3.731097324702702*^9, 
   3.731155817622834*^9, 3.731161448530134*^9, 3.731345443093173*^9, 
   3.731413115848577*^9, 3.731432967732531*^9, 3.7314335756573343`*^9, 
   3.731441276822989*^9, 3.731782659083498*^9, 3.7317999481140614`*^9, 
   3.731849464430245*^9, 3.7318767140465727`*^9, 3.732019789162665*^9, 
   3.7326533288018417`*^9, 3.732971246518063*^9, 3.733663056263041*^9, 
   3.734195449893734*^9, 3.7343586223590927`*^9, 3.734527264041901*^9, 
   3.7349808784834547`*^9, 3.735052663114842*^9, 3.73620496639071*^9, {
   3.736206693108411*^9, 3.736206698609621*^9}, 3.736253195246703*^9, 
   3.736519840173106*^9, 3.736601087110536*^9, 3.736649180315853*^9, 
   3.736772487868825*^9, 3.771168637178917*^9, 3.782251535917036*^9}]
}, Closed]],

Cell["\<\
The probability of persistence to time t is just one minus the probability of \
extinction by time t\
\>", "Text",
 CellChangeTimes->{{3.6844666972229*^9, 3.684466713841943*^9}, {
  3.696611235632126*^9, 3.6966112392804737`*^9}, {3.7306440811282873`*^9, 
  3.730644098631605*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"probpersist", "=", 
  RowBox[{"1", "-", "pextt"}]}]], "Input",
 CellChangeTimes->{{3.684466743145143*^9, 3.6844667799027853`*^9}, {
  3.7822517120027237`*^9, 3.782251730328082*^9}}],

Cell[BoxData[
 RowBox[{"1", "-", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "+", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "\[Lambda]"}], "+", "\[Mu]"}], 
      RowBox[{"\[Lambda]", "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "\[Lambda]"}], "+", "\[Mu]"}], ")"}]}]], " ", 
        "\[Mu]"}]}]]}], ")"}], "N0"]}]], "Output",
 CellChangeTimes->{{3.684466737892905*^9, 3.6844667803778677`*^9}, 
   3.684467448078682*^9, 3.6844896658711987`*^9, 3.684552959081339*^9, 
   3.684744248423552*^9, 3.684744480215053*^9, 3.685678723907852*^9, 
   3.685691609588273*^9, 3.6871501889970207`*^9, 3.6871770972393*^9, 
   3.687252195858509*^9, 3.687258926396929*^9, 3.687504453539102*^9, 
   3.6876914008721943`*^9, 3.6893191969427423`*^9, 3.695559692492277*^9, 
   3.695578582515706*^9, 3.69558635311451*^9, 3.696611081878312*^9, 
   3.700413477602895*^9, 3.718461376596794*^9, 3.718714643832272*^9, 
   3.725289368109521*^9, 3.725289415248872*^9, 3.730644077949806*^9, 
   3.730731872688798*^9, 3.730817748125556*^9, 3.73109732481199*^9, 
   3.731155817787684*^9, 3.731161448894189*^9, 3.731345443200118*^9, 
   3.7314131159725*^9, 3.7314329678540573`*^9, 3.731433575834524*^9, 
   3.73144127708934*^9, 3.7317826592539387`*^9, 3.731799948206223*^9, 
   3.73184946457734*^9, 3.731876714166828*^9, 3.732019789260766*^9, 
   3.7326533288937263`*^9, 3.732971246649177*^9, 3.733663056385985*^9, 
   3.73419545003312*^9, 3.7343586224436607`*^9, 3.734527264153454*^9, 
   3.7349808785606003`*^9, 3.735052663308549*^9, 3.7362049664568253`*^9, {
   3.736206693227561*^9, 3.736206698647221*^9}, 3.736253195368471*^9, 
   3.736519840283515*^9, 3.736601087193944*^9, 3.736649180536961*^9, 
   3.736772488020805*^9, 3.771168637517914*^9, 3.7822515361533527`*^9, {
   3.78225173085917*^9, 3.782251744442107*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Distribution of extinction times  (equation A4)\
\>", "Subsubsection",
 CellChangeTimes->{{3.771169066709568*^9, 3.771169073478096*^9}, {
  3.77116913183951*^9, 3.771169132848804*^9}, {3.771169499272633*^9, 
  3.771169508536894*^9}}],

Cell["\<\
When |m| << 1/t << 1, ie |1/m| >> t >> 1 (that is, at late times but while \
the mutant is still effectively critical) the probability that a new mutant \
persists to time t is approximately\
\>", "Text",
 CellChangeTimes->{{3.6834516244015512`*^9, 3.6834516369888687`*^9}, {
  3.6834519914797363`*^9, 3.683451999593699*^9}, {3.6834520682941723`*^9, 
  3.683452078350583*^9}, {3.684467439143732*^9, 3.684467440490068*^9}, {
  3.6871453949217167`*^9, 3.687145398390486*^9}, {3.695559717484047*^9, 
  3.695559730481361*^9}, {3.696612679526511*^9, 3.6966126865351963`*^9}, {
  3.730644126800403*^9, 3.730644145720707*^9}, {3.730644238390873*^9, 
  3.7306442441810417`*^9}, {3.731871748436433*^9, 3.7318717516125526`*^9}, {
  3.731871833191416*^9, 3.731871866736545*^9}, {3.731871976552835*^9, 
  3.7318719774330473`*^9}, {3.736257466191276*^9, 3.736257475814785*^9}, {
  3.736262507216648*^9, 3.73626252283947*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pestapp1", "=", 
  RowBox[{
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"probpersist", "/.", 
           RowBox[{"\[Lambda]", "\[Rule]", 
            FractionBox[
             RowBox[{"1", "+", "m"}], "2"]}]}], "/.", 
          RowBox[{"\[Mu]", "\[Rule]", 
           FractionBox[
            RowBox[{"1", "-", "m"}], "2"]}]}], "/.", 
         RowBox[{"N0", "\[Rule]", "1"}]}], "/.", 
        RowBox[{"m", " ", "\[Rule]", 
         RowBox[{"m", " ", 
          SuperscriptBox["\[Epsilon]", "2"]}]}]}], "/.", 
       RowBox[{"t", "\[Rule]", 
        RowBox[{"t", " ", "/", "\[Epsilon]"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Epsilon]", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/.", 
   RowBox[{"\[Epsilon]", "\[Rule]", "1"}]}]}]], "Input",
 CellChangeTimes->{{3.696612617855674*^9, 3.696612669123453*^9}, {
   3.7362574811561213`*^9, 3.736257492269125*^9}, 3.782251734170701*^9}],

Cell[BoxData[
 FractionBox["2", "t"]], "Output",
 CellChangeTimes->{{3.696612649467079*^9, 3.6966126695187397`*^9}, 
   3.7004134776486797`*^9, 3.7184613766545753`*^9, 3.718714643908362*^9, 
   3.725289368175878*^9, 3.725289415312327*^9, 3.730644168489012*^9, 
   3.730731872738504*^9, 3.7308177481820927`*^9, 3.7310973248469563`*^9, 
   3.731155817853223*^9, 3.73116144897771*^9, 3.731345443250669*^9, 
   3.731413116020987*^9, 3.731432967919341*^9, 3.731433575900855*^9, 
   3.731441277285152*^9, 3.731782659302368*^9, 3.73179994824017*^9, 
   3.731849464639485*^9, 3.731876714211031*^9, 3.73201978931229*^9, 
   3.732653328929226*^9, 3.732971246698927*^9, 3.7336630564292593`*^9, 
   3.7341954500869703`*^9, 3.7343586224955606`*^9, 3.734527264252894*^9, 
   3.734980878593399*^9, 3.735052663392734*^9, 3.736204966493469*^9, {
   3.736206693258395*^9, 3.736206698696725*^9}, 3.736253195413877*^9, {
   3.736257486115221*^9, 3.73625749327999*^9}, 3.736519840360241*^9, 
   3.736601087240992*^9, 3.736649180631383*^9, 3.736772488069162*^9, 
   3.7711686520837917`*^9, 3.782251539080607*^9, 3.782251745444249*^9}]
}, Closed]],

Cell["\<\
And when -m t >>1, ie -m >> 1/t (that is, when the mutant is effectively \
subcritical) we have roughly\
\>", "Text",
 CellChangeTimes->{{3.684489540697411*^9, 3.68448955909805*^9}, {
  3.695559734587144*^9, 3.695559737082046*^9}, {3.696612693875793*^9, 
  3.696612694998824*^9}, {3.696612768413941*^9, 3.6966127713028393`*^9}, {
  3.730644150224964*^9, 3.7306441642094603`*^9}, {3.7318717943345547`*^9, 
  3.731871804327836*^9}, {3.7318719447387047`*^9, 3.731871950828142*^9}, {
  3.731871981273056*^9, 3.7318719851046257`*^9}, {3.736257497879085*^9, 
  3.736257508471395*^9}, {3.7362584494901447`*^9, 3.736258450224759*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pestapp2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"probpersist", "/.", 
        RowBox[{"\[Lambda]", "\[Rule]", 
         FractionBox[
          RowBox[{"1", "+", "m"}], "2"]}]}], "/.", 
       RowBox[{"\[Mu]", "\[Rule]", 
        FractionBox[
         RowBox[{"1", "-", "m"}], "2"]}]}], "/.", 
      RowBox[{"N0", "\[Rule]", "1"}]}], "]"}], "/.", " ", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "m"}], " ", "t"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "m"}], ")"}]}], "+", "m"}], "\[Rule]", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "m"}], " ", "t"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "m"}], ")"}]}]}]}], "/.", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "1"}], "+", "m"}], "\[Rule]", 
    RowBox[{"-", "1"}]}]}]}]], "Input",
 CellChangeTimes->{{3.69661315286194*^9, 3.6966131848803368`*^9}, {
   3.6966132154872513`*^9, 3.696613240877356*^9}, {3.731441641263702*^9, 
   3.731441666749633*^9}, {3.736257520644968*^9, 3.736257532437285*^9}, {
   3.7362584194503517`*^9, 3.7362584276777267`*^9}, 3.782251735225576*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"m", " ", "t"}]], " ", "m"}]], "Output",
 CellChangeTimes->{{3.696613153381481*^9, 3.696613168730307*^9}, {
   3.696613227616117*^9, 3.6966132412996883`*^9}, 3.700413477682272*^9, 
   3.7184613767130823`*^9, 3.718714643976121*^9, 3.72528936824403*^9, 
   3.72528941537938*^9, 3.730644169505674*^9, 3.730731872788357*^9, 
   3.73081774824115*^9, 3.7310973248963614`*^9, 3.73115581792067*^9, 
   3.7311614490612993`*^9, 3.731345443300316*^9, 3.7314131160724983`*^9, 
   3.731432967985941*^9, 3.731433575973785*^9, 3.73144127735353*^9, 
   3.7314416416061277`*^9, 3.731441696310763*^9, 3.731782659364623*^9, 
   3.731799948292931*^9, 3.731849464694767*^9, 3.73187671426271*^9, 
   3.7320197893628693`*^9, 3.732653328975873*^9, 3.7329712467491817`*^9, 
   3.733663056479065*^9, 3.7341954501480923`*^9, 3.734358622546767*^9, 
   3.734527264406687*^9, 3.734980878648402*^9, 3.7350526634815693`*^9, 
   3.736204966543241*^9, {3.736206693306634*^9, 3.736206698742782*^9}, 
   3.736253195463314*^9, 3.736257532799362*^9, 3.736258432298471*^9, 
   3.736519840436322*^9, 3.73660108729112*^9, 3.736649180730159*^9, 
   3.736772488133519*^9, 3.77116866332265*^9, 3.782251539308989*^9, 
   3.782251746292201*^9}]
}, Closed]],

Cell["\<\
Visually check the critical (red) and subcritical (green) approximations of \
the true solution (blue)\
\>", "Text",
 CellChangeTimes->{{3.7306441762822723`*^9, 3.730644208954678*^9}, {
  3.736257563761153*^9, 3.736257572793482*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"probpersist", "/.", 
         RowBox[{"\[Lambda]", "\[Rule]", 
          FractionBox[
           RowBox[{"1", "+", "m"}], "2"]}]}], "/.", 
        RowBox[{"\[Mu]", "\[Rule]", 
         FractionBox[
          RowBox[{"1", "-", "m"}], "2"]}]}], "/.", 
       RowBox[{"N0", "\[Rule]", "1"}]}], "/.", 
      RowBox[{"m", "\[Rule]", 
       RowBox[{"-", "0.01"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1000"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "4"}]], ",", "1"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{"pestapp1", "/.", 
      RowBox[{"m", "\[Rule]", 
       RowBox[{"-", "0.01"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1000"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{"pestapp2", "/.", 
      RowBox[{"m", "\[Rule]", 
       RowBox[{"-", "0.01"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "1000"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Green"}]}], "]"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.7362576042835207`*^9, 3.736257776031007*^9}, 
   3.7822517394234247`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVxXk01AkcAPAxxtFg3Bo07i3HIDlyZOZLYyQ10a1ipUWecxw5Qu2ySTZd
kqNetDu65MwuKb8vCh0vR0w2kbLT7iOMI0cMu/vH530Mg6J3B5NJJJLff/5/
bHp5BzfkKyv4aleW3A1RU6wg2ZZT+oZ9p/ll/5WEFiJJYTxEu3SErbfkEeXg
201s5jAeXuSPs3utFkZjM/uJk01lJErpDPt1tnvtvNQH4t071m129gKbJeDb
hCV8IpznhTtP8iXssG+VZSILESG5lrFzsUQaTnC4d/SlRwlmWafBWk1ZUOiI
Njtg84U48lB31i5bHuIe+lmkuU4Qj7tqi2L4ShBDsi5PWhUTX4ZWI3NFypDq
/tnWdnCKyJ0TGAiZqjBerhhoUTVNNFGmZ2ZK1OGIW8+aF06zhFChYJA8oAHv
2jcq0qdniQk1VruqphaUyQqGJbe+EnqG54qss+mw+0Upd0g8RziYbsxktWpD
Cz1qrzB3nuBZCyN3SnSgKT1IFLxhgUhzNXIL5zOgUN+PjF6LRB6nwzzlvh5o
z+WYWPUuEuXeURrZIn3YN5znknboGzHBHIx7wzSERzMnTtcfXiL0XMw8p0qM
YYPgYkWgg4S4x1puXHA1Ad3JljUtAgnh4N65kTRgAs+KGu5nqq0QPK8EHWXN
9TCVyQ+r+GuFSD/QPM7MNgXB1lG+z2YSUg/nBdmtN4P4B3XmWiEkzA8IfevS
agY2dULN2SskrAhWat4uMQea49JbxjgJB+P88o7zLUHdPmFMJV8Kjycy18TQ
rMAoKDwvs0kKZ1NW0xLvW0H4oFsO77MUKv4kCD0jsoYNd25OLduSUa8jidHD
tAGDV4NBBzvIyBM+FU+W2IKnqdnKaL80nvrg70ebswWry9ENVUvSWPXPXDPT
2w4ejDxrWmFQUHXJ9ErYVzvorl5odDtKwV798/YjXg7w+vbb7iefKHgobF+K
cNoRdqnUxC++kcGc2IlPs55OIJMbfV4glsHHJ7O81W84wQXUZFOUZJGR27DO
x9MZvD76dA9zZHG4hkE8L3YBekChiFsti6HLIuknHBYINT+e00mXwwKZUxED
hSzInZTpqsyXww4avW9xggVMSoSscqUcmhtuL3MoZMOZirwS6w9yOG90wKT/
BEBKW7+zlqs8PvJsbPN96QaUrlprT7E8wqUMBY94DpSbmsunO1GxfUiLRb7O
gcnQ4dG73lTkMe/FEK0csPXfbt7oT0X/9q4+J3UPUOJ84F74kYopEkaJVY0H
UNs0XOQ7qPgwrN6OLuZC3PU6eraPApq6j/uPhXtBbdK4Sq+vIqrO7K+6dIwH
12b6LhgY0VDP33Bv1jkeULemBidb05DZPjafWs0D0X75iLYtNNxWfJp9fJUH
73OUM1wP0DB9673XrOJdMKxIpvyaQ8O55+lzCWE+cFfMDjg2TcNjOj0axqW+
cFRujBtar4ysxiTfNJW9sNEypy/1qgqWxDU9eH/QD6QO/fFtx7IqDnkN9ixx
AyCStDm/Zr06BnunjAd1HoVfZh3THu/SQLdH85TOqB+AOVJcWReoiQr1H0m6
H0PA8c/PI1v3aKHFlGfUlrNhsK2zX5LosxadG3TQlRwBXPLNpE57OlZ6ff9d
W3QUFBTcsDmrqo1PqCorqtkxEFgWoB67pI069WUDVa18GDDojQ/s0UGjjCX+
I3ocFExojJ6s18WATWsuZ4XGg0Vh8jW1gnWoarbzt6c3EyDPP7BvKoSB0a67
oiOmT0DRtmS9YQ895BRmMTOtkmBKfLRhQEMfn6ql35L9ORnsVx8/s5zVx8QY
y1s7+lKArrNZe0+oAZZqqueRlVNBprSpYPqVASb2/84yPpYG2n9bDQ07G+LT
TxcHakvSQRQYGbun1BA53cZk+f5T8H4/uf6GjBGmDCxsKjt3GrT21TVWhxvh
vzh+o78=
      "]]}}, {{}, {}, 
    {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwV0nk81PkfB3B3M8Y1jjEUucrRLK3ooJl5Y7DuiFpKbXInZ8c4oxwNmVGR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      "]]}}, {{}, {}, 
    {RGBColor[0, 1, 0], LineBox[CompressedData["
1:eJwVjn040wkcwJd2Zena5mUXCrPU7Ffp8dJd3vaVNeUld3TlVMpLxOOxEaGh
2Oa9LeVKEZs7tpTIlbfC90qIxFSOxPP0dk+5nJC4Vu66Pz7P58/Phxki8Duk
QyKRfL7wv/+a/uTND591rfemPRzwomJcRbIdT/mQ+5J1vNfEj4pJehPhxsoX
XH3tRGdIABVFrZUksnKGK7zUc2s6jIqfz4l9/lEsBs6SrEr9NCq2kqdnZhQG
UNb2OdmvlopmTtYeUwoW8M4n0CKX0XDnYPu7SYUdbFge2vA6hoZQINbbFs+D
h2qZdf92OtJndtcWhO6Euw60Sb6hPrreTPohlbYLpJ5O820j+qg40lr9NOAn
MGE0WDGvG+DYjtEBLT8ItJrsSnqaIR7yOjYR0hcMtbzLXuMBRujWPEfuiwkD
e26i/V0bBuo1PiOZPgsHMue80GaegcSUR4xzdiSoe/Q06Zpv0LHJBF10oqFo
/yNJaMlKrNlxwKpDEAN7EvkpHqHG2LKMtkDPEcK4B6XIwMkETRorR2rvxEK3
ruVSAdkULcXa2OaVRyD1RN6FujFTDLKlnM6KiAfSidLY+eurkG7t82t7WQI8
ECwt6U1ZjQIXX0H09FEQMn4fz/3RDHnns9ZLNibBwer+/D/MzbFdP618iTQZ
mNpN/su15pgo3FDu/fgYBB6+eJUZaYFKI4NCHWoKbPfyGZX0WmDiUL0rKzQV
lDlWZvscmdj+/NTIb4o0sEC1rraMiTwNS0d36DhkNZOMihdbYmNMs/BF4QnY
Q0u3qxFYYs7KtOFjtumwM+iKNveRJW7SKEo9RtPh6lLS4BM3Fr7TlrE/SDLg
Qzx7gKhmYbRn8+V9TDGEPdEm8uhrsEVllzffLQbn4jkbTeoa7GZ3hXpHSsBx
V2mB1Ys1OGW6ZVEGWQoWGmMjEd8KJ1ZTtG+vSEFwqaWKV2eFFe7vJ6iemfAq
efn4Y8ZatE1ydTn8PhPaK8ROI+K1KOr/RZp0Jgu671VsVr9Zi6MXXp2OssmG
hmsl/kd91qFRfOangqFsWDF7M6OxaR1SYrceiD2aA3mbMvfeNmPjQMp+s0xm
LsR1JvEhn403Pu4qT7mXC26W4N82x0b/kghzIjwPNifUUZbss8ZO7+H5FbR8
KGT5DGCXNX6wCO+pupoPxt2nee4bOciN6Athe54EqX31UEcBB4Nunds9Mn0S
9n6cTGv9zMHvHETu/FMyCGgcfZAaQuCgaCvnqzMyCM5xreKGEZhwm0Jv/1kG
UYFl0kXhBNb5Fo25Fcsg9dNBZ2kkgeujbiS7VMqgHF5eyhcSaFE2WWN/SwZv
u8YlxWkEUihhq1ivZZA+POfYdIFAtS+x+Pm4DPKqAhiiEgL5Z6ffKCZkUChq
mnIuJVDCSm8wm5GBarVIjUoCF1xK/UwWZHA/eMGoS03gdNxQNt1QDoxx8tRg
PYGnmsoE/Qw5mN88dL+okUAbUsRuubEcrPM7VIHNBEafnGV9bS4Hp43ZQWMt
BP6p0m/T5cghOE7v/qv2L72/hys618shyj1apeogkOWgzM+0kcMRw96MyC4C
D962CSQ7yCGzXrZloufLj+4c3PlWDvKsScOaXgIv+rauy3CUQ1HA9++EfQQ6
n5WucHORQ7n1tR5bDYFPnnrP/suVw+WPdNX7AQL/A5oXSos=
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, -9.210340371976184},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-9.210340371976182, 
       FormBox["\"\"", TraditionalForm]}, {-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{0, 1000}, {-9.210340371976184, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{Automatic, {{-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.736257606506563*^9, 3.7362577764428797`*^9}, 
   3.7362584467591867`*^9, 3.736519840529605*^9, 3.736601087385009*^9, 
   3.736649180843443*^9, 3.736772488234478*^9, 3.771168666661913*^9, 
   3.78225153944378*^9, 3.7822517471412687`*^9}]
}, Closed]],

Cell["\<\
Our equations for persistence times line-up with Weissman et al 2010 Genetics \
eq A2, but with an additional factor of 2 because we have b+d=2 while they \
have b+d=1. They point out that the distribution of persistence time has a \
long tail (like 1/t) before falling off exponentially when t > -1 / m (as can \
be seen in the plot above). Thus we can essentially say that a mutant lineage \
will not persist past t = -1 / m. \
\>", "Text",
 CellChangeTimes->{{3.73625852225922*^9, 3.7362585834766693`*^9}, {
  3.7362586985298634`*^9, 3.7362588469088717`*^9}, {3.771168676989757*^9, 
  3.771168684635795*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Distribution of lineage sizes", "Subsubsection",
 CellChangeTimes->{{3.771169213497446*^9, 3.771169244434677*^9}}],

Cell["The probability that there is 1 individual at time t is", "Text",
 CellChangeTimes->{{3.683452487628579*^9, 3.683452521854187*^9}, {
  3.68345295739398*^9, 3.683452965769898*^9}, {3.683453509339995*^9, 
  3.683453510882987*^9}, {3.683453707712212*^9, 3.683453720519968*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pn1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"F", "[", 
             RowBox[{"s", ",", "t"}], "]"}], "/.", "fst"}], ",", 
           RowBox[{"{", 
            RowBox[{"s", ",", "n"}], "}"}]}], "]"}], "/", 
         RowBox[{"n", "!"}]}], "/.", 
        RowBox[{"n", "\[Rule]", "1"}]}], "/.", 
       RowBox[{"s", "\[Rule]", "0"}]}], "/.", 
      RowBox[{"\[Lambda]", "\[Rule]", 
       FractionBox[
        RowBox[{"1", "+", "m"}], "2"]}]}], "/.", 
     RowBox[{"\[Mu]", "\[Rule]", 
      FractionBox[
       RowBox[{"1", "-", "m"}], "2"]}]}], "/.", 
    RowBox[{"N0", "\[Rule]", "1"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.683452704507859*^9, 3.683452764141777*^9}, {
   3.683452830792989*^9, 3.68345301426602*^9}, {3.683453194440146*^9, 
   3.683453196131719*^9}, 3.683453270806781*^9, {3.68345330144676*^9, 
   3.683453321019013*^9}, {3.683453407852502*^9, 3.6834534689996777`*^9}, {
   3.683453734090692*^9, 3.683453750476204*^9}, 3.683633255324265*^9, {
   3.683633353343932*^9, 3.683633353699792*^9}, {3.68363341799067*^9, 
   3.68363341833253*^9}, 3.68363348785502*^9, {3.683633519656618*^9, 
   3.68363352756743*^9}, 3.683633665424342*^9, 3.6844676110063763`*^9, {
   3.684470034398424*^9, 3.6844700521588163`*^9}, {3.696613496319433*^9, 
   3.696613532500389*^9}, {3.736257803221396*^9, 3.7362578051836643`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"m", " ", "t"}]], " ", 
   SuperscriptBox["m", "2"]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "m", "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"m", " ", "t"}]], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "m"}], ")"}]}]}], ")"}], "2"]]], "Output",
 CellChangeTimes->{{3.6834527053288927`*^9, 3.6834527647745132`*^9}, {
   3.683452832091305*^9, 3.683452923373008*^9}, {3.683452971739629*^9, 
   3.6834529846810923`*^9}, 3.683453015971272*^9, 3.683453196799021*^9, 
   3.683453271533372*^9, {3.683453312116047*^9, 3.683453321566266*^9}, {
   3.68345341879156*^9, 3.683453469315524*^9}, 3.6834537511252127`*^9, 
   3.683534650571692*^9, 3.683619361274403*^9, 3.683624781575345*^9, 
   3.683633255755136*^9, 3.683633354474152*^9, 3.6836334884276857`*^9, {
   3.683633524166411*^9, 3.683633527943392*^9}, 3.6836336660579023`*^9, 
   3.68403744412201*^9, 3.684467622127993*^9, {3.684470035157181*^9, 
   3.6844700529548607`*^9}, 3.684552959437729*^9, 3.6847442487429028`*^9, 
   3.684744480538842*^9, 3.685678724335329*^9, 3.685691609922777*^9, 
   3.687150189340386*^9, 3.6871770975811443`*^9, 3.6872521961814528`*^9, 
   3.687258926817843*^9, 3.6875044538749657`*^9, 3.6876914011451387`*^9, 
   3.689319197254428*^9, 3.695559742974732*^9, 3.695578582835215*^9, 
   3.695586353434659*^9, 3.6966110997724657`*^9, {3.696613512945971*^9, 
   3.696613532995904*^9}, 3.700413477890655*^9, 3.7184613770526333`*^9, 
   3.71871464447775*^9, {3.725289394509655*^9, 3.7252894157007504`*^9}, 
   3.730644423852976*^9, 3.730731873128647*^9, 3.73081774857367*^9, 
   3.7310973253128967`*^9, 3.731155818322117*^9, 3.731161449512436*^9, 
   3.7313454436236763`*^9, 3.731413116395356*^9, 3.7314329683838243`*^9, 
   3.731433576267235*^9, 3.7314412776074963`*^9, 3.731782659607936*^9, 
   3.73179994867096*^9, 3.7318494649193373`*^9, 3.731876714479005*^9, 
   3.732019789745727*^9, 3.732653329264629*^9, 3.732971247073605*^9, 
   3.73366305683388*^9, 3.73419545046775*^9, 3.734358622879081*^9, 
   3.734527264679743*^9, 3.734980878933072*^9, 3.7350526638122587`*^9, 
   3.736204966954679*^9, 3.736206699122582*^9, 3.736253195957192*^9, 
   3.73625780880427*^9, 3.736519840758656*^9, 3.73660108752917*^9, 
   3.736649181010929*^9, 3.73677248837265*^9, 3.771169038503384*^9, 
   3.7822515427798967`*^9}]
}, Closed]],

Cell["and two individuals", "Text",
 CellChangeTimes->{{3.683453726859254*^9, 3.683453730618561*^9}, {
  3.695559743750451*^9, 3.6955597477254057`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pn2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"F", "[", 
             RowBox[{"s", ",", "t"}], "]"}], "/.", "fst"}], ",", 
           RowBox[{"{", 
            RowBox[{"s", ",", "n"}], "}"}]}], "]"}], "/", 
         RowBox[{"n", "!"}]}], "/.", 
        RowBox[{"n", "\[Rule]", "2"}]}], "/.", 
       RowBox[{"s", "\[Rule]", "0"}]}], "/.", 
      RowBox[{"\[Lambda]", "\[Rule]", 
       FractionBox[
        RowBox[{"1", "+", "m"}], "2"]}]}], "/.", 
     RowBox[{"\[Mu]", "\[Rule]", 
      FractionBox[
       RowBox[{"1", "-", "m"}], "2"]}]}], "/.", 
    RowBox[{"N0", "\[Rule]", "1"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.683453732690486*^9, 3.683453758613638*^9}, {
   3.683633233882861*^9, 3.683633250945812*^9}, 3.683633356732368*^9, 
   3.683633421183773*^9, 3.6836334845418873`*^9, 3.683633531119134*^9, 
   3.6836336612883244`*^9, 3.684467672786371*^9, {3.6844700388336067`*^9, 
   3.6844700564426403`*^9}, {3.696613546405466*^9, 3.696613551006531*^9}, 
   3.736257811146914*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"m", " ", "t"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"m", " ", "t"}]]}], ")"}], " ", 
   SuperscriptBox["m", "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "m"}], ")"}]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "m", "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"m", " ", "t"}]], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "m"}], ")"}]}]}], ")"}], "3"]]], "Output",
 CellChangeTimes->{
  3.6834537597695417`*^9, 3.683534650741445*^9, 3.6836193614009447`*^9, 
   3.68362478169415*^9, {3.683633246217806*^9, 3.6836332514722633`*^9}, 
   3.683633357233468*^9, 3.683633490178216*^9, 3.6836335327343483`*^9, 
   3.683633668150757*^9, 3.684037444238244*^9, 3.6844676737932987`*^9, {
   3.684470039480077*^9, 3.6844700571720963`*^9}, 3.684552959711398*^9, 
   3.684744249018758*^9, 3.684744480835396*^9, 3.685678724630419*^9, 
   3.685691610229681*^9, 3.6871501895987873`*^9, 3.687177097875149*^9, 
   3.6872521964922113`*^9, 3.687258927188225*^9, 3.687504454167148*^9, 
   3.687691401416827*^9, 3.6893191975518208`*^9, 3.695559749963942*^9, 
   3.6955785830573997`*^9, 3.695586353699813*^9, {3.696611102451799*^9, 
   3.696611104582451*^9}, {3.6966135473813*^9, 3.696613551617918*^9}, 
   3.700413478063025*^9, 3.7184613772270727`*^9, 3.718714644673089*^9, {
   3.7252894003478117`*^9, 3.725289415876011*^9}, 3.7306444245735073`*^9, 
   3.7307318733067427`*^9, 3.7308177487493973`*^9, 3.731097325536056*^9, 
   3.73115581851742*^9, 3.731161449761628*^9, 3.731345443808588*^9, 
   3.731413116578704*^9, 3.731432968618557*^9, 3.7314335764467793`*^9, 
   3.731441277795149*^9, 3.731782659796809*^9, 3.731799948879643*^9, 
   3.731849465094557*^9, 3.7318767146647987`*^9, 3.732019789930462*^9, 
   3.732653329472891*^9, 3.732971247246313*^9, 3.7336630570190372`*^9, 
   3.734195450724572*^9, 3.7343586230515633`*^9, 3.734527264895268*^9, 
   3.734980879154496*^9, 3.7350526640788937`*^9, 3.736204967171916*^9, 
   3.7362066993414803`*^9, 3.7362531961519537`*^9, 3.736257811958033*^9, 
   3.736519840941064*^9, 3.736601087706448*^9, 3.7366491812314157`*^9, 
   3.736772488554941*^9, 3.771169039293857*^9, 3.782251543224204*^9}]
}, Closed]],

Cell["three", "Text",
 CellChangeTimes->{{3.6834537637538137`*^9, 3.683453770914253*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"F", "[", 
            RowBox[{"s", ",", "t"}], "]"}], "/.", "fst"}], ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", "n"}], "}"}]}], "]"}], "/", 
        RowBox[{"n", "!"}]}], "/.", 
       RowBox[{"n", "\[Rule]", "3"}]}], "/.", 
      RowBox[{"s", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[Lambda]", "\[Rule]", 
      FractionBox[
       RowBox[{"1", "+", "m"}], "2"]}]}], "/.", 
    RowBox[{"\[Mu]", "\[Rule]", 
     FractionBox[
      RowBox[{"1", "-", "m"}], "2"]}]}], "/.", 
   RowBox[{"N0", "\[Rule]", "1"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.683453776975635*^9, 3.683453777227235*^9}, 
   3.683633257385558*^9, {3.683633358850456*^9, 3.683633359566399*^9}, 
   3.6836334859212523`*^9, 3.683633536505954*^9, 3.683633663177216*^9, {
   3.684467678383286*^9, 3.6844676833930473`*^9}, {3.684470042964271*^9, 
   3.684470060246558*^9}, 3.696611117439579*^9, 3.696613567184105*^9, 
   3.736257813778584*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"m", " ", "t"}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"m", " ", "t"}]]}], ")"}], "2"], " ", 
   SuperscriptBox["m", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", "m"}], ")"}], "2"]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "m", "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"m", " ", "t"}]], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "m"}], ")"}]}]}], ")"}], "4"]]], "Output",
 CellChangeTimes->{
  3.683453777633745*^9, 3.6835346509236393`*^9, 3.68361936162424*^9, 
   3.683624781871428*^9, 3.6836332578950872`*^9, 3.683633360129583*^9, 
   3.683633491460246*^9, 3.683633537075666*^9, 3.68363366991577*^9, 
   3.684037444404833*^9, {3.684467679363495*^9, 3.684467684069611*^9}, {
   3.68447004375095*^9, 3.684470061000852*^9}, 3.684552960130445*^9, 
   3.6847442494604053`*^9, 3.684744481334819*^9, 3.685678725050271*^9, 
   3.6856916106973658`*^9, 3.687150190005562*^9, 3.687177098586474*^9, 
   3.6872521969345703`*^9, 3.687258927750408*^9, 3.687504454649969*^9, 
   3.687691401838866*^9, 3.689319198025354*^9, 3.69555975212951*^9, 
   3.6955785834101753`*^9, 3.695586354120144*^9, {3.696611110240354*^9, 
   3.6966111187688217`*^9}, 3.696613568299624*^9, 3.7004134782445*^9, 
   3.718461377411419*^9, 3.718714644869317*^9, 3.725289416060419*^9, 
   3.730644425460319*^9, 3.730731873489613*^9, 3.730817748943466*^9, 
   3.731097325764926*^9, 3.7311558187700043`*^9, 3.731161450280031*^9, 
   3.73134544399069*^9, 3.7314131167732964`*^9, 3.731432968803671*^9, 
   3.7314335766333933`*^9, 3.731441278053525*^9, 3.7317826599965973`*^9, 
   3.731799949099557*^9, 3.731849465275948*^9, 3.731876714861575*^9, 
   3.732019790125123*^9, 3.732653329692564*^9, 3.732971247424768*^9, 
   3.7336630572070312`*^9, 3.734195451006033*^9, 3.734358623236039*^9, 
   3.734527265126876*^9, 3.734980879391773*^9, 3.73505266434699*^9, 
   3.736204967404332*^9, 3.7362066995722513`*^9, 3.736253196346527*^9, 
   3.736257814537385*^9, 3.7365198411310472`*^9, 3.736601087891728*^9, 
   3.736649181479656*^9, 3.7367724887488613`*^9, 3.771169040082779*^9, 
   3.78225154346426*^9}]
}, Closed]],

Cell["\<\
From this series we can see that we can write the probability of n \
individuals at time t like\
\>", "Text",
 CellChangeTimes->{{3.6834537863980913`*^9, 3.683453801023918*^9}, 
   3.687145413538185*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pnt", "=", 
  RowBox[{"pn1", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"pn2", "/", "pn1"}], ")"}], 
    RowBox[{"n", "-", "1"}]]}]}]], "Input",
 CellChangeTimes->{{3.683453808988105*^9, 3.683453825742988*^9}, {
   3.6834538562784653`*^9, 3.683453942599185*^9}, 3.6836332622184258`*^9, {
   3.683633363075041*^9, 3.683633363315096*^9}, {3.6836334740329647`*^9, 
   3.683633496146489*^9}, 3.683633539738274*^9, {3.683633659091584*^9, 
   3.6836336737982683`*^9}, {3.684467695869376*^9, 3.684467757491699*^9}, {
   3.6844701034577303`*^9, 3.684470113848576*^9}, {3.6893192019822397`*^9, 
   3.689319206540667*^9}, 3.7362578248030863`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"m", " ", "t"}]], " ", 
   SuperscriptBox["m", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"m", " ", "t"}]]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "m"}], ")"}]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "m", "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"m", " ", "t"}]], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "m"}], ")"}]}]}]], ")"}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", "n"}]]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "m", "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"m", " ", "t"}]], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "m"}], ")"}]}]}], ")"}], "2"]]], "Output",
 CellChangeTimes->{3.7362578253301783`*^9, 3.736519841192233*^9, 
  3.736601087937645*^9, 3.736649181597273*^9, 3.7367724888028107`*^9, 
  3.771169040902882*^9, 3.782251543566725*^9}]
}, Closed]],

Cell["Check for n=4:", "Text",
 CellChangeTimes->{{3.6836221659060593`*^9, 3.6836221668850517`*^9}, {
  3.736257887180982*^9, 3.736257888714979*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"pnt", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"F", "[", 
              RowBox[{"s", ",", "t"}], "]"}], "/.", "fst"}], ",", 
            RowBox[{"{", 
             RowBox[{"s", ",", "n"}], "}"}]}], "]"}], "/", 
          RowBox[{"n", "!"}]}], ")"}]}], "/.", 
       RowBox[{"n", "\[Rule]", "4"}]}], "/.", 
      RowBox[{"s", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[Lambda]", "\[Rule]", 
      FractionBox[
       RowBox[{"1", "+", "m"}], "2"]}]}], "/.", 
    RowBox[{"\[Mu]", "\[Rule]", 
     FractionBox[
      RowBox[{"1", "-", "m"}], "2"]}]}], "/.", 
   RowBox[{"N0", "\[Rule]", "1"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.68362216852744*^9, 3.6836222267323303`*^9}, {
   3.683633500708136*^9, 3.6836335029532557`*^9}, {3.683633679482752*^9, 
   3.683633683097001*^9}, {3.68446776620725*^9, 3.684467773066671*^9}, 
   3.6844701245210037`*^9, 3.6966135871763353`*^9, {3.736257820128652*^9, 
   3.736257881621915*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.6836221964294*^9, 3.683622227129691*^9}, 
   3.6836247820472*^9, 3.6836332655946207`*^9, 3.6836333668229218`*^9, {
   3.683633498393689*^9, 3.683633503160128*^9}, 3.6836335436159487`*^9, {
   3.683633677252714*^9, 3.683633683422708*^9}, 3.684037444566639*^9, {
   3.684467767149555*^9, 3.68446777330236*^9}, 3.684470125589758*^9, 
   3.684552960432674*^9, 3.6847442499403563`*^9, 3.684744482199965*^9, 
   3.68567872539536*^9, 3.6856916110923634`*^9, 3.687150190378604*^9, 
   3.6871770990115643`*^9, 3.687252197303603*^9, 3.687258928202197*^9, 
   3.687504455031885*^9, 3.687691402220995*^9, 3.689319198588674*^9, 
   3.695559761327403*^9, 3.695578583742848*^9, 3.695586354466879*^9, 
   3.696611122601201*^9, 3.696613588474691*^9, 3.700413478575816*^9, 
   3.718461377860721*^9, 3.718714645380653*^9, 3.725289416581057*^9, 
   3.730644428254962*^9, 3.730731873858198*^9, 3.730817749400426*^9, 
   3.731097326303707*^9, 3.731155819381157*^9, 3.731161450690477*^9, 
   3.7313454443487177`*^9, 3.731413117174402*^9, 3.731432969300557*^9, 
   3.731433577109496*^9, 3.7314412786034927`*^9, 3.731782660382586*^9, 
   3.7317999495484543`*^9, 3.73184946565772*^9, 3.7318767152682*^9, 
   3.732019790542881*^9, 3.732653330087472*^9, 3.732971247780855*^9, 
   3.733663057571485*^9, 3.734195451632524*^9, 3.734358623596292*^9, 
   3.734527265622107*^9, 3.734980879858049*^9, 3.735052665031754*^9, 
   3.736204967849745*^9, 3.736206700075858*^9, 3.736253196829561*^9, {
   3.736257820942563*^9, 3.736257883565082*^9}, 3.7365198419382467`*^9, 
   3.736601088544723*^9, 3.736649182378438*^9, 3.736772489442009*^9, 
   3.771169042571896*^9, 3.782251544345065*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Distribution of lineage sizes given persistence (equation A5)\
\>", "Subsubsection",
 CellChangeTimes->{{3.736258174496496*^9, 3.736258183994265*^9}, {
  3.7711692378102217`*^9, 3.77116923976729*^9}, {3.771169503888761*^9, 
  3.771169506424987*^9}}],

Cell["\<\
Dividing the probability of having n individuals at time t by the probability \
of survival to time t gives the conditional probability of having n \
individuals at time t given a mutant lineage lives to time t\
\>", "Text",
 CellChangeTimes->{{3.683453944745322*^9, 3.683454001113042*^9}, {
   3.6844705710218353`*^9, 3.684470571514979*^9}, 3.687145420536478*^9, {
   3.73064444231042*^9, 3.730644449148733*^9}, {3.7362581524801292`*^9, 
   3.73625816720037*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pntgt", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"pnt", "/", "probpersist"}], "/.", 
      RowBox[{"\[Lambda]", "\[Rule]", 
       FractionBox[
        RowBox[{"1", "+", "m"}], "2"]}]}], "/.", 
     RowBox[{"\[Mu]", "\[Rule]", 
      FractionBox[
       RowBox[{"1", "-", "m"}], "2"]}]}], "/.", 
    RowBox[{"N0", "\[Rule]", "1"}]}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.6834532364444323`*^9, {3.6834539823572483`*^9, 3.683454023643465*^9}, {
   3.6834546244298153`*^9, 3.6834546254553223`*^9}, 3.68446781458637*^9, 
   3.684470138887*^9, 3.69661359418123*^9, 3.736257901507283*^9, 
   3.7822517594475927`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "m", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"2", " ", "m"}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", "m", "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"m", " ", "t"}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "m"}], ")"}]}]}]]}], ")"}], "n"]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"m", " ", "t"}]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "m"}], ")"}]}]]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0W1IkwEUBeBXMkGqKVq5WlCKxQhzRqxs9OHd7NuZZEbNRrTcnOKoqcEq
CzGzVVMahpCZ2hwUgpOGlLoIBlZKa5vbdA2aiwyn3UEZEW616L4/Ls+/A+fc
TMXFE8oEhmEO0ZmbzFueaBFk+Um3WMuKE++wjoVFPlbLrCI8TraeKyz8SRqq
JhZ+kV0lnZwomZ28nsd6XA3bWa3/nolZnfKH6te1COId7fr7dQj1im8GVnfk
xqCRFAtWbxolHd4DtzPqEX7LpWbWioDVHbqM0JZXzZsjtx70SC06hOHUSq2N
XBsc3PCZzM9NVc2SZznzh8uvIHBCRcYX5DwELkw2IDR1Pr03rKcea+KjdtLB
K2t5Q47vVIZH7iLkrKvg2cjWXaHmmBEh5itYUg0hTAWtpi9kEcON1tgRdhta
XvW9R1AHJTVOcijTKlsii7nuYKMDwXhdq3lMnpwo39ZLTqvaE2OkRWhJ4X1A
yBMI7Nlk1hh/1WZSWBJw8Ulpekeji8zRvFz0kw3xvRt/kM+TazVx8lGK/4jE
icAwR006F0I0jZlJd9O+SaJ+5STt+/VaT5WH/iCNHRshq5tF5hVeyvEuy1og
L73lC1b6EEx9CVP7phG6O/QD+8mr3p7zp8jl8pmB0+Qfk+TBR7LrE7eA8SPM
nfHYMsi/74SLpaTOpdvznRsBWVvlzbTcCNT1CrtZ/wPFUzLd
  "]]
}, Closed]],

Cell["\<\
When t << |1/m|  (effectively critical) this is approximately\
\>", "Text",
 CellChangeTimes->{{3.683454201928409*^9, 3.6834542144623823`*^9}, {
   3.683454459935596*^9, 3.683454484455364*^9}, 3.684470563194729*^9, 
   3.687145434822647*^9, {3.695559790011282*^9, 3.695559793931603*^9}, {
   3.69661360037738*^9, 3.6966136283504744`*^9}, {3.730644578929881*^9, 
   3.7306445833766003`*^9}, {3.736257907827497*^9, 3.736257923331777*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"pntgtapp1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Normal", "[", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"pntgt", "/.", 
        RowBox[{"m", "\[Rule]", " ", 
         RowBox[{"m", " ", "\[Epsilon]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]", ",", "0", ",", "0"}], "}"}]}], "]"}], "]"}], "/.", 
    RowBox[{"\[Epsilon]", "\[Rule]", "1"}]}], "//", 
   "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "==", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      FractionBox["1", "t"], ")"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox["2", "t"]}], ")"}], 
      RowBox[{"-", "n"}]]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"t", ">", "0"}], ",", 
     RowBox[{"n", ">", "0"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.683454026747587*^9, 3.6834542253712254`*^9}, {
  3.6834548823852453`*^9, 3.683454883885825*^9}, {3.684467824492326*^9, 
  3.684467828215151*^9}, {3.696613619887817*^9, 3.696613621037631*^9}, {
  3.6966140084538927`*^9, 3.696614043087435*^9}, {3.7362579348081493`*^9, 
  3.736257937416354*^9}, {3.736260312060774*^9, 3.736260315734829*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", 
  SuperscriptBox["t", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "n"}]], " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"2", "+", "t"}], ")"}], 
   RowBox[{"-", "n"}]]}]], "Output",
 CellChangeTimes->{{3.683454060152358*^9, 3.683454086088674*^9}, {
   3.683454134688302*^9, 3.683454225736024*^9}, 3.683454884337645*^9, 
   3.683534651148117*^9, 3.683619362285658*^9, 3.683624782354863*^9, 
   3.6836332712861853`*^9, 3.6836333812646027`*^9, 3.683633547986539*^9, 
   3.683633687642638*^9, 3.684037444841187*^9, 3.6844677918193417`*^9, 
   3.684467828758114*^9, 3.684470145485219*^9, 3.684552960721389*^9, 
   3.684744250289132*^9, 3.6847444826818943`*^9, 3.685678725680106*^9, 
   3.685691611418873*^9, 3.687150190658229*^9, 3.687177099319194*^9, 
   3.687252197574671*^9, 3.687258928628611*^9, 3.687504455348384*^9, 
   3.687691402482314*^9, 3.689319198877412*^9, 3.695559782064913*^9, 
   3.6955785839850483`*^9, 3.695586354743816*^9, 3.696611134098158*^9, 
   3.69661362144761*^9, {3.696614017974484*^9, 3.6966140434851913`*^9}, 
   3.700413479027728*^9, 3.7184613780910187`*^9, 3.718714645658144*^9, 
   3.725289416814239*^9, 3.730644456348703*^9, 3.730731874184999*^9, 
   3.7308177496358852`*^9, 3.7310973265746107`*^9, 3.731155819609872*^9, 
   3.731161451091653*^9, 3.731345444669745*^9, 3.731413117508731*^9, 
   3.731432969550028*^9, 3.731433577338696*^9, 3.731441278859342*^9, 
   3.731782660755186*^9, 3.731799949809297*^9, 3.7318494660034943`*^9, 
   3.731876715695505*^9, 3.732019790793415*^9, 3.732653330380533*^9, 
   3.732971248068069*^9, 3.733663057964924*^9, 3.73419545198685*^9, 
   3.734358623885171*^9, 3.7345272659028254`*^9, 3.734980880199003*^9, 
   3.735052665367343*^9, 3.736204968131744*^9, 3.736206700336999*^9, 
   3.7362531970846767`*^9, 3.736257937749888*^9, 3.73626031687221*^9, 
   3.736519842175984*^9, 3.7366010888679857`*^9, 3.736649182779046*^9, 
   3.736772489739462*^9, 3.771169254137822*^9, 3.78225154758851*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.683454060152358*^9, 3.683454086088674*^9}, {
   3.683454134688302*^9, 3.683454225736024*^9}, 3.683454884337645*^9, 
   3.683534651148117*^9, 3.683619362285658*^9, 3.683624782354863*^9, 
   3.6836332712861853`*^9, 3.6836333812646027`*^9, 3.683633547986539*^9, 
   3.683633687642638*^9, 3.684037444841187*^9, 3.6844677918193417`*^9, 
   3.684467828758114*^9, 3.684470145485219*^9, 3.684552960721389*^9, 
   3.684744250289132*^9, 3.6847444826818943`*^9, 3.685678725680106*^9, 
   3.685691611418873*^9, 3.687150190658229*^9, 3.687177099319194*^9, 
   3.687252197574671*^9, 3.687258928628611*^9, 3.687504455348384*^9, 
   3.687691402482314*^9, 3.689319198877412*^9, 3.695559782064913*^9, 
   3.6955785839850483`*^9, 3.695586354743816*^9, 3.696611134098158*^9, 
   3.69661362144761*^9, {3.696614017974484*^9, 3.6966140434851913`*^9}, 
   3.700413479027728*^9, 3.7184613780910187`*^9, 3.718714645658144*^9, 
   3.725289416814239*^9, 3.730644456348703*^9, 3.730731874184999*^9, 
   3.7308177496358852`*^9, 3.7310973265746107`*^9, 3.731155819609872*^9, 
   3.731161451091653*^9, 3.731345444669745*^9, 3.731413117508731*^9, 
   3.731432969550028*^9, 3.731433577338696*^9, 3.731441278859342*^9, 
   3.731782660755186*^9, 3.731799949809297*^9, 3.7318494660034943`*^9, 
   3.731876715695505*^9, 3.732019790793415*^9, 3.732653330380533*^9, 
   3.732971248068069*^9, 3.733663057964924*^9, 3.73419545198685*^9, 
   3.734358623885171*^9, 3.7345272659028254`*^9, 3.734980880199003*^9, 
   3.735052665367343*^9, 3.736204968131744*^9, 3.736206700336999*^9, 
   3.7362531970846767`*^9, 3.736257937749888*^9, 3.73626031687221*^9, 
   3.736519842175984*^9, 3.7366010888679857`*^9, 3.736649182779046*^9, 
   3.736772489739462*^9, 3.771169254137822*^9, 3.782251547590603*^9}]
}, Closed]],

Cell["with expectation", "Text",
 CellChangeTimes->{{3.771172512979648*^9, 3.771172514919623*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sum", "[", 
  RowBox[{
   RowBox[{"n", " ", "pntgtapp1"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "0", ",", "\[Infinity]"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.771172461186919*^9, 3.771172491475808*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", "+", "t"}], "2"]], "Output",
 CellChangeTimes->{3.7711724946992073`*^9, 3.782251550103253*^9}]
}, Closed]],

Cell["\<\
Using this expectation, the cumulative number of individuals over T \
generations is roughly\
\>", "Text",
 CellChangeTimes->{{3.771172770001577*^9, 3.771172786264573*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sum", "[", 
  RowBox[{
   RowBox[{"t", "/", "2"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "T"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7711727877488728`*^9, 3.771172794083631*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", "T", " ", 
  RowBox[{"(", 
   RowBox[{"1", "+", "T"}], ")"}]}]], "Output",
 CellChangeTimes->{3.771172794499848*^9, 3.782251550379936*^9}]
}, Closed]],

Cell["\<\
Or when -1/m << t (ie subcritical mutants) we have approximately\
\>", "Text",
 CellChangeTimes->{{3.683454435599473*^9, 3.683454447458728*^9}, {
   3.683454490277391*^9, 3.683454497280962*^9}, 3.684470565659294*^9, {
   3.695559795936441*^9, 3.695559797869576*^9}, {3.696613624776561*^9, 
   3.6966136260215054`*^9}, {3.7306444803174*^9, 3.7306444844378757`*^9}, {
   3.73625795486864*^9, 3.736257963574904*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pntgtapp2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"pntgt", "/.", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "+", "m", "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"m", " ", "t"}]], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "m"}], ")"}]}]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "m"}]}]}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"m", " ", "t"}]]}], "\[Rule]", 
      RowBox[{"-", "1"}]}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", " ", 
  RowBox[{
   RowBox[{"1", "-", "m"}], "\[Rule]", "1"}]}]}], "Input",
 CellChangeTimes->{{3.683454376232163*^9, 3.6834544322357407`*^9}, {
  3.6834548857456703`*^9, 3.6834548876268587`*^9}, {3.684467846907605*^9, 
  3.6844678499619913`*^9}, {3.6844701622251987`*^9, 3.68447019624883*^9}, {
  3.696613637693878*^9, 3.696613695582795*^9}, {3.7362579665171432`*^9, 
  3.736257973824437*^9}, {3.736258891212345*^9, 3.7362589100108843`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", "m", " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"1", "+", "m"}], ")"}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", "n"}]]}]], "Output",
 CellChangeTimes->{{3.6834544052204437`*^9, 3.683454430138137*^9}, 
   3.683454888000554*^9, 3.683534651184402*^9, 3.683619362440928*^9, 
   3.68362478240014*^9, 3.683633276505857*^9, 3.6836336916298027`*^9, 
   3.684037444943478*^9, {3.684467833505287*^9, 3.684467851054475*^9}, {
   3.684470191314402*^9, 3.6844701965656157`*^9}, 3.684552960765916*^9, 
   3.68474425039154*^9, 3.684744482730171*^9, 3.685678725723387*^9, 
   3.685691611472416*^9, 3.68715019070119*^9, 3.6871770993709927`*^9, 
   3.687252197618767*^9, 3.687258928690983*^9, 3.687504455411921*^9, 
   3.6876914025250998`*^9, 3.6893191989226217`*^9, 3.695559783696187*^9, 
   3.695578584024784*^9, 3.6955863547886066`*^9, 3.696611136049533*^9, {
   3.69661363840411*^9, 3.696613663442328*^9}, 3.696613702177863*^9, 
   3.70041347909892*^9, 3.71846137820483*^9, 3.718714645758844*^9, 
   3.7252894169500732`*^9, 3.730644560450574*^9, 3.7307318742985764`*^9, 
   3.730817749750074*^9, 3.7310973266616364`*^9, 3.731155819804407*^9, 
   3.7311614512435293`*^9, 3.731345444766019*^9, 3.731413117624371*^9, 
   3.731432969684513*^9, 3.731433577484871*^9, 3.7314412789904623`*^9, 
   3.731782660867625*^9, 3.731799949892807*^9, 3.7318494661234818`*^9, 
   3.731876715895507*^9, 3.7320197908936663`*^9, 3.732653330417556*^9, 
   3.732971248166383*^9, 3.733663058063985*^9, 3.734195452184225*^9, 
   3.73435862398643*^9, 3.734527265986184*^9, 3.734980880293532*^9, 
   3.735052665859015*^9, 3.736204968228479*^9, 3.736206700430217*^9, 
   3.736253197207868*^9, 3.736257974668129*^9, {3.736258907660839*^9, 
   3.736258910569578*^9}, 3.736519842474779*^9, 3.7366010890201893`*^9, 
   3.736649182950664*^9, 3.73677248993451*^9, 3.771169284695298*^9, 
   3.782251550520792*^9}]
}, Closed]],

Cell["with expectation", "Text",
 CellChangeTimes->{{3.7711725264998827`*^9, 3.7711725298484373`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sum", "[", 
  RowBox[{
   RowBox[{"n", " ", "pntgtapp2"}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "0", ",", "\[Infinity]"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{3.771172522821364*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", "1"}], "+", "m"}], 
  RowBox[{"2", " ", "m"}]]], "Output",
 CellChangeTimes->{3.771172523577012*^9, 3.7822515506459417`*^9}]
}, Closed]],

Cell["\<\
Visually check critical (red) and subcritical (green) approximations against \
true solution (blue) for n=20 across time\
\>", "Text",
 CellChangeTimes->{{3.730644494223468*^9, 3.730644503606134*^9}, {
  3.7306445982971697`*^9, 3.730644619065669*^9}, {3.7362579862001657`*^9, 
  3.736257995681674*^9}, {3.77116937670936*^9, 3.7711693913975887`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"pntgt", "/.", 
       RowBox[{"m", "\[Rule]", 
        RowBox[{"-", "0.01"}]}]}], "/.", 
      RowBox[{"n", "\[Rule]", "20"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "500"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"pntgtapp1", "/.", 
       RowBox[{"m", "\[Rule]", 
        RowBox[{"-", "0.01"}]}]}], "/.", 
      RowBox[{"n", "\[Rule]", "20"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "500"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"pntgtapp2", "/.", 
       RowBox[{"m", "\[Rule]", 
        RowBox[{"-", "0.01"}]}]}], "/.", 
      RowBox[{"n", "\[Rule]", "20"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "500"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Green"}]}], "]"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.6966137110611477`*^9, 3.696613763557815*^9}, {
  3.696613814455885*^9, 3.696613894767654*^9}, {3.696613926535116*^9, 
  3.6966139525668716`*^9}, {3.718463650177979*^9, 3.718463675078601*^9}, {
  3.7306445635286016`*^9, 3.7306445660549192`*^9}, {3.736257981270028*^9, 
  3.736258014650298*^9}, {3.736259077983686*^9, 3.7362591177668543`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1mk0lW0XB3DKmJIp8xjKFDJmOGdvOpxjHvIQoVLGKGNEocw5pnNroEIT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      "]]}}, {{}, {}, 
    {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwVlHk41O0XxhFlVJYsWTKSFstYs5RlzjEz9q0oRWkh68sw9ixDso1kma8o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      "]]}}, {{}, {}, 
    {RGBColor[0, 1, 0], LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQ/frTHx+3tKd2be3lX7fv7raXs9Z0/7hA2AHG97t2
5MP7BcpwvsPEZm7XEhM4X/Bz2IaJyXZwvt3uisBaARc4f0HxvrV3Ijzh/Hue
dy/9dvOD81O9q94mnQ+E8x13fWc5nxcC53PveMgg/TAMztf+6J5n0xEJ51vt
lDpgyxQD56/3jFc9lh8H5+/lEvgn2JkA50vtWHZ7w+FEOF+p+XfhLolkOD/O
iHNSe3oKwn+avkuOzE+F8/Nt/fNzPqXB+S4z23Va9DLg/CNCdYvYWjPh/PIC
3UU+V7Pg/IWiwlOY+HMQ8je22Skn5yL0P5pwe/OCPIT5F5WZOG7kw/k78nYV
PJ5SAOd3StTdrDIqhPMNLi6Y534Xwf/we77Gt5YiOD/Ha9fqGMViRPgsN+7+
cQrBP6VxItknswTO/yhtydjEUgrnv5Xl/P1mDYK/1PnLW36vMjjfqMLONuML
gl99YXFrxeRyOP/urKeTsvQr4HzRkrY/E28g+JyFTvGFZZVw/qWaWLk2xSo4
f+uvkEU1JxH84Dnp8tpp1XD+cZ+bP/gEauD8bwppp1etQ/Dt088naXjVIuJ7
z/Sw258QfAvTame3CXUI93CmyCi/QPBv3fH5+t++Hs4HAE0Asek=
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.6966137423098087`*^9, 3.6966137640972233`*^9}, 
   3.6966138151707783`*^9, {3.6966138548800488`*^9, 3.6966138952796307`*^9}, {
   3.696613940942374*^9, 3.6966139531661053`*^9}, 3.700413479151729*^9, 
   3.7184613782640047`*^9, {3.7184636522966967`*^9, 3.718463675522717*^9}, 
   3.718714645812166*^9, 3.725289417018567*^9, 3.730644567798854*^9, 
   3.7307318743478403`*^9, 3.730817749809914*^9, 3.731097326731442*^9, 
   3.731155820132333*^9, 3.731161451328051*^9, 3.7313454448185596`*^9, 
   3.731413117674151*^9, 3.7314329697870693`*^9, 3.731433577550633*^9, 
   3.731441279058567*^9, 3.731782660920422*^9, 3.731799949954664*^9, 
   3.731849466177635*^9, 3.7318767160996847`*^9, 3.732019790946164*^9, 
   3.732653330467599*^9, 3.732971248246976*^9, 3.7336630581145163`*^9, 
   3.734195452252598*^9, 3.734358624046906*^9, 3.734527266048312*^9, 
   3.734980880356741*^9, 3.7350526659579077`*^9, 3.736204968298099*^9, 
   3.736206700500228*^9, 3.736253197277245*^9, {3.7362580022750053`*^9, 
   3.736258014945134*^9}, 3.736258943744542*^9, {3.736259080012397*^9, 
   3.736259118012001*^9}, 3.736519842542429*^9, 3.73660108907367*^9, 
   3.736649183014449*^9, 3.736772489985667*^9, 3.771169286551601*^9, 
   3.782251550759162*^9}]
}, Closed]],

Cell["\<\
Check distribution of n at 3 different times\
\>", "Text",
 CellChangeTimes->{{3.771169381397138*^9, 3.771169408926066*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"nmax", "=", "100"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"pntgt", "/.", 
       RowBox[{"m", "\[Rule]", 
        RowBox[{"-", "0.01"}]}]}], "/.", 
      RowBox[{"t", "\[Rule]", "2"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "nmax"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Blue"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "4"}]], ",", "10"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"pntgt", "/.", 
       RowBox[{"m", "\[Rule]", 
        RowBox[{"-", "0.01"}]}]}], "/.", 
      RowBox[{"t", "\[Rule]", "20"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "nmax"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Dashed"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"pntgt", "/.", 
       RowBox[{"m", "\[Rule]", 
        RowBox[{"-", "0.01"}]}]}], "/.", 
      RowBox[{"t", "\[Rule]", "200"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "nmax"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Blue", ",", "Dotted", ",", "Thick"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"pntgtapp1", "/.", 
       RowBox[{"m", "\[Rule]", 
        RowBox[{"-", "0.01"}]}]}], "/.", 
      RowBox[{"t", "\[Rule]", "2"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "nmax"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"pntgtapp1", "/.", 
       RowBox[{"m", "\[Rule]", 
        RowBox[{"-", "0.01"}]}]}], "/.", 
      RowBox[{"t", "\[Rule]", "20"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "nmax"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Dashed"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"pntgtapp1", "/.", 
       RowBox[{"m", "\[Rule]", 
        RowBox[{"-", "0.01"}]}]}], "/.", 
      RowBox[{"t", "\[Rule]", "200"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "nmax"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Dotted", ",", "Thick"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"LogPlot", "[", 
    RowBox[{
     RowBox[{"pntgtapp2", "/.", 
      RowBox[{"m", "\[Rule]", 
       RowBox[{"-", "0.01"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "nmax"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Green"}]}], "]"}]}], 
  "\[IndentingNewLine]", "]"}]}], "Input",
 CellChangeTimes->{{3.736259128047325*^9, 3.7362595351048326`*^9}, {
  3.73625961025453*^9, 3.736259652200877*^9}, {3.736259697368576*^9, 
  3.736259707000505*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0, 0, 1], 
     LineBox[{{2.040816326530612*^-6, 0.020032234111402317`}, {
      0.03067179205596268, -0.0015351699441814022`}, {
      0.06134154329559883, -0.02310257399976517}, {
      0.12268104577487113`, -0.06623738211093251}, {
      0.2453600507334157, -0.15250699833326736`}, {
      0.4907180606505049, -0.3250462307779369}, {
      0.9814340804846833, -0.6701246956672762}, {
      1.96286612015304, -1.3602816254459544`}, {
      4.090835708545865, -2.8567000206349547`}, {
      6.07778835701521, -4.253953303650462}, {
      8.025764881887605, -5.623798023760854}, {
      10.138846915816112`, -7.10974727950289}, {
      12.110912009821138`, -8.496531423071433}, {
      13.125978210607924`, -9.210340371976184}}]}}, {{}, {}, 
    {RGBColor[0, 0, 1], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVz3k41HkcwPEZwixrXTmbHEPy69iGPGqF30flKMYxiW/HVEvMTLTjDg2N
dFDTODpWOWKpbLWyWtuqlQ9Lou2ppLVRye5TGfVUSJNztv3j/bz+fttFSvjR
GgwGg/e5/+Xkz1SVW7d45UfxAhuPMfEai7LZLTpL/7XUN2LrCSa2pNVWO4mu
0NafvCLVZ5h4i5sg1BY105fl3DSfGibelnf7jwvv0Z0NJtUPWpnY6Z7T+EY4
QGuy+qaUKiZ2FfYnDAnf0amXYy5ZRWrg+iadoJdCNS0Y36crddPEu/puX8wR
GIK4OTtwQkMLV+f74IVgC0iaMpON1mlj9LJJfWd9Wyh4XSOThrOQR0WPmPk5
wLCJrlaLjS7W92SmdK50gjW1sxnZXXq4ynjRlTn7lsBjWWvydLE+CqeKys4R
LmTr5KxibTdAya1Xy6/wXGCu7PWEX44hHtmsvWAmzhUOW8yYK0VGGNWxN8ZZ
5AafxH9/7U8bY4uOZWjsppWQbOpyWWJkgs5GslPKZHf4SpAUmzxugjvGPJcE
xXnABUGW/YquuVhZ3s5WHfOCbZPx83vrTPGqwr2/mw9gMzKYSR83w+TrniFl
gd4wUMHujY4xx+auc6N5W1ZD0xuvRHGABYr9vmkSkzVQMrJIe7GdJZbWODfE
7loLxUWz/Z0sKywca8qO3+MDZcdCLJzfWOHLiympokRfqPKO44XjPGzzLSre
v98POgolbeQ8G5nBff/ky/xh+IyHq2XmfGR4/8qsSF8HZrOHdX8ItsZccxWv
+/B62DFzncNytcH4zVGtqpwAeNTXb3lqji0OZrvupE8Ggq5W0B9mabY49/jp
vrxKHqzZqj67V2mL5w0XpXeUBMF0vmk6vcEOWxJtfBZeCoa2QpuxkXY7LLet
YHuGhYBevEKs6czBJukkQ3Q/BMheD5OJ0xy0C9CZto8IhYawZ4Knevb4yz3q
6OOeUCjQfVFtm2qP8luzXFsBH6SKATlfaY/Hk5S7djzhw8u3Xgn/hjmg1NTa
gLNpA4RLn+aSmw74I6XVlfx8A/T0Srx/5y5A7Q9My5ZtYfDQQPgxq2QBXuD+
nFX+Kgyem/IDuQaOSEVeDJrZvRFG/aWP2mWO2L+usX7j641wgOhtuT7siN1V
GUvppHBwdFNklwkW4qeroR6c0XDwe59SPXB7Iap/S2w49F0ExPWWTmq5OGEA
19dHOh4BlfJrI1bVTtghWCaOTSIQbr3iheIrCo2jRDfKUggUl1W57zKkcJuo
Uv/+HgJP2IYFPsYUfkw0qXeVEoiap3SfNqXQIVc1OXOAgMSipEA8n0JZfbO8
4BSBXGP1qrVLKHTXCalraCRwQ7ujaGIdhYe+zNMYukFAfXD5UE8AhQ+MWsOs
bhLw1qrwrONRKGK7TmS1EritmT4UE0rh984Wq/3vEHjEWOzVQyj8sOX5w74n
BN5NKpS1QgrhW0tH/QECLhlTXkfEFB6N4afRgwRSJoQnomMp5CS0satfEJhS
Ac2WUBh6qCZ691sCrPHRE3mpFJYeHbx29j2BgOTtwzvTKBwqsNLtHiWgGLtD
Q8bnnxJ5rZuKgOlo9fDHTAr/rGhniCcIbEowgu59FJqfn+WXTBEofZ958qds
CiMvrTh3d4bAM8nwcG4OhbV18Sq1mgDnXTjsPEjhf7WhPxA=
      "]]}}, {{}, {}, 
    {RGBColor[0, 0, 1], Thickness[Large], Dashing[{0, Small}], 
     LineBox[CompressedData["
1:eJwVj2s0lAkYgJHYWGOu5tOxgwmZaI1dRxLNi9xyyUzkU6mWNIOkBqVNlpTM
IkrpohHr0qCIXJIjr7YoJUydPQedXHYrKilpp+Sy9sdznvP8fEzDYkURGmpq
an6L/G9uzlxJIad9/dPzfR/26VGw6TuecYzkikBj6IL/KIWC7YnVpZaSGoGt
xa5rQVQKdvAPiLUkbYJT9e/FTgwKPshSen0W9wi8+3SHlhlS8KFjWvM78ZAA
dTy6S80o2HV68MCYeFJw7ejtioF1FNzYqu3/SrwgOBFeEuYRRcFuPftlmqFU
sC/t0Zx4QkHXHHe8uomAs5MmZmPW+hhhM6Nnq2cCLYwKoa5MH/14ER8NPM1g
5Fpmzdw7fax7djThoYMlbFV4u3PNqbiOvqpG8zdr+LN+ZuP1YCqKv52Rl5F8
yF3dGewro2Jsx+ufa/x+gnori5JzTVT8fauW+dxeOwjeXZfeMU7F8M4je2wl
9iDk9imKCRq2axsKo0McoMZXV5nrQUNbWkr+eLwjZNdK88SJNNz1ydnaf68T
tBfszRsrp2Fx4X0jVfZ6SMA8K2E/DW+echxUigCyhX91devQMf62c4Dc1wW+
iasU0w50bOsqm5Jtc4XxW9c5S6LpGOm5tjWSdIMfc1yftlyk42WFbUN01AaY
uqJpsv0xHU9/ak3df8gdlv8wGkedp+OryoSDEqkHXDQWacVaM/Cex5kLx455
wvntk/yGHQxU3zQwmpPiBe84xpfKshmo5tKoXnTYG8r8onQqWxiYwVb5KU9u
hBeNo/T8CQbu3xp+V5XmAzFlEyHWRkwcSbXbLTjnC0lPzNdW+jORmXdxQFbs
B5Phh42dUphYTl11uLPAH5qTd25IrGZiu9TYfWXVJtB4JlW/PMzEQpMiI+fA
APijmpiL1Gdha9KMmqQ3AMo/9y/4OLPQ1Ed7dkWwEHiHHlxixbKwvoeX2f9M
CJrJ3vEyOQuzOub5JqEiCG1Tvfynh4V5ceNRu56LgJLukP9mnoVJLI4+N2Qz
cJvP+mmuNsAK3tKu+OHN0GjBkS/daYBa0+qG7TsCodjQ0ao22wCv8muTC18H
gq5nmnADGiAvrNJ/LiYI+odfJ7/9aICD3s11QW+DYH7hxRsnEzYqS35dLYjb
AiUhSyYTRGz8clPoxJ3aAnKH27YhqWxcuCVtSN8XDLNpWUcCatjow/dwT/oc
DIPLskJtRtjYGWoTGR1HAo3FSb6lTyA9XNIiTyBhwa3QK4NK4A5JsV7vIRLe
SzkMkkbgv1JGnV0SCY96OQoVnUCzDNXM3HESTmQZK+0NCEypa8vKzSdhZomp
RYMRgY7aATcamkn4e2rFk1oegenfyzTGWkhQmpZeSF1FYB/tbuDyOyRggFm4
0IpAiZHd1+S7JMirzb58sCbwvC3h6vWIBDLKnMvnEzi9bfjpwHMSukcsDlbb
Ewi/GFroDZHQQr0KyWsIzNwjShSMkFAhWKnr70Ag98A9o9KXJJyUryyaWEug
MF0REfOeBJcQyy5rZwIvZ440XflAgk2G4uzsYo/lLtdRTpHAabLc+Xj94k9B
VrW9ioRZJm86Ggh8XHRfLfIrCW/cKu6scyGQXT4vKvhGQr+UJ9N1JTCsak1Z
9xwJncUVmwcXu/rGftXCAgmNvTxOlRuB/wEVRDNw
      "]]}}, {{}, {}, 
    {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwVxXk01AkcAPAhR9Lk6MJaV6PS4zFyh/mSwRjD/Ab5SWRJMyLlirbZmo5V
FqlsysoZnW8RCVnmyzJi16rRgezDSrG6XLl22N0/Pu9jGH6EFylPoVA4//l/
oyzZzQK9ZufnqbW9uQ21TbWrTfQPCwoZ4+nvRyzbroqbU8pLtwsqGOX9dTGr
2srEEos4vpJAzPggp/9gorVG/CRD6jnL72YUbuT1DLa2iTsczta/5w8y4guj
3/S1vhB3Xn4dN8b/xAg9MP/+Zeuo2KtR2ectf4UhlTjHvWidFXdRbVQUQtRB
U1YvtK5QQtcsJt721YKRS/4NY33qGGm+SKVTDWCz7FhOBmxCjknk5CYPGnRF
M1+G6epi1fPvkjrstoOC+qnedZ0GuEtzR4XCKVM4EE1P+R63IH/pSn4ZaQGV
OxeUtt3dikck73ZWcCxBrGcz8st+E/xhr5KxLMYKNFQ7Jv/mmmJE+4mDdIEN
GOs841DVzbFZWZuIDrKD9exk75+HLJCuIcoZT3SAhyp01aI9lhg27WTqE+MI
tUFlnzOqd2JxQZvuXKYzBN9z+9RmZo3VFx1eS3kAiQ9iIzcU22DiYyduvrcL
fGT5yYcs2aK4s2wqLdgVVEbC6ybj7THKw74xitwNqVSzq6JnDnjjDr0m+pAb
lNoZpQdzHPHydOPpo8lMsNUpmWe3OOHbe0nHBPHuYJY5kGGjx8BW9yvXz5zx
gHCKYf4jNqCcb/9fWSJP+FOerty9BEhxeSRXdJwFP4YpmcXfccELm+c40vNe
kOcct78hwhWP7o1omTvLBr9I+7LTmrtx+LTVAcZVb9i39trch+7duCE7tz+t
mAOF6x4rjqa54S31Hcfb83wgO8hhW5AtE5vj9Znb7vtCL40bkDDNxAKDIl0n
fy502f2as+amOzYKFymCp1xYvr2UberrgYZs5X+2BBIgutaRP6PiiQ+7TdL7
nhNQ1T3z2L7OEzMkyxYGITywvlDzhpbEwuyE8UNhAzwQpPUYZhp7oXCjnppR
kB+8Gn2kI5J64V0Txc7EIT/IaTE30L7IRqUZOe3mUH9QGlO0N3fyxtsWD04W
vPMHSWZc6MSiN5qE3/ORHQ4AvFjCsKzh4GtWfVXARADE9FpYfQn3QenNb80Y
CXsgqsTfOkzfF+erCUejqT2wqeYFy6PbF1fq4mtSYwPhlMa6zAEnLrIt3JnC
2UDIWy08IcjjYnuIeVR0Agnqpdenq6a4qBkhaMhPIqHfT63eboaLoYJi6tNk
EspWpZ5smuXil/j1VVZCEhwjElQ657lIuzC3KDtHAt/IR394mYuiKnHGpRwS
mopWsdVUCXRQ5lbW1JMQmx9bEr2FwNS1afJjDSTYc0b5kzQCn2m0+Os0kaAg
CzZL3kqgQNdq4WQLCbn7WHVnTAi8Rtdy9fyNBMlXtD9yzQmcCR7q6R8g4euf
+hbadxEI32hvpQ6SMM7iijlOBKYf5KUwhkmoXpCc63Em0CiuVbd0lARW0EO1
QRcCidQ7kYc/kpCklWX8xYPAG+nDtYWfSYAnihMnWASOXdJZI50iQTVFWCnH
JlCUl1FuM0dC8auoXVQfAn8vaqNELZAQc36Iku1L4OZby7y8JRJsbQMlWgSB
4fdty7pkJMi960ov4BFYXnl0bmWFhK4cN4LmT+C/QopJPw==
      "]]}}, {{}, {}, 
    {RGBColor[1, 0, 0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVz3k41AkcgHGGTFvRuHJNjqH5RfYxStZazJcyo0RjKD9EbcIIOXKlqVU2
5WglpVq5ipQ248jaWYvvWEaXCJWjEpWjWm3HGCnZ9o/3+fz9muyM5odQFBQU
PL72v4ycuYtFhhIn88ru+zURFGxYaG4UJShm93JkoVWxFJQkV5WtFIjYwmd6
M5VJFJSyYsNUBC3sLnqwflkaBW9k97jJwrrYiTmyoPwCCt60TxO/Dhtmt8br
T6TcpuCt3KHYibA3bH/2rtl1q5RwYxPVcyxsnp3dJzd88FIJO1Vtv1EOpEFz
1JTYJnMBuuS4YsVmXQgar2xYokbFEKtZVWtVY7CVHtHYkLkQPcxD3i7jmsGw
JqulhbkIa/sOJNy0WwnvnUvuiioW4w8aFiLlnyxh4Mmw1aCbKoZ9OllYTrJg
5qnjlGBUDaOl42tEHqtBMlJ91I5Fw0x/lRVzkTYQnWkh8ZunYXDH/lBrgS14
m1J/a0B1lFD1vCL87KB3Kq6de1ADrdVT8yfj7eGvWClV5q6JO947WnpGOsDQ
c+GnJ4u1sLSonS4/7gTBSw10x4a0sO4X+6EePkB6pFuw0WVtjP/TkVe4yRmG
xf3bT4cuw5Zb5e8yAlygtJl3ZOVaHQznft8UTq6Dc3Wrts3IdPD8Zev6iN3r
YXb7VMALqS7mvm86FJPkCtNOkKl8Sg/HKhMSBXEcMFeThe/w1sc2zsmzhw9z
oe1UbtwAwwAVNw+O5qS6Qf7iXMuc5wao4Py7Ysm+DaBcb6SddIGOx3TkHj1H
N8KAdj5TGLMcY/yDW+Vp7jAWGj3ZxDLEkUM2u9inN0FANOs+XdEItfLODWaU
ekBEZeqba51GeIlmsa+jwBMGXp577MgxRkmckStxdTNYbxv3rbtmjEXGJXRH
Hx6UuY5ZcNVMsEk4qyDo5kHIDUvtD5EmaOJO/Wzq6wVDzPE8Ua8JXu8yzxro
84KIOX5ExhoGZku/sIwD+VAtWv0wtoCBeXsnd+94xAfa4N8FyZ8ZKNQ2XMrw
84bmwvNJZwNM8Yr5glvxT73B2HFyXNpqiiofFPUkQT5Q5DNerWlqhhWsmoNF
4z7QxfVTi84yQ/OdlZ5zUVvAs08j7dlbMxzaIK7d8moLTPYf4CV6rcCeiynf
svduBTvxtlod8QqcqfNyYLzbChfU/4l8qMfE+T/i6tP3+IK/UrtTdTIT3Vkc
V6HMF6TdtPIzw0zsCLQKj9hLgucytV2FbAI1ggWNhQkk8H1SmBudCQwSlKp2
J5Gw9eTYxLQLgdNxmrU2QhKC1FqieBwCzY7JZ+d+JmGPSkySkgeBqbUt2Sfy
STg+fS8z3J9Aeyqvul5Mwp0Hp2vWJhCYviSDMtFIwj0tSvxoIoH31Ft99JtJ
6OPvsc1JJlBAt/l4sJWER3c5jRP7CTxjrevidpuE11J5W8FhAj8EPO0dfETC
kga/fsUTBMKPekzVYRJosvZfq3IJzArlJ7NHSNBaszowII9ARmwbvewFCXTR
otHr+QR6pV8OiZoiwbKi8VVYIYHns0Yaiv8lweoFUaVVTODECf1FPe9IsDE9
FSMp+fpTkF1lKyfBoThSpl9G4J2SdoXwjyTA4/6GjnICdS594Rd8ImG9gWtK
fAWBO69+V945RwLXr8bB5AqBVdUx8vl5EjadWT7fWUngf9D1SBU=
      "]]}}, {{}, {}, 
    {RGBColor[1, 0, 0], Thickness[Large], Dashing[{0, Small}], 
     LineBox[CompressedData["
1:eJwVx3s0VAkcwPFhxfZw1J17L9pRHoXpsWY2r6Y0vxQp7/GYWyLRMMMoj5Rq
iklJRXoctRGRXmqXKCTkN1YUddgpZ3dNW2lXOG0PSjbF7Owf3/M9H6uobSKJ
PovF8tX1/63zJsqK56hWBC0hmqriCaz7ljs3QXpe2Jv7qVFPTqAqreKivbRS
GDnY2xiocxsvKdZQ2izcWlTWOKzz/Ry112hslzDbyKmRv5XAB4LM+n9inwvv
asQNVYkEdpzQJA3GvhNyDxTVV6USuK7JyO9VrFY4+cS+tiqdwEfGzlMNwmeC
4Hfx+sh8At3zPPCKvxn42NyyO19OoMRh3JhvbAkWZI53WhOBvlzJML1mHqTH
KMxZjwmsfrI39YGrPdSxCgizAQKXEQsqDdIXQfrXrppnXwmM/XKy6BLDA8Ni
ZYWQYOO2toEllb4/wJZDkWqeLRuPbDCcPyF3BJFaXNK9jI3R7Xti+FJnMJUo
zrIC2KgyMg+MX+8KhUWcwY5oNvJnZZwe2i6ASpeeF6t2sTHyg9siP/lyOGve
YOCby8bS4nucsdwVQIbXqw3K2HjzmECjFgH4eS75FHqbjdvvuAUU+ayETTt7
Vy99yMbmjksjh8PcQTu1wK2jj42yNUubZMwq2PF31ubXo2w8d5VfEx+3GvZZ
5jg0TCfxxIcmZeJOD1itbxw034rEV9dSd0iTPaFvYUPpXCcSWz1P/rh//xow
qVMW3F9Hop5/78u8DC8gjqTe1dtEImtlrV7JrrXQo9/v0pNMYrbpmK/60Dqw
/1MeJs4mMXFDdMtYpjeItFbXZOdI7FM6bhHm+8CMzHcXFlSTSJ4623u41BcO
/uQ6fLCdxMszF+xqL/SDHovKuCQNiarkuR521/2h5r3bsenDJBZblnDcggMg
fvr4U6cpFDYpxlnS7gDo6+Qrx80otPI2+mojDoSBN8quhO8pvNXFPfrHk0D4
Raz1SnKnMKdtkmcZLgIHm3y5DUPhqZShuMinIkhxZhokcgoV1BwT6/VBkPru
9Cb3DArLuVM6tr8IAqNpb39+lE+h4Uc9c1VEMCTKk+2Gyim8wqvaVzwQDDKe
iffNZgq5Udf8JhJCwLrArtW0h0LN2vrqkNchUOWdIJ0xRKG6bPdiYUoodEd0
1lZOUvjvzcDl1iOh0FYfyvuLoFF7O7kma6sYdt8J196wpdGb5+mhGBVDM2dv
2uLlNLaHO8jiUxjQtD3gCAJoJKKlDUWpDORrTcpO6RwhLTXu3slAgGso943O
n5LZ1Y4KBu6Vv3QqCaRxXvbY+MQBBipzvvgZBtGYUd2cc/w0A5mixUp1CI0C
o4AbNfUMLHx2vD8ujMasGYf1BxsY6Kd/i2/V+ddZLcGz7zJQ4m8xYrGRRinH
8fO+FgYoVflkt85n+GbuXp0MaMtaTF0iaPwY9uJx71MGHss+rv1mM42w2dzW
+DkDuRcE3Rt1PhojShP2MeClyQit1dk6qZVzsZ+BJh/jaFkUjYFZVyUJbxm4
4mCr6Iqm8dzRvrrz7xmIksr1uVtoHDw+e5p6hAFOaXX2fp0zCnMqnMcYOEEI
850kND4suceSfWbAx/vgd3k6m16eFBV+YcDwQGfpoM5R110uPZpgQNU4y949
hsaKG4ljWi0De0bFFYU6/wdn7DWj
      "]]}}, {{}, {}, 
    {RGBColor[0, 1, 0], LineBox[CompressedData["
1:eJwVz3k41Akcx/FhW1Q7Oyc/SjVJLaXNbEJK85V15Bom8lOPI3bMaMKMo1HJ
URsxNkUl5NqIVc84ulYtvtNBJNWsNuFZ7JbGtk9aqllX1v7xed7P68/PyvBY
gVCXQqF4z+//muXOXixdrtqmb6GRO9rR8KaB5YpocRnvjPcqVqo9DVVJykoL
cR1vZXyIEjfTsM1aJtITt/K2tPS8dN5Kwwc5avcPosc8qb/Kz8OJhh0Ox5r+
Fg3yXqQVrQv0pGHn6X6ZRjTGu/zCa1AaSkOPZn2fEdEcz1fR4FqZScNHVNuF
C4LpEGowLez+nYbbc12wmm8MnPiCEWNjOgo3TFG5VA587D/D+8Sjo7el8B8j
N3Oo91ODi4SOjT1HEjvsLUCtXTBSk0/HLcy1dQtSraC3Vr4xppWOoum8kirS
Gu4+914j+ouOsW2vN9Z5fwPGm0yak5kMzN6tt3p2vw3wy8xnJhwZGNF+OJIr
toWxzasHMyMZqNI38ZME2cMBnywR/yQDuYy0c6MJDjAUu/58UhMDwyYcrXz2
b4VGVdv+lmEGVpTeN9X+sA1EnPJRIZWJV0869KsFAJ9NDix2smdiwi1H3xIv
J9DXpantw5jY2lk1nrVnO4wR6ZCnYGKU2+bmKNIZeCEagcE1Jl6o4V6X7PsW
ZA251KFBJp6eaE6Xyl0gO6Uo+s0iFo7UJh4Qx7kCNblIxtrIwnuueeePHnUD
WUbfspIQFurw+/7ITXMHnooW45zJQorTDZ3ygzvgfWJNxLI6Fp4gtN7qTA9Q
2KXrBPWxULo74o72mCdkW/KdG3TZOJxu8x3vrBdEWwSvl3zNRnZ+YV9WhTfY
VXT/Qgax8RJ97cH2Yh+I8tj0Ljydjaq4FS5fXebDEcrAw+4rbCzllJs6+vvC
9IjcM/AZG5uTpyjiJ74Q6iaXsmbZuNJTf2ZVoB9UX7vhyLUwxGuPLRUvevxg
l+CNUuJriDltn6w5wQIYnQl9oJ9siPnxo/vCBgTw8nnHcaw0xGTD5TSzoJ3Q
blWgudJliD9Zft6ZMLQTFCcrJ6a0hqj3XsdEFeIPTZzqH4UcI6y2bkgpfe0P
Ha2jk1wvI7QMr/WZjQ4A7M39yJUbYf+OpsaANwHAMVtX4FNmhOqLh9bz4ndB
RJLeUFenEf571W+r2fgu+HLuty7RhBHO/Rx3PSMmEMrnFoXaLiXQ09rVJflD
ILCpqYWRrgS2B2+IksSTMO6hkV+NIZAZIb5dkkhCSsDDfaJYAkPEFdQnchIW
hymDl0oJ/BjHarRJJsE8McH5mIxA8xPaqdnvSQgoo9B2JhCY1tiac+ocCTcn
jC+NHyTQQd+3/noTCUcu7OjhHicw44ssXc1tEhZWW7W/mvdTxh3/JS0knG2g
3SrMIFBsajOZcocEZduzMp0TBBZwjbe7PyRh6N1eydNsAt/vGfq1b4AEZ5dD
urJTBMJekzXUQRIe84M/mJ8mUBEpSOINk7BnN2h6520mu2da+YqE+Fi9bsgn
0C+jRhj9loSqwrxC+jkCLyiGb5a9I4FbmZhzb96aU0sWqcdJaFGSqUkF83+K
c5S2WhKe310uHDpPYFf5fUrUJAkR3TrkmUICiUufBMXTJIz1vvRwLyIw/LJd
1aNZEg7/2e44M29lvVQ7N0eCwdta6/piAv8DO2M7yQ==
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, -9.210340371976184},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-9.210340371976182, 
       FormBox["\"\"", TraditionalForm]}, {-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{0, 100}, {-9.210340371976184, 2.302585092994046}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{Automatic, {{-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.7362591389566593`*^9, 3.7362593731222*^9}, {
   3.736259413642763*^9, 3.736259447180805*^9}, {3.7362594985719213`*^9, 
   3.736259535671286*^9}, 3.736259614857725*^9, {3.73625964498707*^9, 
   3.736259652723568*^9}, {3.736259699825819*^9, 3.736259707959878*^9}, 
   3.7365198426765747`*^9, 3.736601089223999*^9, 3.736649183179476*^9, 
   3.736772490181992*^9, 3.782251550903126*^9}]
}, Closed]],

Cell["\<\
These lineage sizes given persistence align with eq A3 in Weissman et al \
2010. As they pointed out, the distribution of n given persistence to t and m \
is roughly geometric in both cases (t<<|1/m| and t>>-1/m), with p=1/t or p=-m \
respectively, which implies that the probability of n drops off exponentially \
when n>min(t, -1/m). Thus n will essentially never be greater than the \
minimum of t or -1/m, eg mutants with large -m will be restricted to small \
sizes.\
\>", "Text",
 CellChangeTimes->{{3.736258965043254*^9, 3.736258982467749*^9}, {
  3.7362603710673637`*^9, 3.736260597672077*^9}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Probability of rescue", "Section",
 CellChangeTimes->{{3.769432670003049*^9, 3.769432684658238*^9}}],

Cell[CellGroupData[{

Cell["1-step rescue (equation 5)", "Subsection",
 CellChangeTimes->{{3.7438793784858847`*^9, 3.743879382037346*^9}, {
   3.7691877540321712`*^9, 3.769187755294733*^9}, {3.769188019053742*^9, 
   3.7691880217082157`*^9}, {3.769190112496471*^9, 3.76919011443904*^9}, {
   3.7694326919317713`*^9, 3.769432693746467*^9}, 3.77176167849254*^9}],

Cell[TextData[{
 "The probability that a mutant with growth rate in [m,m+dm] rescues the \
popuation is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "[", 
    RowBox[{"m", "|", 
     SubscriptBox["m", "wt"]}]}], TraditionalForm]]],
 "] ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["p", "est"], "[", "m", "]"}], " ", "dm"}], 
   TraditionalForm]]],
 ". Integrating over all m>0 gives the probability of 1-step rescue from an \
individual with growth rate m0"
}], "Text",
 CellChangeTimes->{{3.743879871226012*^9, 3.743879880920849*^9}, {
  3.743879939902936*^9, 3.7438800024546337`*^9}, {3.743889975623189*^9, 
  3.743889989351871*^9}, {3.743890230526251*^9, 3.743890239996063*^9}, {
  3.743890291540071*^9, 3.743890293158804*^9}, {3.769188138192339*^9, 
  3.769188157064905*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", "\[CapitalLambda]1", "]"}]], "Input",
 CellChangeTimes->{{3.769188309775648*^9, 3.769188312644573*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalLambda]1", "[", 
   RowBox[{
    RowBox[{"m0_", "?", "NumericQ"}], ",", "mmax_", ",", "\[Lambda]_", ",", 
    "n_", ",", "U_"}], "]"}], ":=", 
  RowBox[{"U", " ", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"pest", "[", "m", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "0", ",", "mmax"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.74388999597858*^9, 3.7438901159809847`*^9}, {
  3.743890213941965*^9, 3.7438902151173477`*^9}, {3.751646210192325*^9, 
  3.751646211131884*^9}, {3.7691880980279417`*^9, 3.769188113059965*^9}, {
  3.7691881491405163`*^9, 3.769188160612512*^9}}],

Cell["The total probability of 1-step rescue is then", "Text",
 CellChangeTimes->{{3.743890298409585*^9, 3.7438903144501247`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PR1", "[", 
   RowBox[{"m0_", "?", "NumericQ"}], "]"}], ":=", 
  RowBox[{"prescue", "/.", 
   RowBox[{"p0", "\[Rule]", 
    RowBox[{"prescuem", "[", 
     RowBox[{"m0", ",", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7438903155130796`*^9, 3.743890347256139*^9}, {
   3.7438904499592323`*^9, 3.7438904583600082`*^9}, {3.743890513735414*^9, 
   3.743890533920726*^9}, {3.7438906755034018`*^9, 3.743890675637628*^9}, {
   3.7438910037176657`*^9, 3.74389102709269*^9}, {3.769188082945187*^9, 
   3.769188085648086*^9}, {3.769188177996109*^9, 3.769188192380474*^9}, {
   3.769188510756342*^9, 3.769188511060356*^9}, 3.7691954294682293`*^9}],

Cell["And we can approximate this as", "Text",
 CellChangeTimes->{{3.7691885391796827`*^9, 3.769188544863296*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PR1App", "[", 
   RowBox[{"m0_", "?", "NumericQ"}], "]"}], ":=", 
  RowBox[{"prescueApp", "/.", 
   RowBox[{"p0", "\[Rule]", 
    RowBox[{"prescuem", "[", 
     RowBox[{"m0", ",", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.769188549917161*^9, 3.769188554482113*^9}, {
  3.769195437969903*^9, 3.769195439616495*^9}}],

Cell["Numerical example", "Text",
 CellChangeTimes->{{3.769188197233528*^9, 3.769188199683132*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"N0", "=", 
   SuperscriptBox["10", "4"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "4"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LogPlot", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PR1", "[", "m0", "]"}], ",", 
      RowBox[{"PR1App", "[", "m0", "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"m0", ",", 
      RowBox[{"-", "0.3"}], ",", 
      RowBox[{"-", "0.01"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Wildtype growth rate (\!\(\*SubscriptBox[\(m\), \(0\)]\))\>\"", 
       ",", "\"\<\>\"", ",", "\"\<\>\"", ",", 
       "\"\<Probability of rescue\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], ",",
     "\[IndentingNewLine]", 
    RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], 
   "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "N0", ",", "U", ",", "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", 
   "mwt"}], "]"}]}], "Input",
 CellChangeTimes->{{3.743890350509968*^9, 3.743890432324952*^9}, {
   3.743890474217306*^9, 3.7438905530366488`*^9}, {3.7438906784765463`*^9, 
   3.743890898946547*^9}, {3.743891043018394*^9, 3.743891043816245*^9}, {
   3.743891445264324*^9, 3.7438914751794357`*^9}, 3.745245224429879*^9, {
   3.751032604779484*^9, 3.751032607585558*^9}, {3.769188207176976*^9, 
   3.769188253638474*^9}, {3.769188303900608*^9, 3.7691884178854713`*^9}, {
   3.769188451427352*^9, 3.769188468131811*^9}, {3.769188517840538*^9, 
   3.769188518663293*^9}, {3.769188559452159*^9, 3.76918860390788*^9}, {
   3.769195492970487*^9, 3.7691955085738487`*^9}, 3.769195609861684*^9, {
   3.7822518011562557`*^9, 3.7822518014101152`*^9}, {3.7822518687938757`*^9, 
   3.7822518723494253`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwBcQSO+yFib1JlAgAAAEYAAAACAAAANcI5JjMz07+5Uf0bME4jwBw81ftl
G9O/m29HI0YoI8AEtnDRmAPTv5mWVmRwAiPA1KmnfP7T0r8h+b+oAbciwHOR
FdPJdNK/1ip6tBchIsAGg4VOXKbRvy40jSVr4CDA8uyXxZzl0L+PSzio2nQf
wOAHSCmlKNC/rrEYFKU+HcBHihi3UrfOvwe9fqX24xrAgPXlErc4zb+nFsTX
XbwYwGKl2wsTmsu/HBHSfIByFsBJtwze/gLKvz1SRpN7PxTA4rmCp0aHyL/D
EwwaUz0SwCQBIQ6G68a/P+OGUh8cEMAYOQRsIWvFv5SPsFNvVgzAEdMio0zy
w7+534TDWqAIwLOxaXdvWcK/Q2SJy3a3BMAHgfVC7tvAv9NviR79MQHACipT
V8l8vr8p73if2Bf7vw8WMtvVULu/kDP0Gold9L9345pNmlu4vxxQtx7FN+2/
Tg4yw/D0t7+dJiHlecDrvyY5yThHjre/TaluEb9P6r/Vjvcj9MC2v7INxNUT
g+e/MzpU+k0mtb9O/WneKkXivzehvG17xrS/LCbI40Af4b87CCXhqGa0vyU9
qgUsAeC/Q9b1xwOns7/zpPppPLvbv0c9XjsxR7O/awORDWqx2b9LpMauXuey
v1zWIE5/ude/U3KXlbknsr+rgjzJmAHUv4LqSfDkv7G/KUDDkT4e0r+wYvxK
EFixv82RM4p7UtC/3tqupTvwsL9osh5A1T3NvwxTYQBniLC/nGLfnDEIyr86
yxNbkiCwv3g9SuUCBce/0oaMa3txr7/YlhB1FDXEv4xnVtYo0q2/R0PYKi5i
vr/rCFl4Rwatvzz1+Pd9Drq/SqpbGmY6rL88FgW5FR+2v6lLXryEbqu/5Ms6
sdOSsr8I7WBeo6Kqv8w/G1i3z66/Z45jAMLWqb/J/jUFEjepv8YvZqLgCqm/
d9G+L8lUpL8l0WhE/z6ov5KVtMBAIKC/hHJr5h1zp785uViHaB6ZvzyMEITq
tKa/8KP8z8+Ik7/0pbUht/alv4zwUzmRy42/rL9av4M4pb80RWQGSDyGv2TZ
/1xQeqS/RlyqFtIygL8c86T6HLyjvyIekiSg+Xa/1AxKmOn9or8TNOysFp9v
v4wm7zW2P6K/Hc1qvgYKZb9DQJTTgoGhvzn5M6cr9Fq/UHzNP0uzoL8QWMsk
dK5Pv7lwDVgnyp+/+y6esMmSQb/S6H8wuC2evwx/fNYzPTK/7GDyCEmRnL+W
kgUc74UhvwbZZOHZ9Jq/yayAAzvFDr8fUde5aliZv4zn6gzOTfi+OMlJkvu7
l79Lmq/Z7e/gvlJBvGqMH5a/6LCrpLFUxL5sfNILSaOUv13Oth6C4Ka+hbfo
rAUnk78fXns93HCFvp7y/k3CqpG/W/IO/8gdYL64LRXvfi6Qv8SAq0g6hTK+
o9FWIHdkjb9BQh0ARpn+vdZHg2Lwa4q/zRkBAHTJwL0Ivq+kaXOHvz0PAAAA
FXa9OzTc5uJ6hL90AAAAAIAevb7WSds=
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwVlIk31AkAx8fQmEqlLHlFGLdUmrI5o5TZSUnpoSZW1lWyCS3LbLm11p0j
ass1MTXuyRDm+9spCk9lJnpMydDlKEeol9LW573P+/wHHx2fM4f9yCQSyfG7
P2ousjTYtk2CwDs2GmbOuoSGTe+C33oJVtEidR2NdAmFhpCey/ISFLvk+YaQ
dYkn3HL2okQMdltPhZyARoRlqUo6wsUwcebx1+rQCEp8ovPxGz1IvDiqHzSk
TcxM5LddffUYXTYp3IFwLWJI8RdjjtFjHNnrrsbZqUkwUtQFhwUPQR1J4s6P
rCNi5l6tEVh0g1ZUPejZok74cKTLVQq7YMpU+zsmVI1gCpQGF8mdaMxKqoi2
+4kYboord0x+gI1dhrautmsIPTmdlUnj7UigH0rX0lAm1C0VTusEteGE5INq
iJsSsVpCK90/cxe7Np76xCqiEvW1JyPOHBXByH5aFClQIBRj53a/lxKIk97e
SKLLEctMXN072EIoX2FZD69dwCo1urTXpRmro9+U53vOImKk8EAhqxHB063M
9zvewXkl/e7UrABmT91elBHjMLDssGCkC8BzGJSNHxxDb/pH3VmiAUx2sPee
+DfYZnXk8wGD26As5T302TuMHcUtwdHtfCzd2/JnlJYM1lR9WYU/H7P/8ukB
ckNw6Ju7L19ej0zO1orGZikYtl7WWxn18Dx6ZfJtbT+cytqrvN7UIbsyMZt0
5ylcQ/NzmwzrwPOUyTTJTxA3xpx6iVqMsJ5ptG0Qo8bnyz5lj1qYbGkjy7s+
xuBAFcd6qgbpqnrDL3d2Q8n1BCngYg3CvvZy7Jd2wqpLhZWtXYMAlbiJVZT7
ECelBkWfrcYSeb85zZ/vITXArc9IXIlx3RBzY18hxqlHIxmUSmR5XKUHKt/B
vpusdf5WPNBMFUXj2g3gOnm1JPx+C1JhqHl2Th2o77y9SktuIpksWFwUVyEg
/TeSqI+L6fnzERusuGjf4l8ytIyLyHMcz1z3Muj3BO75trMCX4zzrjygFSEh
NOi1Zlg5klIKPo7SCmCTqpwwxr+BY9IASmfqJcxybusI5jnIjOWIIsRp4OEY
4i040LshfmiwOwm+/d+Ou0SVIVZfNsDfEQOND2WfNVpKYapU0JwhF4EnSvsu
j34tgV71y86iW2eQajBp3mBXgu3Efkaxih8c7HMkcbHF4Co4hv9KZsGF3W3n
VF8EmzymC0V0EE0hKzwMO6/jnG1GUOb1XRC/vWDWuOkanJKfD77YT8eE9wyV
mXUVz8fErx7l64DS7yvrny3EP5V2grqxldA69LTplEcBjhiz01zPfhJadDCz
F5rzEePfptm7QiY8vKvlVKpWHjIm6d2eMfeEp9ni5czSHPyVa9b3aH25MFHw
lrfE8BK2l24dCOMnCq/NLB4Q3czChezNg+uPewsbN6lOnt+cCcuF2k/Tz+nC
0h437QjfNIRzNsQMuHxr7WPE+0wFpaDbRI5kyvyvlSqsLjsZloxg5e8zefdH
q/X2Z6+HoxJgT/qBduv/yMRRVQ==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{-0.3, -9.652710802472214},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  Frame->{True, False, False, True},
  FrameLabel->{{
     FormBox["\"\"", TraditionalForm], 
     FormBox["\"Probability of rescue\"", TraditionalForm]}, {
     FormBox[
     "\"Wildtype growth rate (\\!\\(\\*SubscriptBox[\\(m\\), \\(0\\)]\\))\"", 
      TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}},
  FrameTicks->{{None, {{-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {True, False}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{-0.3, -0.01}, {-9.652710802472214, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, {{-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.7438905262805643`*^9, 3.743890539944377*^9}, {
   3.743890684656702*^9, 3.743890702897759*^9}, {3.743890733938136*^9, 
   3.74389074381181*^9}, {3.7438907854073477`*^9, 3.7438908010253153`*^9}, 
   3.743890839214201*^9, {3.743890869967957*^9, 3.7438909018303747`*^9}, 
   3.743891046783721*^9, {3.745244198738392*^9, 3.745244213225876*^9}, 
   3.745245234514069*^9, 3.745258484342408*^9, 3.745496895499353*^9, 
   3.745587167030031*^9, 3.751032618984234*^9, 3.751568979224064*^9, {
   3.769188212221437*^9, 3.769188263343678*^9}, {3.769188304982161*^9, 
   3.769188418440537*^9}, {3.769188452545719*^9, 3.769188468535613*^9}, 
   3.769188521483775*^9, 3.7691885725303*^9, 3.769195448192039*^9, {
   3.7691954934034967`*^9, 3.769195508947473*^9}, 3.769195606282276*^9, 
   3.7691956470360737`*^9, 3.782251617397283*^9, 3.782251877230639*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2-step rescue (equation 6)", "Subsection",
 CellChangeTimes->{{3.743875419084559*^9, 3.743875419890864*^9}, {
   3.743875538887073*^9, 3.743875542295054*^9}, {3.74387568908377*^9, 
   3.743875689867249*^9}, {3.7456070638411617`*^9, 3.745607066773909*^9}, {
   3.769190837020444*^9, 3.7691908418433123`*^9}, {3.769432718796198*^9, 
   3.769432720203205*^9}, 3.771761680305745*^9}],

Cell["\<\
The rate of 2-step rescue from a single individual with growth rate m0 is the \
probability of a mutation to growth rate m, which does not establish, but \
then creates a second mutation that does\
\>", "Text",
 CellChangeTimes->{{3.769197567688176*^9, 3.769197671074234*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalLambda]2", "[", 
   RowBox[{
    RowBox[{"m0_", "?", "NumericQ"}], ",", "mmax_", ",", "\[Lambda]_", ",", 
    "n_", ",", "U_"}], "]"}], ":=", 
  RowBox[{"U", " ", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
      RowBox[{"prescuem", "[", 
       RowBox[{"m", ",", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"-", "\[Infinity]"}], ",", "mmax"}], "}"}]}], 
    "]"}]}]}]], "Input"],

Cell["\<\
Numerical comparison with probability of 1-step rescue\
\>", "Text",
 CellChangeTimes->{{3.7691975518654003`*^9, 3.769197561240035*^9}, {
  3.771274443041492*^9, 3.7712744442174377`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"N0", "=", 
   SuperscriptBox["10", "4"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "4"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m0", ",", 
      RowBox[{"prescue", "/.", 
       RowBox[{"p0", "\[Rule]", 
        RowBox[{"prescuem", "[", 
         RowBox[{"m0", ",", 
          RowBox[{"\[CapitalLambda]2", "[", 
           RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
           "]"}]}], "]"}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"m0", ",", 
      RowBox[{"-", "0.3"}], ",", 
      RowBox[{"-", "0.01"}], ",", "0.1"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"plot1", "=", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"plot2", "=", 
    RowBox[{"LogPlot", "[", 
     RowBox[{
      RowBox[{"PR1", "[", "m0", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"-", "0.3"}], ",", 
        RowBox[{"-", "0.01"}]}], "}"}], ",", 
      RowBox[{"Frame", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
      ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Wildtype growth rate (\!\(\*
StyleBox[SubscriptBox[\"m\", \"0\"],
FontSlant->\"Italic\"]\))\>\"", ",", "\"\<\>\"", ",", "\"\<\>\"", ",", 
         "\"\<Probability of rescue\>\""}], "}"}]}], ",", 
      RowBox[{"FrameTicks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
      ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", 
   RowBox[{"plot2", ",", "plot1"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "N0", ",", "U"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.751048508972703*^9, 3.7510485694070387`*^9}, {
   3.751048634293634*^9, 3.75104882644912*^9}, {3.751048860391396*^9, 
   3.751048875083177*^9}, {3.751048917508161*^9, 3.751048918223342*^9}, {
   3.751048962099057*^9, 3.751049283819117*^9}, {3.7510493164215813`*^9, 
   3.751049437840077*^9}, {3.751049527477024*^9, 3.75104954116768*^9}, {
   3.751049577823266*^9, 3.75104961948437*^9}, {3.751049649698894*^9, 
   3.751049650408462*^9}, {3.75104968346299*^9, 3.751049683556492*^9}, {
   3.751049970056074*^9, 3.75105004792001*^9}, {3.751050160966742*^9, 
   3.751050165054606*^9}, {3.751050214216941*^9, 3.751050257249219*^9}, {
   3.7510502911075373`*^9, 3.7510502912977543`*^9}, 3.751050324164885*^9, {
   3.751050418047228*^9, 3.751050436052682*^9}, {3.751050483535534*^9, 
   3.7510504842072573`*^9}, {3.751050570091111*^9, 3.751050571658628*^9}, {
   3.75105062341683*^9, 3.7510506993225107`*^9}, {3.751050734747732*^9, 
   3.751050796595666*^9}, {3.7510509008110847`*^9, 3.751050994634091*^9}, {
   3.751051058364265*^9, 3.751051069627078*^9}, {3.7510515584424667`*^9, 
   3.7510515657906218`*^9}, {3.7691970165645733`*^9, 3.76919716584517*^9}, {
   3.769197306669442*^9, 3.769197430406145*^9}, {3.7822519040964117`*^9, 
   3.7822519284353733`*^9}, {3.782251963298023*^9, 3.782251964591922*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw91Isz1AkAB/BfR+yhIm1J0q7Ooy65oms94i5da4XbaCoxThJ5dHVRKqvE
xp0wVIeMSazNI+/F2trd7y8bR6nLLrrKCSFaXWyrROnq5qbvzHe+8/kHvvSg
Q977vyAIgv2xn3ZDk72Fra0CLhaeZmwlnTRx6prZv0wBY4NjnJBmOqnZcLgj
R0OBAy6yxZn5dLKztJgzq5BDPX2WvnIHnYzKpCraouVoDZlY6iilkVqJZ738
r3Zg44y1x+oZU1I1lt2cN3Qfl9dQKrZUmZB92m6r+Fb3YVznyrY7YUwyU4yE
3sJ70NEJWN5uakTGTw4tFDLuYpXFmHbRGyoZxH+sa5h7B11eHbLsSkOSJdTr
nf3iNtYmLJtVcQzIAVFC8dbkVhz0/FLd+XY++dUc+vwkZQuavWhVmtAhjew1
I+kRzfCnbj2IES3SQGHG81DJUPanoUniFg1SUBMWc8i3CTN+fR4Z6llon5nc
/M9jEm7tbnHqzVPQWe2zq40jxf7JSebS1AksWLz+cRf7BrL0PdzC9z6D2OZ0
2FrVddwzt/sgoA8jjNX+JunCdUwp3PlzRgch44QsYnSLkDbAfZqTNoDDWYLC
jBgRnl8rYvlH9GN5NbFu1EiEo1H94sXb+xDzNNcz168Rm3gCTnt4D7zmr5eN
q4VoNPLocXZ+BAv7NgYzXQhfiaarwOIvdKW/WakmG2BsZsztZ3SiXJR+yX1P
AzyeGVmW7JODO2i+oOBVPdihwRuT+Pdh67Bj2tOiHkR1radL321sLBAfjG2p
g+z0T9OBK1vhSDHvLwmpg96sD7M/oxkuh9J2dGvVYdH5jOYxKxlcuyf/0CgW
QBJ161ySkgRzU4DjOqYAr2tUA9o1EmwraqkMeFaLlqdNU/pPRPhR18YsNbkW
+Vp+3pqBDfA5kv27yLIWDzi58R7rBUh4zhofRA2GNSTxhHE1qoPeuevvroHS
kB5nKixD76NKvuN4NdpGS+qth/nQ89lLhP5aDe4pWbp5YwEc7hj6nadVQ9fB
3jT7hzzIk1IjYn+pwsjxJ7olG7JgEzNBkxdUYshqT9Zyq0ykhu7stpJXwJ06
pIrXSoGS4nucqVWB5Eyfiq7oRLiX+RmHOJRDEG35QhXLQem2ADH352s4tsCb
YhoYDcqLwABeYRkCHXs2JUdGIjR9H9HUXYpeV6+Il2770GITUtinU4qbb6mM
uiBfmHcc2PLBuQTUJe2upVZscI9EDC+PKkbA19MiUuEKp1R97vO6q/B1khxZ
48SAml9PF77mY6+zbVxF3BqUYw8SGXz8Vsm6NleXhuCHH/zZJ4uQH5vCG3Qw
gMmromkTMQ/nlHlLctLnoFPPPWf0fSHG+h/x3j8Zl6ZavNzQ4FII6vjCm8rg
XqnrdxcVCWcK8HcDpSIwqk3K5tx12Sa4gnmriF235tVKRYfn7ba8nY9I7zvj
na+zpPKR0980Wl9G61TL0XetJ6RjgSoKKzMPBTTloPcSX6nWw+D+h+pcODt3
u1kL7KQrtj8Qhe++BMPGdWSInZ6U0cY6P3MjG1VB2sQi9Eq8vxeHp67IQsJV
giDvlUoiOXJdFu8iTPQ+nlFVlOSscKR8ruUFTH4kQftWclk169lUlgmdT46f
EDdaU1+eWpsB4r9cEfM6dtJigtP+N0F0MxODxiNSPpsirSoKi0r+bEe7nuGB
k9zP/hcU95Ot
      "]]}}, {{{}, {}, 
     {RGBColor[1, 0, 0], 
      LineBox[{{-0.3, -8.184320925454431}, {-0.19999999999999998`, \
-4.721350571048804}, {-0.09999999999999998, -1.792035234647006}}]}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{-0.3, -8.959595748822833},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  Frame->{True, False, False, True},
  FrameLabel->{{
     FormBox["\"\"", TraditionalForm], 
     FormBox["\"Probability of rescue\"", TraditionalForm]}, {
     FormBox[
     "\"Wildtype growth rate (\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \\\
\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\))\"", TraditionalForm], 
     FormBox["\"\"", TraditionalForm]}},
  FrameTicks->{{None, {{-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {True, False}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{-0.3, -0.01}, {-8.959595748822833, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, {{-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.751049096560864*^9, 3.7510491326626587`*^9}, 
   3.751049166905732*^9, {3.751049202628839*^9, 3.751049238037764*^9}, 
   3.7510492901716843`*^9, {3.7510493397901087`*^9, 3.751049367014514*^9}, {
   3.751049413216548*^9, 3.751049442351787*^9}, {3.7510495419828157`*^9, 
   3.751049547463525*^9}, 3.751049592562895*^9, 3.751049623891436*^9, 
   3.7510497113002377`*^9, {3.751049982123814*^9, 3.7510500528674593`*^9}, 
   3.751050172681757*^9, 3.751050221296638*^9, 3.751050266880004*^9, 
   3.751050301880926*^9, 3.7510503347969427`*^9, 3.751050454755025*^9, 
   3.751050563671138*^9, 3.751050610600458*^9, {3.7510506520887203`*^9, 
   3.751050700557796*^9}, {3.751050762171932*^9, 3.75105080023193*^9}, {
   3.751050943278652*^9, 3.751050968235813*^9}, 3.751051041974625*^9, 
   3.751051162901918*^9, 3.769197088271*^9, {3.769197314370112*^9, 
   3.769197334556209*^9}, 3.769197397301722*^9, 3.769197509218213*^9, 
   3.769966254185999*^9, 3.7822519213782873`*^9, 3.782251959535404*^9, 
   3.782251993317951*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["k-step rescue (equation 7)", "Subsection",
 CellChangeTimes->{{3.769190885612748*^9, 3.7691909101271353`*^9}, {
   3.7692001055100307`*^9, 3.769200107675544*^9}, {3.7694327564871283`*^9, 
   3.769432763757609*^9}, {3.769460943048814*^9, 3.7694609452538548`*^9}, 
   3.7710052514641113`*^9, 3.7717616819948053`*^9}],

Cell["\<\
One can carry on the logic used for 2-step rescue to get the probability of \
k-step rescue, e.g., 3-step is\
\>", "Text",
 CellChangeTimes->{{3.769197862496175*^9, 3.7691978852970343`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalLambda]3", "[", 
   RowBox[{
    RowBox[{"m0_", "?", "NumericQ"}], ",", "mmax_", ",", "\[Lambda]_", ",", 
    "n_", ",", "U_"}], "]"}], ":=", 
  RowBox[{"U", " ", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
      RowBox[{"prescuem", "[", 
       RowBox[{"m", ",", 
        RowBox[{"\[CapitalLambda]2", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"-", "\[Infinity]"}], ",", "mmax"}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.769197737004425*^9, 3.7691977452597437`*^9}}],

Cell["and 4-step is", "Text",
 CellChangeTimes->{{3.769199967833004*^9, 3.769199970247201*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalLambda]4", "[", 
   RowBox[{
    RowBox[{"m0_", "?", "NumericQ"}], ",", "mmax_", ",", "\[Lambda]_", ",", 
    "n_", ",", "U_"}], "]"}], ":=", 
  RowBox[{"U", " ", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
      RowBox[{"prescuem", "[", 
       RowBox[{"m", ",", 
        RowBox[{"\[CapitalLambda]3", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"-", "\[Infinity]"}], ",", "mmax"}], "}"}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.769199975352344*^9, 3.769199979341731*^9}}],

Cell["etc", "Text",
 CellChangeTimes->{{3.769200000097927*^9, 3.769200000472496*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plot probability as a function of wildtype growth rate (figure 3)\
\>", "Subsection",
 CellChangeTimes->{{3.7564892474960623`*^9, 3.756489252807234*^9}, 
   3.7606376392688437`*^9, {3.7642036999242487`*^9, 3.76420371369766*^9}, {
   3.769431834041813*^9, 3.769431845906336*^9}, {3.769431894299581*^9, 
   3.769431896986474*^9}, {3.769432022608979*^9, 3.76943202539149*^9}, {
   3.7694324961732264`*^9, 3.769432496341527*^9}, {3.7694327378288794`*^9, 
   3.769432739203771*^9}, {3.7694390881946793`*^9, 3.769439089784932*^9}, 
   3.7712459034631767`*^9}],

Cell[CellGroupData[{

Cell["Interpolation function", "Subsubsection",
 CellChangeTimes->{{3.782243947281623*^9, 3.782243950993575*^9}}],

Cell["\<\
The probability of rescue by k steps involves k integrals, and so with even \
small k (e.g, k=3) they are very slow to compute in their exact form. We can, \
however, combine an approximation (don\[CloseCurlyQuote]t integrate below \
mmin) with interpolation functions to greatly speed things up (with some loss \
of accuaracy)\
\>", "Text",
 CellChangeTimes->{{3.771000901605348*^9, 3.771000917677836*^9}, {
  3.7710034684445353`*^9, 3.771003501426825*^9}, {3.77100386989631*^9, 
  3.771003887694422*^9}, {3.771004038362863*^9, 3.771004040562957*^9}, {
  3.771246003260221*^9, 3.77124604165723*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mTempmin", "=", 
   RowBox[{"-", "0.4"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mTempmax", "=", 
   RowBox[{"-", "0.01"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"step", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mmin", "=", "mTempmin"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "\[CapitalLambda]1Interpolated", ",", "\[CapitalLambda]2Interpolated", ",",
     "\[CapitalLambda]3Interpolated", ",", "\[CapitalLambda]4Interpolated"}], 
   "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalLambda]1Interpolated", "[", 
    RowBox[{"m0_", ",", "mmax_", ",", "\[Lambda]_", ",", "n_", ",", "U_"}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{"\[CapitalLambda]1Interpolated", "[", 
     RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], "]"}],
     "=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f", "=", 
        RowBox[{"Interpolation", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"mTemp", ",", 
             RowBox[{"U", " ", 
              RowBox[{"NIntegrate", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"fm", "[", 
                  RowBox[{
                  "m", ",", "mTemp", ",", "mmax", ",", "\[Lambda]", ",", 
                   "n"}], "]"}], 
                 RowBox[{"pest", "[", "m", "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"m", ",", "0", ",", "mmax"}], "}"}], ",", 
                RowBox[{"Method", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"Automatic", ",", 
                   RowBox[{"\"\<SymbolicProcessing\>\"", "\[Rule]", "0"}]}], 
                  "}"}]}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"mTemp", ",", "mTempmin", ",", "mTempmax", ",", "step"}], 
            "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"f", "[", "m0", "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalLambda]2Interpolated", "[", 
    RowBox[{"m0_", ",", "mmax_", ",", "\[Lambda]_", ",", "n_", ",", "U_"}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{"\[CapitalLambda]2Interpolated", "[", 
     RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], "]"}],
     "=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f", "=", 
        RowBox[{"Interpolation", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"mTemp", ",", 
             RowBox[{"U", " ", 
              RowBox[{"NIntegrate", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"fm", "[", 
                  RowBox[{
                  "m", ",", "mTemp", ",", "mmax", ",", "\[Lambda]", ",", 
                   "n"}], "]"}], 
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
                 RowBox[{"prescuem", "[", 
                  RowBox[{"m", ",", 
                   RowBox[{"\[CapitalLambda]1Interpolated", "[", 
                    RowBox[{
                    "m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
                    "]"}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"m", ",", "mmin", ",", "mmax"}], "}"}], ",", 
                RowBox[{"Method", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"Automatic", ",", 
                   RowBox[{"\"\<SymbolicProcessing\>\"", "\[Rule]", "0"}]}], 
                  "}"}]}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"mTemp", ",", "mTempmin", ",", "mTempmax", ",", "step"}], 
            "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"f", "[", "m0", "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalLambda]3Interpolated", "[", 
    RowBox[{"m0_", ",", "mmax_", ",", "\[Lambda]_", ",", "n_", ",", "U_"}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{"\[CapitalLambda]3Interpolated", "[", 
     RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], "]"}],
     "=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f", "=", 
        RowBox[{"Interpolation", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"mTemp", ",", 
             RowBox[{"U", " ", 
              RowBox[{"NIntegrate", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"fm", "[", 
                  RowBox[{
                  "m", ",", "mTemp", ",", "mmax", ",", "\[Lambda]", ",", 
                   "n"}], "]"}], 
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
                 RowBox[{"prescuem", "[", 
                  RowBox[{"m", ",", 
                   RowBox[{"\[CapitalLambda]2Interpolated", "[", 
                    RowBox[{
                    "m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
                    "]"}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"m", ",", "mmin", ",", "mmax"}], "}"}], ",", 
                RowBox[{"Method", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"Automatic", ",", 
                   RowBox[{"\"\<SymbolicProcessing\>\"", "\[Rule]", "0"}]}], 
                  "}"}]}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"mTemp", ",", "mTempmin", ",", "mTempmax", ",", "step"}], 
            "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"f", "[", "m0", "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalLambda]4Interpolated", "[", 
   RowBox[{"m0_", ",", "mmax_", ",", "\[Lambda]_", ",", "n_", ",", "U_"}], 
   "]"}], ":=", 
  RowBox[{
   RowBox[{"\[CapitalLambda]4Interpolated", "[", 
    RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], "]"}], 
   "=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"f", "=", 
       RowBox[{"Interpolation", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"mTemp", ",", 
            RowBox[{"U", " ", 
             RowBox[{"NIntegrate", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"fm", "[", 
                 RowBox[{
                 "m", ",", "mTemp", ",", "mmax", ",", "\[Lambda]", ",", "n"}],
                  "]"}], 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
                RowBox[{"prescuem", "[", 
                 RowBox[{"m", ",", 
                  RowBox[{"\[CapitalLambda]3Interpolated", "[", 
                   RowBox[{
                   "m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
                   "]"}]}], "]"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"m", ",", "mmin", ",", "mmax"}], "}"}], ",", 
               RowBox[{"Method", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{"Automatic", ",", 
                  RowBox[{"\"\<SymbolicProcessing\>\"", "\[Rule]", "0"}]}], 
                 "}"}]}]}], "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"mTemp", ",", "mTempmin", ",", "mTempmax", ",", "step"}], 
           "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"f", "[", "m0", "]"}]}]}], "\[IndentingNewLine]", 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.7710006339642363`*^9, 3.771000651261798*^9}, {
   3.7710006849732113`*^9, 3.771000807511991*^9}, 3.7710009000604353`*^9, {
   3.77100102319551*^9, 3.7710010233705263`*^9}, {3.7710011165927973`*^9, 
   3.7710011198500853`*^9}, {3.771001353744179*^9, 3.771001378704712*^9}, {
   3.771001501438855*^9, 3.7710015427566843`*^9}, {3.771001609200037*^9, 
   3.7710016233596582`*^9}, {3.7710029708224497`*^9, 3.771002979497155*^9}, 
   3.771003069824634*^9, 3.771003100981645*^9, {3.77100313615471*^9, 
   3.771003143787877*^9}, {3.771003216851419*^9, 3.771003224224443*^9}, {
   3.771003383067137*^9, 3.771003395942892*^9}, 3.7710035538762283`*^9, 
   3.771003743292034*^9, {3.7712440458668127`*^9, 3.771244056209272*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical data", "Subsubsection",
 CellChangeTimes->{{3.782243962170609*^9, 3.782243970146096*^9}, 
   3.782244119422256*^9}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"N0", "=", 
    SuperscriptBox["10", "4"]}], ";", "\[IndentingNewLine]", 
   RowBox[{"mmax", "=", "0.5"}], ";", "\[IndentingNewLine]", 
   RowBox[{"\[Lambda]", "=", 
    RowBox[{"2", 
     RowBox[{"Es", "/", "n"}]}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"Es", "=", "0.01"}], ";", "\[IndentingNewLine]", 
   RowBox[{"n", "=", "4"}], ";", "\[IndentingNewLine]", 
   RowBox[{"U", "=", 
    RowBox[{"2", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}]}], ";", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"m0min", "=", "mTempmin"}], ";", "\[IndentingNewLine]", 
   RowBox[{"m0max", "=", "mTempmax"}], ";", "\[IndentingNewLine]", 
   RowBox[{"mstep", "=", "step"}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate4", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"\[CapitalLambda]4Interpolated", "[", 
         RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate3", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"\[CapitalLambda]3Interpolated", "[", 
         RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate2", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"\[CapitalLambda]2Interpolated", "[", 
         RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate1", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"\[CapitalLambda]1Interpolated", "[", 
         RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"m0list", "=", 
    RowBox[{"Table", "[", 
     RowBox[{"m0", ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"theory", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m0list", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{
              RowBox[{"m0list", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"rate1", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m0list", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{
              RowBox[{"m0list", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"rate2", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m0list", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{
              RowBox[{"m0list", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"rate3", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m0list", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{
              RowBox[{"m0list", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"rate4", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}]}], 
     "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"alltheory", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"m0list", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"prescue", "/.", 
         RowBox[{"p0", "\[Rule]", 
          RowBox[{"prescuem", "[", 
           RowBox[{
            RowBox[{"m0list", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"rate1", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate2", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate3", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate4", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "]"}]}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}]}], ";", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", 
    RowBox[{
    "N0", ",", "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", 
     "m0min", ",", "m0max"}], "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.771243438404381*^9, 3.771243505591201*^9}, {
   3.771243660674692*^9, 3.771243770343318*^9}, {3.7712438051594973`*^9, 
   3.771243806769825*^9}, {3.77124384246271*^9, 3.7712439832452*^9}, {
   3.771244074547236*^9, 3.771244075614129*^9}, {3.771244170126183*^9, 
   3.771244240128414*^9}, {3.771244491552649*^9, 3.771244539467946*^9}, {
   3.771244637848792*^9, 3.771244771807975*^9}, {3.77124482635817*^9, 
   3.771245429892724*^9}, 3.771246073841148*^9, 3.771246637425001*^9, {
   3.771252282261911*^9, 3.771252288712202*^9}, 3.771254690716058*^9, {
   3.771254724632944*^9, 3.771254752430646*^9}, 3.77125504889705*^9, {
   3.7715446486731167`*^9, 3.771544649294244*^9}, {3.782234584891123*^9, 
   3.7822346390847397`*^9}, {3.782234732642061*^9, 3.7822347636693287`*^9}, {
   3.78223479425648*^9, 3.7822347970725822`*^9}, {3.782234919595743*^9, 
   3.782235065283053*^9}, {3.782235166298839*^9, 3.78223519538727*^9}, {
   3.7822352881132936`*^9, 3.7822352951175117`*^9}, {3.782235335234043*^9, 
   3.7822353377596684`*^9}, {3.782235496732168*^9, 3.7822355628278933`*^9}, {
   3.7822356043396177`*^9, 3.78223562461322*^9}, {3.7822359261903057`*^9, 
   3.782235929907751*^9}, {3.782235969286677*^9, 3.782236093293007*^9}, {
   3.782236124427341*^9, 3.782236163439129*^9}, {3.782236242968176*^9, 
   3.78223627257775*^9}, {3.7822363121939707`*^9, 3.782236329090472*^9}, {
   3.782236361611968*^9, 3.7822364008620358`*^9}, {3.7822364623523283`*^9, 
   3.782236523610194*^9}, {3.7822365640112658`*^9, 3.782236676208467*^9}, {
   3.78223672330368*^9, 3.7822367856352873`*^9}, {3.782236860747128*^9, 
   3.7822370287832003`*^9}, {3.782237076093791*^9, 3.7822370930134077`*^9}, {
   3.7822371354078617`*^9, 3.782237144380975*^9}, {3.7822371817988567`*^9, 
   3.782237186287504*^9}, {3.7822374864599247`*^9, 3.7822377028467484`*^9}, {
   3.782238097767778*^9, 3.782238119564167*^9}, {3.78223942976235*^9, 
   3.7822396342799883`*^9}, 3.782239876069955*^9, {3.782240230407597*^9, 
   3.782240269444977*^9}, {3.782240326799062*^9, 3.782240338972478*^9}, 
   3.78224041065661*^9, {3.782243997493153*^9, 3.7822440072288113`*^9}, 
   3.782252402877418*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"theory", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "5.472398814099222`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39`"}], ",", "9.745688406281872`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38`"}], ",", "1.7238895513305152`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37`"}], ",", "3.0285772651961196`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36000000000000004`"}], ",", 
         "5.2841014319682245`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "9.155420059081543`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34`"}], ",", "0.000015751880195202794`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33`"}], ",", "0.00002690955788409166`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32`"}], ",", "0.000045643083578017496`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31000000000000005`"}], ",", 
         "0.0000768622102641503`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", 
         "0.00012849810996373723`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29000000000000004`"}], ",", 
         "0.0002132574731799064`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28`"}], ",", "0.0003513291377449379`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27`"}], ",", "0.000574520974723769`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26`"}], ",", "0.0009325213318174264`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.0015022797840921198`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24000000000000002`"}], ",", 
         "0.0024019086800984857`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23`"}], ",", "0.0038110379258926574`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22000000000000003`"}], ",", "0.00600020901304088`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21000000000000002`"}], ",", "0.00937261491044139`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.014522096798011974`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19000000000000003`"}], ",", 
         "0.022311337733202485`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18000000000000002`"}], ",", "0.03397263148001661`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17`"}], ",", "0.0512283883233019`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16000000000000003`"}], ",", "0.07641581098977057`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", "0.11257347217569635`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14`"}], ",", "0.16339795924448708`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13`"}], ",", "0.23289952993154328`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12`"}], ",", "0.3244893834485655`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11000000000000004`"}], ",", "0.43919411790398366`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10000000000000003`"}], ",", "0.5729341370203966`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09000000000000002`"}], ",", "0.7137213876566558`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08000000000000002`"}], ",", "0.8414602539868381`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07`"}], ",", "0.9344415307620567`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06`"}], ",", "0.9829032755970813`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", "0.9979187459679042`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.040000000000000036`"}], ",", "0.9999341480370483`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.030000000000000027`"}], ",", "0.9999998505645212`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.020000000000000018`"}], ",", "0.9999999999991431`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.010000000000000009`"}], ",", "1.`"}], "}"}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "7.1817194564616216`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39`"}], ",", "0.000010382868435687698`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38`"}], ",", "0.000015004899198478583`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37`"}], ",", "0.000021674932411452907`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36000000000000004`"}], ",", 
         "0.000031295722740964926`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "0.00004516336475557381`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34`"}], ",", "0.00006513527103491068`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33`"}], ",", "0.00009386674884392932`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32`"}], ",", "0.00013514257904490012`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31000000000000005`"}], ",", 
         "0.0001943394640103735`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", 
         "0.00027906144855771586`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29000000000000004`"}], ",", 
         "0.00040002244449899305`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28`"}], ",", "0.0005722318522486392`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27`"}], ",", "0.0008166042269467377`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26`"}], ",", "0.0011621019720312598`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.0016485639043937184`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24000000000000002`"}], ",", 
         "0.002330394186973561`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23`"}], ",", "0.0032813120522319217`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22000000000000003`"}], ",", 
         "0.0046003825714453495`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21000000000000002`"}], ",", 
         "0.006419557828723499`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.008912948912746632`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19000000000000003`"}], ",", 
         "0.012308013245967753`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18000000000000002`"}], ",", "0.01689876878901897`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17`"}], ",", "0.02306102686962941`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16000000000000003`"}], ",", 
         "0.031269462419949656`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", 
         "0.042116115688766054`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14`"}], ",", "0.05632965853148175`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13`"}], ",", "0.07479449506069946`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12`"}], ",", "0.09856854888921651`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11000000000000004`"}], ",", "0.12889844527072303`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10000000000000003`"}], ",", "0.1672306176682965`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09000000000000002`"}], ",", "0.21521607762716344`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08000000000000002`"}], ",", "0.2747032194313106`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07`"}], ",", "0.3477011299288638`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06`"}], ",", "0.4362577296013713`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", "0.5420788502184701`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.040000000000000036`"}], ",", "0.6653477290582192`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.030000000000000027`"}], ",", "0.8010818232849237`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.020000000000000018`"}], ",", "0.9286233811012167`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.010000000000000009`"}], ",", "0.9962496646879948`"}],
         "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "2.672518644497579`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39`"}], ",", "3.6200066483305093`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38`"}], ",", "4.9024286813414975`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37`"}], ",", "6.639033992561494`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36000000000000004`"}], ",", 
         "8.99229424278225`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "0.000012183830842893428`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34`"}], ",", "0.000016516674993138913`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33`"}], ",", "0.00002240514549411987`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32`"}], ",", "0.000030416485379602953`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31000000000000005`"}], ",", 
         "0.000041327352556463914`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", 
         "0.00005620069935863281`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29000000000000004`"}], ",", 
         "0.00007648968361839703`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28`"}], ",", "0.0001041772194614321`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27`"}], ",", "0.00014196192976223543`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26`"}], ",", "0.00019350379587734778`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.0002637455775598152`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24000000000000002`"}], ",", 
         "0.0003593290092440693`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23`"}], ",", "0.0004891277868906974`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22000000000000003`"}], ",", 
         "0.0006649222935298793`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21000000000000002`"}], ",", 
         "0.0009022438378168962`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.0012214190541605108`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19000000000000003`"}], ",", 
         "0.0016488487049626244`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18000000000000002`"}], ",", 
         "0.0022185608705778126`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17`"}], ",", "0.0029740895246452848`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16000000000000003`"}], ",", 
         "0.003970751527472172`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", 
         "0.0052784386334274735`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14`"}], ",", "0.006985125056896413`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13`"}], ",", "0.009201449505447323`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12`"}], ",", "0.012067026227695399`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11000000000000004`"}], ",", 
         "0.015759693621743676`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10000000000000003`"}], ",", 
         "0.020509966391728862`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09000000000000002`"}], ",", "0.02662504581244618`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08000000000000002`"}], ",", "0.03453108060938248`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07`"}], ",", "0.04485200223554198`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06`"}], ",", "0.0585665300648599`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", "0.0773474840786541`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.040000000000000036`"}], ",", 
         "0.10438028623999529`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.030000000000000027`"}], ",", 
         "0.14667096966766024`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.020000000000000018`"}], ",", "0.2233073280524227`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.010000000000000009`"}], ",", "0.4098900908454398`"}],
         "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "3.665400664099039`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39`"}], ",", "4.882948413387211`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38`"}], ",", "6.507825516255394`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37`"}], ",", "8.679175866888045`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36000000000000004`"}], ",", 
         "1.1585392625246271`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "1.548213704460899`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34`"}], ",", "2.071738417153135`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33`"}], ",", "2.776581790708832`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32`"}], ",", "3.727611290194055`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31000000000000005`"}], ",", 
         "5.013589215119296`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", 
         "6.756030736299046`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29000000000000004`"}], ",", 
         "9.12124881535803`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28`"}], ",", "0.00001233658455390696`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27`"}], ",", "0.000016712145389896627`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26`"}], ",", "0.00002266963795427568`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.000030780242171069006`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24000000000000002`"}], ",", 
         "0.00004181381972367948`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23`"}], ",", "0.000056802136495281985`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22000000000000003`"}], ",", 
         "0.00007711911056884624`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21000000000000002`"}], ",", 
         "0.00010458146610448082`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.0001415735100674942`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19000000000000003`"}], ",", 
         "0.00019120021529694942`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18000000000000002`"}], ",", 
         "0.0002574735404686779`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17`"}], ",", "0.00034553832838446485`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16000000000000003`"}], ",", 
         "0.0004619470399811476`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", 
         "0.0006149981944676419`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14`"}], ",", "0.0008151642974213447`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13`"}], ",", "0.0010756555359718867`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12`"}], ",", "0.0014132038091301258`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11000000000000004`"}], ",", 
         "0.0018492239194836113`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10000000000000003`"}], ",", 
         "0.002411647781310755`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09000000000000002`"}], ",", 
         "0.003138005818001832`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08000000000000002`"}], ",", 
         "0.004080917925158634`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07`"}], ",", "0.005318491045821605`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06`"}], ",", "0.006975434272220693`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", 
         "0.009269923451119766`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.040000000000000036`"}], ",", 
         "0.012631023980203326`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.030000000000000027`"}], ",", 
         "0.01804961542287531`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.020000000000000018`"}], ",", "0.0284671089107692`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.010000000000000009`"}], ",", 
         "0.05823795851907776`"}], "}"}]}], "}"}]}], "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.7822523768220987`*^9, 3.782252383120124*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"alltheory", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.4`"}], ",", "0.000010767989638504893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.39`"}], ",", "0.000015465680252679803`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.38`"}], ",", "0.000022281877958607588`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.37`"}], ",", "0.00003221020658283891`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.36000000000000004`"}], ",", 
       "0.00004673011156652862`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.35000000000000003`"}], ",", 
       "0.00006804965109896699`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.34`"}], ",", "0.00009947299961354794`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.33`"}], ",", "0.0001459524027258574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.32`"}], ",", "0.00021491729975098295`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.31000000000000005`"}], ",", 
       "0.00031751489398534893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.30000000000000004`"}], ",", "0.0004704543728014654`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.29000000000000004`"}], ",", "0.0006987523028609832`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.28`"}], ",", "0.0010397647754660788`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.27`"}], ",", "0.0015491068347829318`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.26`"}], ",", "0.0023092555158806816`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.25`"}], ",", "0.0034419561736643844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.24000000000000002`"}], ",", "0.005125934145003619`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.23`"}], ",", "0.007621874910163862`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.22000000000000003`"}], ",", "0.011307117362613917`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.21000000000000002`"}], ",", "0.01672286182842886`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.2`"}], ",", "0.024636589665609887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.19000000000000003`"}], ",", "0.03612111665412221`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.18000000000000002`"}], ",", "0.0526478810505413`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.17`"}], ",", "0.07618321541025108`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.16000000000000003`"}], ",", "0.10925842311524103`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.15000000000000002`"}], ",", "0.154951959045035`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.14`"}], ",", "0.21667029213726385`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.13`"}], ",", "0.29754827077524637`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.12`"}], ",", "0.39924782631433087`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.11000000000000004`"}], ",", "0.5200288215021587`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.10000000000000003`"}], ",", "0.6524246688522214`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.09000000000000002`"}], ",", "0.7819169338181124`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.08000000000000002`"}], ",", "0.8893420776854711`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.07`"}], ",", "0.9592948833994817`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.06`"}], ",", "0.9909501188644341`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.04999999999999999`"}], ",", "0.9991194054587093`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.040000000000000036`"}], ",", "0.9999799413255674`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.030000000000000027`"}], ",", "0.999999972757273`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.020000000000000018`"}], ",", "0.9999999999999342`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.010000000000000009`"}], ",", "1.`"}], "}"}]}], "}"}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.782252389645158*^9, 3.782252394760631*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure 3", "Subsubsection",
 CellChangeTimes->{{3.782243980947497*^9, 3.782243981402378*^9}, {
  3.784903380347172*^9, 3.784903381137018*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"N0", "=", 
   SuperscriptBox["10", "4"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"U", "=", 
    RowBox[{"2", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat1", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "datadir", "<>", 
     "\"\<prescue_poisson_N10000_n4_U0.00200_Es0.01_mmax0.50_mutmax10_\
nreps1000.csv\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat2", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "datadir", "<>", 
     "\"\<prescue_poisson_N10000_n4_U0.00200_Es0.01_mmax0.50_mutmax10_\
nreps10000.csv\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat3", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "datadir", "<>", 
     "\"\<prescue_poisson_N10000_n4_U0.00200_Es0.01_mmax0.50_mutmax10_\
nreps100000.csv\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"alldat", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dat1", ",", "dat2", ",", "dat3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alldat", "=", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{
        RowBox[{"Select", "[", 
         RowBox[{"alldat", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
            RowBox[{"-", "0.1"}]}], "&"}]}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
          RowBox[{"-", "0.2"}]}], "&"}]}], "]"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[NotEqual]", 
        RowBox[{"-", "0.3"}]}], "&"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "datadir", "<>", 
     "\"\<int_dfe_poisson_N10000_n4_U0.00200_Es0.01_mmax0.50_mwt-0.10_\
mutmax10_nreps100000.csv\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nreps", "=", "100000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"onestep", "=", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"dat", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], "&"}]}], "]"}], 
     "]"}], "/", "nreps"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"twostep", "=", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"dat", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
     "]"}], "/", "nreps"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"threestep", "=", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"dat", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "3"}], "&"}]}], "]"}], 
     "]"}], "/", "nreps"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fourstep", "=", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"dat", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "4"}], "&"}]}], "]"}], 
     "]"}], "/", "nreps"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"total", "=", 
   RowBox[{"onestep", "+", "twostep", "+", "threestep", "+", "fourstep"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k1", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "onestep", ",", "twostep", ",", "threestep", ",", "fourstep", ",", 
      "total"}], "}"}], "//", "N"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.1"}], ",", 
       RowBox[{"k1", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "k1", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"k1plot", "=", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotMarkers", "\[Rule]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"Disk", "[", "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "8"}]}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "datadir", "<>", 
     "\"\<int_dfe_poisson_N10000_n4_U0.00200_Es0.01_mmax0.50_mwt-0.20_\
mutmax10_nreps100000.csv\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nreps", "=", "100000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"onestep", "=", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"dat", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], "&"}]}], "]"}], 
     "]"}], "/", "nreps"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"twostep", "=", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"dat", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
     "]"}], "/", "nreps"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"threestep", "=", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"dat", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "3"}], "&"}]}], "]"}], 
     "]"}], "/", "nreps"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fourstep", "=", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"dat", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "4"}], "&"}]}], "]"}], 
     "]"}], "/", "nreps"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"total", "=", 
   RowBox[{"onestep", "+", "twostep", "+", "threestep", "+", "fourstep"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k2", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "onestep", ",", "twostep", ",", "threestep", ",", "fourstep", ",", 
      "total"}], "}"}], "//", "N"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.2"}], ",", 
       RowBox[{"k2", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "k2", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"k2plot", "=", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotMarkers", "\[Rule]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"Disk", "[", "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "8"}]}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}]}], "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "datadir", "<>", 
     "\"\<int_dfe_poisson_N10000_n4_U0.00200_Es0.01_mmax0.50_mwt-0.30_\
mutmax10_nreps1000000.csv\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nreps", "=", "1000000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"onestep", "=", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"dat", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], "&"}]}], "]"}], 
     "]"}], "/", "nreps"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"twostep", "=", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"dat", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
     "]"}], "/", "nreps"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"threestep", "=", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"dat", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "3"}], "&"}]}], "]"}], 
     "]"}], "/", "nreps"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fourstep", "=", 
   RowBox[{
    RowBox[{"Length", "[", 
     RowBox[{"Select", "[", 
      RowBox[{"dat", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "4"}], "&"}]}], "]"}], 
     "]"}], "/", "nreps"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"total", "=", 
   RowBox[{"onestep", "+", "twostep", "+", "threestep", "+", "fourstep"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k3", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "onestep", ",", "twostep", ",", "threestep", ",", "fourstep", ",", 
      "total"}], "}"}], "//", "N"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.3"}], ",", 
       RowBox[{"k3", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "k3", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"k3plot", "=", "\[IndentingNewLine]", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"%", ",", "\[IndentingNewLine]", 
      RowBox[{"PlotMarkers", "\[Rule]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"Disk", "[", "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "8"}]}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
     RowBox[{"theory", ",", "\[IndentingNewLine]", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.4"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"5", "*", 
            SuperscriptBox["10", 
             RowBox[{"-", "7"}]]}], ",", "1"}], "}"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Frame", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Wildtype growth rate\>\"", ",", ",", ",", 
         "\"\<Probability of rescue\>\""}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"FrameTicks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{
            "\"\<1-step\>\"", ",", "\"\<2-step\>\"", ",", "\"\<3-step\>\"", 
             ",", "\"\<4-step\>\""}], "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{"0.85", ",", "0.23"}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"alltheory", ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Thick"}], "}"}]}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", "\"\<total\>\"", "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{"0.56", ",", "0.23"}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"alldat", ",", 
      RowBox[{"PlotMarkers", "\[Rule]", 
       RowBox[{"Graphics", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Black", ",", 
           RowBox[{"Disk", "[", "]"}]}], "}"}], ",", 
         RowBox[{"ImageSize", "\[Rule]", "8"}]}], "]"}]}]}], "]"}], ",", 
    "\[IndentingNewLine]", "k1plot", ",", "k2plot", ",", "k3plot", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Epilog", "->", 
     RowBox[{"braceLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.125"}], ",", 
           RowBox[{"Log", "@", 
            SuperscriptBox["10", 
             RowBox[{"-", "6"}]]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.125"}], ",", 
           RowBox[{"Log", "@", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              SuperscriptBox["10", 
               RowBox[{"-", "4"}]]}], ")"}]}]}], "}"}]}], "}"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<\>\"", ",", "Larger"}], "]"}]}], "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"ImageSize", "\[Rule]", "350"}]}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"figdir", "<>", "\"\<Figure3.eps\>\""}], ",", "%"}], "]"}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "N0", ",", "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", 
   "m0min", ",", "m0max"}], "]"}]}], "Input",
 CellChangeTimes->{{3.782244022588401*^9, 3.782244023763198*^9}, {
  3.782244059885046*^9, 3.782244060597282*^9}, {3.782252413322342*^9, 
  3.7822524179168377`*^9}, {3.784900812682591*^9, 3.7849008207432547`*^9}, {
  3.7849033407361097`*^9, 3.784903348207075*^9}}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwtkF1I01EYxv9pZKhNVzOWoc6PdE7TUOdVrcKLZRTojMASpKlFBWrQRO3z
QgkinUuTirKLCdaFk2W2abXnTdPlSnHOua0LaX2wygSz1AiLdv7bA4fD4Zzz
e5/nSVTXqKpCOI6T+hfb795h8iD956pJPptJK9Iy7fCyGyM1Y2HPDBmkMsc3
zxe7kd8ywZmuy8ig9DaKDC4sVxj1OWfSKcKlr90T7kKW71d//mEpnTrJNIu8
gQLnm9w0GllmQCeWFJ3lf+JSKcFPM8c7cb7eqrFF7KALIkacwZVm4fuCv8nk
5nEO3P/RKa5eSqK8XCYHsha9+UXzidQ2zIDT6PMpfi/6JPS9mBm0Q90X1do7
lUAHmD2lHT0dsf1RnjjqZjj9FB6rNzhFX7cTx2sKC5vUu21cLA2yeOZJVBZa
S/ZKxHSOPa+dQLnePnRNuZVkrA7pW/hqDzZY6kT0geG9Nkw+fWcPN2ymQH/j
mEnZWNWzEE0lfF+voR1XZXjOCoL9WLHr9NFPFkFEsI9R7Ouqb28ZDaOLfP5X
yBq9HKq7uT6YdwRzW6Ty5IZ1wXwvodO0K3aurSGQh9CVI7vRWLQKfpzZgm3a
mDlByBIyeb/PEZ1Wqrt05Bvu8f4GETqkybZPexHJ+zHBkf3l88AtJwLznyCm
QptySDyGwDwjRMqOBzhuDPIN+KeTf2x9qMNtnvcIK0mFkv3CE7jK/+9GpLm0
rKpACOLfd+FYXWV9m6DJErjvQJ7AX3tq9YvAuQlcUP8Bo3NLMw==
         "]]}, 
       {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJwtkF9Ik1EYxtcKpC2W01nJUnPZmhFp2rKbNVqExhi0CRERYemqm8pZFKkX
I0wRJ2qWbZGZzBGlzYqB3yj2vk1tFpttU9saBG1+JNjoj5sjaBd5vn0PHA6H
c87vfZ6n+PxVnZ7L4XBka4vsDy1EX2CQjmwueLkbU7IzPe7VMKSs7W3nElLU
UYV3fmjDoLrmUEQOStFeHW0W2UNwu2P0ial5F/JD1kYFLwQJbdzS7CrBixeI
PkNyZtE9xi3ByVUCXIA/3KZgefVOLFqjUYULEJ7P8+WbJNgiIsR5kAsFQmOg
GMMMbg78iesu49ZiPFBJNAfBulNdyrM7sNdNgEGYUlVxp9RFGNcSgwFYCX4/
Jv1agDXEXnUAbgrSpesM23GE4Kx+OKzRWxxZYuQw8sMJm2LIOpyPThKPmoVU
3/1UhXIbGsjzRh9U8YbfeL5twT2kDpkXLtn61e/b8zBG8NGPIBdXnu7bL8JM
fx8gEXMqO6M5WMv0NQPjHXQL/4GQ7ccD5fEb+iZdNtvHNMR6636VygTYyuSf
ghVbja6b4rN5J8EtftpgP7mRzfcOBiSfNCXrs9g8CD4v39Tq2oDMOMoFxw23
6EOdXNzL+H0L6aDd463n4CPGnxPkZZO0fDANmxg/E0DfpZLL/X8hM98BDS9+
HlWPJSEz7xVcHqpVZS/9hgzfDpKJ7iVD1zKYGd4z8ONzns68CEbm/wgcGTXv
G8iNADLvH0NBRa5jvN7L3t+Dfz20P2f1NXtug7JpTXLWcwX+AxnkWJE=
         "]]}, 
       {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJwtkGtI01EYxrdRIqtV6qjZ2tbMXcwCwUV+yKhUNCRCqzWjICxXYjDFGJub
4IeK6kMXZ+h0WeaIWTTK1P23yvdNu9jQpblrtWxGLMz6EK0LRuX5+3/gcDic
c37v8zzSSl15FYfFYinnF9nbrUQRaJWEk7bcysIfyoMXhxJh6HnnuhFdloXl
lPj057IwHIr6q631SnQWxxr4zhC08qd694cVuCTUXZvPDYErT7ONla/AY1qi
IBzvv7zZ3CXH4QQBBmBvjUjRt1iOknkaJQ7AdIXMcaVahiY+IfqBvS+XShnL
xDCNmwQjW/dVnJOJqlyiSfBtdXg9zevw0hABvgJrmy0+8z0DZ8uIwQlIPQOB
R+oMLCH2iifAd3KgpZSSop3gusfBZOVb+tOlyKI1DhV3d2yUm9aim8SjfGB7
bddec0uwjjyvHQONLic52CjG9aQO5ShYVEFHTYEIpwk+5gXO4evGGHcNLvT3
Aq6WaHd5/KtxD93XCDxTP1Dru9KZfp7D25aG6IU6AdPHUzAk4vG6olVopvM/
gaYiG9UoWsnkHYbmjp0f5n7zmXyPwVN/ziJ8k8bkQXBtKjgxg6lIj6MGwSQs
FJTeTsENtN+HYNcPyz5ZV6CN9ueGfwZZZLtgOS6l/bjgW6G3KsLmMfP7oP2m
sOPAFy4z7x6opszvRwLJDN8JVXf0lUfuJ2EbzeuBXg3bAMZF2ET/twNvzpD9
MY2DSL/vhE6eJO/swF9YuG+BX6ODAH9+MudTcPTlbm72+Vn4D6fQUYY=
         "]]}, 
       {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQzfzn41b7Fzf22y+uP5nHonsgaIdc6+vAG/tXvXhU
UVOrc2Cd+8MqkXXX92+YMUlA6JX2Ae7riwtsua7vN99/i8coTPtAehoIXNt/
cEHEqX0HtQ4c/qoR03/o6v4M5VmBs3W0DsgDTdshd3X/tY40nbXTNA9Ui4BM
vLI//Lqv373/GgdugI27vF9qyYxZchkaB0yMQeDy/pS7d/6mnlc/MOEQyMBL
+xkUa79sNVU/8CYQ5MCL+w8mKytKz1Y74AFynvvF/U2SL/nW/Vc9sARk3OIL
+29WeWdNTlY9wAAGF/a/WL244fcxlQM7Qd7bcW7/w5xUUUUtlQOFIOUFZ/ez
2TROcO9VPqAFdP1XjTP7H0X/2bPjg9KBRyDjH57av/nUJ9NDIUoHZs0EgZP7
CxNcNm3aqXggGBxeJ/ZfDOH2vi6vCA2f4/v1il+er2hXgIbH0f0qmglxmx7K
H6gB+//I/m9mfbsSd8hB/Xt4/1G97RYRk2Wh/ju4v+FuzoXzRTJQ/xzYr/+u
O/ZOmPQBsHU79u3/y7xpWaK91AEdsHv37J/DWBzHqiN5YA7YfTv37/gW2Ssl
I3GAB+ye7fun/Pj7r5FPHGr/lv1LvPP2ljOKQe3buH/mZS8Xu08iUPPX7f/h
ldzcfkf4wAyweSv3V3cduBO0U+hAA1j/kv3GrK9bWmoEDxwAq5+3P1VYPv03
nwBUfsr+64X8UjcqeKD8lv0KRtO4Xu5jOwAAoZBGJA==
         "]]}}, {}}, {{{}, {}, 
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwtkHtI01EcxWckmQ9SmmKbzcd0LhsxMuuPGAWGGyaMrYTWWlH4KBhN+6fM
pFyG/RMzHGayTFCp1doyQjesnTvfmuXM3AxTXIUgbajUSmJB3t924HK53Hs/
33NO5gWdsnwLi8USbi66tz2k+oyWl9Hv+pcE5LfwjGEgOIfcDrFLkysgSjvv
zg/FHH6VhYYvanOIVeq7zrZ64cvi1vTbskmct7NKEuvF38KFpYPrfFJZQeXB
UJ3/0aiYTwaDFDiL3ivF8orLWSR9k2bnzcJU64vnPMsktWxK/ISxkHJg41sG
mWNwM4jzyjm5aRnkQD7VDA6rild7unmkaYACP0JtYF9tS9xN/ApqcBoLIZnW
VMMlMmpPOo159fNJtW8X6aK4TjcmVHxboyyVsBi5UbD4lO+xpRAHjWf/AJ9G
J49KTSbV9HnVe6xy9h4bqd9J8mgdwkm4SswJy4Ek8pXifRNoNJXV7NEkknB/
4/BKuTp3RwI5wfQ1Bsua5Ljwfmykn1HkG788ab63LdLHMMaPaGVTrVvJDSb/
EJondhSe7o2K5B3EPtGllabZfwjnc+GcqsFQem0D4TwEMdlFpuTyn2DG2Z0w
O14VWM4HIGL8voG4XPRH7/8OE+PPgaS8lJH1k/OIZ/z04cXy9lJB3RTC819j
5awk+DjaGZnXg/S1lvpAUXeEb4UjVJl2ql2PVoZnhmct5+ahxRLcYv53obrP
qLsdE3QS5n07Hihseu1RjTN8b4SF1n53/9vwuQGsiP4D/QhP6Q==
         "]]}}, {}}, {
      GraphicsComplexBox[{{-0.15, -2.0099154790312257`}, {-0.25, \
-5.8781358618009785`}, {-0.35, -9.315700887634009}, {-0.15, \
-2.0099154790312257`}, {-0.25, -5.8781358618009785`}, {-0.35, \
-9.315700887634009}}, {
        {Hue[0.67, 0.6, 0.6], InsetBox[
          GraphicsBox[
           {GrayLevel[0], DiskBox[{0, 0}]},
           ImageSize->8], 4], InsetBox[
          GraphicsBox[
           {GrayLevel[0], DiskBox[{0, 0}]},
           ImageSize->8], 5], InsetBox[
          GraphicsBox[
           {GrayLevel[0], DiskBox[{0, 0}]},
           ImageSize->8], 6]}, {}}], {}}, {GraphicsComplexBox[CompressedData["

1:eJxTTMoPSmViYGAQAWIQPWsmCOzczy3az3FhydP9uPip08qU1WSZD+DiL/NP
OqWzSRgn/9Hm5E8RDfI4+UtmXYuvunt/Py7+YHUfAClSt/4=
       "], {
        {Hue[0.67, 0.6, 0.6], InsetBox[
          GraphicsBox[{
            {Hue[0.67, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.24720000000000014`, 0.24, 0.6]}},
           ImageSize->10], 11], InsetBox[
          GraphicsBox[{
            {Hue[0.67, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.24720000000000014`, 0.24, 0.6]}},
           ImageSize->10], 12]}, 
        {Hue[0.9060679774997897, 0.6, 0.6], InsetBox[
          GraphicsBox[{
            {Hue[0.9060679774997897, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.6, 0.24, 0.4428931686004542]}},
           ImageSize->10], 13], InsetBox[
          GraphicsBox[{
            {Hue[0.9060679774997897, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.6, 0.24, 0.4428931686004542]}},
           ImageSize->10], 14]}, 
        {Hue[0.1421359549995791, 0.6, 0.6], InsetBox[
          GraphicsBox[{
            {Hue[0.1421359549995791, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.6, 0.5470136627990908, 0.24]}},
           ImageSize->10], 15], InsetBox[
          GraphicsBox[{
            {Hue[0.1421359549995791, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.6, 0.5470136627990908, 0.24]}},
           ImageSize->10], 16]}, 
        {Hue[0.37820393249936934`, 0.6, 0.6], InsetBox[
          GraphicsBox[{
            {Hue[0.37820393249936934`, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.24, 0.6, 0.33692049419863584`]}},
           ImageSize->10], 17], InsetBox[
          GraphicsBox[{
            {Hue[0.37820393249936934`, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.24, 0.6, 0.33692049419863584`]}},
           ImageSize->10], 18]}, 
        {Hue[0.6142719099991583, 0.6, 0.6], InsetBox[
          GraphicsBox[
           {GrayLevel[0], DiskBox[{0, 0}]},
           ImageSize->8], 19], InsetBox[
          GraphicsBox[
           {GrayLevel[0], DiskBox[{0, 0}]},
           ImageSize->8], 20]}, {}}], {}}, {GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQPWsmCJzcP+9+8JPlnYIHcPETr+b8vXFaGCd/mYaI
VR6vDE5+3f7Lsz7eVcLJ36ltvcZJlB8nf7C6DwDuYbpO
       "], {
        {Hue[0.67, 0.6, 0.6], InsetBox[
          GraphicsBox[{
            {Hue[0.67, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.24720000000000014`, 0.24, 0.6]}},
           ImageSize->10], 11], InsetBox[
          GraphicsBox[{
            {Hue[0.67, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.24720000000000014`, 0.24, 0.6]}},
           ImageSize->10], 12]}, 
        {Hue[0.9060679774997897, 0.6, 0.6], InsetBox[
          GraphicsBox[{
            {Hue[0.9060679774997897, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.6, 0.24, 0.4428931686004542]}},
           ImageSize->10], 13], InsetBox[
          GraphicsBox[{
            {Hue[0.9060679774997897, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.6, 0.24, 0.4428931686004542]}},
           ImageSize->10], 14]}, 
        {Hue[0.1421359549995791, 0.6, 0.6], InsetBox[
          GraphicsBox[{
            {Hue[0.1421359549995791, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.6, 0.5470136627990908, 0.24]}},
           ImageSize->10], 15], InsetBox[
          GraphicsBox[{
            {Hue[0.1421359549995791, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.6, 0.5470136627990908, 0.24]}},
           ImageSize->10], 16]}, 
        {Hue[0.37820393249936934`, 0.6, 0.6], InsetBox[
          GraphicsBox[{
            {Hue[0.37820393249936934`, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.24, 0.6, 0.33692049419863584`]}},
           ImageSize->10], 17], InsetBox[
          GraphicsBox[{
            {Hue[0.37820393249936934`, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.24, 0.6, 0.33692049419863584`]}},
           ImageSize->10], 18]}, 
        {Hue[0.6142719099991583, 0.6, 0.6], InsetBox[
          GraphicsBox[
           {GrayLevel[0], DiskBox[{0, 0}]},
           ImageSize->8], 19], InsetBox[
          GraphicsBox[
           {GrayLevel[0], DiskBox[{0, 0}]},
           ImageSize->8], 20]}, {}}], {}}, {GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQbQwGl/ev3/jl35xwpQO4+O8nGu4201bEya88+Wtz
/xRlnPwF//tndi3Uxsn/bHA+L/eWPE7+YHUfAGwalcY=
       "], {
        {Hue[0.67, 0.6, 0.6], InsetBox[
          GraphicsBox[{
            {Hue[0.67, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.24720000000000014`, 0.24, 0.6]}},
           ImageSize->10], 11], InsetBox[
          GraphicsBox[{
            {Hue[0.67, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.24720000000000014`, 0.24, 0.6]}},
           ImageSize->10], 12]}, 
        {Hue[0.9060679774997897, 0.6, 0.6], InsetBox[
          GraphicsBox[{
            {Hue[0.9060679774997897, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.6, 0.24, 0.4428931686004542]}},
           ImageSize->10], 13], InsetBox[
          GraphicsBox[{
            {Hue[0.9060679774997897, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.6, 0.24, 0.4428931686004542]}},
           ImageSize->10], 14]}, 
        {Hue[0.1421359549995791, 0.6, 0.6], InsetBox[
          GraphicsBox[{
            {Hue[0.1421359549995791, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.6, 0.5470136627990908, 0.24]}},
           ImageSize->10], 15], InsetBox[
          GraphicsBox[{
            {Hue[0.1421359549995791, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.6, 0.5470136627990908, 0.24]}},
           ImageSize->10], 16]}, 
        {Hue[0.37820393249936934`, 0.6, 0.6], InsetBox[
          GraphicsBox[{
            {Hue[0.37820393249936934`, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.24, 0.6, 0.33692049419863584`]}},
           ImageSize->10], 17], InsetBox[
          GraphicsBox[{
            {Hue[0.37820393249936934`, 0.6, 0.6], CircleBox[{0, 0}]}, 
            {RGBColor[0.24, 0.6, 0.33692049419863584`]}},
           ImageSize->10], 18]}, 
        {Hue[0.6142719099991583, 0.6, 0.6], InsetBox[
          GraphicsBox[
           {GrayLevel[0], DiskBox[{0, 0}]},
           ImageSize->8], 19], InsetBox[
          GraphicsBox[
           {GrayLevel[0], DiskBox[{0, 0}]},
           ImageSize->8], 20]}, {}}], {}}}, {InsetBox[
      TemplateBox[{
       StyleBox[
        "\"total\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"Directive", "[", 
                RowBox[{
                  RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                  RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], 
            ",", 
            RowBox[{"{", #, "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      Scaled[{0.56, 0.23}], ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TemplateBox[{
       StyleBox[
        "\"1-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"2-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"3-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"4-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{
                    "0.6`", ",", "0.5470136627990908`", ",", "0.24`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24`", ",", "0.6`", ",", "0.33692049419863584`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      Scaled[{0.85, 0.23}], ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesOrigin->{-0.4, -14.508657738524219`},
   CoordinatesToolOptions:>{"DisplayFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& ), "CopiedValueFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& )},
   Epilog->{
     Arrowheads[{{0.02, 0, {
         GraphicsBox[
          CircleBox[{1, -1}, 1, 
           
           NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
            3.141592653589793}]]], -1}}, {0.02, 1, {
         GraphicsBox[{
           CircleBox[{-1, 1}, 1, 
            NCache[{Rational[-1, 2] Pi, 0}, {-1.5707963267948966`, 0}]], 
           InsetBox[
            BoxData[
             FormBox[
              StyleBox["\"\"", Larger, StripOnInput -> False], 
              TraditionalForm]], {0, 2}]}], 1}}}], 
     ArrowBox[
      NCache[{{-0.125, -Log[1000000]}, {-0.125, 
         Rational[1, 2] (-Log[5000] - Log[
          1000000])}}, {{-0.125, -13.815510557964274`}, {-0.125, \
-11.166351874690257`}}]], 
     Arrowheads[{{0.02, 0, {
         GraphicsBox[
          CircleBox[{1, 1}, 1, 
           
           NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
            4.71238898038469}]]], -1}}, {0.02, 1, {
         GraphicsBox[
          CircleBox[{-1, -1}, 1, 
           NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]], 1}}}], 
     
     ArrowBox[
      NCache[{{-0.125, Rational[1, 2] (-Log[5000] - Log[1000000])}, {-0.125, -
         Log[5000]}}, {{-0.125, -11.166351874690257`}, {-0.125, \
-8.517193191416238}}]]},
   Frame->{True, False, False, True},
   FrameLabel->{{"", 
      FormBox["\"Probability of rescue\"", TraditionalForm]}, {
      FormBox["\"Wildtype growth rate\"", TraditionalForm], ""}},
   FrameTicks->{{None, {{-13.815510557964274`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-11.512925464970229`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-9.210340371976182, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-6.907755278982137, 
        FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
        FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
        FormBox["0.1`", TraditionalForm]}, {0., 
        FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.716898269296165`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.429216196844383`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.206072645530174`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.02375108873622, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.86960040890896, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.736069016284437`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.618285980628055`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.819778284410283`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.414313176302118`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.126631103850338`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.903487552536127, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.721165995742174, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.567015315914915, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.433483923290392, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.315700887634009, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-8.517193191416238, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-8.111728083308073, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.824046010856292, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.600902459542082, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.418580902748127, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.264430222920869, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.1308988302963465`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.013115794639964, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-6.214608098422191, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.298317366548036, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.995732273553991, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.659260036932778, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.407945608651872, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.6931471805599453, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659905, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.35667494393873245`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782616`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {True, False}},
   GridLines->{None, None},
   ImageSize->350,
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.4, 0}, {-14.508657738524219`, 0.}},
   PlotRangeClipping->True,
   PlotRangePadding->{{None, None}, {None, None}},
   Ticks->{Automatic, {{-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.716898269296165`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.429216196844383`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.02375108873622, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.86960040890896, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.736069016284437`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.618285980628055`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}],
  InterpretTemplate[Legended[
    Graphics[{{{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJwtkF1I01EYxv9pZKhNVzOWoc6PdE7TUOdVrcKLZRTojMASpKlFBWrQRO3z
QgkinUuTirKLCdaFk2W2abXnTdPlSnHOua0LaX2wygSz1AiLdv7bA4fD4Zzz
e5/nSVTXqKpCOI6T+hfb795h8iD956pJPptJK9Iy7fCyGyM1Y2HPDBmkMsc3
zxe7kd8ywZmuy8ig9DaKDC4sVxj1OWfSKcKlr90T7kKW71d//mEpnTrJNIu8
gQLnm9w0GllmQCeWFJ3lf+JSKcFPM8c7cb7eqrFF7KALIkacwZVm4fuCv8nk
5nEO3P/RKa5eSqK8XCYHsha9+UXzidQ2zIDT6PMpfi/6JPS9mBm0Q90X1do7
lUAHmD2lHT0dsf1RnjjqZjj9FB6rNzhFX7cTx2sKC5vUu21cLA2yeOZJVBZa
S/ZKxHSOPa+dQLnePnRNuZVkrA7pW/hqDzZY6kT0geG9Nkw+fWcPN2ymQH/j
mEnZWNWzEE0lfF+voR1XZXjOCoL9WLHr9NFPFkFEsI9R7Ouqb28ZDaOLfP5X
yBq9HKq7uT6YdwRzW6Ty5IZ1wXwvodO0K3aurSGQh9CVI7vRWLQKfpzZgm3a
mDlByBIyeb/PEZ1Wqrt05Bvu8f4GETqkybZPexHJ+zHBkf3l88AtJwLznyCm
QptySDyGwDwjRMqOBzhuDPIN+KeTf2x9qMNtnvcIK0mFkv3CE7jK/+9GpLm0
rKpACOLfd+FYXWV9m6DJErjvQJ7AX3tq9YvAuQlcUP8Bo3NLMw==
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJwtkF9Ik1EYxtcKpC2W01nJUnPZmhFp2rKbNVqExhi0CRERYemqm8pZFKkX
I0wRJ2qWbZGZzBGlzYqB3yj2vk1tFpttU9saBG1+JNjoj5sjaBd5vn0PHA6H
c87vfZ6n+PxVnZ7L4XBka4vsDy1EX2CQjmwueLkbU7IzPe7VMKSs7W3nElLU
UYV3fmjDoLrmUEQOStFeHW0W2UNwu2P0ial5F/JD1kYFLwQJbdzS7CrBixeI
PkNyZtE9xi3ByVUCXIA/3KZgefVOLFqjUYULEJ7P8+WbJNgiIsR5kAsFQmOg
GMMMbg78iesu49ZiPFBJNAfBulNdyrM7sNdNgEGYUlVxp9RFGNcSgwFYCX4/
Jv1agDXEXnUAbgrSpesM23GE4Kx+OKzRWxxZYuQw8sMJm2LIOpyPThKPmoVU
3/1UhXIbGsjzRh9U8YbfeL5twT2kDpkXLtn61e/b8zBG8NGPIBdXnu7bL8JM
fx8gEXMqO6M5WMv0NQPjHXQL/4GQ7ccD5fEb+iZdNtvHNMR6636VygTYyuSf
ghVbja6b4rN5J8EtftpgP7mRzfcOBiSfNCXrs9g8CD4v39Tq2oDMOMoFxw23
6EOdXNzL+H0L6aDd463n4CPGnxPkZZO0fDANmxg/E0DfpZLL/X8hM98BDS9+
HlWPJSEz7xVcHqpVZS/9hgzfDpKJ7iVD1zKYGd4z8ONzns68CEbm/wgcGTXv
G8iNADLvH0NBRa5jvN7L3t+Dfz20P2f1NXtug7JpTXLWcwX+AxnkWJE=
           "]]}, {
          Hue[0.1421359549995791, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJwtkGtI01EYxrdRIqtV6qjZ2tbMXcwCwUV+yKhUNCRCqzWjICxXYjDFGJub
4IeK6kMXZ+h0WeaIWTTK1P23yvdNu9jQpblrtWxGLMz6EK0LRuX5+3/gcDic
c37v8zzSSl15FYfFYinnF9nbrUQRaJWEk7bcysIfyoMXhxJh6HnnuhFdloXl
lPj057IwHIr6q631SnQWxxr4zhC08qd694cVuCTUXZvPDYErT7ONla/AY1qi
IBzvv7zZ3CXH4QQBBmBvjUjRt1iOknkaJQ7AdIXMcaVahiY+IfqBvS+XShnL
xDCNmwQjW/dVnJOJqlyiSfBtdXg9zevw0hABvgJrmy0+8z0DZ8uIwQlIPQOB
R+oMLCH2iifAd3KgpZSSop3gusfBZOVb+tOlyKI1DhV3d2yUm9aim8SjfGB7
bddec0uwjjyvHQONLic52CjG9aQO5ShYVEFHTYEIpwk+5gXO4evGGHcNLvT3
Aq6WaHd5/KtxD93XCDxTP1Dru9KZfp7D25aG6IU6AdPHUzAk4vG6olVopvM/
gaYiG9UoWsnkHYbmjp0f5n7zmXyPwVN/ziJ8k8bkQXBtKjgxg6lIj6MGwSQs
FJTeTsENtN+HYNcPyz5ZV6CN9ueGfwZZZLtgOS6l/bjgW6G3KsLmMfP7oP2m
sOPAFy4z7x6opszvRwLJDN8JVXf0lUfuJ2EbzeuBXg3bAMZF2ET/twNvzpD9
MY2DSL/vhE6eJO/swF9YuG+BX6ODAH9+MudTcPTlbm72+Vn4D6fQUYY=
           "]]}, {
          Hue[0.37820393249936934`, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJxTTMoPSmViYGBQB2IQzfzn41b7Fzf22y+uP5nHonsgaIdc6+vAG/tXvXhU
UVOrc2Cd+8MqkXXX92+YMUlA6JX2Ae7riwtsua7vN99/i8coTPtAehoIXNt/
cEHEqX0HtQ4c/qoR03/o6v4M5VmBs3W0DsgDTdshd3X/tY40nbXTNA9Ui4BM
vLI//Lqv373/GgdugI27vF9qyYxZchkaB0yMQeDy/pS7d/6mnlc/MOEQyMBL
+xkUa79sNVU/8CYQ5MCL+w8mKytKz1Y74AFynvvF/U2SL/nW/Vc9sARk3OIL
+29WeWdNTlY9wAAGF/a/WL244fcxlQM7Qd7bcW7/w5xUUUUtlQOFIOUFZ/ez
2TROcO9VPqAFdP1XjTP7H0X/2bPjg9KBRyDjH57av/nUJ9NDIUoHZs0EgZP7
CxNcNm3aqXggGBxeJ/ZfDOH2vi6vCA2f4/v1il+er2hXgIbH0f0qmglxmx7K
H6gB+//I/m9mfbsSd8hB/Xt4/1G97RYRk2Wh/ju4v+FuzoXzRTJQ/xzYr/+u
O/ZOmPQBsHU79u3/y7xpWaK91AEdsHv37J/DWBzHqiN5YA7YfTv37/gW2Ssl
I3GAB+ye7fun/Pj7r5FPHGr/lv1LvPP2ljOKQe3buH/mZS8Xu08iUPPX7f/h
ldzcfkf4wAyweSv3V3cduBO0U+hAA1j/kv3GrK9bWmoEDxwAq5+3P1VYPv03
nwBUfsr+64X8UjcqeKD8lv0KRtO4Xu5jOwAAoZBGJA==
           
           "]]}}}, {}}, {{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          GrayLevel[0], 
          Thickness[Large], 
          Line[CompressedData["
1:eJwtkHtI01EcxWckmQ9SmmKbzcd0LhsxMuuPGAWGGyaMrYTWWlH4KBhN+6fM
pFyG/RMzHGayTFCp1doyQjesnTvfmuXM3AxTXIUgbajUSmJB3t924HK53Hs/
33NO5gWdsnwLi8USbi66tz2k+oyWl9Hv+pcE5LfwjGEgOIfcDrFLkysgSjvv
zg/FHH6VhYYvanOIVeq7zrZ64cvi1vTbskmct7NKEuvF38KFpYPrfFJZQeXB
UJ3/0aiYTwaDFDiL3ivF8orLWSR9k2bnzcJU64vnPMsktWxK/ISxkHJg41sG
mWNwM4jzyjm5aRnkQD7VDA6rild7unmkaYACP0JtYF9tS9xN/ApqcBoLIZnW
VMMlMmpPOo159fNJtW8X6aK4TjcmVHxboyyVsBi5UbD4lO+xpRAHjWf/AJ9G
J49KTSbV9HnVe6xy9h4bqd9J8mgdwkm4SswJy4Ek8pXifRNoNJXV7NEkknB/
4/BKuTp3RwI5wfQ1Bsua5Ljwfmykn1HkG788ab63LdLHMMaPaGVTrVvJDSb/
EJondhSe7o2K5B3EPtGllabZfwjnc+GcqsFQem0D4TwEMdlFpuTyn2DG2Z0w
O14VWM4HIGL8voG4XPRH7/8OE+PPgaS8lJH1k/OIZ/z04cXy9lJB3RTC819j
5awk+DjaGZnXg/S1lvpAUXeEb4UjVJl2ql2PVoZnhmct5+ahxRLcYv53obrP
qLsdE3QS5n07Hihseu1RjTN8b4SF1n53/9vwuQGsiP4D/QhP6Q==
           "]]}}}, {}}, {
      
       GraphicsComplex[{{-0.15, -2.0099154790312257`}, {-0.25, \
-5.8781358618009785`}, {-0.35, -9.315700887634009}, {-0.15, \
-2.0099154790312257`}, {-0.25, -5.8781358618009785`}, {-0.35, \
-9.315700887634009}}, {{{
           Hue[0.67, 0.6, 0.6], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              GrayLevel[0], 
              Disk[{0, 0}]}, ImageSize -> 8], 4], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              GrayLevel[0], 
              Disk[{0, 0}]}, ImageSize -> 8], 5], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              GrayLevel[0], 
              Disk[{0, 0}]}, ImageSize -> 8], 6]}, {}}}], {}}, {
       GraphicsComplex[CompressedData["
1:eJxTTMoPSmViYGAQAWIQPWsmCOzczy3az3FhydP9uPip08qU1WSZD+DiL/NP
OqWzSRgn/9Hm5E8RDfI4+UtmXYuvunt/Py7+YHUfAClSt/4=
        "], {{{
           Hue[0.67, 0.6, 0.6], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.24720000000000014`, 0.24, 0.6]}, ImageSize -> 10], 
            11], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.24720000000000014`, 0.24, 0.6]}, ImageSize -> 10], 
            12]}, {
           Hue[0.9060679774997897, 0.6, 0.6], 
           Inset[
            Graphics[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.24, 0.4428931686004542]}, ImageSize -> 10], 13], 
           Inset[
            Graphics[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.24, 0.4428931686004542]}, ImageSize -> 10], 
            14]}, {
           Hue[0.1421359549995791, 0.6, 0.6], 
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.5470136627990908, 0.24]}, ImageSize -> 10], 15], 
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.5470136627990908, 0.24]}, ImageSize -> 10], 
            16]}, {
           Hue[0.37820393249936934`, 0.6, 0.6], 
           Inset[
            Graphics[{
              Hue[0.37820393249936934`, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.24, 0.6, 0.33692049419863584`]}, ImageSize -> 10], 
            17], 
           Inset[
            Graphics[{
              Hue[0.37820393249936934`, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.24, 0.6, 0.33692049419863584`]}, ImageSize -> 10], 
            18]}, {
           Hue[0.6142719099991583, 0.6, 0.6], 
           Inset[
            Graphics[{
              Hue[0.6142719099991583, 0.6, 0.6], 
              GrayLevel[0], 
              Disk[{0, 0}]}, ImageSize -> 8], 19], 
           Inset[
            Graphics[{
              Hue[0.6142719099991583, 0.6, 0.6], 
              GrayLevel[0], 
              Disk[{0, 0}]}, ImageSize -> 8], 20]}, {}}}], {}}, {
       GraphicsComplex[CompressedData["
1:eJxTTMoPSmViYGAQAWIQPWsmCJzcP+9+8JPlnYIHcPETr+b8vXFaGCd/mYaI
VR6vDE5+3f7Lsz7eVcLJ36ltvcZJlB8nf7C6DwDuYbpO
        "], {{{
           Hue[0.67, 0.6, 0.6], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.24720000000000014`, 0.24, 0.6]}, ImageSize -> 10], 
            11], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.24720000000000014`, 0.24, 0.6]}, ImageSize -> 10], 
            12]}, {
           Hue[0.9060679774997897, 0.6, 0.6], 
           Inset[
            Graphics[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.24, 0.4428931686004542]}, ImageSize -> 10], 13], 
           Inset[
            Graphics[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.24, 0.4428931686004542]}, ImageSize -> 10], 
            14]}, {
           Hue[0.1421359549995791, 0.6, 0.6], 
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.5470136627990908, 0.24]}, ImageSize -> 10], 15], 
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.5470136627990908, 0.24]}, ImageSize -> 10], 
            16]}, {
           Hue[0.37820393249936934`, 0.6, 0.6], 
           Inset[
            Graphics[{
              Hue[0.37820393249936934`, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.24, 0.6, 0.33692049419863584`]}, ImageSize -> 10], 
            17], 
           Inset[
            Graphics[{
              Hue[0.37820393249936934`, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.24, 0.6, 0.33692049419863584`]}, ImageSize -> 10], 
            18]}, {
           Hue[0.6142719099991583, 0.6, 0.6], 
           Inset[
            Graphics[{
              Hue[0.6142719099991583, 0.6, 0.6], 
              GrayLevel[0], 
              Disk[{0, 0}]}, ImageSize -> 8], 19], 
           Inset[
            Graphics[{
              Hue[0.6142719099991583, 0.6, 0.6], 
              GrayLevel[0], 
              Disk[{0, 0}]}, ImageSize -> 8], 20]}, {}}}], {}}, {
       GraphicsComplex[CompressedData["
1:eJxTTMoPSmViYGAQAWIQbQwGl/ev3/jl35xwpQO4+O8nGu4201bEya88+Wtz
/xRlnPwF//tndi3Uxsn/bHA+L/eWPE7+YHUfAGwalcY=
        "], {{{
           Hue[0.67, 0.6, 0.6], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.24720000000000014`, 0.24, 0.6]}, ImageSize -> 10], 
            11], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.24720000000000014`, 0.24, 0.6]}, ImageSize -> 10], 
            12]}, {
           Hue[0.9060679774997897, 0.6, 0.6], 
           Inset[
            Graphics[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.24, 0.4428931686004542]}, ImageSize -> 10], 13], 
           Inset[
            Graphics[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.24, 0.4428931686004542]}, ImageSize -> 10], 
            14]}, {
           Hue[0.1421359549995791, 0.6, 0.6], 
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.5470136627990908, 0.24]}, ImageSize -> 10], 15], 
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.5470136627990908, 0.24]}, ImageSize -> 10], 
            16]}, {
           Hue[0.37820393249936934`, 0.6, 0.6], 
           Inset[
            Graphics[{
              Hue[0.37820393249936934`, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.24, 0.6, 0.33692049419863584`]}, ImageSize -> 10], 
            17], 
           Inset[
            Graphics[{
              Hue[0.37820393249936934`, 0.6, 0.6], 
              Circle[{0, 0}], 
              RGBColor[0.24, 0.6, 0.33692049419863584`]}, ImageSize -> 10], 
            18]}, {
           Hue[0.6142719099991583, 0.6, 0.6], 
           Inset[
            Graphics[{
              Hue[0.6142719099991583, 0.6, 0.6], 
              GrayLevel[0], 
              Disk[{0, 0}]}, ImageSize -> 8], 19], 
           Inset[
            Graphics[{
              Hue[0.6142719099991583, 0.6, 0.6], 
              GrayLevel[0], 
              Disk[{0, 0}]}, ImageSize -> 8], 20]}, {}}}], {}}}, {Epilog -> {
        Arrowheads[{{0.02, 0, {
            Graphics[
             Circle[{1, -1}, 1, {Rational[1, 2] Pi, Pi}]], -1}}, {0.02, 1, {
            Graphics[{
              Circle[{-1, 1}, 1, {Rational[-1, 2] Pi, 0}], 
              Inset[
               Style["", Larger], {0, 2}]}], 1}}}], 
        Arrow[{{-0.125, -Log[1000000]}, {-0.125, 
           Rational[1, 2] (-Log[5000] - Log[1000000])}}], 
        Arrowheads[{{0.02, 0, {
            Graphics[
             Circle[{1, 1}, 1, {Pi, Rational[3, 2] Pi}]], -1}}, {0.02, 1, {
            Graphics[
             Circle[{-1, -1}, 1, {0, Rational[1, 2] Pi}]], 1}}}], 
        Arrow[{{-0.125, 
           Rational[1, 2] (-Log[5000] - Log[1000000])}, {-0.125, -
           Log[5000]}}]}, ImageSize -> 350, 
      FrameLabel -> {{Null, "Probability of rescue"}, {
        "Wildtype growth rate", Null}}, 
      Ticks -> {Automatic, {{-13.815510557964274`, 
          Superscript[10, -6]}, {-11.512925464970229`, 
          Superscript[10, -5]}, {-9.210340371976182, 
          Superscript[10, -4]}, {-6.907755278982137, 
         0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 0.1}, {
         0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 0.}, {
           Thickness[0.001]}}}}, GridLines -> {None, None}, 
      FrameTicks -> {{None, {{-13.815510557964274`, 
           Superscript[10, -6]}, {-11.512925464970229`, 
           Superscript[10, -5]}, {-9.210340371976182, 
           Superscript[10, -4]}, {-6.907755278982137, 
          0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 0.1}, {
          0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 0.}, {
            Thickness[0.001]}}}}, {True, False}}, 
      AxesOrigin -> {-0.4, -14.508657738524219`}, 
      PlotRange -> {{-0.4, 0}, {-14.508657738524219`, 0.}}, AspectRatio -> 
      GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0, 0}, 
      CoordinatesToolOptions -> {"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )}, Frame -> {True, False, False, True}, 
      FrameLabel -> {
       "Wildtype growth rate", Null, Null, "Probability of rescue"}, 
      FrameTicks -> {True, False, False, True}, LabelStyle -> 
      Directive[12, FontFamily -> "Helvetica"], Method -> {}, 
      PlotRange -> {{-0.4, 0}, {-14.508657738524219`, 0.}}, PlotRangeClipping -> 
      True, PlotRangePadding -> {{None, None}, {None, None}}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          Thickness[Large]], 
         Directive[
          RGBColor[0.6, 0.24, 0.4428931686004542], 
          Thickness[Large]], 
         Directive[
          RGBColor[0.6, 0.5470136627990908, 0.24], 
          Thickness[Large]], 
         Directive[
          RGBColor[0.24, 0.6, 0.33692049419863584`], 
          Thickness[Large]]}, {
         Style["1-step", 12, FontFamily -> "Helvetica"], 
         Style["2-step", 12, FontFamily -> "Helvetica"], 
         Style["3-step", 12, FontFamily -> "Helvetica"], 
         Style["4-step", 12, FontFamily -> "Helvetica"]}, LegendLayout -> 
        "Column"]], 
      Scaled[{0.85, 0.23}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{3.7822524258547993`*^9, 3.7849008244256783`*^9, 
  3.784903360887595*^9}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot probability as a function of mutation rate (figure S1)", \
"Subsection",
 CellChangeTimes->{{3.764203693747327*^9, 3.764203723979628*^9}, {
  3.769431903058765*^9, 3.769431904490643*^9}, {3.769432496990147*^9, 
  3.7694324971186943`*^9}, {3.76943274189194*^9, 3.769432743323926*^9}, {
  3.769432802504182*^9, 3.769432805279036*^9}, {3.769432841905702*^9, 
  3.7694328492802*^9}, {3.769439082713304*^9, 3.7694390851994867`*^9}}],

Cell[CellGroupData[{

Cell["Interpolation functions", "Subsubsection",
 CellChangeTimes->{{3.7822424087669897`*^9, 3.7822424123854933`*^9}}],

Cell["\<\
We again use interpolation functions to speed things up, this time across U \
instead of m0\
\>", "Text",
 CellChangeTimes->{{3.771246102716693*^9, 3.771246111931101*^9}, {
  3.771274494146963*^9, 3.771274504954303*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Umin", "=", 
   RowBox[{"-", "5"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Umax", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ustep", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mmin", "=", 
    RowBox[{"-", "0.4"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "\[CapitalLambda]1InterpolatedU", ",", "\[CapitalLambda]2InterpolatedU", 
    ",", "\[CapitalLambda]3InterpolatedU", ",", 
    "\[CapitalLambda]4InterpolatedU"}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalLambda]1InterpolatedU", "[", 
    RowBox[{"m0_", ",", "mmax_", ",", "\[Lambda]_", ",", "n_", ",", "x_"}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{"\[CapitalLambda]1InterpolatedU", "[", 
     RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "x"}], "]"}],
     "=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f", "=", 
        RowBox[{"Interpolation", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"xtemp", ",", 
             RowBox[{
              SuperscriptBox["10", "xtemp"], " ", 
              RowBox[{"NIntegrate", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"fm", "[", 
                  RowBox[{
                  "m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
                  "]"}], 
                 RowBox[{"pest", "[", "m", "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"m", ",", "0", ",", "mmax"}], "}"}], ",", 
                RowBox[{"Method", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"Automatic", ",", 
                   RowBox[{"\"\<SymbolicProcessing\>\"", "\[Rule]", "0"}]}], 
                  "}"}]}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"xtemp", ",", "Umin", ",", "Umax", ",", "Ustep"}], 
            "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"f", "[", "x", "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalLambda]2InterpolatedU", "[", 
    RowBox[{"m0_", ",", "mmax_", ",", "\[Lambda]_", ",", "n_", ",", "x_"}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{"\[CapitalLambda]2InterpolatedU", "[", 
     RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "x"}], "]"}],
     "=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f", "=", 
        RowBox[{"Interpolation", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"xtemp", ",", 
             RowBox[{
              SuperscriptBox["10", "xtemp"], " ", 
              RowBox[{"NIntegrate", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"fm", "[", 
                  RowBox[{
                  "m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
                  "]"}], 
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
                 RowBox[{"prescuem", "[", 
                  RowBox[{"m", ",", 
                   RowBox[{"\[CapitalLambda]1Interpolated", "[", 
                    RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", 
                    SuperscriptBox["10", "xtemp"]}], "]"}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"m", ",", "mmin", ",", "mmax"}], "}"}], ",", 
                RowBox[{"Method", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"Automatic", ",", 
                   RowBox[{"\"\<SymbolicProcessing\>\"", "\[Rule]", "0"}]}], 
                  "}"}]}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"xtemp", ",", "Umin", ",", "Umax", ",", "Ustep"}], 
            "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"f", "[", "x", "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalLambda]3InterpolatedU", "[", 
    RowBox[{"m0_", ",", "mmax_", ",", "\[Lambda]_", ",", "n_", ",", "x_"}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{"\[CapitalLambda]3InterpolatedU", "[", 
     RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "x"}], "]"}],
     "=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f", "=", 
        RowBox[{"Interpolation", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"xtemp", ",", 
             RowBox[{
              SuperscriptBox["10", "xtemp"], " ", 
              RowBox[{"NIntegrate", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"fm", "[", 
                  RowBox[{
                  "m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
                  "]"}], 
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
                 RowBox[{"prescuem", "[", 
                  RowBox[{"m", ",", 
                   RowBox[{"\[CapitalLambda]2Interpolated", "[", 
                    RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", 
                    SuperscriptBox["10", "xtemp"]}], "]"}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"m", ",", "mmin", ",", "mmax"}], "}"}], ",", 
                RowBox[{"Method", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"Automatic", ",", 
                   RowBox[{"\"\<SymbolicProcessing\>\"", "\[Rule]", "0"}]}], 
                  "}"}]}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"xtemp", ",", "Umin", ",", "Umax", ",", "Ustep"}], 
            "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"f", "[", "x", "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalLambda]4InterpolatedU", "[", 
   RowBox[{"m0_", ",", "mmax_", ",", "\[Lambda]_", ",", "n_", ",", "x_"}], 
   "]"}], ":=", 
  RowBox[{
   RowBox[{"\[CapitalLambda]4InterpolatedU", "[", 
    RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "x"}], "]"}], 
   "=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"f", "=", 
       RowBox[{"Interpolation", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"xtemp", ",", 
            RowBox[{
             SuperscriptBox["10", "xtemp"], " ", 
             RowBox[{"NIntegrate", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"fm", "[", 
                 RowBox[{
                 "m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
                 "]"}], 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
                RowBox[{"prescuem", "[", 
                 RowBox[{"m", ",", 
                  RowBox[{"\[CapitalLambda]3Interpolated", "[", 
                   RowBox[{
                   "m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", 
                    SuperscriptBox["10", "xtemp"]}], "]"}]}], "]"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"m", ",", "mmin", ",", "mmax"}], "}"}], ",", 
               RowBox[{"Method", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{"Automatic", ",", 
                  RowBox[{"\"\<SymbolicProcessing\>\"", "\[Rule]", "0"}]}], 
                 "}"}]}]}], "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"xtemp", ",", "Umin", ",", "Umax", ",", "Ustep"}], "}"}]}],
          "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"f", "[", "x", "]"}]}]}], "\[IndentingNewLine]", 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.7710006339642363`*^9, 3.771000651261798*^9}, {
   3.7710006849732113`*^9, 3.771000807511991*^9}, 3.7710009000604353`*^9, {
   3.77100102319551*^9, 3.7710010233705263`*^9}, {3.7710011165927973`*^9, 
   3.7710011198500853`*^9}, {3.771001353744179*^9, 3.771001378704712*^9}, {
   3.771001501438855*^9, 3.7710015427566843`*^9}, {3.771001609200037*^9, 
   3.7710016233596582`*^9}, {3.7710029708224497`*^9, 3.771002979497155*^9}, 
   3.771003069824634*^9, 3.771003100981645*^9, {3.77100313615471*^9, 
   3.771003143787877*^9}, {3.771003216851419*^9, 3.771003224224443*^9}, {
   3.771003383067137*^9, 3.771003395942892*^9}, 3.7710035538762283`*^9, 
   3.771003743292034*^9, {3.7712440458668127`*^9, 3.771244056209272*^9}, {
   3.771246116186899*^9, 3.771246328649214*^9}, {3.771246416276656*^9, 
   3.771246440121401*^9}, {3.771246480492791*^9, 3.771246592737934*^9}, {
   3.771247135427474*^9, 3.77124714820094*^9}, {3.7712472141735888`*^9, 
   3.7712472145337963`*^9}, 3.7712486500724*^9, {3.771248683904112*^9, 
   3.771248698575097*^9}, {3.771248734449698*^9, 3.7712487994164762`*^9}, {
   3.771248846485548*^9, 3.7712488608523912`*^9}, {3.771249055302999*^9, 
   3.7712490579861917`*^9}, {3.771249248783689*^9, 3.771249270071356*^9}, {
   3.771249351690132*^9, 3.7712494436608553`*^9}, 3.771249666027176*^9, {
   3.7712503616258173`*^9, 3.7712504328581333`*^9}, {3.771250478678226*^9, 
   3.77125050723883*^9}, {3.771250711072382*^9, 3.771250868787327*^9}, {
   3.771251803824194*^9, 3.771251803942484*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical data for panel A", "Subsubsection",
 CellChangeTimes->{{3.7822421644234743`*^9, 3.782242168077767*^9}, {
   3.782242356451124*^9, 3.782242358931278*^9}, {3.7822433229733047`*^9, 
   3.782243325407856*^9}, {3.782243725948131*^9, 3.7822437262678537`*^9}, 
   3.782244110662057*^9}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"N0", "=", 
    SuperscriptBox["10", "4"]}], ";", "\[IndentingNewLine]", 
   RowBox[{"m0", "=", 
    RowBox[{"-", "0.1"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"mmax", "=", "0.5"}], ";", "\[IndentingNewLine]", 
   RowBox[{"\[Lambda]", "=", 
    RowBox[{"2", 
     RowBox[{"Es", "/", "n"}]}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"Es", "=", "0.01"}], ";", "\[IndentingNewLine]", 
   RowBox[{"n", "=", "4"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"rate4", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[CapitalLambda]4InterpolatedU", "[", 
       RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "x"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Umin", ",", "Umax", ",", "Ustep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate3", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[CapitalLambda]3InterpolatedU", "[", 
       RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "x"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Umin", ",", "Umax", ",", "Ustep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate2", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[CapitalLambda]2InterpolatedU", "[", 
       RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "x"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Umin", ",", "Umax", ",", "Ustep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate1", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[CapitalLambda]1InterpolatedU", "[", 
       RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "x"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Umin", ",", "Umax", ",", "Ustep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"Ulist", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      SuperscriptBox["10", "x"], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Umin", ",", "Umax", ",", "Ustep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"theory", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Ulist", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{"m0", ",", 
              RowBox[{"rate1", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "Ulist", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Ulist", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{"m0", ",", 
              RowBox[{"rate2", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "Ulist", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Ulist", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{"m0", ",", 
              RowBox[{"rate3", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "Ulist", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Ulist", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{"m0", ",", 
              RowBox[{"rate4", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "Ulist", "]"}]}], "}"}]}], "]"}]}], 
     "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"alltheory", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Ulist", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"prescue", "/.", 
         RowBox[{"p0", "\[Rule]", 
          RowBox[{"prescuem", "[", 
           RowBox[{"m0", ",", 
            RowBox[{
             RowBox[{"rate1", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "+", 
             RowBox[{"rate2", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "+", 
             RowBox[{"rate3", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "+", 
             RowBox[{"rate4", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}]}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "Ulist", "]"}]}], "}"}]}], "]"}]}], ";", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", 
    RowBox[{
    "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "m0", ",", "N0", ",", 
     "U"}], "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.7510768239974546`*^9, 3.751076850477788*^9}, {
   3.751077073209116*^9, 3.75107707404215*^9}, 3.7510772333562117`*^9, {
   3.7510780814540033`*^9, 3.7510780939241743`*^9}, 3.751079983731886*^9, {
   3.751080193820591*^9, 3.751080314860424*^9}, {3.751080438938933*^9, 
   3.751080453002974*^9}, {3.751080543209502*^9, 3.751080573569518*^9}, {
   3.751081090205201*^9, 3.751081108714032*^9}, {3.75156278825319*^9, 
   3.7515628382903976`*^9}, 3.751646165611027*^9, {3.751646548106408*^9, 
   3.751646656277231*^9}, 3.751646837751152*^9, {3.751646901889613*^9, 
   3.751647017114812*^9}, {3.7516470710458508`*^9, 3.7516471140016603`*^9}, 
   3.751647239375453*^9, {3.751647274447871*^9, 3.751647308444126*^9}, {
   3.751655188488014*^9, 3.7516551948421173`*^9}, 3.7516553497399673`*^9, {
   3.7516558244590063`*^9, 3.751655855414094*^9}, {3.7516785570908422`*^9, 
   3.751678622405755*^9}, {3.751678785435092*^9, 3.751678797451065*^9}, {
   3.7516789290519457`*^9, 3.7516790098557253`*^9}, {3.751679079869364*^9, 
   3.751679081963086*^9}, {3.751679566365776*^9, 3.7516795717600317`*^9}, {
   3.751679647169375*^9, 3.751679648392433*^9}, 3.7516798837830763`*^9, {
   3.7516806524922543`*^9, 3.751680669037451*^9}, {3.7564891699284067`*^9, 
   3.756489175638451*^9}, {3.7564923277678747`*^9, 3.756492331912068*^9}, {
   3.756502094040043*^9, 3.756502095005869*^9}, {3.756520270671589*^9, 
   3.75652027344243*^9}, 3.756520348755927*^9, {3.756520400861586*^9, 
   3.756520439180738*^9}, 3.756520651678936*^9, {3.756556638142688*^9, 
   3.756556640041947*^9}, {3.756570843447299*^9, 3.756570846775318*^9}, {
   3.756570974146035*^9, 3.756571120745819*^9}, 3.760624717472529*^9, {
   3.76420440689139*^9, 3.7642046427775908`*^9}, {3.764204754899797*^9, 
   3.7642047716289186`*^9}, {3.76420481154845*^9, 3.764204825101851*^9}, {
   3.764204877914257*^9, 3.764204944872558*^9}, {3.764205207233889*^9, 
   3.7642052275611*^9}, {3.764205258864553*^9, 3.764205287291357*^9}, {
   3.764205609641672*^9, 3.7642056115708113`*^9}, {3.7642056795535307`*^9, 
   3.764205689443074*^9}, 3.764205980500901*^9, {3.764209232274527*^9, 
   3.7642092792726517`*^9}, 3.764209327120954*^9, 3.764251492281107*^9, {
   3.76943292341084*^9, 3.769432965089745*^9}, {3.769458302479702*^9, 
   3.769458322534122*^9}, 3.7699675931068783`*^9, {3.771246663332436*^9, 
   3.771246699348748*^9}, {3.771246730333727*^9, 3.771246855741597*^9}, {
   3.771246890332162*^9, 3.771247074062579*^9}, {3.771248419105422*^9, 
   3.771248520499831*^9}, {3.771248807775511*^9, 3.771248822219911*^9}, {
   3.771248900616621*^9, 3.7712489008722353`*^9}, {3.77124898134147*^9, 
   3.771249011221075*^9}, {3.771249300656846*^9, 3.7712493263214703`*^9}, {
   3.7712494670163717`*^9, 3.771249525868437*^9}, {3.771249775527567*^9, 
   3.771249842817733*^9}, {3.771250190789572*^9, 3.77125021131152*^9}, 
   3.771250250390286*^9, {3.771250380877308*^9, 3.7712503813315773`*^9}, {
   3.771250529621471*^9, 3.771250562619721*^9}, {3.7712505999952583`*^9, 
   3.7712506584019213`*^9}, {3.771250871998402*^9, 3.771250929508836*^9}, {
   3.7712510935067263`*^9, 3.771251160617013*^9}, {3.7712512100306463`*^9, 
   3.771251308362179*^9}, {3.7712518181926537`*^9, 3.771251819424254*^9}, {
   3.771252809790859*^9, 3.7712528171363583`*^9}, {3.7712529260931177`*^9, 
   3.77125303581524*^9}, 3.771253681601934*^9, 3.771527423155959*^9, 
   3.77152924355512*^9, 3.7715456016552362`*^9, 3.771547576753459*^9, {
   3.771551533704193*^9, 3.771551540759741*^9}, {3.771551599161521*^9, 
   3.771551742144014*^9}, {3.771552783452035*^9, 3.7715527936978617`*^9}, {
   3.782241122938232*^9, 3.782241123525981*^9}, {3.7822421813159857`*^9, 
   3.782242182589962*^9}, 3.782243317039748*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"theory", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.00001`", ",", "0.004246842378678117`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000012589254117941661`", ",", "0.0053435122405096624`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001584893192461114`", ",", "0.006722418845097056`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000019952623149688786`", ",", "0.008455638902157614`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000025118864315095822`", ",", "0.010633329634670008`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000031622776601683795`", ",", "0.013368073668290736`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000039810717055349695`", ",", "0.01680015577769267`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00005011872336272725`", ",", "0.021103903488885356`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00006309573444801929`", ",", "0.026495197360892786`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00007943282347242822`", ",", "0.03324019208311246`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0001`", ",", "0.04166516094921757`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00012589254117941674`", ",", "0.05216714629405583`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00015848931924611142`", ",", "0.06522471323417367`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00019952623149688788`", ",", "0.08140749078007126`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0002511886431509582`", ",", "0.10138225267144507`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00031622776601683794`", ",", "0.12591194417039553`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00039810717055349735`", ",", "0.15584223469333813`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0005011872336272725`", ",", "0.19206791297501513`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000630957344480193`", ",", "0.2354690490355157`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.0007943282347242822`", ",", "0.2868051576697973`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.001`", ",", "0.3465563408388336`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0012589254117941675`", ",", "0.4147065687699266`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.001584893192461114`", ",", "0.49048019295427137`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.0019952623149688807`", ",", "0.5720729042194002`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.002511886431509582`", ",", "0.6564634113805501`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.0031622776601683794`", ",", "0.7394414586022069`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.003981071705534973`", ",", "0.8160091713130636`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.005011872336272725`", ",", "0.8812494467922933`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.006309573444801936`", ",", "0.9315527837690738`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.00794328234724282`", ",", "0.9657778626534119`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.01`", ",", "0.9856911478435505`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.012589254117941675`", ",", "0.9952212549506977`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.01584893192461114`", ",", "0.9987965255597829`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.01995262314968881`", ",", "0.9997873527267671`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.025118864315095822`", ",", "0.9999759117384616`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.03162277660168379`", ",", "0.9999984370833104`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.039810717055349734`", ",", "0.999999949529219`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.05011872336272725`", ",", "0.9999999993188536`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.06309573444801936`", ",", "0.9999999999969065`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.07943282347242822`", ",", "0.9999999999999963`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.1`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.12589254117941687`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.15848931924611143`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.1995262314968879`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.25118864315095824`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.31622776601683794`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.39810717055349776`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5011872336272725`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.6309573444801942`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.7943282347242822`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.2589254117941688`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.584893192461114`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.9952623149688828`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "2.5118864315095824`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999990882692415201705748004867578032019228354459\
5670076`350.693693167964"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "3.1622776601683795`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99999999999999999999992856451351483750358497095725866324893100901`415.\
79964576784744"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "3.9810717055349776`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999690169529840971883105206648335660884633012538`491.\
16243564847895"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "5.011872336272725`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999951515939185131148963512307991522836`577.\
9679607872213"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "6.309573444801943`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999986348305517572241997695246183\
4752920144890966808521`677.2173432184245"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "7.943282347242821`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999974879857232219754039793752586575377467758595708218857`790.\
9525076755224"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "10.`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999992438019099882639745\
10553564755581064171`920.4738942027665"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.00001`", ",", "9.089462310263308`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000012589254117941661`", ",", "0.000014095372247391325`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001584893192461114`", ",", "0.000021846705690387047`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000019952623149688786`", ",", "0.000033842251587645755`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000025118864315095822`", ",", "0.000052394765066354765`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000031622776601683795`", ",", "0.00008107033945503606`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000039810717055349695`", ",", "0.00012536320914824373`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00005011872336272725`", ",", "0.00019373090777141666`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00006309573444801929`", ",", "0.00029918058007960546`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00007943282347242822`", ",", "0.00046169534771944853`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0001`", ",", "0.00071194036251232`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00012589254117941674`", ",", "0.0010969121970224593`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00015848931924611142`", ",", "0.0016885236639123669`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00019952623149688788`", ",", "0.0025966109616063493`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0002511886431509582`", ",", "0.003988544198877064`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00031622776601683794`", ",", "0.006118603636309117`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00039810717055349735`", ",", "0.009371572030332342`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0005011872336272725`", ",", "0.014326522298207078`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000630957344480193`", ",", "0.021848163889908734`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0007943282347242822`", ",", "0.033213203085142196`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001`", ",", "0.05027508225807342`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0012589254117941675`", ",", "0.07565590908493547`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001584893192461114`", ",", "0.11291662105759348`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.0019952623149688807`", ",", "0.16657497225167373`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.002511886431509582`", ",", "0.24169255460819006`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.0031622776601683794`", ",", "0.3425523103434259`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.003981071705534973`", ",", "0.46986766480852515`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.005011872336272725`", ",", "0.6165535196310404`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.006309573444801936`", ",", "0.7642508154485257`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.00794328234724282`", ",", "0.8862494786994978`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.01`", ",", "0.961720591184484`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.012589254117941675`", ",", "0.9924489494028248`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.01584893192461114`", ",", "0.9993232933992733`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.01995262314968881`", ",", "0.9999810027657433`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.025118864315095822`", ",", "0.999999902530299`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.03162277660168379`", ",", "0.9999999999578743`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.039810717055349734`", ",", "0.9999999999999994`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.05011872336272725`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.06309573444801936`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.07943282347242822`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.1`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.12589254117941687`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.15848931924611143`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.1995262314968879`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.25118864315095824`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.31622776601683794`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999983573142437863610415418910972869\
348008`362.4380052831524"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.39810717055349776`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99982605866119165668268777834309219187319159`475.4131569660562"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.5011872336272725`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999855439872124\
53225055476455897705098`616.4935112508043"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.6309573444801942`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999848024803482649638130474991640853791592780169082413222`790.\
1707570652251"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.7943282347242822`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999369326322548100\
04247066495779506359408485778660908942`1002.5527250737235"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999995865768517262195920389146651558075586727112788`1259.4351049933316"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.2589254117941688`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999998560751246735442555079407348807174559786590603`1568.8933639212753"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.584893192461114`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999951170322779921\
050253992265506746256005533`1939.3628159297323"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.9952623149688828`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999989648518195638366129812765592595509911742\
82`2381.0364972601315"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "2.5118864315095824`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999980828903265581306681184649493544802303`2905.4678228289563"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "3.1622776601683795`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999994254515030768866648862009803863842706066728322046596`3526.\
9911430947072"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "3.9810717055349776`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999960122156427802243134906815744792\
128051201731984135`4261.149738122099"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "5.011872336272725`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999996046592718553412256554612\
730909803645975654386354424`5126.1534982297135"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "6.309573444801943`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999991908480771597138902916\
009474409565613`6142.8424397170265"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "7.943282347242821`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
421833363567823030118364623063156723433`7334.988416760788"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "10.`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999998541463732\
05823206880661436871849525320234858720505`8729.586552554783"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.00001`", ",", 
         RowBox[{"8.752998326144734`*^-9", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000012589254117941661`", ",", 
         RowBox[{"1.7090773130057357`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001584893192461114`", ",", 
         RowBox[{"3.332556397506181`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000019952623149688786`", ",", 
         RowBox[{"6.4872549887518`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000025118864315095822`", ",", 
         RowBox[{"1.260103055233941`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000031622776601683795`", ",", 
         RowBox[{"2.440958251082037`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000039810717055349695`", ",", 
         RowBox[{"4.712729129163762`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00005011872336272725`", ",", 
         RowBox[{"9.064345221077019`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00006309573444801929`", ",", 
         RowBox[{"1.7363417931237635`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00007943282347242822`", ",", 
         RowBox[{"3.3125780688481044`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0001`", ",", 
         RowBox[{"6.29553431341634`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00012589254117941674`", ",", 
         RowBox[{"0.000011923379003131451`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00015848931924611142`", ",", 
         RowBox[{"0.000022513246609512372`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00019952623149688788`", ",", 
         RowBox[{"0.00004239236152348003`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0002511886431509582`", ",", 
         RowBox[{"0.00007962260499227991`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00031622776601683794`", ",", 
         RowBox[{"0.00014918493858973036`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00039810717055349735`", ",", 
         RowBox[{"0.0002788394891600765`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0005011872336272725`", ",", 
         RowBox[{"0.0005198673291508804`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000630957344480193`", ",", 
         RowBox[{"0.000966668700344675`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0007943282347242822`", ",", 
         RowBox[{"0.001792313017914382`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001`", ",", 
         RowBox[{"0.003312525027161395`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0012589254117941675`", ",", 
         RowBox[{"0.006099627650495765`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001584893192461114`", ",", 
         RowBox[{"0.011182046316595917`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0019952623149688807`", ",", 
         RowBox[{"0.02038422955412711`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.002511886431509582`", ",", 
         RowBox[{"0.03687820059908342`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0031622776601683794`", ",", 
         RowBox[{"0.06599647010553689`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.003981071705534973`", ",", 
         RowBox[{"0.11618401545733381`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.005011872336272725`", ",", 
         RowBox[{"0.19936169441965734`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.006309573444801936`", ",", 
         RowBox[{"0.32848031668977784`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00794328234724282`", ",", 
         RowBox[{"0.5079603333042872`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01`", ",", 
         RowBox[{"0.7150493863402883`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.012589254117941675`", ",", 
         RowBox[{"0.8900803755551275`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01584893192461114`", ",", 
         RowBox[{"0.9788516140366471`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01995262314968881`", ",", 
         RowBox[{"0.9987489284470218`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.025118864315095822`", ",", 
         RowBox[{"0.9999897588683007`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.03162277660168379`", ",", 
         RowBox[{"0.9999999968287793`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.039810717055349734`", ",", 
         RowBox[{"0.9999999999999953`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.05011872336272725`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.06309573444801936`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.07943282347242822`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.1`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.12589254117941687`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"2.764473032650923`*^-174", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.15848931924611143`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"6.954318481178101`*^-245", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.1995262314968879`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999541950950865109021483195991503635719155\
1341868`355.29367778426564", "+", 
          RowBox[{
          "2.087234795303845338146796740467790237`15.954589770191005*^-349", 
           " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.25118864315095824`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999999999978695952263364421338480839623535806351`498.\
62612764362206", "+", 
          RowBox[{
          "2.681074505449572837767527147147354826589274784238`15.\
954589770191005*^-491", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.31622776601683794`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999415704060294905940600\
1228781806385930601112`684.8869268966961", "+", 
          RowBox[{
          "2.53989668964218087585074425191485894`15.653559774527023*^-677", 
           " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.39810717055349776`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999876334344026013866\
07801705650442636671`922.5613106116448", "+", 
          RowBox[{
          "3.2670811791520309978005568966896573057580040633735`15.\
653559774527023*^-914", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5011872336272725`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999976629704796885206887240154622768\
1929637429681257`1220.2848954657975", "+", 
          RowBox[{
          "1.1891297176213295084513677641885012334805`15.653559774527023*^-\
1211", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.6309573444801942`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999999997581373265499837237011155134731883880215539706`1587.\
968960597958", "+", 
          RowBox[{
          "2.463992640505014090339631605843690926322`15.35252972355796*^-\
1579", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.7943282347242822`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999667436863321838278054299691194879721229`2037.8306551720596", "+", 
          RowBox[{
          "5.095797644003562223499538532687619528851876246054813`15.\
352529695680404*^-2029", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999945589694610696992609792423610028474382014695691126329`2582.315817553162",
           "+", 
          RowBox[{
          "1.52711565691458167661226239381689454233188347141`15.\
051499516560282*^-2573", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.2589254117941688`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999995900785303824847245479906003778406`3236.\
4387974342512", "+", 
          RowBox[{
          "1.816437040670734990355761197170370558877529238132`15.\
051499362228064*^-3227", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.584893192461114`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999965472949382129627607232036751385186827018210\
2`4015.5133378966484", "+", 
          RowBox[{
          "2.185224002438526808295169872783051684272`15.051499181929639*^-\
4006", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.9952623149688828`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999097655047822849017632035389062868190297314325691`4936.\
096123882469", "+", 
          RowBox[{
          "7.853917392523956250555846410873893534560484`15.051498956311525*^-\
4927", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2.5118864315095824`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999994918622061318685440250894871271231765363822102111`6015.044478259875", 
          "+", 
          RowBox[{
          "1.25177057306061402873847238443669667040511525`14.750466862129239*^\
-6005", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.1622776601683795`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99999999999997282153603657727460796384545424989523095468653`7270.\
316229003585", "+", 
          RowBox[{
          "1.0597518678248573247051189957963363520496`14.750465157092915*^-\
7260", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.9810717055349776`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999900850496332996045696\
2300258590997088441568`8718.754157176232", "+", 
          RowBox[{
          "5.3737234781142323672526454757651104327`14.75046335135372*^-8709", 
           " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5.011872336272725`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
37377758758979775719623276320164474839753`10376.953663472077", "+", 
          RowBox[{
          "1.1952145546961707192695407173501453833`14.750447122126301*^-\
10366", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6.309573444801943`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99999999999911555351137423195440911348189326857614577004`12260.803672504146", 
          "+", 
          RowBox[{
          "2.73106070260253711853020160907243257795446`14.750433117738908*^-\
12250", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"7.943282347242821`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999999999999998642703943106485956402588673177592482734`14385.\
617639841981", "+", 
          RowBox[{
          "5.17917942107663023483942194603421606`14.750424473100997*^-14375", 
           " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10.`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999998794469\
81862352311680513826444897546388500536858`16766.66867403286", "+", 
          RowBox[{
          "1.82897815340040880960126122582955262534531088`14.75028960875842*^-\
16755", " ", "\[ImaginaryI]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.00001`", ",", 
         RowBox[{"7.771561172376096`*^-12", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000012589254117941661`", ",", 
         RowBox[{"1.7763568394002505`*^-11", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001584893192461114`", ",", 
         RowBox[{"4.440892098500626`*^-11", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000019952623149688786`", ",", 
         RowBox[{"1.0880185641326534`*^-10", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000025118864315095822`", ",", 
         RowBox[{"2.653433028854124`*^-10", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000031622776601683795`", ",", 
         RowBox[{"6.472600233564663`*^-10", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000039810717055349695`", ",", 
         RowBox[{"1.574296248918472`*^-9", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00005011872336272725`", ",", 
         RowBox[{"3.810285420513537`*^-9", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00006309573444801929`", ",", 
         RowBox[{"9.183764859699295`*^-9", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00007943282347242822`", ",", 
         RowBox[{"2.203459625871318`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0001`", ",", 
         RowBox[{"5.263456226423102`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00012589254117941674`", ",", 
         RowBox[{"1.2518318948107066`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00015848931924611142`", ",", 
         RowBox[{"2.9639508802858927`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00019952623149688788`", ",", 
         RowBox[{"6.982079188144752`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0002511886431509582`", ",", 
         RowBox[{"1.634581147769154`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00031622776601683794`", ",", 
         RowBox[{"3.7975450881688744`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00039810717055349735`", ",", 
         RowBox[{"8.744046156916596`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0005011872336272725`", ",", 
         RowBox[{"0.000019943908636133045`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000630957344480193`", ",", 
         RowBox[{"0.00004508176259132579`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0007943282347242822`", ",", 
         RowBox[{"0.0001010974426889355`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001`", ",", 
         RowBox[{"0.0002251406424497171`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0012589254117941675`", ",", 
         RowBox[{"0.0004981729268668245`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001584893192461114`", ",", 
         RowBox[{"0.001095349877802243`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0019952623149688807`", ",", 
         RowBox[{"0.0023924079609550786`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.002511886431509582`", ",", 
         RowBox[{"0.005186972207966822`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0031622776601683794`", ",", 
         RowBox[{"0.011148757660240483`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.003981071705534973`", ",", 
         RowBox[{"0.023701036601979975`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.005011872336272725`", ",", 
         RowBox[{"0.04962209139705409`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.006309573444801936`", ",", 
         RowBox[{"0.10149876716581652`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00794328234724282`", ",", 
         RowBox[{"0.19978722710392505`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01`", ",", 
         RowBox[{"0.3682276758319597`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.012589254117941675`", ",", 
         RowBox[{"0.6075523467641892`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01584893192461114`", ",", 
         RowBox[{"0.8476300474296083`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01995262314968881`", ",", 
         RowBox[{"0.9760902792835732`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.025118864315095822`", ",", 
         RowBox[{"0.9993244941897982`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.03162277660168379`", ",", 
         RowBox[{"0.9999992050363701`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.039810717055349734`", ",", 
         RowBox[{"0.9999999999970253`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.05011872336272725`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.06309573444801936`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.07943282347242822`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"7.326670348383186`*^-88", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.1`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"3.757868417519997`*^-123", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.12589254117941687`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"2.470147808875862`*^-193", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.15848931924611143`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"1.5888192023257797`*^-299", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.1995262314968879`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999986823878522\
4842888139389040468112399`461.8348021800242", "+", 
          RowBox[{
          "4.16299245260377231854517234848457891036548515492123`15.\
954589770191005*^-449", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.25118864315095824`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999996792614485528254667703295786176929601409179\
007`663.1462139993372", "+", 
          RowBox[{
          "1.7620966616132219996790516276012661075265709`15.653559774527023*^-\
650", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.31622776601683794`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999793391701005440\
072769589508248442984320613282671679128`925.3369395921532", "+", 
          RowBox[{
          "1.398602133116689581135611072747850237324010890356658`15.\
653559774527023*^-912", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.39810717055349776`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99999938838774535999766267142007479155024657431741608`1257.563822116834", "+", 
          RowBox[{
          "4.188928035928510250214495276920232208795278215`15.352157496235277*^\
-1245", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5011872336272725`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999997500510063048460231820273665452382301444`1670.\
9528337751806", "+", 
          RowBox[{
          "1.4151742940332911171838054637897385191`15.35222209138885*^-1658", 
           " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.6309573444801942`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999895515513875\
497345790985924138710936`2176.331590326622", "+", 
          RowBox[{
          "6.053724638248544987237103719408129141423329919497289`15.\
352214907844614*^-2164", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.7943282347242822`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999810514071909925470687741057\
2238618062836249`2784.772334698187", "+", 
          RowBox[{
          "7.919865117599821828930925817610741554589`15.051102565111776*^-\
2773", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999882157\
3010909763593295415254397580801764933588132927`3507.979055991208", "+", 
          RowBox[{
          "3.538944447851822797228938758036404918417389864768`15.\
051214408253964*^-3496", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.2589254117941688`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999998549267226556484\
292521361695896267573754686133211194`4355.888692230206", "+", 
          RowBox[{
          "4.658426174444860314296747655673362400361070760841`15.\
051194639595089*^-4344", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.584893192461114`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999452987476246043379502225613824087691861612957198\
0529`5337.0112463587275", "+", 
          RowBox[{
          "1.64759940500436302120657794219120508598033969440549`14.\
750112055889216*^-5325", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.9952623149688828`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999337535587169903331\
302596897883332955806743404297`6458.92841028019", "+", 
          RowBox[{
          "1.459564375052413705131345625397015100208183279`14.750208121320368*^\
-6447", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2.5118864315095824`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
978082586849401326483560918795607048116130906368553484`7726.408287227432", 
          "+", 
          RowBox[{
          "7.5013494480701199642981231909532200459166598882883`14.\
750063286932834*^-7715", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.1622776601683795`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99999999999999466404779966324679093685209326952530229165`9143.021869852722", 
          "+", 
          RowBox[{
          "1.819359825442730443852663385781787295727`14.750064822519922*^-\
9131", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.9810717055349776`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999991730752596586247808854388859581969`10711.832994179247",
           "-", 
          RowBox[{
          "1.954380865861466795319476937008471962008280567742`14.\
75046698089892*^-10702", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5.011872336272725`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999993779262419139903723102083397952631214860704`\
12436.954441844173", "+", 
          RowBox[{
          "3.3408868958785375385913202427814342387434`14.7498318637798*^-\
12425", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6.309573444801943`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999832139551376609182003219998866\
5919928980735`14325.522340752208", "+", 
          RowBox[{
          "1.3118212737013177059126475736832209257922`14.749541417211237*^-\
14313", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"7.943282347242821`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999998843002767591683777559835733668430728466`16389.684162456175", "+", 
          RowBox[{
          "8.457065655566641259065390831705081119`14.749601481265914*^-16378",
            " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10.`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99968428016089138006416389136843081752`18648.24727789297", "+", 
          RowBox[{
          "3.017873804981505379977654690647825621571677669637647`14.\
749334185622937*^-18636", " ", "\[ImaginaryI]"}]}]}], "}"}]}], "}"}]}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.78224222422806*^9, 3.782242224711516*^9}, {
  3.782242289772006*^9, 3.782242292832909*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alltheory", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0.00001`", ",", 
      RowBox[{"0.004255901923682859`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.000012589254117941661`", ",", 
      RowBox[{"0.0053575492358338694`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.00001584893192461114`", ",", 
      RowBox[{"0.0067441516854744865`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.000019952623149688786`", ",", 
      RowBox[{"0.008489259139161986`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.000025118864315095822`", ",", 
      RowBox[{"0.01068529164012788`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.000031622776601683795`", ",", 
      RowBox[{"0.013448300625872878`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.000039810717055349695`", ",", 
      RowBox[{"0.016923875613529704`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.00005011872336272725`", ",", 
      RowBox[{"0.02129443271835585`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.00006309573444801929`", ",", 
      RowBox[{"0.026788141996554327`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.00007943282347242822`", ",", 
      RowBox[{"0.03368974767574706`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.0001`", ",", 
      RowBox[{"0.04235348825450003`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.00012589254117941674`", ",", 
      RowBox[{"0.05321818691335278`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.00015848931924611142`", ",", 
      RowBox[{"0.06682428147338215`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.00019952623149688788`", ",", 
      RowBox[{"0.08383199232399552`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.0002511886431509582`", ",", 
      RowBox[{"0.10503876670250001`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.00031622776601683794`", ",", 
      RowBox[{"0.13139230800576218`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.00039810717055349735`", ",", 
      RowBox[{"0.16399243239687444`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.0005011872336272725`", ",", 
      RowBox[{"0.204070097507436`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.000630957344480193`", ",", 
      RowBox[{"0.25292457924668266`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.0007943282347242822`", ",", 
      RowBox[{"0.3117896993698642`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.001`", ",", 
      RowBox[{"0.38158864596192277`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.0012589254117941675`", ",", 
      RowBox[{"0.4625305052352049`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.001584893192461114`", ",", 
      RowBox[{"0.553516711619294`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.0019952623149688807`", ",", 
      RowBox[{"0.6513985086181926`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.002511886431509582`", ",", 
      RowBox[{"0.7503139738505484`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.0031622776601683794`", ",", 
      RowBox[{"0.8416742198469033`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.003981071705534973`", ",", 
      RowBox[{"0.9157168838785625`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.005011872336272725`", ",", 
      RowBox[{"0.9652521927879277`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.006309573444801936`", ",", 
      RowBox[{"0.9902055896921497`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.00794328234724282`", ",", 
      RowBox[{"0.9984478578862828`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.01`", ",", 
      RowBox[{"0.9998986899380937`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.012589254117941675`", ",", 
      RowBox[{"0.9999983479084642`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.01584893192461114`", ",", 
      RowBox[{"0.9999999969990214`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.01995262314968881`", ",", 
      RowBox[{"0.9999999999998354`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.025118864315095822`", ",", 
      RowBox[{"1.`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.03162277660168379`", ",", 
      RowBox[{"1.`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.039810717055349734`", ",", 
      RowBox[{"1.`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.05011872336272725`", ",", 
      RowBox[{"1.`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.06309573444801936`", ",", 
      RowBox[{"1.`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.07943282347242822`", ",", 
      RowBox[{"1.`", "\[VeryThinSpace]", "+", 
       RowBox[{"7.925116675345696`*^-192", " ", "\[ImaginaryI]"}]}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"0.1`", ",", 
      RowBox[{"1.`", "\[VeryThinSpace]", "+", 
       RowBox[{"1.325850814458533`*^-265", " ", "\[ImaginaryI]"}]}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"0.12589254117941687`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999998105\
544370494843266675760495623965870191877083`393.677105332175", "+", 
       RowBox[{
       "8.8096426117104020809430720304899022027527`15.954589770191005*^-383", 
        " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.15848931924611143`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9997877005711393764140654024117679236351`556.6276409443859", "+", 
       RowBox[{
       "1.42456216451978839720619080292861272279620504619044725`15.\
954589770191005*^-544", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.1995262314968879`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999997832145994125915\
75342911014428675970685902875689672122`771.3170219790189", "+", 
       RowBox[{
       "5.06622582867291220787243987525325846434080102793786`15.\
653559774527023*^-759", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.25118864315095824`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999999999999043316026279388431831793557032837255131511401`\
1048.671910856781", "+", 
       RowBox[{
       "3.874942183534860300293149810957302624599942`15.653559774527023*^-\
1036", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.31622776601683794`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999961021482178\
828457408511857231603379732283`1399.7600747452423", "+", 
       RowBox[{
       "1.94985210959028942979835550752567166033`15.352257962982229*^-1387", 
        " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.39810717055349776`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999990719880261254368001405415270022960058238\
98784`1838.3833189626719", "+", 
       RowBox[{
       "4.720650251756940774803143408061445574166883`15.352253369029476*^-\
1826", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.5011872336272725`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99999999999999999999999999999999775582709217306226405103856605227581669775113`\
2379.000095638583", "+", 
       RowBox[{
       "9.49137833905216965933816749798400528804549`15.352300000353498*^-\
2367", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.6309573444801942`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999965555517888\
386008483120250759970027924518`3037.5127270842336", "+", 
       RowBox[{
       "1.49851811410178856716322936681565168454`15.051086320049887*^-3025", 
        " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0.7943282347242822`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9998652325854559539534291182874245498177`3831.9207175839215", "+", 
       RowBox[{
       "4.24652358220754704821391492650732171104736002863901`15.\
051200350726608*^-3820", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999207988132520052593715731433154106122235811488107659`4780.\
151905554485", "+", 
       RowBox[{
       "1.797815037828110042906587192153850528496055536492`15.051284092775497*^\
-4768", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.2589254117941688`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999998380880196490323645644399863477840\
2312953068823`5900.540202074338", "+", 
       RowBox[{
       "3.93234164021937870852681223736397749117115875`14.750181342080543*^-\
5889", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.584893192461114`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999999999999997263865941313624651694137197358213158018375518`\
7212.31240601915", "+", 
       RowBox[{
       "6.226244265760924188390656661815403747135483`14.75019953039571*^-\
7201", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1.9952623149688828`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999810502327\
23777294795381851407626570899180725691`8733.47218975716", "+", 
       RowBox[{
       "3.1472105355544011740227005944598306897286243`14.750272546166403*^-\
8722", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2.5118864315095824`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999999993455015247803104703368107330585783784115971165772729`\
10481.933514092443", "+", 
       RowBox[{
       "1.6833590270750803174403280129878951189755339094447`14.\
750164321868958*^-10470", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3.1622776601683795`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999982323364543\
34134902831113313812058375404244`12475.502031373631", "+", 
       RowBox[{
       "4.510584285245385250000329710564164841807`14.750166728605452*^-12464",
         " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3.9810717055349776`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999998517835143190380\
163898842124793594659065`14732.57956703659", "+", 
       RowBox[{
       "2.2713229781720432365974409052144436`14.750467967729048*^-14723", " ",
         "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5.011872336272725`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999999999999970658919999043780302902185468125272822432`17273.\
281357680135", "+", 
       RowBox[{
       "1.179210322339889937309859350455571054299`14.74999243642257*^-17261", 
        " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"6.309573444801943`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999254698696\
6257921780455601466231166288064093055`20120.87577685515", "+", 
       RowBox[{
       "4.3231858597076347397834452233263834847780033`14.749780771825648*^-\
20109", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"7.943282347242821`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999997249221184191042036546013\
408644588216061633`23303.308809008122", "+", 
       RowBox[{
       "1.4901979990699957961887232577575697087163`14.749826303043864*^-\
23291", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"10.`", ",", 
      RowBox[{
      "0.999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999873285559433971429478101252767874326`26854.644534775794", "+", 
       RowBox[{
       "9.6791864110205398321730458104448`14.749562375722904*^-26843", " ", 
        "\[ImaginaryI]"}]}]}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.782242318499735*^9, 3.782242322144066*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.00001`", ",", 
     RowBox[{"0.004255901923682859`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.000012589254117941661`", ",", 
     RowBox[{"0.0053575492358338694`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.00001584893192461114`", ",", 
     RowBox[{"0.0067441516854744865`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.000019952623149688786`", ",", 
     RowBox[{"0.008489259139161986`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.000025118864315095822`", ",", 
     RowBox[{"0.01068529164012788`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.000031622776601683795`", ",", 
     RowBox[{"0.013448300625872878`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.000039810717055349695`", ",", 
     RowBox[{"0.016923875613529704`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.00005011872336272725`", ",", 
     RowBox[{"0.02129443271835585`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.00006309573444801929`", ",", 
     RowBox[{"0.026788141996554327`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.00007943282347242822`", ",", 
     RowBox[{"0.03368974767574706`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.0001`", ",", 
     RowBox[{"0.04235348825450003`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.00012589254117941674`", ",", 
     RowBox[{"0.05321818691335278`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.00015848931924611142`", ",", 
     RowBox[{"0.06682428147338215`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.00019952623149688788`", ",", 
     RowBox[{"0.08383199232399552`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.0002511886431509582`", ",", 
     RowBox[{"0.10503876670250001`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.00031622776601683794`", ",", 
     RowBox[{"0.13139230800576218`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.00039810717055349735`", ",", 
     RowBox[{"0.16399243239687444`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.0005011872336272725`", ",", 
     RowBox[{"0.204070097507436`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.000630957344480193`", ",", 
     RowBox[{"0.25292457924668266`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.0007943282347242822`", ",", 
     RowBox[{"0.3117896993698642`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.001`", ",", 
     RowBox[{"0.38158864596192277`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.0012589254117941675`", ",", 
     RowBox[{"0.4625305052352049`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.001584893192461114`", ",", 
     RowBox[{"0.553516711619294`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.0019952623149688807`", ",", 
     RowBox[{"0.6513985086181926`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.002511886431509582`", ",", 
     RowBox[{"0.7503139738505484`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.0031622776601683794`", ",", 
     RowBox[{"0.8416742198469033`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.003981071705534973`", ",", 
     RowBox[{"0.9157168838785625`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.005011872336272725`", ",", 
     RowBox[{"0.9652521927879277`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.006309573444801936`", ",", 
     RowBox[{"0.9902055896921497`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.00794328234724282`", ",", 
     RowBox[{"0.9984478578862828`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.01`", ",", 
     RowBox[{"0.9998986899380937`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.012589254117941675`", ",", 
     RowBox[{"0.9999983479084642`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.01584893192461114`", ",", 
     RowBox[{"0.9999999969990214`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.01995262314968881`", ",", 
     RowBox[{"0.9999999999998354`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.025118864315095822`", ",", 
     RowBox[{"1.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.03162277660168379`", ",", 
     RowBox[{"1.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.039810717055349734`", ",", 
     RowBox[{"1.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.05011872336272725`", ",", 
     RowBox[{"1.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.06309573444801936`", ",", 
     RowBox[{"1.`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.07943282347242822`", ",", 
     RowBox[{"1.`", "\[VeryThinSpace]", "+", 
      RowBox[{"7.925116675345696`*^-192", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0.1`", ",", 
     RowBox[{"1.`", "\[VeryThinSpace]", "+", 
      RowBox[{"1.325850814458533`*^-265", " ", "\[ImaginaryI]"}]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0.12589254117941687`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999981055\
44370494843266675760495623965870191877083`393.677105332175", "+", 
      RowBox[{
      "8.8096426117104020809430720304899022027527`15.954589770191005*^-383", 
       " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.15848931924611143`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
997877005711393764140654024117679236351`556.6276409443859", "+", 
      RowBox[{
      "1.42456216451978839720619080292861272279620504619044727`15.\
954589770191005*^-544", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.1995262314968879`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999978321459941259157\
5342911014428675970685902875689672122`771.3170219790189", "+", 
      RowBox[{
      "5.06622582867291220787243987525325846434080102793786`15.\
653559774527023*^-759", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.25118864315095824`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999043316026279388431831793557032837255131511401`1048.\
671910856781", "+", 
      RowBox[{
      "3.874942183534860300293149810957302624599942`15.653559774527023*^-\
1036", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.31622776601683794`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999610214821788\
28457408511857231603379732283`1399.7600747452423", "+", 
      RowBox[{
      "1.94985210959028942979835550752567166033`15.352257962982229*^-1387", 
       " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.39810717055349776`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999907198802612543680014054152700229600582389\
8784`1838.3833189626719", "+", 
      RowBox[{
      "4.720650251756940774803143408061445574166883`15.352253369029476*^-\
1826", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5011872336272725`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999999999999999775582709217306226405103856605227581669775113`\
2379.000095638583", "+", 
      RowBox[{
      "9.49137833905216965933816749798400528804549`15.352300000353498*^-2367",
        " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6309573444801942`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999655555178883\
86008483120250759970027924518`3037.5127270842336", "+", 
      RowBox[{
      "1.49851811410178856716322936681565168454`15.051086320049887*^-3025", 
       " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.7943282347242822`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
998652325854559539534291182874245498177`3831.9207175839215", "+", 
      RowBox[{
      "4.24652358220754704821391492650732171104736002863901`15.\
051200350726608*^-3820", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999207988132520052593715731433154106122235811488107659`4780.\
151905554485", "+", 
      RowBox[{
      "1.797815037828110042906587192153850528496055536492`15.051284092775497*^\
-4768", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.2589254117941688`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999983808801964903236456443998634778402\
312953068823`5900.540202074338", "+", 
      RowBox[{
      "3.93234164021937870852681223736397749117115875`14.750181342080543*^-\
5889", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.584893192461114`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999997263865941313624651694137197358213158018375518`\
7212.31240601915", "+", 
      RowBox[{
      "6.226244265760924188390656661815403747135483`14.75019953039571*^-7201",
        " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.9952623149688828`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999998105023272\
3777294795381851407626570899180725691`8733.47218975716", "+", 
      RowBox[{
      "3.1472105355544011740227005944598306897286243`14.750272546166403*^-\
8722", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.5118864315095824`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999993455015247803104703368107330585783784115971165772729`\
10481.933514092443", "+", 
      RowBox[{
      "1.6833590270750803174403280129878951189755339094447`14.750164321868958*^\
-10470", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.1622776601683795`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999823233645433\
4134902831113313812058375404244`12475.502031373631", "+", 
      RowBox[{
      "4.510584285245385250000329710564164841807`14.750166728605452*^-12464", 
       " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.9810717055349776`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999985178351431903801\
63898842124793594659065`14732.57956703659", "+", 
      RowBox[{
      "2.2713229781720432365974409052144436`14.750467967729048*^-14723", " ", 
       "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.011872336272725`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999970658919999043780302902185468125272822432`17273.\
281357680135", "+", 
      RowBox[{
      "1.179210322339889937309859350455571054299`14.74999243642257*^-17261", 
       " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.309573444801943`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999992546986966\
257921780455601466231166288064093055`20120.87577685515", "+", 
      RowBox[{
      "4.3231858597076347397834452233263834847780033`14.749780771825648*^-\
20109", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7.943282347242821`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999972492211841910420365460134\
08644588216061633`23303.308809008122", "+", 
      RowBox[{
      "1.4901979990699957961887232577575697087163`14.749826303043864*^-23291",
        " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"10.`", ",", 
     RowBox[{
     "0.9999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999873285559433971429478101252767874326`26854.644534775794", "+", 
      
      RowBox[{
      "9.6791864110205398321730458104448`14.749562375722904*^-26843", " ", 
       "\[ImaginaryI]"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.782252451752054*^9, 3.7822698621763983`*^9, {3.784901038472451*^9, 
   3.784901044790539*^9}, 3.7849052675218773`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot panel A", "Subsubsection",
 CellChangeTimes->{{3.78224219119035*^9, 3.782242191656519*^9}, {
  3.782242350843356*^9, 3.782242352499173*^9}, {3.7822433307197733`*^9, 
  3.7822433322630377`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"N0", "=", 
   SuperscriptBox["10", "4"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m0", "=", 
   RowBox[{"-", "0.1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"letter", "=", "\"\<A\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"datadir", "<>", 
     RowBox[{"ToString", "[", 
      RowBox[{"StringForm", "[", 
       RowBox[{
       "\"\<prescue_poisson_N``_n``_Es``_mmax``_mwt``_mutmax10_nreps10000.csv\
\>\"", ",", 
        RowBox[{"NumberForm", "[", 
         RowBox[{"N0", ",", "1"}], "]"}], ",", "n", ",", "Es", ",", 
        RowBox[{"NumberForm", "[", 
         RowBox[{"mmax", ",", 
          RowBox[{"{", 
           RowBox[{"3", ",", "2"}], "}"}]}], "]"}], ",", 
        RowBox[{"NumberForm", "[", 
         RowBox[{"m0", ",", 
          RowBox[{"{", 
           RowBox[{"3", ",", "2"}], "}"}]}], "]"}]}], "]"}], "]"}]}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"dat", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", 
       RowBox[{"{", "1", "}"}]}], "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"dat", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", 
          RowBox[{"{", "1", "}"}]}], "]"}], "]"}], "*", "Uc"}], "/.", 
      RowBox[{"Uc", "\[Rule]", 
       RowBox[{
        SuperscriptBox["n", "2"], 
        RowBox[{"\[Lambda]", "/", "4"}]}]}]}], "/.", 
     RowBox[{"\[Lambda]", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"Es", "/", "n"}]}]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figS1a", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListLogLogPlot", "[", 
      RowBox[{
       RowBox[{"Re", "[", "theory", "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
       
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SuperscriptBox["10", 
             RowBox[{"-", "5"}]], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SuperscriptBox["10", 
             RowBox[{"-", "6"}]], ",", "1"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{",", "\"\<Probability of rescue\>\"", ",", ","}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"FrameTicksStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontColor", "\[Rule]", "White"}], ",", "Automatic", ",", 
          "Automatic", ",", "Automatic"}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"LineLegend", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{
             "\"\<1-step\>\"", ",", "\"\<2-step\>\"", ",", "\"\<3-step\>\"", 
              ",", "\"\<4-step\>\""}], "}"}]}], "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.85", ",", "0.23"}], "}"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ListLogLogPlot", "[", 
      RowBox[{
       RowBox[{"Re", "[", "alltheory", "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Black"}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"LineLegend", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", "\"\<total\>\"", "}"}]}], "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.56", ",", "0.23"}], "}"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ListLogLogPlot", "[", 
      RowBox[{"dat", ",", 
       RowBox[{"PlotMarkers", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "Medium"}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"letter", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"StringForm", "[", 
             RowBox[{"\"\<\!\(\*
StyleBox[SubscriptBox[\"m\", \"0\"],
FontSlant->\"Italic\"]\)=``\>\"", ",", "m0"}], "]"}], ",", "12", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"2", "/", "10"}], ",", 
             RowBox[{"9.5", "/", "10"}]}], "}"}]}]}], "]"}], ",", 
        RowBox[{"braceLabel", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Log", "@", 
               RowBox[{"(", 
                RowBox[{"3", "*", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "2"}]]}], ")"}]}], ",", 
              RowBox[{"Log", "@", 
               RowBox[{"(", 
                RowBox[{"2", "*", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "6"}]]}], ")"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Log", "@", 
               RowBox[{"(", 
                RowBox[{"3", "*", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "2"}]]}], ")"}]}], ",", 
              RowBox[{"Log", "@", 
               RowBox[{"(", 
                RowBox[{"3", "*", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "4"}]]}], ")"}]}]}], "}"}]}], "}"}], ",", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<\>\"", ",", "Larger"}], "]"}]}], "]"}]}], 
       "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "m0", ",", "N0", ",", 
   "U", ",", "letter"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.782242343520281*^9, {3.782242380591099*^9, 3.78224239315565*^9}, {
   3.78224266156839*^9, 3.7822426641556063`*^9}, {3.782242704876136*^9, 
   3.7822428395426064`*^9}, {3.782242888113319*^9, 3.782242908799192*^9}, {
   3.7822429661752462`*^9, 3.782243227130135*^9}, {3.7849010522225*^9, 
   3.7849010630628033`*^9}, 3.7849052759224653`*^9}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJxdkntIk1EYxseYk2nW8u7ysjk3rynoNHGV4v6QRjcTtUw0zFQyMzHwgqDC
qFmJmuYyYamJ1kBJc9F07bxCMK8ZuJmJmiZJYtrUvMY0+059kgcOHz/Oed/3
eZ7zcZIyL1yjUiiUE7v7z/eyosFLTneH91uvzj4ftQGh1E2lKueD+K7kS+aC
NbBSmiL0LD4k+CTr4qnWsCXyGDE08uCdtqw/184KRjmK5AN+PEhgaeeHfCzh
zY73irvKDTT+AblZ4Yfh8URLsUjkBpc6Ip/eusiEnC4/ZuIgFzJGFSt9Ewch
tqZNnh/LBV1IVsW4uQUE5QQcrZ52heYwATVJaA420cqutnRXyN6eu9l5gwGr
/sfEg6scyGfFGOPrTEHHVI1+K+SASlLUODliAh2LIak0Mw7ckTSIN5k0qBxQ
r7pUsUHb/eRK1TkqZCtOSoTObGicF3oOVVKgkVnMaz3vAkofRbmDxoiuDkjC
vyY7Q4AskEVL2UJcqTTRMc8JljTS4yXcdTQlelAQVeoIav2HU8pfK6hup6zm
Xv0REHz0i33404ASuypfdytZEJ1U0Jvj9R0558iGN3odoCRUvaHun0Xj/rUG
v0l72G4+beR+nka1i3KL1GU7SJlnlOt/jCH8HnbQ7lgobokcRjh/W+A1s0yU
9D6E87aBHkoNO84XkIzI1xqWWrLOvOC3oxgiTytYm9MLnHT1COdnCXyPMQFf
UopwXofh5cz07Rl5NsL5MGE47pOZtjMKPSPyOARpTT1ptClvxCH8W4C8OlMR
HL6pwX7NIW9Jdr01uFOD/TEgcCS3p8k+XYP9mMK60DUsI9VU40Dop0OE7+7P
FnT/bTWhlwaMXaQUGdRYHxUof1cFoYdCMpuYb0QkE/M2SbYl+q+RjPstk2xH
1C/sMXF/lmQ6cT5BsgnBgyTvX5H4PPQfe+J6kj1wf5K98HySbbE+ktlY/x5j
f/vqjSQ/wvmE/d+PSvJvRgiT9Q==
         "]]}, 
       {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJxdkgtIU1EYx9ea07Ws+dqcj7m7hzOlBKcJiiVOSoKghw8iQbDZBNFA05GI
OhgxS7HQ5iskUyskLSXF5eN+QQ8ER/mojPIZ5iOV6ZjZdKy8p47ogcPlxznf
9/3//3OJ1GsX0ug0Gi3q797+Xm55GFjPlIF72aGbReEyiNRJDIY7/hBWZpZP
JPqD19VHpz96+cOT6hGrJk8KVkXAJ1OTFCLsOkamXgJjRIvyYLAUivMWvzd0
iaHbHmSWGSSQmVulF38WQfV4q0ahkEDGJSi3/CJA3RPMSTGKIdR5bcSbT0BS
TXt9fpIYbjslLtVGCOG4Wn5UPy0Cvmqs2tQtAI+Ezp72DBHE14pWr9t8wBIS
fsZoIeD+l0zNcIw3jHIMY/NFBOjy+bG+JXx4sRKhYhwgYCh7eDnrAw8qBnst
fpVCSJ/Z37HgyYWclhPaSIEQ5jbexPWmukMTRyNtO+cHyelpNlmbK1wZ1MbM
KgWQFEu8LdnkgFinS/G54QtK9bjhvf4QTClKCy6W+UCyE2uSHcWGB/bymlsN
3vBSaDU5LDlCSk9F16tOL6BLBgacHjNAoK4a2RjgA6vArXAuex98C6kzBU94
wnqynXm2dYusW6l3Vq3xoHBG6/ise51E78GDSWXYZJBklUT5cyF6K+F5TtA8
ifL2gNYsrVVtniCrqHzdYfGrMcsWOkQmUnm6QR6L3re40E+i/FyhObejeWGz
kUR5uUCBoTh+ll1Eonw4oNqQx5UeO0U2UnkchtHpqbTKn+Z+gvLvDPIKZYhL
YH4/8suGBE867WnAuz7kjwXb/xKN9roX+XEE2r/Fp/QzMespvQzMSB8d811K
Dw2zkJpvIzFT835j5lL918nd/dYw86j65R2m7v/AzKTOxzE7UGzEvHedR+cn
//MRVI85APXHHIjmY+YifZiFSP8OI3976m2Y76F8onf3o2P+AwGYhPM=
         "]]}, 
       {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQzRlQ8bp3t/KBBf/7Z3Yt1D4QPnPjvKpw5QPcLx8v
YG/XOmBWbqw77aHSgQyjSg0/G80DoqFbd2/MVjpwdI0Oa/dn9QNfjcy9zn5V
PGB2QKaxZ43agSsCO2+8qFc80KX54JhcuuqBLe+s0lm4FA9UTJP9I66scmDy
mT1f5acoHHD+5JcS+0DpQPEquxZrOYUDGjPnHX40T/HAEoFG1XUB8gdMz+Re
Wx6ncCD5TIvT0xS5A5XzWVJy7OUOKHd0xMtUyh4QvfdfyfGI9IEHzj01wb0y
B0KnxO1n95GE+kP6QJbll5ei18UOxO+evO3gVqkDnd9v9bxKFTkgVz798o+T
kgc2n958y/On4IE7RrM/6N+TOOBxYvmzmyr8B2a/m8eb/kn8gFjgaca1aVwH
olct0prHJn6AO0i58/g+1gNSacvcr0qJHZhd0H+32oLxwA3FVSk8+qIH1LrM
Hkae/bl/+t21jc7OIgdM2Jb/+HP+4/4wcHgKH7h+yOrd3TVP90PCT+hAnRPX
R4fyq/sh4SV4wPxtwjvb83v3Q8JH4MDJSqfWpMdT9y8Ghwf/AVVps1srmkL2
K4L9z3ugySlroWHV030Q/3IfUG3eOWGarfY+iP84D/AxgMDXPRD/sB9ggAJJ
sPvZ4PxpYPeywPkQ9zHB+RPB7mGA8xXA9v/dD+eD7fsJ54uBzf+2H9W8T3C+
OFj/WwQfrP4ZnM8Glr8L57OC+WfhfHQQCJG3h/E1IfrhfA2I+XC+FsR+OF8M
4j44XwHifgQf4j80/X/h/KmQ8HFANY8JzgcAR7tKhw==
         "]]}, 
       {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQ/feNWbPVDYUDC/73z+xaqH1g8pk9X+WnKBxQbOiZ
/Hmp1oHiVXYt1nIKB+qiTLijvmkcWCLQqLouQP7AA17DOaHe6geSz7Q4PU2R
OxCqPUtCa6nqAeWOjniZStkDD6vnnpnJrHLggXNPTXCvzIEf3/4rSKcpQe2R
PtBeGz5V94zCgfjdk7cd3Cp1wPSm7hKhbLkDcuXTL/84KXmg7dQ7ZQ8X6QN3
jGZ/0L8nceCxRaaXn4rEgdnv5vGmfxI/kO133/wRt+iB6FWLtOaxiR9Y+PZX
ZvgfwQNSacvcr0qJHdCeeHS95AfeAzcUV6Xw6IseuBNkYXiGjePA9LtrG52d
RQ58KTDRs/JlOhA2c+O8qnDhA9t1n0jNO/Jzv2jo1t0bs4UOfHmRdsz+x/v9
VwR23nhRL3iA8wDPnpwn9/dDwkfgQPYsc5OXGkf3LwaHB/+Bu/NXHXl/fMZ+
RbD/eQ/I7WO4U67ith/iX+4DD/mCTDasWbUP4j/OA6e1GBgatLr2QvzDfoAB
CiTB7meD86eB3csC50PcxwTnTwS7hwHOVwDb/3c/nA+27yecLwY2/9t+VPM+
wfniYP1vEXyw+mdwPhtY/i6czwrmn4Xz0UEgRN4exteE6IfzNSDmw/laEPvh
fDGI++B8BYj7EXyI/9D0/4Xzp0LCxwHVPCY4HwCxARrd
         "]]}}, {}}, {{{}, {}, 
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJxd0m1IU1EYB/DLmprv06lr03RXnXNaSAuWpKa0QrCkWegoCWlZGlJ9kBhK
ZNayIZmWpon42vSDVKLkbC09j0EvvkGZmmQOTSsRJrZYuUpX3lNH9MLl8uPc
85zn+d9Lq84fPsWiKCru7736TG9tiqhzFANSdbTljflCjDbUYCgLg5XX78Qw
7wOC0y2Jo4IwmLQ803vYufBTHj62qBNBevnMzWwuF8bp1ky3KBEUxb1nD4u9
4bE98pvYEApS+vlXRawX3J18UCiXh0LEZa3MrOCA2hjFyRgKgcQd82OqAQ9Q
VrfX5StDQEJdr1Ba3UCm3rm9cjoY4p9o3piCXME3tdPYnhMMuvx+Q+QBZ7BK
dyUNWWkIvnDJdEXtBCMcw/hcAQ3DLsnihGYHeLSwO4vtQkP0we4B08gmKB98
ag2qEIJHUR+f7cSC3NY9mphAIXS5pthLYinQcQpFDxVBcM3gH59s/o1ODmr2
fsoMBF3vkqT7rA2FaLUZAXlbIcfWUVu/YkVT8hsXj5QEQPYZXkBlswU12Eur
ixv9wZCUWr1/ZAFlGMv1vZ0CqD+UP33i/hwKVFe9Xerjg9Y2e3Wf+SP6IK1Z
jDJtAc2KftF4bgLVLNS5Z1l44FU4UFakGkb4e/Bgdqbg+A/PFwjn7wcTYf12
RbEe4bx9YVQpgzz/JlTF5OsDv9JuN2aFa1AakycXpA1fdLLcowjn5w1TqaxX
olIBwnl5QX9a+7G2LmMPzocDm+kWiH4p6bnH5OEJ/NWfY1tiN83M7w7UvwvP
60qM53MmxvM4EfOZ/h2JK5l+2cS4PxbxLaYfiljInL+MiJnzbMR+TP3vaH09
CzGP2W9eM/P+Z2JHZn2S2IHxEPHGKwWvx/+3BO8nDsf1iSPw+cR+uD9iIe5/
zXi+DfuXie/gfBLW12MR/wH9m3un
         "]]}}, {}}, {
      GraphicsComplexBox[{{-10.819778284410283`, -4.9062752787720125`}, \
{-8.517193191416238, -2.569158202235591}, {-6.214608098422191, \
-0.48906413198447785`}, {-10.819778284410283`, -4.9062752787720125`}, \
{-8.517193191416238, -2.569158202235591}, {-6.214608098422191, \
-0.48906413198447785`}}, {
        {GrayLevel[0], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 4], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 5], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 6]}, {}}], {}}}, {InsetBox[
      TemplateBox[{
       StyleBox[
        "\"total\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"Directive", "[", 
                RowBox[{
                  RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                  RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], "}"}], ",", 
            RowBox[{"{", #, "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      Scaled[{0.56, 0.23}], ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TemplateBox[{
       StyleBox[
        "\"1-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"2-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"3-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"4-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.5470136627990908`", ",", "0.24`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24`", ",", "0.6`", ",", "0.33692049419863584`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      Scaled[{0.85, 0.23}], ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesOrigin->{-11.512925464970229`, -13.815510557964274`},
   CoordinatesToolOptions:>{"DisplayFunction" -> ({
       Exp[
        Part[#, 1]], 
       Exp[
        Part[#, 2]]}& ), "CopiedValueFunction" -> ({
       Exp[
        Part[#, 1]], 
       Exp[
        Part[#, 2]]}& )},
   Epilog->{
     InsetBox[
      FormBox[
       StyleBox[
       "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
       TraditionalForm], 
      Scaled[{0.05, 0.95}]], 
     InsetBox[
      FormBox[
       StyleBox[
        InterpretationBox[
        "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=\\!\\(TraditionalForm\\`\\(-0.1`\\\
)\\)\"", 
         StringForm[
         "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=``", -0.1], Editable -> False], 12, FontFamily -> 
        "Helvetica", StripOnInput -> False], TraditionalForm], 
      NCache[
       Scaled[{
         Rational[1, 5], 0.9500000000000001}], 
       Scaled[{0.2, 0.9500000000000001}]]], {
      Arrowheads[{{0.02, 0, {
          GraphicsBox[
           CircleBox[{1, -1}, 1, 
            
            NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
             3.141592653589793}]]], -1}}, {0.02, 1, {
          GraphicsBox[{
            CircleBox[{-1, 1}, 1, 
             NCache[{Rational[-1, 2] Pi, 0}, {-1.5707963267948966`, 0}]], 
            InsetBox[
             BoxData[
              FormBox[
               StyleBox["\"\"", Larger, StripOnInput -> False], 
               TraditionalForm]], {0, 2}]}], 1}}}], 
      ArrowBox[
       NCache[{{-Log[
            Rational[100, 3]], -Log[500000]}, {-Log[
            Rational[100, 3]], Rational[1, 2] (-Log[
              Rational[10000, 3]] - Log[
           500000])}}, {{-3.506557897319982, -13.122363377404328`}, \
{-3.506557897319982, -10.6170457303562}}]], 
      Arrowheads[{{0.02, 0, {
          GraphicsBox[
           CircleBox[{1, 1}, 1, 
            
            NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
             4.71238898038469}]]], -1}}, {0.02, 1, {
          GraphicsBox[
           CircleBox[{-1, -1}, 1, 
            NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]], 1}}}], 
      ArrowBox[
       NCache[{{-Log[
            Rational[100, 3]], Rational[1, 2] (-Log[
              Rational[10000, 3]] - Log[500000])}, {-Log[
            Rational[100, 3]], -Log[
            Rational[
            10000, 3]]}}, {{-3.506557897319982, -10.6170457303562}, \
{-3.506557897319982, -8.111728083308073}}]]}},
   Frame->{True, True, False, False},
   FrameLabel->{{
      FormBox["\"Probability of rescue\"", TraditionalForm], ""}, {"", ""}},
   FrameTicks->{{{{-13.815510557964274`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-11.512925464970229`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-9.210340371976182, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-6.907755278982137, 
        FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
        FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
        FormBox["0.1`", TraditionalForm]}, {0., 
        FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.716898269296165`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.429216196844383`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.206072645530174`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.02375108873622, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.86960040890896, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.736069016284437`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.618285980628055`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.819778284410283`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.414313176302118`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.126631103850338`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.903487552536127, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.721165995742174, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.567015315914915, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.433483923290392, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.315700887634009, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-8.517193191416238, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-8.111728083308073, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.824046010856292, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.600902459542082, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.418580902748127, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.264430222920869, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.1308988302963465`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.013115794639964, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-6.214608098422191, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.298317366548036, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.995732273553991, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.659260036932778, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.407945608651872, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.6931471805599453, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659905, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.35667494393873245`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782616`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, None}, {{{-11.512925464970229`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-9.210340371976182, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-6.907755278982137, 
        FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
        FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
        FormBox["0.1`", TraditionalForm]}, {0., 
        FormBox["1", TraditionalForm]}, {-10.819778284410283`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.414313176302118`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.126631103850338`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.903487552536127, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.721165995742174, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.567015315914915, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.433483923290392, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.315700887634009, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-8.517193191416238, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-8.111728083308073, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.824046010856292, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.600902459542082, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.418580902748127, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.264430222920869, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.1308988302963465`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.013115794639964, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-6.214608098422191, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.298317366548036, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.995732273553991, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.659260036932778, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.407945608651872, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.6931471805599453, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659905, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.35667494393873245`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782616`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, None}},
   FrameTicksStyle->{
    FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
   GridLines->{None, None},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-11.512925464970229`, 0.}, {-13.815510557964274`, 0.}},
   PlotRangeClipping->True,
   PlotRangePadding->{{None, None}, {None, None}},
   Ticks->{{{-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.716898269296165`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.429216196844383`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.02375108873622, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.86960040890896, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.736069016284437`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.618285980628055`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}],
  InterpretTemplate[Legended[
    Graphics[{{{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJxdkntIk1EYxseYk2nW8u7ysjk3rynoNHGV4v6QRjcTtUw0zFQyMzHwgqDC
qFmJmuYyYamJ1kBJc9F07bxCMK8ZuJmJmiZJYtrUvMY0+059kgcOHz/Oed/3
eZ7zcZIyL1yjUiiUE7v7z/eyosFLTneH91uvzj4ftQGh1E2lKueD+K7kS+aC
NbBSmiL0LD4k+CTr4qnWsCXyGDE08uCdtqw/184KRjmK5AN+PEhgaeeHfCzh
zY73irvKDTT+AblZ4Yfh8URLsUjkBpc6Ip/eusiEnC4/ZuIgFzJGFSt9Ewch
tqZNnh/LBV1IVsW4uQUE5QQcrZ52heYwATVJaA420cqutnRXyN6eu9l5gwGr
/sfEg6scyGfFGOPrTEHHVI1+K+SASlLUODliAh2LIak0Mw7ckTSIN5k0qBxQ
r7pUsUHb/eRK1TkqZCtOSoTObGicF3oOVVKgkVnMaz3vAkofRbmDxoiuDkjC
vyY7Q4AskEVL2UJcqTTRMc8JljTS4yXcdTQlelAQVeoIav2HU8pfK6hup6zm
Xv0REHz0i33404ASuypfdytZEJ1U0Jvj9R0558iGN3odoCRUvaHun0Xj/rUG
v0l72G4+beR+nka1i3KL1GU7SJlnlOt/jCH8HnbQ7lgobokcRjh/W+A1s0yU
9D6E87aBHkoNO84XkIzI1xqWWrLOvOC3oxgiTytYm9MLnHT1COdnCXyPMQFf
UopwXofh5cz07Rl5NsL5MGE47pOZtjMKPSPyOARpTT1ptClvxCH8W4C8OlMR
HL6pwX7NIW9Jdr01uFOD/TEgcCS3p8k+XYP9mMK60DUsI9VU40Dop0OE7+7P
FnT/bTWhlwaMXaQUGdRYHxUof1cFoYdCMpuYb0QkE/M2SbYl+q+RjPstk2xH
1C/sMXF/lmQ6cT5BsgnBgyTvX5H4PPQfe+J6kj1wf5K98HySbbE+ktlY/x5j
f/vqjSQ/wvmE/d+PSvJvRgiT9Q==
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJxdkgtIU1EYx9ea07Ws+dqcj7m7hzOlBKcJiiVOSoKghw8iQbDZBNFA05GI
OhgxS7HQ5iskUyskLSXF5eN+QQ8ER/mojPIZ5iOV6ZjZdKy8p47ogcPlxznf
9/3//3OJ1GsX0ug0Gi3q797+Xm55GFjPlIF72aGbReEyiNRJDIY7/hBWZpZP
JPqD19VHpz96+cOT6hGrJk8KVkXAJ1OTFCLsOkamXgJjRIvyYLAUivMWvzd0
iaHbHmSWGSSQmVulF38WQfV4q0ahkEDGJSi3/CJA3RPMSTGKIdR5bcSbT0BS
TXt9fpIYbjslLtVGCOG4Wn5UPy0Cvmqs2tQtAI+Ezp72DBHE14pWr9t8wBIS
fsZoIeD+l0zNcIw3jHIMY/NFBOjy+bG+JXx4sRKhYhwgYCh7eDnrAw8qBnst
fpVCSJ/Z37HgyYWclhPaSIEQ5jbexPWmukMTRyNtO+cHyelpNlmbK1wZ1MbM
KgWQFEu8LdnkgFinS/G54QtK9bjhvf4QTClKCy6W+UCyE2uSHcWGB/bymlsN
3vBSaDU5LDlCSk9F16tOL6BLBgacHjNAoK4a2RjgA6vArXAuex98C6kzBU94
wnqynXm2dYusW6l3Vq3xoHBG6/ise51E78GDSWXYZJBklUT5cyF6K+F5TtA8
ifL2gNYsrVVtniCrqHzdYfGrMcsWOkQmUnm6QR6L3re40E+i/FyhObejeWGz
kUR5uUCBoTh+ll1Eonw4oNqQx5UeO0U2UnkchtHpqbTKn+Z+gvLvDPIKZYhL
YH4/8suGBE867WnAuz7kjwXb/xKN9roX+XEE2r/Fp/QzMespvQzMSB8d811K
Dw2zkJpvIzFT835j5lL918nd/dYw86j65R2m7v/AzKTOxzE7UGzEvHedR+cn
//MRVI85APXHHIjmY+YifZiFSP8OI3976m2Y76F8onf3o2P+AwGYhPM=
           "]]}, {
          Hue[0.1421359549995791, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJxTTMoPSmViYGAwA2IQzRlQ8bp3t/KBBf/7Z3Yt1D4QPnPjvKpw5QPcLx8v
YG/XOmBWbqw77aHSgQyjSg0/G80DoqFbd2/MVjpwdI0Oa/dn9QNfjcy9zn5V
PGB2QKaxZ43agSsCO2+8qFc80KX54JhcuuqBLe+s0lm4FA9UTJP9I66scmDy
mT1f5acoHHD+5JcS+0DpQPEquxZrOYUDGjPnHX40T/HAEoFG1XUB8gdMz+Re
Wx6ncCD5TIvT0xS5A5XzWVJy7OUOKHd0xMtUyh4QvfdfyfGI9IEHzj01wb0y
B0KnxO1n95GE+kP6QJbll5ei18UOxO+evO3gVqkDnd9v9bxKFTkgVz798o+T
kgc2n958y/On4IE7RrM/6N+TOOBxYvmzmyr8B2a/m8eb/kn8gFjgaca1aVwH
olct0prHJn6AO0i58/g+1gNSacvcr0qJHZhd0H+32oLxwA3FVSk8+qIH1LrM
Hkae/bl/+t21jc7OIgdM2Jb/+HP+4/4wcHgKH7h+yOrd3TVP90PCT+hAnRPX
R4fyq/sh4SV4wPxtwjvb83v3Q8JH4MDJSqfWpMdT9y8Ghwf/AVVps1srmkL2
K4L9z3ugySlroWHV030Q/3IfUG3eOWGarfY+iP84D/AxgMDXPRD/sB9ggAJJ
sPvZ4PxpYPeywPkQ9zHB+RPB7mGA8xXA9v/dD+eD7fsJ54uBzf+2H9W8T3C+
OFj/WwQfrP4ZnM8Glr8L57OC+WfhfHQQCJG3h/E1IfrhfA2I+XC+FsR+OF8M
4j44XwHifgQf4j80/X/h/KmQ8HFANY8JzgcAR7tKhw==
           "]]}, {
          Hue[0.37820393249936934`, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJxTTMoPSmViYGAwAGIQ/feNWbPVDYUDC/73z+xaqH1g8pk9X+WnKBxQbOiZ
/Hmp1oHiVXYt1nIKB+qiTLijvmkcWCLQqLouQP7AA17DOaHe6geSz7Q4PU2R
OxCqPUtCa6nqAeWOjniZStkDD6vnnpnJrHLggXNPTXCvzIEf3/4rSKcpQe2R
PtBeGz5V94zCgfjdk7cd3Cp1wPSm7hKhbLkDcuXTL/84KXmg7dQ7ZQ8X6QN3
jGZ/0L8nceCxRaaXn4rEgdnv5vGmfxI/kO133/wRt+iB6FWLtOaxiR9Y+PZX
ZvgfwQNSacvcr0qJHdCeeHS95AfeAzcUV6Xw6IseuBNkYXiGjePA9LtrG52d
RQ58KTDRs/JlOhA2c+O8qnDhA9t1n0jNO/Jzv2jo1t0bs4UOfHmRdsz+x/v9
VwR23nhRL3iA8wDPnpwn9/dDwkfgQPYsc5OXGkf3LwaHB/+Bu/NXHXl/fMZ+
RbD/eQ/I7WO4U67ith/iX+4DD/mCTDasWbUP4j/OA6e1GBgatLr2QvzDfoAB
CiTB7meD86eB3csC50PcxwTnTwS7hwHOVwDb/3c/nA+27yecLwY2/9t+VPM+
wfniYP1vEXyw+mdwPhtY/i6czwrmn4Xz0UEgRN4exteE6IfzNSDmw/laEPvh
fDGI++B8BYj7EXyI/9D0/4Xzp0LCxwHVPCY4HwCxARrd
           
           "]]}}}, {}}, {{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Thickness[Large], 
          GrayLevel[0], 
          Line[CompressedData["
1:eJxd0m1IU1EYB/DLmprv06lr03RXnXNaSAuWpKa0QrCkWegoCWlZGlJ9kBhK
ZNayIZmWpon42vSDVKLkbC09j0EvvkGZmmQOTSsRJrZYuUpX3lNH9MLl8uPc
85zn+d9Lq84fPsWiKCru7736TG9tiqhzFANSdbTljflCjDbUYCgLg5XX78Qw
7wOC0y2Jo4IwmLQ803vYufBTHj62qBNBevnMzWwuF8bp1ky3KBEUxb1nD4u9
4bE98pvYEApS+vlXRawX3J18UCiXh0LEZa3MrOCA2hjFyRgKgcQd82OqAQ9Q
VrfX5StDQEJdr1Ba3UCm3rm9cjoY4p9o3piCXME3tdPYnhMMuvx+Q+QBZ7BK
dyUNWWkIvnDJdEXtBCMcw/hcAQ3DLsnihGYHeLSwO4vtQkP0we4B08gmKB98
ag2qEIJHUR+f7cSC3NY9mphAIXS5pthLYinQcQpFDxVBcM3gH59s/o1ODmr2
fsoMBF3vkqT7rA2FaLUZAXlbIcfWUVu/YkVT8hsXj5QEQPYZXkBlswU12Eur
ixv9wZCUWr1/ZAFlGMv1vZ0CqD+UP33i/hwKVFe9Xerjg9Y2e3Wf+SP6IK1Z
jDJtAc2KftF4bgLVLNS5Z1l44FU4UFakGkb4e/Bgdqbg+A/PFwjn7wcTYf12
RbEe4bx9YVQpgzz/JlTF5OsDv9JuN2aFa1AakycXpA1fdLLcowjn5w1TqaxX
olIBwnl5QX9a+7G2LmMPzocDm+kWiH4p6bnH5OEJ/NWfY1tiN83M7w7UvwvP
60qM53MmxvM4EfOZ/h2JK5l+2cS4PxbxLaYfiljInL+MiJnzbMR+TP3vaH09
CzGP2W9eM/P+Z2JHZn2S2IHxEPHGKwWvx/+3BO8nDsf1iSPw+cR+uD9iIe5/
zXi+DfuXie/gfBLW12MR/wH9m3un
           "]]}}}, {}}, {
       GraphicsComplex[{{-10.819778284410283`, -4.9062752787720125`}, \
{-8.517193191416238, -2.569158202235591}, {-6.214608098422191, \
-0.48906413198447785`}, {-10.819778284410283`, -4.9062752787720125`}, \
{-8.517193191416238, -2.569158202235591}, {-6.214608098422191, \
-0.48906413198447785`}}, {{{
           Hue[0.67, 0.6, 0.6], 
           GrayLevel[0], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 4], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 5], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 6]}, {}}}], {}}}, {
     Epilog -> {
        Text[
         Style["A", 14, Bold, FontFamily -> "Helvetica"], 
         Scaled[{0.05, 0.95}]], 
        Text[
         Style[
          StringForm[
          "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=``", -0.1], 12, FontFamily -> "Helvetica"], 
         Scaled[{
           Rational[1, 5], 0.9500000000000001}]], {
         Arrowheads[{{0.02, 0, {
             Graphics[
              Circle[{1, -1}, 1, {Rational[1, 2] Pi, Pi}]], -1}}, {0.02, 1, {
             Graphics[{
               Circle[{-1, 1}, 1, {Rational[-1, 2] Pi, 0}], 
               Inset[
                Style["", Larger], {0, 2}]}], 1}}}], 
         Arrow[{{-Log[
              Rational[100, 3]], -Log[500000]}, {-Log[
              Rational[100, 3]], Rational[1, 2] (-Log[
                Rational[10000, 3]] - Log[500000])}}], 
         Arrowheads[{{0.02, 0, {
             Graphics[
              Circle[{1, 1}, 1, {Pi, Rational[3, 2] Pi}]], -1}}, {0.02, 1, {
             Graphics[
              Circle[{-1, -1}, 1, {0, Rational[1, 2] Pi}]], 1}}}], 
         Arrow[{{-Log[
              Rational[100, 3]], Rational[1, 2] (-Log[
                Rational[10000, 3]] - Log[500000])}, {-Log[
              Rational[100, 3]], -Log[
              Rational[10000, 3]]}}]}}, 
      FrameLabel -> {{"Probability of rescue", Null}, {Null, Null}}, 
      Ticks -> {{{-11.512925464970229`, 
          Superscript[10, -5]}, {-9.210340371976182, 
          Superscript[10, -4]}, {-6.907755278982137, 
         0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 0.1}, {
         0., 1}, {-10.819778284410283`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 0.}, {
           Thickness[0.001]}}}, {{-13.815510557964274`, 
          Superscript[10, -6]}, {-11.512925464970229`, 
          Superscript[10, -5]}, {-9.210340371976182, 
          Superscript[10, -4]}, {-6.907755278982137, 
         0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 0.1}, {
         0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 0.}, {
           Thickness[0.001]}}}}, GridLines -> {None, None}, 
      FrameTicks -> {{{{-13.815510557964274`, 
           Superscript[10, -6]}, {-11.512925464970229`, 
           Superscript[10, -5]}, {-9.210340371976182, 
           Superscript[10, -4]}, {-6.907755278982137, 
          0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 0.1}, {
          0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 0.}, {
            Thickness[0.001]}}}, None}, {{{-11.512925464970229`, 
           Superscript[10, -5]}, {-9.210340371976182, 
           Superscript[10, -4]}, {-6.907755278982137, 
          0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 0.1}, {
          0., 1}, {-10.819778284410283`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 0.}, {
            Thickness[0.001]}}}, None}}, 
      AxesOrigin -> {-11.512925464970229`, -13.815510557964274`}, 
      PlotRange -> {{-11.512925464970229`, 0.}, {-13.815510557964274`, 0.}}, 
      AspectRatio -> GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0, 0}, 
      CoordinatesToolOptions -> {"DisplayFunction" -> ({
          Exp[
           Part[#, 1]], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Exp[
           Part[#, 1]], 
          Exp[
           Part[#, 2]]}& )}, Frame -> {True, True, False, False}, 
      FrameLabel -> {Null, "Probability of rescue", Null, Null}, 
      FrameTicks -> {True, True, False, False}, 
      FrameTicksStyle -> {
       FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, 
      LabelStyle -> Directive[12, FontFamily -> "Helvetica"], Method -> {}, 
      PlotRange -> {{-11.512925464970229`, 0.}, {-13.815510557964274`, 0.}}, 
      PlotRangeClipping -> True, 
      PlotRangePadding -> {{None, None}, {None, None}}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          Thickness[Large]], 
         Directive[
          RGBColor[0.6, 0.24, 0.4428931686004542], 
          Thickness[Large]], 
         Directive[
          RGBColor[0.6, 0.5470136627990908, 0.24], 
          Thickness[Large]], 
         Directive[
          RGBColor[0.24, 0.6, 0.33692049419863584`], 
          Thickness[Large]]}, {
         Style["1-step", 12, FontFamily -> "Helvetica"], 
         Style["2-step", 12, FontFamily -> "Helvetica"], 
         Style["3-step", 12, FontFamily -> "Helvetica"], 
         Style["4-step", 12, FontFamily -> "Helvetica"]}, LegendLayout -> 
        "Column"]], 
      Scaled[{0.85, 0.23}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{{3.782243210428216*^9, 3.7822432277662973`*^9}, 
   3.782252453382649*^9, 3.7822698623918552`*^9, 3.784901067304152*^9, 
   3.7849052775205183`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical data for panel B", "Subsubsection",
 CellChangeTimes->{{3.782242444982089*^9, 3.782242445766099*^9}, {
   3.7822432932811193`*^9, 3.782243296745947*^9}, 3.78224376000844*^9, 
   3.782244112206266*^9}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"N0", "=", 
    SuperscriptBox["10", "4"]}], ";", "\[IndentingNewLine]", 
   RowBox[{"m0", "=", 
    RowBox[{"-", "0.2"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"mmax", "=", "0.5"}], ";", "\[IndentingNewLine]", 
   RowBox[{"\[Lambda]", "=", 
    RowBox[{"2", 
     RowBox[{"Es", "/", "n"}]}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"Es", "=", "0.01"}], ";", "\[IndentingNewLine]", 
   RowBox[{"n", "=", "4"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"rate4", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[CapitalLambda]4InterpolatedU", "[", 
       RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "x"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Umin", ",", "Umax", ",", "Ustep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate3", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[CapitalLambda]3InterpolatedU", "[", 
       RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "x"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Umin", ",", "Umax", ",", "Ustep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate2", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[CapitalLambda]2InterpolatedU", "[", 
       RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "x"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Umin", ",", "Umax", ",", "Ustep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate1", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[CapitalLambda]1InterpolatedU", "[", 
       RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "x"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Umin", ",", "Umax", ",", "Ustep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"Ulist", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      SuperscriptBox["10", "x"], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Umin", ",", "Umax", ",", "Ustep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"theory", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Ulist", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{"m0", ",", 
              RowBox[{"rate1", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "Ulist", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Ulist", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{"m0", ",", 
              RowBox[{"rate2", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "Ulist", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Ulist", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{"m0", ",", 
              RowBox[{"rate3", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "Ulist", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Ulist", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{"m0", ",", 
              RowBox[{"rate4", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "Ulist", "]"}]}], "}"}]}], "]"}]}], 
     "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"alltheory", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Ulist", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"prescue", "/.", 
         RowBox[{"p0", "\[Rule]", 
          RowBox[{"prescuem", "[", 
           RowBox[{"m0", ",", 
            RowBox[{
             RowBox[{"rate1", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "+", 
             RowBox[{"rate2", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "+", 
             RowBox[{"rate3", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "+", 
             RowBox[{"rate4", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}]}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "Ulist", "]"}]}], "}"}]}], "]"}]}], ";", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", 
    RowBox[{
    "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "m0", ",", "N0", ",", 
     "U"}], "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.7510768239974546`*^9, 3.751076850477788*^9}, {
   3.751077073209116*^9, 3.75107707404215*^9}, 3.7510772333562117`*^9, {
   3.7510780814540033`*^9, 3.7510780939241743`*^9}, 3.751079983731886*^9, {
   3.751080193820591*^9, 3.751080314860424*^9}, {3.751080438938933*^9, 
   3.751080453002974*^9}, {3.751080543209502*^9, 3.751080573569518*^9}, {
   3.751081090205201*^9, 3.751081108714032*^9}, {3.75156278825319*^9, 
   3.7515628382903976`*^9}, 3.751646165611027*^9, {3.751646548106408*^9, 
   3.751646656277231*^9}, 3.751646837751152*^9, {3.751646901889613*^9, 
   3.751647017114812*^9}, {3.7516470710458508`*^9, 3.7516471140016603`*^9}, 
   3.751647239375453*^9, {3.751647274447871*^9, 3.751647308444126*^9}, {
   3.751655188488014*^9, 3.7516551948421173`*^9}, 3.7516553497399673`*^9, {
   3.7516558244590063`*^9, 3.751655855414094*^9}, {3.7516785570908422`*^9, 
   3.751678622405755*^9}, {3.751678785435092*^9, 3.751678797451065*^9}, {
   3.7516789290519457`*^9, 3.7516790098557253`*^9}, {3.751679079869364*^9, 
   3.751679081963086*^9}, {3.751679566365776*^9, 3.7516795717600317`*^9}, {
   3.751679647169375*^9, 3.751679648392433*^9}, 3.7516798837830763`*^9, {
   3.7516806524922543`*^9, 3.751680669037451*^9}, {3.7564891699284067`*^9, 
   3.756489175638451*^9}, {3.7564923277678747`*^9, 3.756492331912068*^9}, {
   3.756502094040043*^9, 3.756502095005869*^9}, {3.756520270671589*^9, 
   3.75652027344243*^9}, 3.756520348755927*^9, {3.756520400861586*^9, 
   3.756520439180738*^9}, 3.756520651678936*^9, {3.756556638142688*^9, 
   3.756556640041947*^9}, {3.756570843447299*^9, 3.756570846775318*^9}, {
   3.756570974146035*^9, 3.756571120745819*^9}, 3.760624717472529*^9, {
   3.76420440689139*^9, 3.7642046427775908`*^9}, {3.764204754899797*^9, 
   3.7642047716289186`*^9}, {3.76420481154845*^9, 3.764204825101851*^9}, {
   3.764204877914257*^9, 3.764204944872558*^9}, {3.764205207233889*^9, 
   3.7642052275611*^9}, {3.764205258864553*^9, 3.764205287291357*^9}, {
   3.764205609641672*^9, 3.7642056115708113`*^9}, {3.7642056795535307`*^9, 
   3.764205689443074*^9}, 3.764205980500901*^9, {3.764209232274527*^9, 
   3.7642092792726517`*^9}, 3.764209327120954*^9, 3.764251492281107*^9, {
   3.76943292341084*^9, 3.769432965089745*^9}, {3.769458302479702*^9, 
   3.769458322534122*^9}, 3.7699675931068783`*^9, {3.771246663332436*^9, 
   3.771246699348748*^9}, {3.771246730333727*^9, 3.771246855741597*^9}, {
   3.771246890332162*^9, 3.771247074062579*^9}, {3.771248419105422*^9, 
   3.771248520499831*^9}, {3.771248807775511*^9, 3.771248822219911*^9}, {
   3.771248900616621*^9, 3.7712489008722353`*^9}, {3.77124898134147*^9, 
   3.771249011221075*^9}, {3.771249300656846*^9, 3.7712493263214703`*^9}, {
   3.7712494670163717`*^9, 3.771249525868437*^9}, {3.771249775527567*^9, 
   3.771249842817733*^9}, {3.771250190789572*^9, 3.77125021131152*^9}, 
   3.771250250390286*^9, {3.771250380877308*^9, 3.7712503813315773`*^9}, {
   3.771250529621471*^9, 3.771250562619721*^9}, {3.7712505999952583`*^9, 
   3.7712506584019213`*^9}, {3.771250871998402*^9, 3.771250929508836*^9}, {
   3.7712510935067263`*^9, 3.771251160617013*^9}, {3.7712512100306463`*^9, 
   3.7712513693375053`*^9}, {3.771251417142316*^9, 3.771251524219696*^9}, {
   3.7712518231927967`*^9, 3.771251824706218*^9}, {3.771252827855999*^9, 
   3.771252830393717*^9}, {3.7712530506465073`*^9, 3.771253058680765*^9}, 
   3.7712536774870443`*^9, 3.771527430739964*^9, 3.771529620359338*^9, 
   3.771547569567946*^9, 3.771551821750421*^9, 3.7715519737485237`*^9, 
   3.771552139395878*^9, {3.7822433600394907`*^9, 3.78224336090213*^9}, 
   3.782244569951168*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"theory", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.00001`", ",", "0.00007314046372652871`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000012589254117941661`", ",", "0.00009207751649298324`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001584893192461114`", ",", "0.00011591734214455585`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000019952623149688786`", ",", "0.00014592909698574186`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000025118864315095822`", ",", "0.00018371037608155838`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000031622776601683795`", ",", "0.00023127215734253248`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000039810717055349695`", ",", "0.0002911456743308616`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00005011872336272725`", ",", "0.0003665168639935823`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00006309573444801929`", ",", "0.00046139548729717816`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00007943282347242822`", ",", "0.0005808277843870613`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0001`", ",", "0.0007311638383529218`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00012589254117941674`", ",", "0.0009203935461855606`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00015848931924611142`", ",", "0.0011585686548950536`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00019952623149688788`", ",", "0.0014583325790454849`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0002511886431509582`", ",", "0.0018355850219021752`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00031622776601683794`", ",", "0.0023103149524704714`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00039810717055349735`", ",", "0.002907643335313459`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0005011872336272725`", ",", "0.003659126474774843`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000630957344480193`", ",", "0.0046043820138911284`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0007943282347242822`", ",", "0.0057931125466891276`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001`", ",", "0.007287616255093221`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0012589254117941675`", ",", "0.009165889373952796`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001584893192461114`", ",", "0.011525440245827356`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0019952623149688807`", ",", "0.014487946773210414`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.002511886431509582`", ",", "0.01820489368806233`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.0031622776601683794`", ",", "0.022864315726856432`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.003981071705534973`", ",", "0.028698735439603107`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.005011872336272725`", ",", "0.03599430063226294`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.006309573444801936`", ",", "0.04510096739305791`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.00794328234724282`", ",", "0.056443297210017174`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.01`", ",", "0.07053098067476249`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.012589254117941675`", ",", "0.08796748609482852`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.01584893192461114`", ",", "0.10945416429540689`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.01995262314968881`", ",", "0.1357856297038481`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.025118864315095822`", ",", "0.16783024246560252`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.03162277660168379`", ",", "0.20648715014405516`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.039810717055349734`", ",", "0.2526090657216514`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.05011872336272725`", ",", "0.30687886115628715`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.06309573444801936`", ",", "0.36963028456950564`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.07943282347242822`", ",", "0.44061216795489566`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.1`", ",", "0.5187159793971413`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.12589254117941687`", ",", "0.601722269310496`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.15848931924611143`", ",", "0.6861703279391542`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.1995262314968879`", ",", "0.7675000901966439`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.25118864315095824`", ",", "0.8406145024006825`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.31622776601683794`", ",", "0.9009027165105612`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.39810717055349776`", ",", "0.9455114221673739`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.5011872336272725`", ",", "0.9743314137635509`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.6309573444801942`", ",", "0.9900452733886792`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.7943282347242822`", ",", "0.9969771393163126`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1.`", ",", "0.9993251282747677`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.2589254117941688`", ",", "0.9998976462095102`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1.584893192461114`", ",", "0.9999904503291296`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1.9952623149688828`", ",", "0.9999995159676723`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"2.5118864315095824`", ",", "0.9999999885937381`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"3.1622776601683795`", ",", "0.9999999998971417`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"3.9810717055349776`", ",", "0.9999999999997217`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"5.011872336272725`", ",", "0.9999999999999998`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"6.309573444801943`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"7.943282347242821`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10.`", ",", "1.`"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.00001`", ",", "3.9781170735331273`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000012589254117941661`", ",", "6.185083899490351`*^-7"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001584893192461114`", ",", "9.61248396325054`*^-7"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000019952623149688786`", ",", "1.4932866104766518`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000025118864315095822`", ",", "2.318803576040196`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000031622776601683795`", ",", "3.5990879018177324`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000039810717055349695`", ",", "5.58370016112697`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00005011872336272725`", ",", "8.65857304854778`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00006309573444801929`", ",", "0.00001342014829053273`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00007943282347242822`", ",", "0.00002078963603246997`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0001`", ",", "0.00003218888321243618`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00012589254117941674`", ",", "0.00004981092503608675`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00015848931924611142`", ",", "0.00007703575809892005`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00019952623149688788`", ",", "0.00011906869870936809`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0002511886431509582`", ",", "0.00018391942155249197`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00031622776601683794`", ",", "0.00028390177851211895`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00039810717055349735`", ",", "0.00043792830910882596`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0005011872336272725`", ",", "0.00067501510905843`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000630957344480193`", ",", "0.0010396256017933814`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0007943282347242822`", ",", "0.0015997982802221644`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001`", ",", "0.002459472831711329`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0012589254117941675`", ",", "0.0037771032309573682`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001584893192461114`", ",", "0.005793606427017428`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0019952623149688807`", ",", "0.008873967800442362`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.002511886431509582`", ",", "0.013568411187415474`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0031622776601683794`", ",", "0.02070059137299496`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.003981071705534973`", ",", "0.03149081520058106`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.005011872336272725`", ",", "0.047719336033438586`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.006309573444801936`", ",", "0.07192223617335669`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.00794328234724282`", ",", "0.10757853682236074`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.01`", ",", "0.15917061625964812`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.012589254117941675`", ",", "0.23185456326841936`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.01584893192461114`", ",", "0.33026393031790713`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.01995262314968881`", ",", "0.4558346040848027`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.025118864315095822`", ",", "0.6024970158096243`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.03162277660168379`", ",", "0.7526456884117092`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.039810717055349734`", ",", "0.8790635503787811`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.05011872336272725`", ",", "0.9588369814985114`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.06309573444801936`", ",", "0.9918585694188747`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.07943282347242822`", ",", "0.9992850469430472`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.1`", ",", "0.9999813038111507`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.12589254117941687`", ",", "0.9999999193463172`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.15848931924611143`", ",", "0.9999999999759245`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.1995262314968879`", ",", "0.9999999999999999`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.25118864315095824`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.31622776601683794`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.39810717055349776`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5011872336272725`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.6309573444801942`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.7943282347242822`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.2589254117941688`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99999999999999999999091295346218524206357674508655766640345323828`335.\
695137022301"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.584893192461114`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999197625471085\
811962678088765011322878`459.74918264081526"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.9952623149688828`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999766037\
7615093050846941784533714161398632244880124`622.2844140065977"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
        "2.5118864315095824`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999996933181117382034138279070696542\
89441394764179177863`830.8658416502892"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "3.1622776601683795`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999995\
8975534603211079820614206583116605887`1094.7394868485344"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "3.9810717055349776`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999998795486376935469074369786041643117377`1422.970688066961"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "5.011872336272725`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999999999999992749374863181987944955401760213999968`1827.\
1911243308673"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "6.309573444801943`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999849670585894907779625930\
394944859254998457346`2319.874455818356"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "7.943282347242821`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999998700483247782582208600101889491643499599634146`2915.\
6366879051225"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "10.`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999998387852296519816201553610351817568287\
10819`3632.5430649585846"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.00001`", ",", 
         RowBox[{"4.418687638008123`*^-10", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000012589254117941661`", ",", 
         RowBox[{"8.637535131583718`*^-10", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001584893192461114`", ",", 
         RowBox[{"1.6842083283563625`*^-9", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000019952623149688786`", ",", 
         RowBox[{"3.2795988147427124`*^-9", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000025118864315095822`", ",", 
         RowBox[{"6.377121053446899`*^-9", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000031622776601683795`", ",", 
         RowBox[{"1.2368994717348869`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000039810717055349695`", ",", 
         RowBox[{"2.392974696174832`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00005011872336272725`", ",", 
         RowBox[{"4.615419080256089`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00006309573444801929`", ",", 
         RowBox[{"8.873568213552119`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00007943282347242822`", ",", 
         RowBox[{"1.70060618809309`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0001`", ",", 
         RowBox[{"3.249466846710902`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00012589254117941674`", ",", 
         RowBox[{"6.192433571472478`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00015848931924611142`", ",", 
         RowBox[{"1.1773064517717202`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00019952623149688788`", ",", 
         RowBox[{"2.2336263456601557`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0002511886431509582`", ",", 
         RowBox[{"4.229589960713653`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00031622776601683794`", ",", 
         RowBox[{"7.994506472597251`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00039810717055349735`", ",", 
         RowBox[{"0.000015083488488443209`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0005011872336272725`", ",", 
         RowBox[{"0.00002840662115266568`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000630957344480193`", ",", 
         RowBox[{"0.00005339745429833176`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0007943282347242822`", ",", 
         RowBox[{"0.00010017705063736226`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001`", ",", 
         RowBox[{"0.0001875491121779982`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0012589254117941675`", ",", 
         RowBox[{"0.00035035057860666186`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001584893192461114`", ",", 
         RowBox[{"0.000652920270138857`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0019952623149688807`", ",", 
         RowBox[{"0.0012136620053456726`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.002511886431509582`", ",", 
         RowBox[{"0.0022495688302851535`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0031622776601683794`", ",", 
         RowBox[{"0.004156273123707366`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.003981071705534973`", ",", 
         RowBox[{"0.007650253367894266`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.005011872336272725`", ",", 
         RowBox[{"0.014016715672122482`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.006309573444801936`", ",", 
         RowBox[{"0.02552791853466152`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00794328234724282`", ",", 
         RowBox[{"0.04610795517095467`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01`", ",", 
         RowBox[{"0.08226434723181797`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.012589254117941675`", ",", 
         RowBox[{"0.14401229878287225`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01584893192461114`", ",", 
         RowBox[{"0.24458809905274304`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01995262314968881`", ",", 
         RowBox[{"0.39573140534593476`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.025118864315095822`", ",", 
         RowBox[{"0.5936310952527153`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.03162277660168379`", ",", 
         RowBox[{"0.7984973396002573`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.039810717055349734`", ",", 
         RowBox[{"0.9412974796998601`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.05011872336272725`", ",", 
         RowBox[{"0.9932004560943932`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.06309573444801936`", ",", 
         RowBox[{"0.9998390291644069`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.07943282347242822`", ",", 
         RowBox[{"0.9999997465953634`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.1`", ",", 
         RowBox[{"0.9999999999959165`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.12589254117941687`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"3.225142491954387`*^-45", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.15848931924611143`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"1.27814506090624`*^-50", " ", "\[ImaginaryI]"}]}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.1995262314968879`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"7.604814167737124`*^-70", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.25118864315095824`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"3.4186641276386514`*^-104", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.31622776601683794`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"1.6705852639120784`*^-160", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.39810717055349776`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"1.9661773118882585`*^-246", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5011872336272725`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999712305604818580\
49290224639804661284872995`379.4956583690775", "+", 
          RowBox[{
          "3.4048731672364191326379092461473292421463446149661`15.\
954589770191005*^-374", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.6309573444801942`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999995523615408085422972636192859771959154234876047198756`561.\
3036623779981", "+", 
          RowBox[{
          "1.253146533628167840796821230577701305529206`15.954589770191005*^-\
555", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.7943282347242822`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999992408771188650264019641930221644443784811030173259052\
3`809.7732476925", "+", 
          RowBox[{
          "3.4331672177402766323673385482682152942629028`15.653559774527023*^-\
804", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999981438604461774417833146941255021750\
1895383476933459`1139.3849491487904", "+", 
          RowBox[{
          "1.732282896678261347073240066270244803165472`15.653559774527023*^-\
1133", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.2589254117941688`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
894898976076111696304412197373148077256671854859639`1564.330922831292", "+", 
          RowBox[{
          "1.6226969719262929041749600448858166530378`15.352529778779246*^-\
1558", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.584893192461114`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999915527521\
06625400377751395934543081758223071958689378`2101.425814538938", "+", 
          RowBox[{
          "1.885641252764332116913604773342899479754353`15.352529778741857*^-\
2095", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.9952623149688828`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999991511141721307124346314614753292852790958`\
2768.122650498929", "+", 
          RowBox[{
          "2.60164762469710233963231929867110043712932166357505`15.\
051499782907864*^-2762", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2.5118864315095824`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999176788\
697196538095202695185228577574945861330409644`3585.135988454494", "+", 
          RowBox[{
          "8.637151709896641892830962911152037301719543`15.051499782202285*^-\
3579", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.1622776601683795`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999994641831371986674235463467438472\
05663873612672`4574.322483399568", "+", 
          RowBox[{
          "8.986172143414903153655593302490237426`15.051499781605775*^-4568", 
           " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.9810717055349776`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999997659306150756798\
514808424506718771`5759.381125164193", "+", 
          RowBox[{
          "5.4174968765042289430537590155900446541062860888`14.\
750469784786546*^-5753", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5.011872336272725`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999997808778480174\
642997300074736439531`7166.409783460291", "+", 
          RowBox[{
          "2.3036482328352733628737831289441791469117730081`14.\
750469775050654*^-7159", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6.309573444801943`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99998758500384432204851399923341830872184`8821.656523087988", "+", 
          RowBox[{
          "3.358340334811537810444371799125549878078431813945`14.\
750469755411448*^-8814", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"7.943282347242821`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999680202250618021\
050398363395802696680753864897226813`10752.245594234546", "+", 
          RowBox[{
          "1.17795160708086248756844001567789814264882399`14.750469743793625*^\
-10744", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10.`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999980249464740033287483107465155872749813007074\
157983296`12985.454890759207", "+", 
          RowBox[{
          "7.682702177671813283687401874837569005405910572`14.750469741342203*^\
-12978", " ", "\[ImaginaryI]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.00001`", ",", 
         RowBox[{"0.`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000012589254117941661`", ",", 
         RowBox[{"1.1102230246251565`*^-12", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001584893192461114`", ",", 
         RowBox[{"2.220446049250313`*^-12", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000019952623149688786`", ",", 
         RowBox[{"5.551115123125783`*^-12", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000025118864315095822`", ",", 
         RowBox[{"1.3322676295501878`*^-11", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000031622776601683795`", ",", 
         RowBox[{"3.3306690738754696`*^-11", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000039810717055349695`", ",", 
         RowBox[{"8.215650382226158`*^-11", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00005011872336272725`", ",", 
         RowBox[{"1.9984014443252818`*^-10", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00006309573444801929`", ",", 
         RowBox[{"4.807265696626928`*^-10", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00007943282347242822`", ",", 
         RowBox[{"1.1546319456101628`*^-9", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0001`", ",", 
         RowBox[{"2.760014439218139`*^-9", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00012589254117941674`", ",", 
         RowBox[{"6.570299859731676`*^-9", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00015848931924611142`", ",", 
         RowBox[{"1.5574208478419393`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00019952623149688788`", ",", 
         RowBox[{"3.675504289812892`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0002511886431509582`", ",", 
         RowBox[{"8.628875070026965`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00031622776601683794`", ",", 
         RowBox[{"2.0132560407670752`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00039810717055349735`", ",", 
         RowBox[{"4.664090276218502`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0005011872336272725`", ",", 
         RowBox[{"1.0725792282118007`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000630957344480193`", ",", 
         RowBox[{"2.449499834633606`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0007943282347242822`", ",", 
         RowBox[{"5.560078072730512`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001`", ",", 
         RowBox[{"0.00001255392244825515`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0012589254117941675`", ",", 
         RowBox[{"0.000028208129979501173`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001584893192461114`", ",", 
         RowBox[{"0.00006308546684641314`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0019952623149688807`", ",", 
         RowBox[{"0.00014041515236307145`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.002511886431509582`", ",", 
         RowBox[{"0.0003109810422605719`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0031622776601683794`", ",", 
         RowBox[{"0.0006850864189982264`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.003981071705534973`", ",", 
         RowBox[{"0.0015005492160643508`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.005011872336272725`", ",", 
         RowBox[{"0.0032656369054233636`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.006309573444801936`", ",", 
         RowBox[{"0.007054707193345888`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00794328234724282`", ",", 
         RowBox[{"0.015103878234248191`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01`", ",", 
         RowBox[{"0.031956051712924816`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.012589254117941675`", ",", 
         RowBox[{"0.06645640724050006`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01584893192461114`", ",", 
         RowBox[{"0.1344537697107403`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01995262314968881`", ",", 
         RowBox[{"0.2595533496434107`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.025118864315095822`", ",", 
         RowBox[{"0.4617769931813598`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.03162277660168379`", ",", 
         RowBox[{"0.7175599832462397`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.039810717055349734`", ",", 
         RowBox[{"0.9221463977852586`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.05011872336272725`", ",", 
         RowBox[{"0.9938850508244099`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.06309573444801936`", ",", 
         RowBox[{"0.999956983609777`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.07943282347242822`", ",", 
         RowBox[{"0.9999999968384369`", "\[VeryThinSpace]", "+", 
          RowBox[{"1.7850516780818037`*^-34", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.1`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"2.9584802576422846`*^-28", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.12589254117941687`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"1.5155454541289638`*^-39", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.15848931924611143`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"5.072815104828867`*^-64", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.1995262314968879`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"2.470293036725584`*^-108", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.25118864315095824`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"1.1399923207647062`*^-184", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.31622776601683794`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"1.1831176358187376`*^-306", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.39810717055349776`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999997848871434612475362838593010658243704038716416625\
2789`501.62192340277437", "+", 
          RowBox[{
          "4.149840164384190659811365943429945014633197099739`15.\
954589770191005*^-491", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5011872336272725`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999998229467210721524745\
898662793039756299926`765.405451475801", "+", 
          RowBox[{
          "3.5261442898592343708210568670069289`15.653559774527023*^-755", 
           " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.6309573444801942`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999998203252444820498180362531465764575568640907661`\
1125.3990666205382", "+", 
          RowBox[{
          "5.0401896884479192524008736848151795141739`15.653559774527023*^-\
1115", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.7943282347242822`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999999999999999995096393920241957313171713642360919345`1596.\
662004969559", "+", 
          RowBox[{
          "1.390213329639810673379367260559376040073369868102803`15.\
352528239778401*^-1586", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999814907873815271868947964528257811205`2195.085128658576", "+", 
          RowBox[{
          "7.4873109916051305142017576876050609260987232350397`15.\
352527582846808*^-2185", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.2589254117941688`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999899257963508295045744027597824410\
90093177520679`2935.0482693955632", "+", 
          RowBox[{
          "5.2124538717814733667216840181503933590103`15.051494867720281*^-\
2925", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.584893192461114`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999995564567509754848206382418180217929321`3831.4045408879015", "+", 
          RowBox[{
          "2.675434749888148644209993736691143338221036070264297`15.\
051494052692103*^-3821", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.9952623149688828`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999716780486946992456095\
260535857978771246324471745291`4896.599351441554", "+", 
          RowBox[{
          "1.8759138331963642812714943882323456503968775598`15.\
051493490679299*^-4886", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2.5118864315095824`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999998892697693628478476667727\
086756000944587`6140.7061546028635", "+", 
          RowBox[{
          "1.33208963181718317641150472533886721`14.750455501487203*^-6130", 
           " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.1622776601683795`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99868508013930708412236923590398162452777681302658729927`7571.631514537781", 
          "+", 
          RowBox[{
          "1.8074268800907733536206570674617707399949541143781`14.\
750453464284291*^-7561", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.9810717055349776`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999954213240177996\
767483084468588905421069782392876538`9193.08970303599", "+", 
          RowBox[{
          "3.018398517165474216474583577295165136590228813`14.750461959001617*^\
-9183", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5.011872336272725`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99999741565670200273544322332279311083936602310626496`11006.338025543002", 
          "+", 
          RowBox[{
          "5.9691905565223974077208168773216453176877991`14.750442358384815*^-\
10996", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6.309573444801943`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999744849122719848447\
89485373678344677660243079715`13011.343546785583", "+", 
          RowBox[{
          "7.892198515857649194892648679010697027783209`14.750433055105809*^-\
13001", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"7.943282347242821`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999996304\
45139427130226012027926397038893972640273`15209.18266447023", "+", 
          RowBox[{
          "1.14728690415930658197824494003733690663782`14.75043292019074*^-\
15198", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10.`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999956420937784722264527717749\
758440470909`17605.111037298033", "+", 
          RowBox[{
          "1.6548757005928404625130224896339642`14.75042469157325*^-17594", 
           " ", "\[ImaginaryI]"}]}]}], "}"}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.782244482196589*^9, 3.782244498212232*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"alltheory", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.00001`", ",", 
       RowBox[{"0.00007353868931081475`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.000012589254117941661`", ",", 
       RowBox[{"0.00009269683280133112`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00001584893192461114`", ",", 
       RowBox[{"0.00011688016643474075`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.000019952623149688786`", ",", 
       RowBox[{"0.00014742545042500943`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.000025118864315095822`", ",", 
       RowBox[{"0.00018603514306725355`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.000031622776601683795`", ",", 
       RowBox[{"0.00023488281227146413`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.000039810717055349695`", ",", 
       RowBox[{"0.00029675175164667333`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00005011872336272725`", ",", 
       RowBox[{"0.00037521859908717925`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00006309573444801929`", ",", 
       RowBox[{"0.00047489861384109044`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00007943282347242822`", ",", 
       RowBox[{"0.0006017764515722224`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0001`", ",", 
       RowBox[{"0.0007636566304430881`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00012589254117941674`", ",", 
       RowBox[{"0.0009707838076260522`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00015848931924611142`", ",", 
       RowBox[{"0.0012367065256327914`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00019952623149688788`", ",", 
       RowBox[{"0.0015794943486258095`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0002511886431509582`", ",", 
       RowBox[{"0.0020234738347264525`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00031622776601683794`", ",", 
       RowBox[{"0.002601735063939792`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00039810717055349735`", ",", 
       RowBox[{"0.003359795530018528`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0005011872336272725`", ",", 
       RowBox[{"0.00436102179747655`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.000630957344480193`", ",", 
       RowBox[{"0.005694750129110915`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0007943282347242822`", ",", 
       RowBox[{"0.0074885938616378045`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.001`", ",", 
       RowBox[{"0.009927309374558435`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0012589254117941675`", ",", 
       RowBox[{"0.013282014848632229`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.001584893192461114`", ",", 
       RowBox[{"0.017955846125511266`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0019952623149688807`", ",", 
       RowBox[{"0.024555720893033373`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.002511886431509582`", ",", 
       RowBox[{"0.03400527987740665`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0031622776601683794`", ",", 
       RowBox[{"0.04772128169536172`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.003981071705534973`", ",", 
       RowBox[{"0.06788259385275097`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.005011872336272725`", ",", 
       RowBox[{"0.09781776056513802`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.006309573444801936`", ",", 
       RowBox[{"0.14249197168917993`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00794328234724282`", ",", 
       RowBox[{"0.20889963138070355`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.01`", ",", 
       RowBox[{"0.30567121904306294`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.012589254117941675`", ",", 
       RowBox[{"0.44013821788519225`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.01584893192461114`", ",", 
       RowBox[{"0.6099676829216958`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.01995262314968881`", ",", 
       RowBox[{"0.7894961882297732`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.025118864315095822`", ",", 
       RowBox[{"0.9275635037742979`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.03162277660168379`", ",", 
       RowBox[{"0.9887901345810385`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.039810717055349734`", ",", 
       RowBox[{"0.999582611323144`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.05011872336272725`", ",", 
       RowBox[{"0.9999987763242779`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.06309573444801936`", ",", 
       RowBox[{"0.9999999999609833`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.07943282347242822`", ",", 
       RowBox[{"1.`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.3688088639289025`*^-44", " ", "\[ImaginaryI]"}]}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0.1`", ",", 
       RowBox[{"1.`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.4618446884222435`*^-44", " ", "\[ImaginaryI]"}]}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0.12589254117941687`", ",", 
       RowBox[{"1.`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.6926801174727181`*^-65", " ", "\[ImaginaryI]"}]}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0.15848931924611143`", ",", 
       RowBox[{"1.`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.9170369302038582`*^-105", " ", "\[ImaginaryI]"}]}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.1995262314968879`", ",", 
       RowBox[{"1.`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.581892315725188`*^-172", " ", "\[ImaginaryI]"}]}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0.25118864315095824`", ",", 
       RowBox[{"1.`", "\[VeryThinSpace]", "+", 
        RowBox[{"9.713609093068933`*^-281", " ", "\[ImaginaryI]"}]}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0.31622776601683794`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999998515852183904203035\
11738164667323983289738`455.78311261283443", "+", 
        RowBox[{
        "1.979445076079181588747079480675390037`15.954589770191005*^-445", 
         " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39810717055349776`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999955227834238737\
1582441427060756954572570740724947174386`694.0025480042041", "+", 
        RowBox[{
        "7.56139689980818569403409064163738630047276131587`15.653559774527023*^\
-684", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.5011872336272725`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999555981911011682960878575332981794935851754080507524`1024.0061553823589", 
        "+", 
        RowBox[{
        "7.624616097793328219876523574920157456011702012`15.653559774527023*^-\
1014", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.6309573444801942`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999998673117560078851637107630\
33654347791`1463.2296895288482", "+", 
        RowBox[{
        "3.178843357332366043073089931788506614634633737902`15.\
352528478295362*^-1453", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.7943282347242822`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999755\
9182212336812079457436062579153841518289402`2030.964986575233", "+", 
        RowBox[{
        "5.8779844100207923403962984135080408418725`15.352528471520623*^-\
2021", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999994889372493776486042996911920674610400963832`2746.3430125381806", 
        "+", 
        RowBox[{
        "1.75061804809622743868245294048842513443`15.051496528949595*^-2736", 
         " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.2589254117941688`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999980364925673571100547248658791698028677965\
5394`3630.7584506219", "+", 
        RowBox[{
        "8.583317438446112601955328928333813004918`15.051495630249555*^-3621",
          " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.584893192461114`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999995441110239627696180616038183909842291572499367852`4705.\
392621374156", "+", 
        RowBox[{
        "2.31761143172762584505339722039110822334849046`15.05149495354723*^-\
4695", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.9952623149688828`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999982864472953888488666\
46750039403377`5991.516549667056", "+", 
        RowBox[{
        "9.534151258495109078002545419437881647355669215271`14.\
750463180173256*^-5982", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.5118864315095824`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999040074805353695105144147000796685784`7510.768191437132", 
        "+", 
        RowBox[{
        "9.657008022279147956809002045266549460352031924525179`14.\
75045784078847*^-7501", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.1622776601683795`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999992839\
256324160828471956461259730562126`9282.89546513887", "+", 
        RowBox[{
        "8.181817787601263182096203053636934357905681900864512`14.\
750456218892575*^-9273", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.9810717055349776`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99999999999933128377381476146496714845670560774`11326.925205782489", "+", 
        RowBox[{
        "3.6369527826289916083594838378824861001458117861275`14.\
750463328921363*^-11317", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5.011872336272725`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999997944833290189538751123347717364827231998500365819455`13661.\
437545868213", "+", 
        RowBox[{
        "3.87982199781847496886439850430715578262177109133`14.750447368805625*^\
-13651", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6.309573444801943`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999992\
068709616278486504097397505718753611175521489`16305.851024116953", "+", 
        RowBox[{
        "1.983471160429126499078553923091341318219995`14.750440089374996*^-\
16295", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7.943282347242821`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999997432553152605008585862528483138037945`19282.34086740881", "+", 
        RowBox[{
        "6.363805293415704697114641558089888108693988037904476`14.\
750440352613316*^-19272", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10.`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999995716556\
370266807752120831953837863`22618.118555049143", "+", 
        RowBox[{
        "1.2801817559858338633552424569094621615600684739077`14.\
750434295811687*^-22607", " ", "\[ImaginaryI]"}]}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.782244507873752*^9, 3.782244518461224*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot panel B", "Subsubsection",
 CellChangeTimes->{{3.782243366920619*^9, 3.782243367410922*^9}, {
  3.782243765996829*^9, 3.782243767339923*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"N0", "=", 
   SuperscriptBox["10", "4"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m0", "=", 
   RowBox[{"-", "0.2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"letter", "=", "\"\<B\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"datadir", "<>", 
     RowBox[{"ToString", "[", 
      RowBox[{"StringForm", "[", 
       RowBox[{
       "\"\<prescue_poisson_N``_n``_Es``_mmax``_mwt``_mutmax10_nreps10000.csv\
\>\"", ",", 
        RowBox[{"NumberForm", "[", 
         RowBox[{"N0", ",", "1"}], "]"}], ",", "n", ",", "Es", ",", 
        RowBox[{"NumberForm", "[", 
         RowBox[{"mmax", ",", 
          RowBox[{"{", 
           RowBox[{"3", ",", "2"}], "}"}]}], "]"}], ",", 
        RowBox[{"NumberForm", "[", 
         RowBox[{"m0", ",", 
          RowBox[{"{", 
           RowBox[{"3", ",", "2"}], "}"}]}], "]"}]}], "]"}], "]"}]}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"dat", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", 
       RowBox[{"{", "1", "}"}]}], "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"dat", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", 
          RowBox[{"{", "1", "}"}]}], "]"}], "]"}], "*", "Uc"}], "/.", 
      RowBox[{"Uc", "\[Rule]", 
       RowBox[{
        SuperscriptBox["n", "2"], 
        RowBox[{"\[Lambda]", "/", "4"}]}]}]}], "/.", 
     RowBox[{"\[Lambda]", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"Es", "/", "n"}]}]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figS1b", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListLogLogPlot", "[", 
      RowBox[{
       RowBox[{"Re", "[", "theory", "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
       
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SuperscriptBox["10", 
             RowBox[{"-", "5"}]], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SuperscriptBox["10", 
             RowBox[{"-", "6"}]], ",", "1"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{",", "\"\<Probability of rescue\>\"", ",", ","}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"letter", ",", "14", ",", "Bold", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             ",", 
            RowBox[{"Scaled", "@", 
             RowBox[{"{", 
              RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"StringForm", "[", 
               RowBox[{"\"\<\!\(\*
StyleBox[SubscriptBox[\"m\", \"0\"],
FontSlant->\"Italic\"]\)=``\>\"", ",", "m0"}], "]"}], ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             ",", 
            RowBox[{"Scaled", "@", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "/", "10"}], ",", 
               RowBox[{"9.5", "/", "10"}]}], "}"}]}]}], "]"}]}], "}"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"FrameTicksStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontColor", "\[Rule]", "White"}], ",", "Automatic", ",", 
          "Automatic", ",", "Automatic"}], "}"}]}]}], "\[IndentingNewLine]", 
      "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ListLogLogPlot", "[", 
      RowBox[{
       RowBox[{"Re", "[", "alltheory", "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Black"}], "}"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ListLogLogPlot", "[", 
      RowBox[{"dat", ",", 
       RowBox[{"PlotMarkers", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "Medium"}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "m0", ",", "N0", ",", 
   "U", ",", "letter"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7822433887729197`*^9, 3.782243389404941*^9}, {
   3.7822437855286617`*^9, 3.782243823526492*^9}, 3.78224386428154*^9, {
   3.7822445954970512`*^9, 3.78224459633095*^9}, {3.784901076515172*^9, 
   3.7849010810213547`*^9}, 3.784905286629592*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJw9kw1MzGEcx68XxxW60nXuyt3/rq4XSlNeUjv/uCGMlZZDJiMvmyxllpq8
Zpekohe6JuG83VJqheuq58u8jFUiUVQuZGZDKx0lDv//8WzPnv32e36/3/f7
efbINiau3GzL4XCUf/bfM1Z/fmop1wf6gI9HXzh6IizTy2DI88aa436rvhbK
Id5yaXG72BsqL+fdzpQcIyrf5/06BcxRy35M18vQIdPHjw9UQPd4rP3ymTLc
skwb9DF4oWenXdX2Rgqnu68dVKm8kLBe738sgkKKMZAf1+yJ+8G71qgvSqEu
ripNU3sin3flg9YgweyU4ICiXjmy3vKqepunQBBTa6zaLsfuXKPG/40HhoLm
LG0ekkFsfyd1r9kdz/iGjg/7ZShUazufOrij5nPoVnsHGc6McqNmSMXIb6of
khZQOFqh/F4cLMIu/byMMAmFimJRslPEZOj4BxUVkVIYrnY7Fa4TYlNTxoK+
eAmeb478NT3JDZ6ZmXEeqVOgGbdh35sjAphU2Xujj3ugJCbM/4bWFWWW3OKs
c+444H11dXXlJMQZ82/crhVD5+qd2nvXBZKUU23fH4qwR11QE/nSGV1BJf2B
PZPhPpKUz+/no+Rz6YStA0JQNdFds7h8sO8hxPInPStq50608neDwCRJoLeN
t/IWYNicELbutANOMXxdUZPYUZ38aBxWMTwnoXMk75qdhWvl5wIP02jA9dlj
rLycERXb+iM82c7Kh48dptVPKqttcIHh4YS1mrOH4wcsRMb4n4CQ1w1t2Tmj
hPXriKeaV3mHlMOE9cdDeUpqer2dmbB+xiInK0J+5v0AETH6uUiLGawTd34h
RYxeeyQuXLJEEPqRsPpsERDZygux6SMnGD0cBK3NaQ+ebyIUM/8nOdn/0rda
3EEoZt4wGWp71JL2pZW4Mf3N5PFlzT167n1rvwGi+OpSO/NmHREy9Z9IX3Zu
5evKciJk7r8nI6J3OmOZlnCZfDe5uKns8LL0DDKGiZuJ0i+0xdK0jXCsqyW9
IFwhXUSi2DwdUh5bF9QuJn5sPa3uLOB9475r9GX70z6BC7QtyrLGqex8eukv
tf7KvohGN1Yf/WAel2O7qKuBYvXTlr+fsSi6weqPtmGmXq9n63/S/3QUsnzC
/8VsP9v/8W9ZotWl
       "]]}, 
     {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
      LineBox[CompressedData["
1:eJxdkHsslXEYx1/mHITjuBzXg3Oc4z7TnKKyEJPN2iK5bCbLtc0fkkqo5JKk
i5kOcTYpl+lsbo04Dt6vrdraaC2OrCFlDJNchphL9b56Lb/tt98+e37P83y/
X2FsyrkEdYIgvP7cv++GDT/tFNce1bvFFUXPXbDp7zi8WGuHfm3P5JNDzhgR
yuN13ewQsyMKmV92Queuy4qDQowAaYKvysAJT8cac/z9xbh4qVOyedgR6Uo3
bsyACKORUnF0sAMiKlqrMiNEeMA5k0pctodHusS17JstFKSkZLrYDrywdmVr
si1k8x0Bhi1irLp7Bg2sCsGTHcst+CjCEFcxMpMtRNMVx6zTS7ZoWziRpHFI
CEvWTGOYoS1K+7tXbZ4IEOk9udIhESJN7p3vZS3AdnNKWWqYALXcHLumYBvY
H5HOcX5aI64/328q3hpXXVm3diRWEBUWxvAzrDCbl5VHZlhiwv/hzdBHfNzv
lLDiYL6XiyUyRA3fdzTNEKMsfd3XboGjsaqElmATWKeXD/56b44Frvfgs0pj
jLrLFt3GzVDTcc+PPW0I2UKVXtKyKca3znM8JAaIkr9wrmKbosxoLessSx8W
ifWBKgsTGE0I2ZZynb28eai/Xlj8NVwL5VS+xoiaVWk3c1gIp/I0gtb67S3e
sNpefoZQRY4VFCVtk3ReBrBfSv4yFbtO0vlwkWgQ1PFBsUTWUHnogz9n9viz
aJYUUv71oBuxGPvSY4Kk/eqgzcIjosXtE0n700YirzlXmQ2S9qOJ4+K1+Zy7
daQ5pZ+Nt9L2d/M9d8gySq8Gsl918WUpgSStTx1JfT6hbypXeksoPQQ4k3X1
mfXXegXU/m0y+oIa0XCjq0dA7dsgCepUd5tQ89f2mCDoecsMm1L9P/aZ+j/N
MJuqjzHMoniA4YMnhK77/GMnup9hR3o+w870foZNaH0MC2j9+0z7O9C/zbCU
zsf3/3nqDP8Gb/qK6g==
       "]]}, 
     {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQ/TpNqfjOXMUDC/73z+xaqH3gisDOGy/qFQ+caT96
+buv9oEt76zSWbgUDxj7mq4VZdM6MPnMnq/yUxQOaBQvZdTfr3GgeJVdi7Wc
wgG2TENhi0r1A0sEGlXXBcgf2F9T2aFronYg+UyL09MUuQPrDsxSEPqgckC5
oyNeplL2wOSFHLZv1ygfeODcUxPcK3PgzOtn909mKUHdIX3AVzIhc5um4oH4
3ZO3HdwqdWD6msk7Oy7LH5Arn375x0nJAxLOqcuFwmQP3DGa/UH/nsSBSv/L
RQ63pQ7MfjePN/2T+IFlx8IiI5IlDkSvWqQ1j038wIyL/0N2vxM9IJW2zP2q
lNiB+VOiuH7UCh+4obgqhUdf9MDKyW373wgKHph+d22js7PIgS2BqQ7sEbwH
wmZunFcVLnzgzN6WSsu5HAdEQ7fu3pgtdKAp4MzO9t/M0PASPOAWHvK0lPH/
fkj4CBzYn8NW/Lz92/7F4PDgPxD7qfKDyqq3+xXB/uc9oLx0/XOpDQ/2Q/zL
feCc7FvFyWfP7If4j/PA7sT8O2E/1+2H+If9wMr3OWEGn6r3S4Ldz3bg3hNp
hx2Sqvungd3LcqDN+FlLKePEfRD3MR0I1GBgWPB14t6JYPcwHGCAAgWw/X/3
w/lg+37C+WJg87/B+RDzPsH54mD9bxF8sPpncD4bWP4unM8K5p+F89FBIETe
HsbXhOiH8zUg5sP5WhD74XwxiPvgfAWI+xF8iP/Q9P+F86dCwscB1TwmOB8A
CNc9DA==
       "]]}, 
     {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQ3a0m+2B3hdyBBf/7Z3Yt1D6QfKbF6WmK3IFtP+c/
WFWrfUC5oyNeplL2wGeh9f43r2keeODcUxPcK3PgoWDYI1VjDag+6QPihrfF
tSapHYjfPXnbwa1SB1jlhE1XflY5IFc+/fKPk5IHgu+Uf+4PVz5wx2j2B/17
EgeCn+7oer5X8cDsd/N40z+JH7Au4yk5o6ZwIHrVIq15bOIHdOYUaVxRkT0g
lbbM/aqU2IH//QeSfzBKHbihuCqFR1/0QHJrIuv6p2IHpt9d2+jsLHKgeLmQ
xtcLwgfCZm6cVxUufGC5SUp43lGBA6KhW3dvzBY6cNdy8n/BHu4DVwR23nhR
L3ig2iIxqW8D64HJZ/Z8lZ8icOBW9kPVJF6GA4sFGlXXBfAfyFrC/Hv5lK/7
FcH+5z3wb4eL+t6dL/ZD/Mt9YNqUCQZXbK/uh/iP80DYHo3Xx/Zv2Q/xD/uB
eNvqyjXylfslwe5nO2Dd4LtlfS/b/mlg97IcCEnacSFSQ3sfxH1MBxigYCLY
PQxwvgLY/r/74XywfT/hfDGw+d/gfIh5n+B8cbD+twg+WP0zOJ8NLH8XzmcF
88/C+eggECJvD+NrQvTD+RoQ8+F8LYj9cL4YxH1wvgLE/Qg+xH9o+v/C+VMh
4eOAah4TnA8AgNYQRA==
       "]]}}, {}}, {{{}, {}, 
     {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJxdkWssm1Ecxru6j9Kidatq3S+zLpbsopnrB9timW1FFpI2wyzrh32wRdjM
GCFCDMMawlxGCEKUTbD32Y0Sl8kQybD5MJYmqA5BJra9r73CSU5Ofjnn//8/
z3NEt+5dT2AyGIwLf/e/M6a51rvK0ANf1apJCxMXSHJde3qeuaPUv7wju9gZ
9rcbwqbs3cHVDgRNOThjJ9RzWlvvhvAlvYmNehFmRM3xZmI3KJirH2d9RXiz
5/PLo8cVw9KH4rRuIV7MtWaEhrqisvp39GCAEMm9YrZs1AUDQ1ZREQVOiFZ2
VKVGu+BBbacXp1KAM8mnfcsWnHF+pz1F2eQIbmRXb4fCGcZPvKUNXXxs+J29
PLohQrFWr3CJcMAku2fmZ7oIHuuymt1Be6hW/BP1j4sg4fpIk0ftUDLSt+H0
XIgaA518fNwWSc0BWRKBEBOrW8K7YzaoZ2e4tUU4IeZ1XnqJmoe4kayQH/EC
zKk199P6uXDJzZXxUxzRvvw4LrDFGt9D8x/dKODDKnZ+errECi/3CpV5NQ6w
VcxLvJMsIest6X7XZQ/+KflT80scCJLLv2wN2SHhptfnCGs2Zv0qtOJ5W8T2
ac7lN7JQsVLFStTZwGcq7OKgmSmo/7BBtfykeDjKeD9/HtStxmucbIP9vLmI
VK3XLrxgopzM1xqaO5rUlRN7RBSZpxXM1a+UK6xtgsrPEkXyyJYPmzqCyouD
96V86WKIhqDyYaOpNiRYUfeNqCPzsIBRpqCNFTxGiEj/LIQ7el3RBHYSlF9T
NM5d9Yvj5RCUPxO4ha1prWMlBOXHCKxlfmZDjuqtHanfELyRYwx+0qf+MlKv
Phj7i9LHpLmI1MOgWUjO3yVoJudt08wj+28Sh/vpaLYh65cPmHy/SLMheT9H
swHJozQfXdeo+8D/7EXV0+xJ9afZm5pPM4/SR7OQ0n/AlL8j9bs0l1L5BB3u
x6T5D2u5iUg=
       "]]}}, {}}, {
    GraphicsComplexBox[{{-8.517193191416238, -6.319968614080018}, \
{-6.214608098422191, -3.8490482062667577`}, {-3.912023005428146, \
-0.7916424273090445}, {-8.517193191416238, -6.319968614080018}, \
{-6.214608098422191, -3.8490482062667577`}, {-3.912023005428146, \
-0.7916424273090445}}, {
      {GrayLevel[0], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 4], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 5], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 6]}, {}}], {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{-11.512925464970229`, -13.815510557964274`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
      TraditionalForm], 
     Scaled[{0.05, 0.95}]], 
    InsetBox[
     FormBox[
      StyleBox[
       InterpretationBox[
       "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=\\!\\(TraditionalForm\\`\\(-0.2`\\\
)\\)\"", 
        StringForm[
        "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\nFontSlant->\"Italic\"]\
\)=``", -0.2], Editable -> False], 12, FontFamily -> "Helvetica", 
       StripOnInput -> False], TraditionalForm], 
     NCache[
      Scaled[{
        Rational[1, 5], 0.9500000000000001}], 
      Scaled[{0.2, 0.9500000000000001}]]]},
  Frame->{True, True, False, False},
  FrameLabel->{{
     FormBox["\"Probability of rescue\"", TraditionalForm], ""}, {"", ""}},
  FrameTicks->{{{{-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.716898269296165`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.429216196844383`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.02375108873622, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.86960040890896, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.736069016284437`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.618285980628055`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, None}, {{{-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, None}},
  FrameTicksStyle->{
   FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
  GridLines->{None, None},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{-11.512925464970229`, 0.}, {-13.815510557964274`, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{{{-11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {-10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.414313176302118`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.126631103850338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.721165995742174, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.567015315914915, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.433483923290392, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.315700887634009, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{-13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.716898269296165`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.429216196844383`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.206072645530174`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.02375108873622, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.86960040890896, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.736069016284437`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.618285980628055`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.414313176302118`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.126631103850338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.721165995742174, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.567015315914915, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.433483923290392, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.315700887634009, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.7822445243322887`*^9, 3.782244549312735*^9}, 
   3.782252463614602*^9, 3.7822698768220377`*^9, 3.784901081836565*^9, 
   3.784905288487458*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical data for panel C", "Subsubsection",
 CellChangeTimes->{{3.782243374793446*^9, 3.782243378905702*^9}, {
   3.782243829670867*^9, 3.782243832557908*^9}, 3.782244114414242*^9}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"N0", "=", 
    SuperscriptBox["10", "4"]}], ";", "\[IndentingNewLine]", 
   RowBox[{"m0", "=", 
    RowBox[{"-", "0.3"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"mmax", "=", "0.5"}], ";", "\[IndentingNewLine]", 
   RowBox[{"\[Lambda]", "=", 
    RowBox[{"2", 
     RowBox[{"Es", "/", "n"}]}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"Es", "=", "0.01"}], ";", "\[IndentingNewLine]", 
   RowBox[{"n", "=", "4"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"rate4", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[CapitalLambda]4InterpolatedU", "[", 
       RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "x"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Umin", ",", "Umax", ",", "Ustep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate3", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[CapitalLambda]3InterpolatedU", "[", 
       RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "x"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Umin", ",", "Umax", ",", "Ustep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate2", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[CapitalLambda]2InterpolatedU", "[", 
       RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "x"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Umin", ",", "Umax", ",", "Ustep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate1", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[CapitalLambda]1InterpolatedU", "[", 
       RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "x"}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Umin", ",", "Umax", ",", "Ustep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"Ulist", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      SuperscriptBox["10", "x"], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "Umin", ",", "Umax", ",", "Ustep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"theory", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Ulist", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{"m0", ",", 
              RowBox[{"rate1", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "Ulist", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Ulist", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{"m0", ",", 
              RowBox[{"rate2", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "Ulist", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Ulist", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{"m0", ",", 
              RowBox[{"rate3", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "Ulist", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Ulist", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{"m0", ",", 
              RowBox[{"rate4", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "Ulist", "]"}]}], "}"}]}], "]"}]}], 
     "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"alltheory", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Ulist", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"prescue", "/.", 
         RowBox[{"p0", "\[Rule]", 
          RowBox[{"prescuem", "[", 
           RowBox[{"m0", ",", 
            RowBox[{
             RowBox[{"rate1", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "+", 
             RowBox[{"rate2", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "+", 
             RowBox[{"rate3", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "+", 
             RowBox[{"rate4", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}]}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "Ulist", "]"}]}], "}"}]}], "]"}]}], ";", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", 
    RowBox[{
    "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "m0", ",", "N0", ",", 
     "U"}], "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.7510768239974546`*^9, 3.751076850477788*^9}, {
   3.751077073209116*^9, 3.75107707404215*^9}, 3.7510772333562117`*^9, {
   3.7510780814540033`*^9, 3.7510780939241743`*^9}, 3.751079983731886*^9, {
   3.751080193820591*^9, 3.751080314860424*^9}, {3.751080438938933*^9, 
   3.751080453002974*^9}, {3.751080543209502*^9, 3.751080573569518*^9}, {
   3.751081090205201*^9, 3.751081108714032*^9}, {3.75156278825319*^9, 
   3.7515628382903976`*^9}, 3.751646165611027*^9, {3.751646548106408*^9, 
   3.751646656277231*^9}, 3.751646837751152*^9, {3.751646901889613*^9, 
   3.751647017114812*^9}, {3.7516470710458508`*^9, 3.7516471140016603`*^9}, 
   3.751647239375453*^9, {3.751647274447871*^9, 3.751647308444126*^9}, {
   3.751655188488014*^9, 3.7516551948421173`*^9}, 3.7516553497399673`*^9, {
   3.7516558244590063`*^9, 3.751655855414094*^9}, {3.7516785570908422`*^9, 
   3.751678622405755*^9}, {3.751678785435092*^9, 3.751678797451065*^9}, {
   3.7516789290519457`*^9, 3.7516790098557253`*^9}, {3.751679079869364*^9, 
   3.751679081963086*^9}, {3.751679566365776*^9, 3.7516795717600317`*^9}, {
   3.751679647169375*^9, 3.751679648392433*^9}, 3.7516798837830763`*^9, {
   3.7516806524922543`*^9, 3.751680669037451*^9}, {3.7564891699284067`*^9, 
   3.756489175638451*^9}, {3.7564923277678747`*^9, 3.756492331912068*^9}, {
   3.756502094040043*^9, 3.756502095005869*^9}, {3.756520270671589*^9, 
   3.75652027344243*^9}, 3.756520348755927*^9, {3.756520400861586*^9, 
   3.756520439180738*^9}, 3.756520651678936*^9, {3.756556638142688*^9, 
   3.756556640041947*^9}, {3.756570843447299*^9, 3.756570846775318*^9}, {
   3.756570974146035*^9, 3.756571120745819*^9}, 3.760624717472529*^9, {
   3.76420440689139*^9, 3.7642046427775908`*^9}, {3.764204754899797*^9, 
   3.7642047716289186`*^9}, {3.76420481154845*^9, 3.764204825101851*^9}, {
   3.764204877914257*^9, 3.764204944872558*^9}, {3.764205207233889*^9, 
   3.7642052275611*^9}, {3.764205258864553*^9, 3.764205287291357*^9}, {
   3.764205609641672*^9, 3.7642056115708113`*^9}, {3.7642056795535307`*^9, 
   3.764205689443074*^9}, 3.764205980500901*^9, {3.764209232274527*^9, 
   3.7642092792726517`*^9}, 3.764209327120954*^9, 3.764251492281107*^9, {
   3.76943292341084*^9, 3.769432965089745*^9}, {3.769458302479702*^9, 
   3.769458322534122*^9}, 3.7699675931068783`*^9, {3.771246663332436*^9, 
   3.771246699348748*^9}, {3.771246730333727*^9, 3.771246855741597*^9}, {
   3.771246890332162*^9, 3.771247074062579*^9}, {3.771248419105422*^9, 
   3.771248520499831*^9}, {3.771248807775511*^9, 3.771248822219911*^9}, {
   3.771248900616621*^9, 3.7712489008722353`*^9}, {3.77124898134147*^9, 
   3.771249011221075*^9}, {3.771249300656846*^9, 3.7712493263214703`*^9}, {
   3.7712494670163717`*^9, 3.771249525868437*^9}, {3.771249775527567*^9, 
   3.771249842817733*^9}, {3.771250190789572*^9, 3.77125021131152*^9}, 
   3.771250250390286*^9, {3.771250380877308*^9, 3.7712503813315773`*^9}, {
   3.771250529621471*^9, 3.771250562619721*^9}, {3.7712505999952583`*^9, 
   3.7712506584019213`*^9}, {3.771250871998402*^9, 3.771250929508836*^9}, {
   3.7712510935067263`*^9, 3.771251160617013*^9}, {3.7712512100306463`*^9, 
   3.7712513693375053`*^9}, {3.771251417142316*^9, 3.771251524219696*^9}, {
   3.771251579964191*^9, 3.771251638779459*^9}, {3.771252846121793*^9, 
   3.771252848544426*^9}, {3.7712530727771463`*^9, 3.771253081523308*^9}, {
   3.771254475662434*^9, 3.7712544847563553`*^9}, 3.771527439435844*^9, 
   3.771530473892355*^9, 3.771548850306716*^9, 3.7715499001839533`*^9, 
   3.771551809393807*^9, {3.7715519623861628`*^9, 3.77155196436862*^9}, {
   3.782243846292348*^9, 3.7822438722810497`*^9}, 3.782244588188711*^9, 
   3.782245623826991*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"theory", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.00001`", ",", "6.425313789915066`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000012589254117941661`", ",", "8.088992932142602`*^-7"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001584893192461114`", ",", "1.018343781855613`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000019952623149688786`", ",", "1.2820181188866187`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000025118864315095822`", ",", "1.6139654472890896`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000031622776601683795`", ",", "2.031861507045818`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000039810717055349695`", ",", "2.557961690463628`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00005011872336272725`", ",", "3.220282207117009`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00006309573444801929`", ",", "4.054093288852201`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00007943282347242822`", ",", "5.103798812799987`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0001`", ",", "6.425297459533574`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00012589254117941674`", ",", "8.08896460335884`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00015848931924611142`", ",", "0.000010183391189189095`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00019952623149688788`", ",", "0.000012820113925116061`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0002511886431509582`", ",", "0.00001613954059820344`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00031622776601683794`", ",", "0.00002031843485172935`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00039810717055349735`", ",", "0.00002557932584146272`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0005011872336272725`", ",", "0.00003220235756073997`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000630957344480193`", ",", "0.00004054019664556652`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0007943282347242822`", ",", "0.00005103681593787712`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001`", ",", "0.00006425111905661307`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0012589254117941675`", ",", "0.00008088669342876109`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001584893192461114`", ",", "0.00010182924751034328`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0019952623149688807`", ",", "0.0001281937380451792`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.002511886431509582`", ",", "0.00016138367485374339`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0031622776601683794`", ",", "0.00020316576204426617`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.003981071705534973`", ",", "0.0002557638106833737`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.005011872336272725`", ",", "0.0003219768956345126`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.006309573444801936`", ",", "0.00040532799164916256`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00794328234724282`", ",", "0.000510250921635591`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.01`", ",", "0.000642325398099941`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.012589254117941675`", ",", "0.0008085724878367229`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01584893192461114`", ",", "0.001017825838958597`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.01995262314968881`", ",", "0.0012811978673202828`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.025118864315095822`", ",", "0.0016126648467947868`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.03162277660168379`", ",", "0.0020298005758730975`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.039810717055349734`", ",", "0.0025546954574532377`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.05011872336272725`", ",", "0.0032151062945346975`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.06309573444801936`", ",", "0.00404589236538766`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.07943282347242822`", ",", "0.005090805230013262`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.1`", ",", "0.006404713400978701`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.12589254117941687`", ",", "0.008056357966623184`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.15848931924611143`", ",", "0.010131750671247608`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.1995262314968879`", ",", "0.012738340082092292`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.25118864315095824`", ",", "0.016010080931823767`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.31622776601683794`", ",", "0.02011354101132823`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.39810717055349776`", ",", "0.025255159661379922`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.5011872336272725`", ",", "0.03168971719900204`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.6309573444801942`", ",", "0.039729962274141384`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.7943282347242822`", ",", "0.049757139592040533`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1.`", ",", "0.06223181354444862`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.2589254117941688`", ",", "0.07770382531038755`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1.584893192461114`", ",", "0.09681936470326569`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1.9952623149688828`", ",", "0.12032188654624432`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"2.5118864315095824`", ",", "0.14904187737115948`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"3.1622776601683795`", ",", "0.18386829169052188`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"3.9810717055349776`", ",", "0.22569206110805295`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"5.011872336272725`", ",", "0.27531012647733377`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"6.309573444801943`", ",", "0.33327845755254115`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"7.943282347242821`", ",", "0.39970722185453755`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"10.`", ",", "0.47400472671919136`"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.00001`", ",", "9.694467451026867`*^-9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000012589254117941661`", ",", "1.5178969081652838`*^-8"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001584893192461114`", ",", "2.3763213508054548`*^-8"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000019952623149688786`", ",", "3.719247076983123`*^-8"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000025118864315095822`", ",", "5.82034407337062`*^-8"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000031622776601683795`", ",", "9.106826037719173`*^-8"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000039810717055349695`", ",", "1.4246269852691285`*^-7"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00005011872336272725`", ",", "2.2282284772856542`*^-7"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00006309573444801929`", ",", "3.484489891070197`*^-7"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00007943282347242822`", ",", "5.448007234232222`*^-7"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0001`", ",", "8.516328503516135`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00012589254117941674`", ",", "1.3310144183487083`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00015848931924611142`", ",", "2.0798197147842146`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00019952623149688788`", ",", "3.249222299772647`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0002511886431509582`", ",", "5.075060834469625`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00031622776601683794`", ",", "7.925169151601352`*^-6"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00039810717055349735`", ",", "0.000012373097117102105`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0005011872336272725`", ",", "0.00001931290686918441`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000630957344480193`", ",", "0.000030137891150472385`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0007943282347242822`", ",", "0.000047018633896778184`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001`", ",", "0.0000733355711646233`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0012589254117941675`", ",", "0.00011435143408466963`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001584893192461114`", ",", "0.00017825620690314903`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0019952623149688807`", ",", "0.00027778964574598497`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.002511886431509582`", ",", "0.00043276006328796246`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0031622776601683794`", ",", "0.0006739423615106377`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.003981071705534973`", ",", "0.001049120245748436`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.005011872336272725`", ",", "0.0016324246574039858`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.006309573444801936`", ",", "0.0025386974323072797`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00794328234724282`", ",", "0.003945566462648875`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.01`", ",", "0.006127117925012193`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.012589254117941675`", ",", "0.009504837921938125`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01584893192461114`", ",", "0.014723640491375867`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.01995262314968881`", ",", "0.02276291296216315`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.025118864315095822`", ",", "0.035093089130379784`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.03162277660168379`", ",", "0.05388271685120427`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.039810717055349734`", ",", "0.0822409991733245`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.05011872336272725`", ",", "0.12442366513963876`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.06309573444801936`", ",", "0.18580499420744057`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.07943282347242822`", ",", "0.27218856201712116`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.1`", ",", "0.38773668425067875`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.12589254117941687`", ",", "0.5308082152761506`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.15848931924611143`", ",", "0.688372124798042`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.1995262314968879`", ",", "0.8337357597192929`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.25118864315095824`", ",", "0.9365285887414073`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.31622776601683794`", ",", "0.9854586924944397`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.39810717055349776`", ",", "0.9984684299695721`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.5011872336272725`", ",", "0.9999504184800403`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.6309573444801942`", ",", "0.9999997308870225`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0.7943282347242822`", ",", "0.9999999999012561`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"1.`", ",", "0.9999999999999993`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.2589254117941688`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.584893192461114`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.9952623149688828`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2.5118864315095824`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.1622776601683795`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.9810717055349776`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5.011872336272725`", ",", "1.`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "6.309573444801943`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999955042165807663900488\
47290824010212213836373421`374.00075439325104"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "7.943282347242821`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999973300127388628287844811290\
914997017166110266654705`524.227050585234"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "10.`", ",", 
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999952761087031440911602319857897077462910223`725.\
6782298835114"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.00001`", ",", 
         RowBox[{"1.554312234475219`*^-11", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000012589254117941661`", ",", 
         RowBox[{"3.108624468950438`*^-11", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001584893192461114`", ",", 
         RowBox[{"5.995204332975845`*^-11", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000019952623149688786`", ",", 
         RowBox[{"1.1657341758564144`*^-10", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000025118864315095822`", ",", 
         RowBox[{"2.275957200481571`*^-10", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000031622776601683795`", ",", 
         RowBox[{"4.418687638008123`*^-10", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000039810717055349695`", ",", 
         RowBox[{"8.604228440844963`*^-10", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00005011872336272725`", ",", 
         RowBox[{"1.6686652060116103`*^-9", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00006309573444801929`", ",", 
         RowBox[{"3.2318592246838307`*^-9", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00007943282347242822`", ",", 
         RowBox[{"6.247224959565756`*^-9", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0001`", ",", 
         RowBox[{"1.2060352716503075`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00012589254117941674`", ",", 
         RowBox[{"2.324695980160385`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00015848931924611142`", ",", 
         RowBox[{"4.475419956850857`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00019952623149688788`", ",", 
         RowBox[{"8.605560386509836`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0002511886431509582`", ",", 
         RowBox[{"1.6528777058155697`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00031622776601683794`", ",", 
         RowBox[{"3.171273861291013`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00039810717055349735`", ",", 
         RowBox[{"6.077947434235398`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0005011872336272725`", ",", 
         RowBox[{"1.1635941018495188`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000630957344480193`", ",", 
         RowBox[{"2.2251198369405145`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0007943282347242822`", ",", 
         RowBox[{"4.250024638663419`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001`", ",", 
         RowBox[{"8.107587335715039`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0012589254117941675`", ",", 
         RowBox[{"0.000015446372656269247`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001584893192461114`", ",", 
         RowBox[{"0.000029387684739257125`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0019952623149688807`", ",", 
         RowBox[{"0.00005583087490845795`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.002511886431509582`", ",", 
         RowBox[{"0.00010590496370177505`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0031622776601683794`", ",", 
         RowBox[{"0.00020056224735576222`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.003981071705534973`", ",", 
         RowBox[{"0.0003791619258938228`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.005011872336272725`", ",", 
         RowBox[{"0.0007154589266925582`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.006309573444801936`", ",", 
         RowBox[{"0.0013472693402620806`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00794328234724282`", ",", 
         RowBox[{"0.00253122196023281`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01`", ",", 
         RowBox[{"0.004743042327598146`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.012589254117941675`", ",", 
         RowBox[{"0.008859045147107447`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01584893192461114`", ",", 
         RowBox[{"0.01647798013593138`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01995262314968881`", ",", 
         RowBox[{"0.030471167172742564`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.025118864315095822`", ",", 
         RowBox[{"0.055857030908089245`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.03162277660168379`", ",", 
         RowBox[{"0.10098043051529881`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.039810717055349734`", ",", 
         RowBox[{"0.1784296544914452`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.05011872336272725`", ",", 
         RowBox[{"0.3034748832651081`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.06309573444801936`", ",", 
         RowBox[{"0.48473506434437297`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.07943282347242822`", ",", 
         RowBox[{"0.7020857156795866`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.1`", ",", 
         RowBox[{"0.8894230881742398`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.12589254117941687`", ",", 
         RowBox[{"0.9814164439376099`", "\[VeryThinSpace]", "+", 
          RowBox[{"1.7474672315436695`*^-33", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.15848931924611143`", ",", 
         RowBox[{"0.9992351786348997`", "\[VeryThinSpace]", "+", 
          RowBox[{"9.717437661790875`*^-26", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.1995262314968879`", ",", 
         RowBox[{"0.9999973617156914`", "\[VeryThinSpace]", "+", 
          RowBox[{"1.1037207205305933`*^-24", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.25118864315095824`", ",", 
         RowBox[{"0.9999999998800407`", "\[VeryThinSpace]", "+", 
          RowBox[{"5.930979588924709`*^-27", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.31622776601683794`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"6.581371517908493`*^-34", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.39810717055349776`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"7.866005678953907`*^-46", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5011872336272725`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"8.688263599936316`*^-68", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.6309573444801942`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"7.783364382810619`*^-105", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.7943282347242822`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"6.052608005861694`*^-166", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"1.377091605293845`*^-263", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.2589254117941688`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99999999999999999999994922816673862181854017891556410484902023701`416.\
2489669250664", "+", 
          RowBox[{
          "7.844756684672630418954036187629150881303307061978`15.\
954589770191005*^-414", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.584893192461114`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99999999996706806660968807135782795733865181909690673200278451`638.\
1359425462111", "+", 
          RowBox[{
          "7.37924779616001313665258276293879382117`15.653559774527023*^-636",
            " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.9952623149688828`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999657959181692720994725919583842139435116765709`953.1194818377461",
           "+", 
          RowBox[{
          "4.280676039726981980747762940737726538068790344170356`15.\
653559774527023*^-950", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2.5118864315095824`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999994412712117006805942650829\
21146147512479`1382.6053287300592", "+", 
          RowBox[{
          "1.1690295900008001429919280368226523031559118855`15.\
352529778862957*^-1379", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.1622776601683795`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999998526\
3339416473168053969965983048602906130857111222`1950.1841306979481", "+", 
          RowBox[{
          "4.4330770540766393209240211135816620264`15.35252977886287*^-1947", 
           " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.9810717055349776`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999999998717033056982618133077187795894534692510752862548772`\
2679.943284316729", "+", 
          RowBox[{
          "5.032221316598749285047362959655927426544`15.051499783198667*^-\
2677", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5.011872336272725`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99999999797481996273431390323359030922397237`3599.7450361454057", "+", 
          RowBox[{
          "6.957492505255906295461578818412256217009408734`15.051499783195817*^\
-3596", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6.309573444801943`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999997865920928881261256588\
216789900403641403817111602957`4739.7222892764585", "+", 
          RowBox[{
          "1.856969125620337932138928134888490586415379`15.051499783190762*^-\
4735", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"7.943282347242821`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999977585359673404039773281761955960\
710872333509686`6133.399938013075", "+", 
          RowBox[{
          "2.618001215353933015878995671400061376`14.750469787521325*^-6129", 
           " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10.`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99999999999999981143680268449980124868131440068076409`7818.4750128539235", 
          "+", 
          RowBox[{
          "2.2844175812487870054514634264022168465500438392`14.\
750469787520727*^-7814", " ", "\[ImaginaryI]"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.00001`", ",", 
         RowBox[{"0.`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000012589254117941661`", ",", 
         RowBox[{"0.`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00001584893192461114`", ",", 
         RowBox[{"0.`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000019952623149688786`", ",", 
         RowBox[{"0.`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000025118864315095822`", ",", 
         RowBox[{"1.1102230246251565`*^-12", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000031622776601683795`", ",", 
         RowBox[{"1.1102230246251565`*^-12", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000039810717055349695`", ",", 
         RowBox[{"3.3306690738754696`*^-12", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00005011872336272725`", ",", 
         RowBox[{"7.771561172376096`*^-12", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00006309573444801929`", ",", 
         RowBox[{"1.887379141862766`*^-11", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00007943282347242822`", ",", 
         RowBox[{"4.551914400963142`*^-11", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0001`", ",", 
         RowBox[{"1.0769163338864018`*^-10", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00012589254117941674`", ",", 
         RowBox[{"2.575717417130363`*^-10", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00015848931924611142`", ",", 
         RowBox[{"6.139533326177116`*^-10", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00019952623149688788`", ",", 
         RowBox[{"1.454392162258955`*^-9", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0002511886431509582`", ",", 
         RowBox[{"3.43836070726411`*^-9", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00031622776601683794`", ",", 
         RowBox[{"8.094636072542016`*^-9", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00039810717055349735`", ",", 
         RowBox[{"1.898370338704325`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0005011872336272725`", ",", 
         RowBox[{"4.433786604529644`*^-8", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.000630957344480193`", ",", 
         RowBox[{"1.031596985612282`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0007943282347242822`", ",", 
         RowBox[{"2.39186419892512`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001`", ",", 
         RowBox[{"5.528032063217836`*^-7", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0012589254117941675`", ",", 
         RowBox[{"1.2737014484232034`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.001584893192461114`", ",", 
         RowBox[{"2.9256610027950103`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0019952623149688807`", ",", 
         RowBox[{"6.698744719368932`*^-6", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.002511886431509582`", ",", 
         RowBox[{"0.000015286385312895945`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.0031622776601683794`", ",", 
         RowBox[{"0.00003475909339045735`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.003981071705534973`", ",", 
         RowBox[{"0.00007873724008899963`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.005011872336272725`", ",", 
         RowBox[{"0.00017763207850762797`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.006309573444801936`", ",", 
         RowBox[{"0.0003989857795272389`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.00794328234724282`", ",", 
         RowBox[{"0.0008919245374604534`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01`", ",", 
         RowBox[{"0.001983479855357184`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.012589254117941675`", ",", 
         RowBox[{"0.004384909537185067`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01584893192461114`", ",", 
         RowBox[{"0.009625975972992307`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.01995262314968881`", ",", 
         RowBox[{"0.02094133942218479`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.025118864315095822`", ",", 
         RowBox[{"0.044972666038738396`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.03162277660168379`", ",", 
         RowBox[{"0.09460326538138408`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.039810717055349734`", ",", 
         RowBox[{"0.19194325088236586`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.05011872336272725`", ",", 
         RowBox[{"0.3646632823623164`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.06309573444801936`", ",", 
         RowBox[{"0.616211017620879`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.07943282347242822`", ",", 
         RowBox[{"0.8652565489948346`", "\[VeryThinSpace]", "+", 
          RowBox[{"6.86480542158121`*^-33", " ", "\[ImaginaryI]"}]}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.1`", ",", 
         RowBox[{"0.9843254695918204`", "\[VeryThinSpace]", "+", 
          RowBox[{"4.944427652253176`*^-18", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.12589254117941687`", ",", 
         RowBox[{"0.9998018994576795`", "\[VeryThinSpace]", "+", 
          RowBox[{"8.70662587436642`*^-16", " ", "\[ImaginaryI]"}]}]}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"0.15848931924611143`", ",", 
         RowBox[{"0.9999999690628478`", "\[VeryThinSpace]", "+", 
          RowBox[{"1.0609054519606643`*^-17", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.1995262314968879`", ",", 
         RowBox[{"0.999999999999999`", "\[VeryThinSpace]", "+", 
          RowBox[{"1.3295337783362737`*^-24", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.25118864315095824`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"3.433760447134135`*^-38", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.31622776601683794`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"2.5727910003219743`*^-65", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.39810717055349776`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"2.8676653039367497`*^-115", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5011872336272725`", ",", 
         RowBox[{"1.`", "\[VeryThinSpace]", "+", 
          RowBox[{"4.680366506440045`*^-204", " ", "\[ImaginaryI]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.6309573444801942`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999874321378773453904042157831313155\
6438317`361.8553283626163", "+", 
          RowBox[{
          "6.549461433460595882670450894037620584676104037270159`15.\
954589770191005*^-353", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.7943282347242822`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999995958793913861596267297282231928\
36100592996684839711406`597.348078771817", "+", 
          RowBox[{
          "2.55650230634637484115856407536728569331871756964`15.\
954589770191005*^-588", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999998168467327955687525889817020698975537067382287418299`946.3907448908188",
           "+", 
          RowBox[{
          "1.80007298843587418487723087386396319738356961`15.653559774527023*^\
-937", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.2589254117941688`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999866347343426762092996710108174246018602275494`1435.\
2265517571977", "+", 
          RowBox[{
          "1.74860563894107988844684741210950969828`15.352529707838459*^-\
1426", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.584893192461114`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999991830535357585504979420\
1131256374035426687474144`2087.440335678966", "+", 
          RowBox[{
          "1.26012185934870972033141381751472515287731`15.352529695126812*^-\
2078", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1.9952623149688828`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999999999999999999375995068168981436996654750539899491615`\
2923.256311113066", "+", 
          RowBox[{
          "1.0640467374363521400017100729332260674449073655424466`15.\
051499621202774*^-2914", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2.5118864315095824`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999974590584440263229755\
5060090246729587757121`3961.6465039101327", "+", 
          RowBox[{
          "8.00433793948543151599752605819826901`15.051499483928996*^-3953", 
           " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.1622776601683795`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999563554629002\
24192393130338966417411245`5217.110538441931", "+", 
          RowBox[{
          "1.558550846791585706498162846653020227237935456028252`14.\
750469363469087*^-5208", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3.9810717055349776`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999990400603708\
962153531828190357039303051`6700.7682247323455", "+", 
          RowBox[{
          "2.674110302342741777141672303855951841605995307081359`14.\
750469456725629*^-6692", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"5.011872336272725`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999995735813596\
90064644108673451181291629`8417.12063107332", "+", 
          RowBox[{
          "2.6530696166418445051747103355565664049053388445941`14.\
75046904868732*^-8408", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"6.309573444801943`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999420863034766\
080576765282258887659`10364.987685395936", "+", 
          RowBox[{
          "4.41740708961220419545068823849221496644646878261`14.\
75046888174273*^-10356", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"7.943282347242821`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999970820992370299676327359\
137902009176404`12538.285396111745", "+", 
          RowBox[{
          "2.263381438061784040509916930251108308352519698480295`14.\
750468866386253*^-12529", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"10.`", ",", 
         RowBox[{
         "0.999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999999999998854457083802912327732671674894973149`14928.\
691454512516", "+", 
          RowBox[{
          "1.10036598677555690205800295780627328777961313571916`14.\
750468646843236*^-14919", " ", "\[ImaginaryI]"}]}]}], "}"}]}], "}"}]}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.782245584423847*^9, 3.78224559725624*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"alltheory", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.00001`", ",", 
       RowBox[{"6.522424942367877`*^-7", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.000012589254117941661`", ",", 
       RowBox[{"8.241093366612162`*^-7", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00001584893192461114`", ",", 
       RowBox[{"1.0421669225380015`*^-6", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.000019952623149688786`", ",", 
       RowBox[{"1.3193282266676931`*^-6", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.000025118864315095822`", ",", 
       RowBox[{"1.6723974951560194`*^-6", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.000031622776601683795`", ",", 
       RowBox[{"2.1233736705594808`*^-6", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.000039810717055349695`", ",", 
       RowBox[{"2.701287778905659`*^-6", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00005011872336272725`", ",", 
       RowBox[{"3.4447818685334752`*^-6", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00006309573444801929`", ",", 
       RowBox[{"4.405791574679796`*^-6", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00007943282347242822`", ",", 
       RowBox[{"5.654889480677383`*^-6", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0001`", ",", 
       RowBox[{"7.289093905682442`*^-6", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00012589254117941674`", ",", 
       RowBox[{"9.443473634740407`*^-6", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00015848931924611142`", ",", 
       RowBox[{"0.000012308558425044858`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00019952623149688788`", ",", 
       RowBox[{"0.00001615680429178923`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0002511886431509582`", ",", 
       RowBox[{"0.000021383241984085366`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00031622776601683794`", ",", 
       RowBox[{"0.000028568656911032164`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00039810717055349735`", ",", 
       RowBox[{"0.00003857886096036989`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0005011872336272725`", ",", 
       RowBox[{"0.00005272251338162004`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.000630957344480193`", ",", 
       RowBox[{"0.00007300498089335417`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0007943282347242822`", ",", 
       RowBox[{"0.00010254181901458992`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.001`", ",", 
       RowBox[{"0.0001462411717603196`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0012589254117941675`", ",", 
       RowBox[{"0.00021194566614224364`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.001584893192461114`", ",", 
       RowBox[{"0.00031237150299834315`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0019952623149688807`", ",", 
       RowBox[{"0.0004684516151626239`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.002511886431509582`", ",", 
       RowBox[{"0.000715191584378716`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.0031622776601683794`", ",", 
       RowBox[{"0.0011120790901624211`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.003981071705534973`", ",", 
       RowBox[{"0.0017618873994811324`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.005011872336272725`", ",", 
       RowBox[{"0.002845094326627051`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.006309573444801936`", ",", 
       RowBox[{"0.004683574129253243`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00794328234724282`", ",", 
       RowBox[{"0.007859450549812408`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.01`", ",", 
       RowBox[{"0.013437158034683927`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.012589254117941675`", ",", 
       RowBox[{"0.0233746853395439`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.01584893192461114`", ",", 
       RowBox[{"0.041263601475378`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.01995262314968881`", ",", 
       RowBox[{"0.07356939955763908`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.025118864315095822`", ",", 
       RowBox[{"0.1313616570542161`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.03162277660168379`", ",", 
       RowBox[{"0.23144690353800978`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.039810717055349734`", ",", 
       RowBox[{"0.39226297632515994`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.05011872336272725`", ",", 
       RowBox[{"0.613743271143804`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.06309573444801936`", ",", 
       RowBox[{"0.8395897950578348`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.`", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.07943282347242822`", ",", 
       RowBox[{"0.9708993564874809`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.4818406183380653`*^-33", " ", "\[ImaginaryI]"}]}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0.1`", ",", 
       RowBox[{"0.9989412696807748`", "\[VeryThinSpace]", "+", 
        RowBox[{"3.3367019574748103`*^-19", " ", "\[ImaginaryI]"}]}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0.12589254117941687`", ",", 
       RowBox[{"0.9999982616792098`", "\[VeryThinSpace]", "+", 
        RowBox[{"7.628006216915802`*^-18", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.15848931924611143`", ",", 
       RowBox[{"0.9999999999923229`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.6254259232651074`*^-21", " ", "\[ImaginaryI]"}]}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{"0.1995262314968879`", ",", 
       RowBox[{"1.`", "\[VeryThinSpace]", "+", 
        RowBox[{"6.818559425001438`*^-31", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.25118864315095824`", ",", 
       RowBox[{"1.`", "\[VeryThinSpace]", "+", 
        RowBox[{"4.578605834220335`*^-49", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.31622776601683794`", ",", 
       RowBox[{"1.`", "\[VeryThinSpace]", "+", 
        RowBox[{"7.46949882281936`*^-84", " ", "\[ImaginaryI]"}]}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.39810717055349776`", ",", 
       RowBox[{"1.`", "\[VeryThinSpace]", "+", 
        RowBox[{"3.5246244259058307`*^-146", " ", "\[ImaginaryI]"}]}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.5011872336272725`", ",", 
       RowBox[{"1.`", "\[VeryThinSpace]", "+", 
        RowBox[{"5.4228587885864995`*^-254", " ", "\[ImaginaryI]"}]}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.6309573444801942`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999952033267241802490648745727430443037\
3694`439.2736496325759", "+", 
        RowBox[{
        "2.387571618452056003444834975123947293958717904639768`15.\
954589770191005*^-430", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.7943282347242822`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999918596307308820306487416889476564434`711.7429155389339", "+", 
        RowBox[{
        "4.854194514604713184312418336516634239446371747682`15.\
653559774527023*^-703", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999996573185788793435612102409488067560291862332`1109.118669016324", 
        "+", 
        RowBox[{
        "3.139246795877328143671639671107141653`15.653559774527023*^-1100", 
         " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.2589254117941688`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999985754133355620640090943107475217140354486845234041566`1658.\
198840510377", "+", 
        RowBox[{
        "1.7227380330462907506212930133350062024892008775`15.35252971321454*^-\
1649", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.584893192461114`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999942093896354893976034322415316413448674\
`2385.5898049738853", "+", 
        RowBox[{
        "8.20688226074579045991425928376617509648155142834813`15.\
352529701923736*^-2377", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.9952623149688828`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999983972217240897074044996123918427008758461395\
26026274`3315.8466257431082", "+", 
        RowBox[{
        "2.499974904863851284591997273710314416721139125`15.051499635017365*^-\
3307", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.5118864315095824`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999989001117325449131888621219778246009036786234126398`4474.\
010150123129", "+", 
        RowBox[{
        "3.1567069122030296606167988239206745419523542`15.051499510541094*^-\
4465", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.1622776601683795`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
99999999999999999999999999985422323433211021990782883760026580668968108732`\
5882.586780158169", "+", 
        RowBox[{
        "4.7225915396612605147387320322274309232708`14.750469402824116*^-\
5874", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.9810717055349776`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999944046670\
2195293700882210941105000457166247`7563.002642827339", "+", 
        RowBox[{
        "1.406856143760017301032239131893529944`14.75046948895129*^-7554", 
         " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5.011872336272725`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999992067627636632813167587930456264922442`9532.85106442276", "+", 
        RowBox[{
        "4.426463600901113479617753980451128432089813340210718`14.\
750469124866694*^-9524", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6.309573444801943`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999999999999999999997505737058769073452266815526728837352`11807.\
35352478981", "+", 
        RowBox[{
        "1.69297888204994600951838797083851028160700839831653`14.\
75046898150409*^-11798", " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7.943282347242821`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999985434644102088527275326688353089372\
7184939994`14400.587145903299", "+", 
        RowBox[{
        "9.95712643614615469567320877195902353814`14.75046897572326*^-14392", 
         " ", "\[ImaginaryI]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10.`", ",", 
       RowBox[{
       "0.99999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
999999999999999999999999999999999999999999999999999999999999999999999999999999\
9999999763517830565341367315845292178648152944073249`17328.376667979843", "+", 
        RowBox[{
        "1.978767758281649622793477614434503003587`14.750468793872267*^-\
17319", " ", "\[ImaginaryI]"}]}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.782245605383587*^9, 3.7822456127997723`*^9}, 
   3.7822525119619627`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot panel C", "Subsubsection",
 CellChangeTimes->{{3.782243851654668*^9, 3.782243853150518*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"N0", "=", 
   SuperscriptBox["10", "4"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m0", "=", 
   RowBox[{"-", "0.3"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"letter", "=", "\"\<C\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"datadir", "<>", 
     RowBox[{"ToString", "[", 
      RowBox[{"StringForm", "[", 
       RowBox[{
       "\"\<prescue_poisson_N``_n``_Es``_mmax``_mwt``_mutmax10_nreps10000.csv\
\>\"", ",", 
        RowBox[{"NumberForm", "[", 
         RowBox[{"N0", ",", "1"}], "]"}], ",", "n", ",", "Es", ",", 
        RowBox[{"NumberForm", "[", 
         RowBox[{"mmax", ",", 
          RowBox[{"{", 
           RowBox[{"3", ",", "2"}], "}"}]}], "]"}], ",", 
        RowBox[{"NumberForm", "[", 
         RowBox[{"m0", ",", 
          RowBox[{"{", 
           RowBox[{"3", ",", "2"}], "}"}]}], "]"}]}], "]"}], "]"}]}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"dat", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", 
       RowBox[{"{", "1", "}"}]}], "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"dat", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", 
          RowBox[{"{", "1", "}"}]}], "]"}], "]"}], "*", "Uc"}], "/.", 
      RowBox[{"Uc", "\[Rule]", 
       RowBox[{
        SuperscriptBox["n", "2"], 
        RowBox[{"\[Lambda]", "/", "4"}]}]}]}], "/.", 
     RowBox[{"\[Lambda]", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"Es", "/", "n"}]}]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figS1c", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListLogLogPlot", "[", 
      RowBox[{
       RowBox[{"Re", "[", "theory", "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
       
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SuperscriptBox["10", 
             RowBox[{"-", "5"}]], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            SuperscriptBox["10", 
             RowBox[{"-", "6"}]], ",", "1"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Mutation probability\>\"", ",", "\"\<Probability of rescue\>\"",
           ",", ","}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"letter", ",", "14", ",", "Bold", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             ",", 
            RowBox[{"Scaled", "@", 
             RowBox[{"{", 
              RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"StringForm", "[", 
               RowBox[{"\"\<\!\(\*
StyleBox[SubscriptBox[\"m\", \"0\"],
FontSlant->\"Italic\"]\)=``\>\"", ",", "m0"}], "]"}], ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             ",", 
            RowBox[{"Scaled", "@", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"2", "/", "10"}], ",", 
               RowBox[{"9.5", "/", "10"}]}], "}"}]}]}], "]"}]}], "}"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ListLogLogPlot", "[", 
      RowBox[{
       RowBox[{"Re", "[", "alltheory", "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Black"}], "}"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ListLogLogPlot", "[", 
      RowBox[{"dat", ",", 
       RowBox[{"PlotMarkers", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Automatic", ",", "Medium"}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "m0", ",", "N0", ",", 
   "U", ",", "letter"}], "]"}]}], "Input",
 CellChangeTimes->{{3.78224385918368*^9, 3.7822439087542152`*^9}, {
   3.784901089952484*^9, 3.784901093467702*^9}, 3.784905296837949*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwtkAlMk2cYx0vBIgixFXoK5ft60dIhpCgMPNpZ3RQNwZMlW6jDa56oNbIp
8QgFhOCIKYcKMlkJiVVUzNw4tr3/xc6JgrLBCB6oeGxoPJDSwYYF9ev3Jm/e
PHne5//8/z86K3v5ei6Hw5nz7r5/Dft/vqVUaXBqovR4ca0esg31n/wl0yD2
qx8D5xzT43+ztmewTo1WDk5nKPTopZ3rQuLUyJxx32A9G4OmCb07ulmF2uat
179JjMGxvoZDZrMK7otSixM65LTG8S0dSgjtJzy/peqQcbyxZm+GEiMu2t7f
rUViTkJsRb8CXYHZ8d5MLYSrLrU2blEgpdzVI3kaDY8hKbXDQ6PafTF3pjUa
3fzm3oEDNCYFZRvSvRp8/zJlY0AwDcWZ+8+2FGpgb//JE1VGIUzQeKFQoIHV
Oc82W07h3IrIAkeVGnX8Q+pz6VFIyBjbRtRqrG23zX+yTg7Sd37znfMqKA8f
tkR8HYnSD+35I8kqPDCX5K44EoFTUp0rzKVkOU0Hyb0bH5+mhKXV/sOvl2Rw
h1T0LO1VQJ5T2TXaJkXe3j2uTVkK3DVUDcbdk2DJgDK08DmNqpc1oRuHxChN
//1q3R4anzm/i6nhibHYH+GXOTTLX4Qcq170sJhieQvBrZe98RNSqGT4hiO5
zO3/8bworGZ4hqEDw4+Kl8tZftNw88qilV0bIlleAmyyeUzUvgiWDx/Pro3/
uat0OhwMj6nYVt12sN0hA83kD0VCi4SOa5KyeadAOt4ZcLJdwuYLQku3Ryjt
F7N5AiG8Y5uo94ggZfzzMOLlWZYEi1DB+A2ALt/sHxIlZP1x0fn51ZTBhHAc
ZfxwcONeYaLf4jBQzH4vKTjSlJ+aOQ0Us+8/MrmA23jbKoCI0f+XyNKevLlc
xGf1hoj226LmFNNUiJn5F0QS8suCwO2hEDP//yZ59NpXs05OAY/p95EzH9i+
pG8EYRJTd5CuhWnm2X6TwWFPXqyhRJDEwzJf37hzqKR61Y53OXzzxuGi5C8e
N3Ch9ekbvfryBZ2DHMT49hup+aMtt3aPE5HPn5FX73Q1ScYI5fNvHFsTmzT3
jxHC5jMO7Cie8ZFjmPjmvcbtOlpeWfaalPv4mEYbXh00ffqC1eOa1KuDax2P
/iFvAUoi064=
       "]]}, 
     {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQrbtvpoO3o9KBBf/7Z3Yt1D7w1cjc6+xXxQMl+2w2
KvNrH7gisPPGi3rFA3HTIznnamkd2PLOKp2FS/GA3J5XPoZumgcmn9nzVX6K
woFHStm+DxM1DhSvsmuxllM4UG9qfm1trfqBJQKNqusC5A+cMbh6ZPpMtQPJ
Z1qcnqbIHcipTBFZsFX1gHJHR7xMpeyBiRxsJ45fVDnwwLmnJrhX5gDrYjlJ
gXfKUHdJH1ibYx1TxaV8IH735G0Ht0odaFx2Vp1DXemAXPn0yz9OSh4oO1IU
vttZ8cAdo9kf9O9JHMg/cclpWoLCgdnv5vGmfxI/8DFjObv5b7kD0asWac1j
Ez+wd9fsnPmmsgek0pa5X5USOxCd0OtRUCB94IbiqhQefdEDk84ZLdi2WvLA
9LtrG52dRQ5s9Nx/o/25+IGwmRvnVYULH3DecG8zo4rYAdHQrbs3ZgsdCNT9
eMA/UQQaXoIHbsyfVb9pvhA0fAQOfDgi6tJ1X+DAYnB48B84cnrq+vNOfAcU
wf7nPaBrWunhdYYL6l/uAz/0bNdKxLFD/cd5wMmnq0fmDzPUP+wHtstKaWqu
YTggCXY/2wHvMLPjZ9/+2j8N7F6WA7y5jy2/XfyyH+I+pgNXox7bhgW+2z8R
7B6GAy8/HFxe4PJkvwLY/r/7u5z4Ppo8u75fAWzfz/1NogHidW7H94uBzf+2
3zX14NnOkxug5n3av2HLmapz/3v3i4P1v93/82VY7mmZyP3iYPXP9n92+ej5
6B/nfjaw/N39UqKsvcH8k/axgvln9+cfZGWoUbm9lwEKmMDkiT2BEHl7mLgm
RD+crwExH87XgtgP54tB3AfnK0Dcj+BD/Iem/y+cPxUSPg6o5jHB+QAKMGdh

       "]]}, 
     {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQnRZcO+H5bLkDC/73z+xaqH0g+UyL09MUuQOxJ2oy
vwdrH1Du6IiXqZQ9cPRD5FlODq0DD5x7aoJ7ZQ5cEMty275HA6pP+gB/r7ow
e5H6gfjdk7cd3Cp1YE6yTS2jhtoBufLpl3+clDzQ7yhzYv09lQN3jGZ/0L8n
cSCgZr+azDTlA7PfzeNN/yR+QE7q04NAP6UD0asWac1jEz8wtWnltFh2xQNS
acvcr0qJHaj/t3D37Cb5AzcUV6Xw6Ise2Hwhuz/jh8yB6XfXNjo7ixzYLz31
kF+B1IGwmRvnVYULH5BMWvq055X4AdHQrbs3ZgsdOBE8f2ZDuuiBKwI7b7yo
FzzQJ2NRuv+50IHJZ/Z8lZ8icOBhtvQklxyBA4sFGlXXBfAfOBj9/mfzW+4D
imD/8x448C7neqoIO9S/3AcirovVbgtngvqP88CKe+pdWyb/3g/xD/uBtNW2
hr4in/dLgt3PdoBllkWNk87z/dPA7mU5oCPtkM6y+Np+iPuYDkiYfzqx/P/e
/RPB7mE4UNPz5Xma6eT9CmD7/+4PmZ10wlbIc78C2L6f+0NtvvGsUzy2Twxs
/rf93vYsDBtrHuyFmPdpPwMUiIP1v0XwweqfwflsYPm7cD4rmH8WzkcHgRB5
exhfE6IfzteAmA/na0Hsh/PFIO6D8xUg7kfwIf5D0/8Xzp8KCR8HVPOY4HwA
T+gh+w==
       "]]}, 
     {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQfcbr+FeJX1IHFvzvn9m1UPtA/O7J2w5ulTpw+qbB
jjWq2gfkyqdf/nFS8sDE9X8VnlVrHrhjNPuD/j2JAxsZpeQPXVY/MPvdPN70
T+IH7Of81QjTVTsQvWqR1jw28QO7lRkD9naoHJBKW+Z+VUrsgLGxJ7P4M6UD
NxRXpfDoix5YnL9TsN1V8cD0u2sbnZ1FDtjI7LDN8ZM/EDZz47yqcOEDCRyf
/q4QkzkgGrp198ZsoQPm3Je7HZ5IHLgisPPGi3rBA8emVZQ/3S56YPKZPV/l
pwgceH8mbe6uSUIHFgs0qq4L4D/wb9otw4Vv+Q4odnTEy1TyHljV/sPb4wIH
1J/cB57mbfQIuMsE9R/ngZyPSc/XZPzaD/EP+wHVponp35U/7JcEu5/twCVP
09mT/tzbPw3sXpYD/QWLD9a0HdoPcR/TgRkzWOTbdSfsnwh2D8OBprO2bue/
a+5XANv/d799hb/Xj9kJ+xTA9v3cz8wAApf2iIHN/7afAQog5n2C88XB+t8i
+GD1z+B8NrD8XTifFcw/C+ejg0CIvD2MrwnRD+drQMyH87Ug9sP5YhD3wfkK
EPcj+BD/oen/C+dPhYSPA6p5THA+AM0fASg=
       "]]}}, {}}, {{{}, {}, 
     {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJxdkXtIU1Ecx2+yZiu11dLlI93d5jZnJln5aM2kJWaQuqysrEb2EHqgVCA+
yqYLRlS+apaGaUnmRKHUTCzv1/0RJGpiL4Ue9sTIRyysqZjZvetKHjgcPpzz
+/2+3+8hk1K2HnIgCEI9vf+eieabyjKuHMFNey07spZDZZQ2N+fL0FrbTZk4
y+Fx+HbUCw8ZVF2hTocu+GNco3j5vdIX3M0BRVUCf/SS5oNOgb44GTrVqi5R
4sGU/w95sxRN3bZCQqTE1Te1eo1GClQmlKDSD2ktgXxdpwS/UoOeblT4IeHa
3bKMBAk+da3URpsVCE5bFWB6L0bBEmfzaaUCrtsbW+4eFSPRJfxL7h05RoNC
NneOkqgr5OWMSOR4zm/uHcgmcdKUsS7yugwNw2uTOfNJ7HKOyZ/gy1DU8XDU
57IIxz+m6rP00zrN4QaVtwh9lrariiEpKvl637o4H0QW67SJ8VIc6DBs+HzQ
G+Pp2edT6yWQGI06r/Rl8DlbeqndSYJ+zYWs+Ite6I3kWl7tE6N8Ku/a+QpP
iOsM427VJHQtRffbGj2wwJb5wP2bCN5pxc9sT9whGK5ozJWK8Dqo9Hvg26VI
7YndxDd7o3S4zDnZKkTmU52x3eYF5j+EuBF37p5ltac9fzd8qp+Yk7/X3Z63
Kwa2fujpOyFEMZ3vEuxbMyg+dsoVO+g8Bcixjo0kJAns+S3GWrJfpVQvsue1
CJmmKsdsJxd7Pnzs1JNf887ycIvOYyFyKlaExfZzQNL+nSEzOGrnqQm73wX4
XS2Teh75RTH+eMirSq7ZYB2iGD+OiPGVb9GGv6Pcaf1cvEs50xCy/zFlovVy
EB69Z7VFXUYx+hwQNlijmtytpQpoPQS2pQdf4SkftYro+ZNURBRBdL8vfySi
541RhH250f1/ssz0s7IspOuHZph+/4VlLn3/huW5NHeyPHtpmfv1/9iPqWdZ
wfRnWcnMZ9mN0ceyiNE/w4y/WfWTLF9h8on4v58Dy38AatyQ2Q==
       "]]}}, {}}, {
    GraphicsComplexBox[{{-6.214608098422191, -8.517193191416238}, \
{-3.912023005428146, -3.6045383056801854`}, {-6.214608098422191, \
-8.517193191416238}, {-3.912023005428146, -3.6045383056801854`}}, {
      {GrayLevel[0], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 3], InsetBox[
        StyleBox["\<\"\[FilledCircle]\"\>",
         StripOnInput->False,
         FontSize->Medium], 4]}, {}}], {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{-11.512925464970229`, -13.815510557964274`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"C\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
      TraditionalForm], 
     Scaled[{0.05, 0.95}]], 
    InsetBox[
     FormBox[
      StyleBox[
       InterpretationBox[
       "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=\\!\\(TraditionalForm\\`\\(-0.3`\\\
)\\)\"", 
        StringForm[
        "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\nFontSlant->\"Italic\"]\
\)=``", -0.3], Editable -> False], 12, FontFamily -> "Helvetica", 
       StripOnInput -> False], TraditionalForm], 
     NCache[
      Scaled[{
        Rational[1, 5], 0.9500000000000001}], 
      Scaled[{0.2, 0.9500000000000001}]]]},
  Frame->{True, True, False, False},
  FrameLabel->{{
     FormBox["\"Probability of rescue\"", TraditionalForm], ""}, {
     FormBox["\"Mutation probability\"", TraditionalForm], ""}},
  FrameTicks->{{{{-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.716898269296165`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.429216196844383`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.02375108873622, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.86960040890896, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.736069016284437`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.618285980628055`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, None}, {{{-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, None}},
  GridLines->{None, None},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{-11.512925464970229`, 0.}, {-13.815510557964274`, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{{{-11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {-10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.414313176302118`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.126631103850338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.721165995742174, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.567015315914915, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.433483923290392, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.315700887634009, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{-13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.716898269296165`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.429216196844383`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.206072645530174`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.02375108873622, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.86960040890896, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.736069016284437`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.618285980628055`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.414313176302118`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.126631103850338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.721165995742174, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.567015315914915, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.433483923290392, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.315700887634009, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.782245630167761*^9, 3.782245638773806*^9}, 
   3.7822524710052834`*^9, 3.782252519765205*^9, 3.782269888423016*^9, 
   3.784901093898398*^9, 3.7849052980140533`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure S1", "Subsubsection",
 CellChangeTimes->{{3.784901099636249*^9, 3.784901100739853*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GraphicsColumn", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"figS1a", ",", "figS1b", ",", "figS1c"}], "}"}], ",", 
   RowBox[{"Spacings", "\[Rule]", 
    RowBox[{"-", "30"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{"supfigdir", "<>", "\"\<FigureS1.eps\>\""}], ",", "%"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.784901102988967*^9, 3.784901177865283*^9}, {
  3.784905313882443*^9, 3.784905315250272*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     FormBox[
      TagBox[
       FormBox[
        GraphicsBox[{{{{{}, {}, 
             {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJxdkntIk1EYxseYk2nW8u7ysjk3rynoNHGV4v6QRjcTtUw0zFQyMzHwgqDC
qFmJmuYyYamJ1kBJc9F07bxCMK8ZuJmJmiZJYtrUvMY0+059kgcOHz/Oed/3
eZ7zcZIyL1yjUiiUE7v7z/eyosFLTneH91uvzj4ftQGh1E2lKueD+K7kS+aC
NbBSmiL0LD4k+CTr4qnWsCXyGDE08uCdtqw/184KRjmK5AN+PEhgaeeHfCzh
zY73irvKDTT+AblZ4Yfh8URLsUjkBpc6Ip/eusiEnC4/ZuIgFzJGFSt9Ewch
tqZNnh/LBV1IVsW4uQUE5QQcrZ52heYwATVJaA420cqutnRXyN6eu9l5gwGr
/sfEg6scyGfFGOPrTEHHVI1+K+SASlLUODliAh2LIak0Mw7ckTSIN5k0qBxQ
r7pUsUHb/eRK1TkqZCtOSoTObGicF3oOVVKgkVnMaz3vAkofRbmDxoiuDkjC
vyY7Q4AskEVL2UJcqTTRMc8JljTS4yXcdTQlelAQVeoIav2HU8pfK6hup6zm
Xv0REHz0i33404ASuypfdytZEJ1U0Jvj9R0558iGN3odoCRUvaHun0Xj/rUG
v0l72G4+beR+nka1i3KL1GU7SJlnlOt/jCH8HnbQ7lgobokcRjh/W+A1s0yU
9D6E87aBHkoNO84XkIzI1xqWWrLOvOC3oxgiTytYm9MLnHT1COdnCXyPMQFf
UopwXofh5cz07Rl5NsL5MGE47pOZtjMKPSPyOARpTT1ptClvxCH8W4C8OlMR
HL6pwX7NIW9Jdr01uFOD/TEgcCS3p8k+XYP9mMK60DUsI9VU40Dop0OE7+7P
FnT/bTWhlwaMXaQUGdRYHxUof1cFoYdCMpuYb0QkE/M2SbYl+q+RjPstk2xH
1C/sMXF/lmQ6cT5BsgnBgyTvX5H4PPQfe+J6kj1wf5K98HySbbE+ktlY/x5j
f/vqjSQ/wvmE/d+PSvJvRgiT9Q==
               "]]}, 
             {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
              LineBox[CompressedData["
1:eJxdkgtIU1EYx9ea07Ws+dqcj7m7hzOlBKcJiiVOSoKghw8iQbDZBNFA05GI
OhgxS7HQ5iskUyskLSXF5eN+QQ8ER/mojPIZ5iOV6ZjZdKy8p47ogcPlxznf
9/3//3OJ1GsX0ug0Gi3q797+Xm55GFjPlIF72aGbReEyiNRJDIY7/hBWZpZP
JPqD19VHpz96+cOT6hGrJk8KVkXAJ1OTFCLsOkamXgJjRIvyYLAUivMWvzd0
iaHbHmSWGSSQmVulF38WQfV4q0ahkEDGJSi3/CJA3RPMSTGKIdR5bcSbT0BS
TXt9fpIYbjslLtVGCOG4Wn5UPy0Cvmqs2tQtAI+Ezp72DBHE14pWr9t8wBIS
fsZoIeD+l0zNcIw3jHIMY/NFBOjy+bG+JXx4sRKhYhwgYCh7eDnrAw8qBnst
fpVCSJ/Z37HgyYWclhPaSIEQ5jbexPWmukMTRyNtO+cHyelpNlmbK1wZ1MbM
KgWQFEu8LdnkgFinS/G54QtK9bjhvf4QTClKCy6W+UCyE2uSHcWGB/bymlsN
3vBSaDU5LDlCSk9F16tOL6BLBgacHjNAoK4a2RjgA6vArXAuex98C6kzBU94
wnqynXm2dYusW6l3Vq3xoHBG6/ise51E78GDSWXYZJBklUT5cyF6K+F5TtA8
ifL2gNYsrVVtniCrqHzdYfGrMcsWOkQmUnm6QR6L3re40E+i/FyhObejeWGz
kUR5uUCBoTh+ll1Eonw4oNqQx5UeO0U2UnkchtHpqbTKn+Z+gvLvDPIKZYhL
YH4/8suGBE867WnAuz7kjwXb/xKN9roX+XEE2r/Fp/QzMespvQzMSB8d811K
Dw2zkJpvIzFT835j5lL918nd/dYw86j65R2m7v/AzKTOxzE7UGzEvHedR+cn
//MRVI85APXHHIjmY+YifZiFSP8OI3976m2Y76F8onf3o2P+AwGYhPM=
               
               "]]}, 
             {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
              LineBox[CompressedData["
1:eJxTTMoPSmViYGAwA2IQzRlQ8bp3t/KBBf/7Z3Yt1D4QPnPjvKpw5QPcLx8v
YG/XOmBWbqw77aHSgQyjSg0/G80DoqFbd2/MVjpwdI0Oa/dn9QNfjcy9zn5V
PGB2QKaxZ43agSsCO2+8qFc80KX54JhcuuqBLe+s0lm4FA9UTJP9I66scmDy
mT1f5acoHHD+5JcS+0DpQPEquxZrOYUDGjPnHX40T/HAEoFG1XUB8gdMz+Re
Wx6ncCD5TIvT0xS5A5XzWVJy7OUOKHd0xMtUyh4QvfdfyfGI9IEHzj01wb0y
B0KnxO1n95GE+kP6QJbll5ei18UOxO+evO3gVqkDnd9v9bxKFTkgVz798o+T
kgc2n958y/On4IE7RrM/6N+TOOBxYvmzmyr8B2a/m8eb/kn8gFjgaca1aVwH
olct0prHJn6AO0i58/g+1gNSacvcr0qJHZhd0H+32oLxwA3FVSk8+qIH1LrM
Hkae/bl/+t21jc7OIgdM2Jb/+HP+4/4wcHgKH7h+yOrd3TVP90PCT+hAnRPX
R4fyq/sh4SV4wPxtwjvb83v3Q8JH4MDJSqfWpMdT9y8Ghwf/AVVps1srmkL2
K4L9z3ugySlroWHV030Q/3IfUG3eOWGarfY+iP84D/AxgMDXPRD/sB9ggAJJ
sPvZ4PxpYPeywPkQ9zHB+RPB7mGA8xXA9v/dD+eD7fsJ54uBzf+2H9W8T3C+
OFj/WwQfrP4ZnM8Glr8L57OC+WfhfHQQCJG3h/E1IfrhfA2I+XC+FsR+OF8M
4j44XwHifgQf4j80/X/h/KmQ8HFANY8JzgcAR7tKhw==
               "]]}, 
             {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], 
              LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQ/feNWbPVDYUDC/73z+xaqH1g8pk9X+WnKBxQbOiZ
/Hmp1oHiVXYt1nIKB+qiTLijvmkcWCLQqLouQP7AA17DOaHe6geSz7Q4PU2R
OxCqPUtCa6nqAeWOjniZStkDD6vnnpnJrHLggXNPTXCvzIEf3/4rSKcpQe2R
PtBeGz5V94zCgfjdk7cd3Cp1wPSm7hKhbLkDcuXTL/84KXmg7dQ7ZQ8X6QN3
jGZ/0L8nceCxRaaXn4rEgdnv5vGmfxI/kO133/wRt+iB6FWLtOaxiR9Y+PZX
ZvgfwQNSacvcr0qJHdCeeHS95AfeAzcUV6Xw6IseuBNkYXiGjePA9LtrG52d
RQ58KTDRs/JlOhA2c+O8qnDhA9t1n0jNO/Jzv2jo1t0bs4UOfHmRdsz+x/v9
VwR23nhRL3iA8wDPnpwn9/dDwkfgQPYsc5OXGkf3LwaHB/+Bu/NXHXl/fMZ+
RbD/eQ/I7WO4U67ith/iX+4DD/mCTDasWbUP4j/OA6e1GBgatLr2QvzDfoAB
CiTB7meD86eB3csC50PcxwTnTwS7hwHOVwDb/3c/nA+27yecLwY2/9t+VPM+
wfniYP1vEXyw+mdwPhtY/i6czwrmn4Xz0UEgRN4exteE6IfzNSDmw/laEPvh
fDGI++B8BYj7EXyI/9D0/4Xzp0LCxwHVPCY4HwCxARrd
               
               "]]}}, {}}, {{{}, {}, 
             {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJxd0m1IU1EYB/DLmprv06lr03RXnXNaSAuWpKa0QrCkWegoCWlZGlJ9kBhK
ZNayIZmWpon42vSDVKLkbC09j0EvvkGZmmQOTSsRJrZYuUpX3lNH9MLl8uPc
85zn+d9Lq84fPsWiKCru7736TG9tiqhzFANSdbTljflCjDbUYCgLg5XX78Qw
7wOC0y2Jo4IwmLQ803vYufBTHj62qBNBevnMzWwuF8bp1ky3KBEUxb1nD4u9
4bE98pvYEApS+vlXRawX3J18UCiXh0LEZa3MrOCA2hjFyRgKgcQd82OqAQ9Q
VrfX5StDQEJdr1Ba3UCm3rm9cjoY4p9o3piCXME3tdPYnhMMuvx+Q+QBZ7BK
dyUNWWkIvnDJdEXtBCMcw/hcAQ3DLsnihGYHeLSwO4vtQkP0we4B08gmKB98
ag2qEIJHUR+f7cSC3NY9mphAIXS5pthLYinQcQpFDxVBcM3gH59s/o1ODmr2
fsoMBF3vkqT7rA2FaLUZAXlbIcfWUVu/YkVT8hsXj5QEQPYZXkBlswU12Eur
ixv9wZCUWr1/ZAFlGMv1vZ0CqD+UP33i/hwKVFe9Xerjg9Y2e3Wf+SP6IK1Z
jDJtAc2KftF4bgLVLNS5Z1l44FU4UFakGkb4e/Bgdqbg+A/PFwjn7wcTYf12
RbEe4bx9YVQpgzz/JlTF5OsDv9JuN2aFa1AakycXpA1fdLLcowjn5w1TqaxX
olIBwnl5QX9a+7G2LmMPzocDm+kWiH4p6bnH5OEJ/NWfY1tiN83M7w7UvwvP
60qM53MmxvM4EfOZ/h2JK5l+2cS4PxbxLaYfiljInL+MiJnzbMR+TP3vaH09
CzGP2W9eM/P+Z2JHZn2S2IHxEPHGKwWvx/+3BO8nDsf1iSPw+cR+uD9iIe5/
zXi+DfuXie/gfBLW12MR/wH9m3un
               "]]}}, {}}, {
            GraphicsComplexBox[{{-10.819778284410283`, -4.9062752787720125`}, \
{-8.517193191416238, -2.569158202235591}, {-6.214608098422191, \
-0.48906413198447785`}, {-10.819778284410283`, -4.9062752787720125`}, \
{-8.517193191416238, -2.569158202235591}, {-6.214608098422191, \
-0.48906413198447785`}}, {
              {GrayLevel[0], InsetBox[
                StyleBox["\<\"\[FilledCircle]\"\>",
                 StripOnInput->False,
                 FontSize->Medium], 4], InsetBox[
                StyleBox["\<\"\[FilledCircle]\"\>",
                 StripOnInput->False,
                 FontSize->Medium], 5], InsetBox[
                StyleBox["\<\"\[FilledCircle]\"\>",
                 StripOnInput->False,
                 FontSize->Medium], 6]}, {}}], {}}}, {InsetBox[
            
            TemplateBox[{
             StyleBox[
              "\"total\"", StripOnInput -> False, FontFamily -> "Helvetica", 
               FontSize -> 12]},
             "LineLegend",
             DisplayFunction->(StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
               False]& ),
             Editable->True,
             InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], "}"}], ",", 
                  RowBox[{"{", #, "}"}], ",", 
                  RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                "]"}]& )], Scaled[{0.56, 0.23}], ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm], InsetBox[
            
            TemplateBox[{
             StyleBox[
              "\"1-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
               FontSize -> 12],StyleBox[
              "\"2-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
               FontSize -> 12],StyleBox[
              "\"3-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
               FontSize -> 12],StyleBox[
              "\"4-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
               FontSize -> 12]},
             "LineLegend",
             DisplayFunction->(StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
               False]& ),
             Editable->True,
             InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.24720000000000014`", ",", "0.24`", ",", 
                    "0.6`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.6`", ",", "0.24`", ",", 
                    "0.4428931686004542`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.6`", ",", "0.5470136627990908`", ",", 
                    "0.24`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.24`", ",", "0.6`", ",", 
                    "0.33692049419863584`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
                    "}"}], ",", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                  RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                "]"}]& )], Scaled[{0.85, 0.23}], ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm]}},
         AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
         Axes->True,
         AxesOrigin->{-11.512925464970229`, -13.815510557964274`},
         CoordinatesToolOptions:>{"DisplayFunction" -> ({
             Exp[
              Part[#, 1]], 
             Exp[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             Exp[
              Part[#, 1]], 
             Exp[
              Part[#, 2]]}& )},
         Epilog->{
           InsetBox[
            FormBox[
             StyleBox[
             "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
              False], TraditionalForm], 
            Scaled[{0.05, 0.95}]], 
           InsetBox[
            FormBox[
             StyleBox[
              InterpretationBox[
              
              "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=\\!\\(TraditionalForm\\`\\(-0.1`\\\
)\\)\"", 
               StringForm[
               "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=``", -0.1], Editable -> False], 12, FontFamily -> 
              "Helvetica", StripOnInput -> False], TraditionalForm], 
            NCache[
             Scaled[{
               Rational[1, 5], 0.9500000000000001}], 
             Scaled[{0.2, 0.9500000000000001}]]], {
            Arrowheads[{{0.02, 0, {
                GraphicsBox[
                 CircleBox[{1, -1}, 1, 
                  
                  NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
                   3.141592653589793}]]], -1}}, {0.02, 1, {
                GraphicsBox[{
                  CircleBox[{-1, 1}, 1, 
                   
                   NCache[{
                    Rational[-1, 2] Pi, 0}, {-1.5707963267948966`, 0}]], 
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox["\"\"", Larger, StripOnInput -> False], 
                    TraditionalForm]], {0, 2}]}], 1}}}], 
            ArrowBox[
             NCache[{{-Log[
                  Rational[100, 3]], -Log[500000]}, {-Log[
                  Rational[100, 3]], Rational[1, 2] (-Log[
                    Rational[10000, 3]] - Log[
                 500000])}}, {{-3.506557897319982, -13.122363377404328`}, \
{-3.506557897319982, -10.6170457303562}}]], 
            Arrowheads[{{0.02, 0, {
                GraphicsBox[
                 CircleBox[{1, 1}, 1, 
                  
                  NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
                   4.71238898038469}]]], -1}}, {0.02, 1, {
                GraphicsBox[
                 CircleBox[{-1, -1}, 1, 
                  NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]], 
                1}}}], 
            ArrowBox[
             NCache[{{-Log[
                  Rational[100, 3]], Rational[1, 2] (-Log[
                    Rational[10000, 3]] - Log[500000])}, {-Log[
                  Rational[100, 3]], -Log[
                  Rational[
                  10000, 3]]}}, {{-3.506557897319982, -10.6170457303562}, \
{-3.506557897319982, -8.111728083308073}}]]}},
         Frame->{True, True, False, False},
         FrameLabel->{{
            FormBox["\"Probability of rescue\"", TraditionalForm], ""}, {
           "", ""}},
         FrameTicks->{{{{-13.815510557964274`, 
              FormBox[
               TemplateBox[{"10", 
                 RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
                SuperscriptBox], TraditionalForm]}, {-11.512925464970229`, 
              FormBox[
               TemplateBox[{"10", 
                 RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
                SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
              FormBox[
               TemplateBox[{"10", 
                 RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
                SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
              FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
              FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
              FormBox["0.1`", TraditionalForm]}, {0., 
              FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-12.716898269296165`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-12.429216196844383`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-12.206072645530174`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-12.02375108873622, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-11.86960040890896, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-11.736069016284437`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-11.618285980628055`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-10.819778284410283`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-10.414313176302118`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-10.126631103850338`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.903487552536127, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.721165995742174, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.567015315914915, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.433483923290392, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.315700887634009, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-8.517193191416238, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-8.111728083308073, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.824046010856292, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.600902459542082, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.418580902748127, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.264430222920869, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.1308988302963465`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.013115794639964, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-6.214608098422191, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-5.809142990314028, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-5.521460917862246, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-5.298317366548036, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-5.115995809754082, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-4.961845129926823, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-4.8283137373023015`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-4.710530701645918, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-3.912023005428146, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-3.506557897319982, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-3.2188758248682006`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.995732273553991, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.8134107167600364`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.659260036932778, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.5257286443082556`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.407945608651872, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-1.6094379124341003`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-1.203972804325936, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.916290731874155, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.6931471805599453, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.5108256237659905, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.35667494393873245`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.2231435513142097, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.10536051565782616`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}}, None}, {{{-11.512925464970229`, 
              FormBox[
               TemplateBox[{"10", 
                 RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
                SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
              FormBox[
               TemplateBox[{"10", 
                 RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
                SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
              FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
              FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
              FormBox["0.1`", TraditionalForm]}, {0., 
              FormBox["1", TraditionalForm]}, {-10.819778284410283`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-10.414313176302118`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-10.126631103850338`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.903487552536127, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.721165995742174, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.567015315914915, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.433483923290392, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.315700887634009, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-8.517193191416238, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-8.111728083308073, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.824046010856292, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.600902459542082, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.418580902748127, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.264430222920869, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.1308988302963465`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.013115794639964, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-6.214608098422191, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-5.809142990314028, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-5.521460917862246, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-5.298317366548036, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-5.115995809754082, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-4.961845129926823, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-4.8283137373023015`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-4.710530701645918, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-3.912023005428146, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-3.506557897319982, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-3.2188758248682006`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.995732273553991, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.8134107167600364`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.659260036932778, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.5257286443082556`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.407945608651872, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-1.6094379124341003`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-1.203972804325936, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.916290731874155, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.6931471805599453, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.5108256237659905, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.35667494393873245`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.2231435513142097, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.10536051565782616`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}}, None}},
         FrameTicksStyle->{
          FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
         GridLines->{None, None},
         LabelStyle->Directive[12, FontFamily -> "Helvetica"],
         Method->{},
         PlotRange->{{-11.512925464970229`, 0.}, {-13.815510557964274`, 0.}},
         PlotRangeClipping->True,
         PlotRangePadding->{{None, None}, {None, None}},
         Ticks->{{{-11.512925464970229`, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
             FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
             FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
             FormBox["0.1`", TraditionalForm]}, {0., 
             FormBox["1", TraditionalForm]}, {-10.819778284410283`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-10.414313176302118`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-10.126631103850338`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.903487552536127, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.721165995742174, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.567015315914915, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.433483923290392, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.315700887634009, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-8.517193191416238, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-8.111728083308073, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.824046010856292, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.600902459542082, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.418580902748127, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.264430222920869, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.1308988302963465`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.013115794639964, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-6.214608098422191, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-5.809142990314028, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-5.521460917862246, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-5.298317366548036, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-5.115995809754082, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-4.961845129926823, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-4.8283137373023015`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-4.710530701645918, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-3.912023005428146, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-3.506557897319982, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-3.2188758248682006`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.995732273553991, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.8134107167600364`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.659260036932778, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.5257286443082556`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.407945608651872, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-1.6094379124341003`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-1.203972804325936, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.916290731874155, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.6931471805599453, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.5108256237659905, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.35667494393873245`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.2231435513142097, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.10536051565782616`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}}, {{-13.815510557964274`, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm]}, {-11.512925464970229`, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
             FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
             FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
             FormBox["0.1`", TraditionalForm]}, {0., 
             FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-12.716898269296165`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-12.429216196844383`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-12.206072645530174`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-12.02375108873622, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-11.86960040890896, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-11.736069016284437`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-11.618285980628055`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-10.819778284410283`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-10.414313176302118`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-10.126631103850338`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.903487552536127, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.721165995742174, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.567015315914915, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.433483923290392, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.315700887634009, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-8.517193191416238, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-8.111728083308073, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.824046010856292, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.600902459542082, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.418580902748127, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.264430222920869, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.1308988302963465`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.013115794639964, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-6.214608098422191, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-5.809142990314028, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-5.521460917862246, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-5.298317366548036, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-5.115995809754082, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-4.961845129926823, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-4.8283137373023015`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-4.710530701645918, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-3.912023005428146, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-3.506557897319982, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-3.2188758248682006`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.995732273553991, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.8134107167600364`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.659260036932778, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.5257286443082556`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.407945608651872, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-1.6094379124341003`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-1.203972804325936, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.916290731874155, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.6931471805599453, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.5108256237659905, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.35667494393873245`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.2231435513142097, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.10536051565782616`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}}}],
        TraditionalForm],
       InterpretTemplate[Legended[
         Graphics[{{{{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Thickness[Large], 
               Line[CompressedData["
1:eJxdkntIk1EYxseYk2nW8u7ysjk3rynoNHGV4v6QRjcTtUw0zFQyMzHwgqDC
qFmJmuYyYamJ1kBJc9F07bxCMK8ZuJmJmiZJYtrUvMY0+059kgcOHz/Oed/3
eZ7zcZIyL1yjUiiUE7v7z/eyosFLTneH91uvzj4ftQGh1E2lKueD+K7kS+aC
NbBSmiL0LD4k+CTr4qnWsCXyGDE08uCdtqw/184KRjmK5AN+PEhgaeeHfCzh
zY73irvKDTT+AblZ4Yfh8URLsUjkBpc6Ip/eusiEnC4/ZuIgFzJGFSt9Ewch
tqZNnh/LBV1IVsW4uQUE5QQcrZ52heYwATVJaA420cqutnRXyN6eu9l5gwGr
/sfEg6scyGfFGOPrTEHHVI1+K+SASlLUODliAh2LIak0Mw7ckTSIN5k0qBxQ
r7pUsUHb/eRK1TkqZCtOSoTObGicF3oOVVKgkVnMaz3vAkofRbmDxoiuDkjC
vyY7Q4AskEVL2UJcqTTRMc8JljTS4yXcdTQlelAQVeoIav2HU8pfK6hup6zm
Xv0REHz0i33404ASuypfdytZEJ1U0Jvj9R0558iGN3odoCRUvaHun0Xj/rUG
v0l72G4+beR+nka1i3KL1GU7SJlnlOt/jCH8HnbQ7lgobokcRjh/W+A1s0yU
9D6E87aBHkoNO84XkIzI1xqWWrLOvOC3oxgiTytYm9MLnHT1COdnCXyPMQFf
UopwXofh5cz07Rl5NsL5MGE47pOZtjMKPSPyOARpTT1ptClvxCH8W4C8OlMR
HL6pwX7NIW9Jdr01uFOD/TEgcCS3p8k+XYP9mMK60DUsI9VU40Dop0OE7+7P
FnT/bTWhlwaMXaQUGdRYHxUof1cFoYdCMpuYb0QkE/M2SbYl+q+RjPstk2xH
1C/sMXF/lmQ6cT5BsgnBgyTvX5H4PPQfe+J6kj1wf5K98HySbbE+ktlY/x5j
f/vqjSQ/wvmE/d+PSvJvRgiT9Q==
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Thickness[Large], 
               Line[CompressedData["
1:eJxdkgtIU1EYx9ea07Ws+dqcj7m7hzOlBKcJiiVOSoKghw8iQbDZBNFA05GI
OhgxS7HQ5iskUyskLSXF5eN+QQ8ER/mojPIZ5iOV6ZjZdKy8p47ogcPlxznf
9/3//3OJ1GsX0ug0Gi3q797+Xm55GFjPlIF72aGbReEyiNRJDIY7/hBWZpZP
JPqD19VHpz96+cOT6hGrJk8KVkXAJ1OTFCLsOkamXgJjRIvyYLAUivMWvzd0
iaHbHmSWGSSQmVulF38WQfV4q0ahkEDGJSi3/CJA3RPMSTGKIdR5bcSbT0BS
TXt9fpIYbjslLtVGCOG4Wn5UPy0Cvmqs2tQtAI+Ezp72DBHE14pWr9t8wBIS
fsZoIeD+l0zNcIw3jHIMY/NFBOjy+bG+JXx4sRKhYhwgYCh7eDnrAw8qBnst
fpVCSJ/Z37HgyYWclhPaSIEQ5jbexPWmukMTRyNtO+cHyelpNlmbK1wZ1MbM
KgWQFEu8LdnkgFinS/G54QtK9bjhvf4QTClKCy6W+UCyE2uSHcWGB/bymlsN
3vBSaDU5LDlCSk9F16tOL6BLBgacHjNAoK4a2RjgA6vArXAuex98C6kzBU94
wnqynXm2dYusW6l3Vq3xoHBG6/ise51E78GDSWXYZJBklUT5cyF6K+F5TtA8
ifL2gNYsrVVtniCrqHzdYfGrMcsWOkQmUnm6QR6L3re40E+i/FyhObejeWGz
kUR5uUCBoTh+ll1Eonw4oNqQx5UeO0U2UnkchtHpqbTKn+Z+gvLvDPIKZYhL
YH4/8suGBE867WnAuz7kjwXb/xKN9roX+XEE2r/Fp/QzMespvQzMSB8d811K
Dw2zkJpvIzFT835j5lL918nd/dYw86j65R2m7v/AzKTOxzE7UGzEvHedR+cn
//MRVI85APXHHIjmY+YifZiFSP8OI3976m2Y76F8onf3o2P+AwGYhPM=
                
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Thickness[Large], 
               Line[CompressedData["
1:eJxTTMoPSmViYGAwA2IQzRlQ8bp3t/KBBf/7Z3Yt1D4QPnPjvKpw5QPcLx8v
YG/XOmBWbqw77aHSgQyjSg0/G80DoqFbd2/MVjpwdI0Oa/dn9QNfjcy9zn5V
PGB2QKaxZ43agSsCO2+8qFc80KX54JhcuuqBLe+s0lm4FA9UTJP9I66scmDy
mT1f5acoHHD+5JcS+0DpQPEquxZrOYUDGjPnHX40T/HAEoFG1XUB8gdMz+Re
Wx6ncCD5TIvT0xS5A5XzWVJy7OUOKHd0xMtUyh4QvfdfyfGI9IEHzj01wb0y
B0KnxO1n95GE+kP6QJbll5ei18UOxO+evO3gVqkDnd9v9bxKFTkgVz798o+T
kgc2n958y/On4IE7RrM/6N+TOOBxYvmzmyr8B2a/m8eb/kn8gFjgaca1aVwH
olct0prHJn6AO0i58/g+1gNSacvcr0qJHZhd0H+32oLxwA3FVSk8+qIH1LrM
Hkae/bl/+t21jc7OIgdM2Jb/+HP+4/4wcHgKH7h+yOrd3TVP90PCT+hAnRPX
R4fyq/sh4SV4wPxtwjvb83v3Q8JH4MDJSqfWpMdT9y8Ghwf/AVVps1srmkL2
K4L9z3ugySlroWHV030Q/3IfUG3eOWGarfY+iP84D/AxgMDXPRD/sB9ggAJJ
sPvZ4PxpYPeywPkQ9zHB+RPB7mGA8xXA9v/dD+eD7fsJ54uBzf+2H9W8T3C+
OFj/WwQfrP4ZnM8Glr8L57OC+WfhfHQQCJG3h/E1IfrhfA2I+XC+FsR+OF8M
4j44XwHifgQf4j80/X/h/KmQ8HFANY8JzgcAR7tKhw==
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Thickness[Large], 
               Line[CompressedData["
1:eJxTTMoPSmViYGAwAGIQ/feNWbPVDYUDC/73z+xaqH1g8pk9X+WnKBxQbOiZ
/Hmp1oHiVXYt1nIKB+qiTLijvmkcWCLQqLouQP7AA17DOaHe6geSz7Q4PU2R
OxCqPUtCa6nqAeWOjniZStkDD6vnnpnJrHLggXNPTXCvzIEf3/4rSKcpQe2R
PtBeGz5V94zCgfjdk7cd3Cp1wPSm7hKhbLkDcuXTL/84KXmg7dQ7ZQ8X6QN3
jGZ/0L8nceCxRaaXn4rEgdnv5vGmfxI/kO133/wRt+iB6FWLtOaxiR9Y+PZX
ZvgfwQNSacvcr0qJHdCeeHS95AfeAzcUV6Xw6IseuBNkYXiGjePA9LtrG52d
RQ58KTDRs/JlOhA2c+O8qnDhA9t1n0jNO/Jzv2jo1t0bs4UOfHmRdsz+x/v9
VwR23nhRL3iA8wDPnpwn9/dDwkfgQPYsc5OXGkf3LwaHB/+Bu/NXHXl/fMZ+
RbD/eQ/I7WO4U67ith/iX+4DD/mCTDasWbUP4j/OA6e1GBgatLr2QvzDfoAB
CiTB7meD86eB3csC50PcxwTnTwS7hwHOVwDb/3c/nA+27yecLwY2/9t+VPM+
wfniYP1vEXyw+mdwPhtY/i6czwrmn4Xz0UEgRN4exteE6IfzNSDmw/laEPvh
fDGI++B8BYj7EXyI/9D0/4Xzp0LCxwHVPCY4HwCxARrd
                
                "]]}}}, {}}, {{{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Thickness[Large], 
               GrayLevel[0], 
               Line[CompressedData["
1:eJxd0m1IU1EYB/DLmprv06lr03RXnXNaSAuWpKa0QrCkWegoCWlZGlJ9kBhK
ZNayIZmWpon42vSDVKLkbC09j0EvvkGZmmQOTSsRJrZYuUpX3lNH9MLl8uPc
85zn+d9Lq84fPsWiKCru7736TG9tiqhzFANSdbTljflCjDbUYCgLg5XX78Qw
7wOC0y2Jo4IwmLQ803vYufBTHj62qBNBevnMzWwuF8bp1ky3KBEUxb1nD4u9
4bE98pvYEApS+vlXRawX3J18UCiXh0LEZa3MrOCA2hjFyRgKgcQd82OqAQ9Q
VrfX5StDQEJdr1Ba3UCm3rm9cjoY4p9o3piCXME3tdPYnhMMuvx+Q+QBZ7BK
dyUNWWkIvnDJdEXtBCMcw/hcAQ3DLsnihGYHeLSwO4vtQkP0we4B08gmKB98
ag2qEIJHUR+f7cSC3NY9mphAIXS5pthLYinQcQpFDxVBcM3gH59s/o1ODmr2
fsoMBF3vkqT7rA2FaLUZAXlbIcfWUVu/YkVT8hsXj5QEQPYZXkBlswU12Eur
ixv9wZCUWr1/ZAFlGMv1vZ0CqD+UP33i/hwKVFe9Xerjg9Y2e3Wf+SP6IK1Z
jDJtAc2KftF4bgLVLNS5Z1l44FU4UFakGkb4e/Bgdqbg+A/PFwjn7wcTYf12
RbEe4bx9YVQpgzz/JlTF5OsDv9JuN2aFa1AakycXpA1fdLLcowjn5w1TqaxX
olIBwnl5QX9a+7G2LmMPzocDm+kWiH4p6bnH5OEJ/NWfY1tiN83M7w7UvwvP
60qM53MmxvM4EfOZ/h2JK5l+2cS4PxbxLaYfiljInL+MiJnzbMR+TP3vaH09
CzGP2W9eM/P+Z2JHZn2S2IHxEPHGKwWvx/+3BO8nDsf1iSPw+cR+uD9iIe5/
zXi+DfuXie/gfBLW12MR/wH9m3un
                "]]}}}, {}}, {
            
            GraphicsComplex[{{-10.819778284410283`, -4.9062752787720125`}, \
{-8.517193191416238, -2.569158202235591}, {-6.214608098422191, \
-0.48906413198447785`}, {-10.819778284410283`, -4.9062752787720125`}, \
{-8.517193191416238, -2.569158202235591}, {-6.214608098422191, \
-0.48906413198447785`}}, {{{
                Hue[0.67, 0.6, 0.6], 
                GrayLevel[0], 
                Inset[
                 Style["\[FilledCircle]", FontSize -> Medium], 4], 
                Inset[
                 Style["\[FilledCircle]", FontSize -> Medium], 5], 
                Inset[
                 Style["\[FilledCircle]", FontSize -> Medium], 
                 6]}, {}}}], {}}}, {Epilog -> {
             Text[
              Style["A", 14, Bold, FontFamily -> "Helvetica"], 
              Scaled[{0.05, 0.95}]], 
             Text[
              Style[
               StringForm[
               "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=``", -0.1], 12, FontFamily -> "Helvetica"], 
              Scaled[{
                Rational[1, 5], 0.9500000000000001}]], {
              Arrowheads[{{0.02, 0, {
                  Graphics[
                   Circle[{1, -1}, 1, {Rational[1, 2] Pi, Pi}]], -1}}, {
                0.02, 1, {
                  Graphics[{
                    Circle[{-1, 1}, 1, {Rational[-1, 2] Pi, 0}], 
                    Inset[
                    Style["", Larger], {0, 2}]}], 1}}}], 
              Arrow[{{-Log[
                   Rational[100, 3]], -Log[500000]}, {-Log[
                   Rational[100, 3]], Rational[1, 2] (-Log[
                    Rational[10000, 3]] - Log[500000])}}], 
              Arrowheads[{{0.02, 0, {
                  Graphics[
                   Circle[{1, 1}, 1, {Pi, Rational[3, 2] Pi}]], -1}}, {
                0.02, 1, {
                  Graphics[
                   Circle[{-1, -1}, 1, {0, Rational[1, 2] Pi}]], 1}}}], 
              Arrow[{{-Log[
                   Rational[100, 3]], Rational[1, 2] (-Log[
                    Rational[10000, 3]] - Log[500000])}, {-Log[
                   Rational[100, 3]], -Log[
                   Rational[10000, 3]]}}]}}, 
           FrameLabel -> {{"Probability of rescue", Null}, {Null, Null}}, 
           Ticks -> {{{-11.512925464970229`, 
               Superscript[10, -5]}, {-9.210340371976182, 
               Superscript[10, -4]}, {-6.907755278982137, 
              0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 
              0.1}, {0., 1}, {-10.819778284410283`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
               
                Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
               
                Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 
               0.}, {
                Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
               
                Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 
               0.}, {
                Thickness[0.001]}}}, {{-13.815510557964274`, 
               Superscript[10, -6]}, {-11.512925464970229`, 
               Superscript[10, -5]}, {-9.210340371976182, 
               Superscript[10, -4]}, {-6.907755278982137, 
              0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 
              0.1}, {0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
               
                Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
               
                Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 
               0.}, {
                Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
               
                Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 
               0.}, {
                Thickness[0.001]}}}}, GridLines -> {None, None}, 
           FrameTicks -> {{{{-13.815510557964274`, 
                Superscript[10, -6]}, {-11.512925464970229`, 
                Superscript[10, -5]}, {-9.210340371976182, 
                Superscript[10, -4]}, {-6.907755278982137, 
               0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 
               0.1}, {0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
                 Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
                 Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
                 Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
                 Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}}, None}, {{{-11.512925464970229`, 
                Superscript[10, -5]}, {-9.210340371976182, 
                Superscript[10, -4]}, {-6.907755278982137, 
               0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 
               0.1}, {0., 1}, {-10.819778284410283`, "", {0.00375, 0.}, {
                 Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
                 Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
                 Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
                 Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}}, None}}, 
           AxesOrigin -> {-11.512925464970229`, -13.815510557964274`}, 
           PlotRange -> {{-11.512925464970229`, 0.}, {-13.815510557964274`, 
            0.}}, AspectRatio -> GoldenRatio^(-1), Axes -> True, 
           AxesOrigin -> {0, 0}, 
           CoordinatesToolOptions -> {"DisplayFunction" -> ({
               Exp[
                Part[#, 1]], 
               Exp[
                Part[#, 2]]}& ), "CopiedValueFunction" -> ({
               Exp[
                Part[#, 1]], 
               Exp[
                Part[#, 2]]}& )}, Frame -> {True, True, False, False}, 
           FrameLabel -> {Null, "Probability of rescue", Null, Null}, 
           FrameTicks -> {True, True, False, False}, 
           FrameTicksStyle -> {
            FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, 
           LabelStyle -> Directive[12, FontFamily -> "Helvetica"], 
           Method -> {}, 
           PlotRange -> {{-11.512925464970229`, 0.}, {-13.815510557964274`, 
            0.}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {{None, None}, {None, None}}}], {
          Placed[
           Unevaluated[
            LineLegend[{
              Directive[
               RGBColor[0.24720000000000014`, 0.24, 0.6], 
               Thickness[Large]], 
              Directive[
               RGBColor[0.6, 0.24, 0.4428931686004542], 
               Thickness[Large]], 
              Directive[
               RGBColor[0.6, 0.5470136627990908, 0.24], 
               Thickness[Large]], 
              Directive[
               RGBColor[0.24, 0.6, 0.33692049419863584`], 
               Thickness[Large]]}, {
              Style["1-step", 12, FontFamily -> "Helvetica"], 
              Style["2-step", 12, FontFamily -> "Helvetica"], 
              Style["3-step", 12, FontFamily -> "Helvetica"], 
              Style["4-step", 12, FontFamily -> "Helvetica"]}, LegendLayout -> 
             "Column"]], 
           Scaled[{0.85, 0.23}], Identity]}]& ],
       AutoDelete->True,
       Editable->True,
       SelectWithContents->False,
       Selectable->True],
      TraditionalForm], {189., -119.16407864998737`}, {
     Center, Center}, {360., 268.32815729997475`}], InsetBox[
     GraphicsBox[{{{{}, {}, 
         {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJw9kw1MzGEcx68XxxW60nXuyt3/rq4XSlNeUjv/uCGMlZZDJiMvmyxllpq8
Zpekohe6JuG83VJqheuq58u8jFUiUVQuZGZDKx0lDv//8WzPnv32e36/3/f7
efbINiau3GzL4XCUf/bfM1Z/fmop1wf6gI9HXzh6IizTy2DI88aa436rvhbK
Id5yaXG72BsqL+fdzpQcIyrf5/06BcxRy35M18vQIdPHjw9UQPd4rP3ymTLc
skwb9DF4oWenXdX2Rgqnu68dVKm8kLBe738sgkKKMZAf1+yJ+8G71qgvSqEu
ripNU3sin3flg9YgweyU4ICiXjmy3vKqepunQBBTa6zaLsfuXKPG/40HhoLm
LG0ekkFsfyd1r9kdz/iGjg/7ZShUazufOrij5nPoVnsHGc6McqNmSMXIb6of
khZQOFqh/F4cLMIu/byMMAmFimJRslPEZOj4BxUVkVIYrnY7Fa4TYlNTxoK+
eAmeb478NT3JDZ6ZmXEeqVOgGbdh35sjAphU2Xujj3ugJCbM/4bWFWWW3OKs
c+444H11dXXlJMQZ82/crhVD5+qd2nvXBZKUU23fH4qwR11QE/nSGV1BJf2B
PZPhPpKUz+/no+Rz6YStA0JQNdFds7h8sO8hxPInPStq50608neDwCRJoLeN
t/IWYNicELbutANOMXxdUZPYUZ38aBxWMTwnoXMk75qdhWvl5wIP02jA9dlj
rLycERXb+iM82c7Kh48dptVPKqttcIHh4YS1mrOH4wcsRMb4n4CQ1w1t2Tmj
hPXriKeaV3mHlMOE9cdDeUpqer2dmbB+xiInK0J+5v0AETH6uUiLGawTd34h
RYxeeyQuXLJEEPqRsPpsERDZygux6SMnGD0cBK3NaQ+ebyIUM/8nOdn/0rda
3EEoZt4wGWp71JL2pZW4Mf3N5PFlzT167n1rvwGi+OpSO/NmHREy9Z9IX3Zu
5evKciJk7r8nI6J3OmOZlnCZfDe5uKns8LL0DDKGiZuJ0i+0xdK0jXCsqyW9
IFwhXUSi2DwdUh5bF9QuJn5sPa3uLOB9475r9GX70z6BC7QtyrLGqex8eukv
tf7KvohGN1Yf/WAel2O7qKuBYvXTlr+fsSi6weqPtmGmXq9n63/S/3QUsnzC
/8VsP9v/8W9ZotWl
           "]]}, 
         {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
          LineBox[CompressedData["
1:eJxdkHsslXEYx1/mHITjuBzXg3Oc4z7TnKKyEJPN2iK5bCbLtc0fkkqo5JKk
i5kOcTYpl+lsbo04Dt6vrdraaC2OrCFlDJNchphL9b56Lb/tt98+e37P83y/
X2FsyrkEdYIgvP7cv++GDT/tFNce1bvFFUXPXbDp7zi8WGuHfm3P5JNDzhgR
yuN13ewQsyMKmV92Queuy4qDQowAaYKvysAJT8cac/z9xbh4qVOyedgR6Uo3
bsyACKORUnF0sAMiKlqrMiNEeMA5k0pctodHusS17JstFKSkZLrYDrywdmVr
si1k8x0Bhi1irLp7Bg2sCsGTHcst+CjCEFcxMpMtRNMVx6zTS7ZoWziRpHFI
CEvWTGOYoS1K+7tXbZ4IEOk9udIhESJN7p3vZS3AdnNKWWqYALXcHLumYBvY
H5HOcX5aI64/328q3hpXXVm3diRWEBUWxvAzrDCbl5VHZlhiwv/hzdBHfNzv
lLDiYL6XiyUyRA3fdzTNEKMsfd3XboGjsaqElmATWKeXD/56b44Frvfgs0pj
jLrLFt3GzVDTcc+PPW0I2UKVXtKyKca3znM8JAaIkr9wrmKbosxoLessSx8W
ifWBKgsTGE0I2ZZynb28eai/Xlj8NVwL5VS+xoiaVWk3c1gIp/I0gtb67S3e
sNpefoZQRY4VFCVtk3ReBrBfSv4yFbtO0vlwkWgQ1PFBsUTWUHnogz9n9viz
aJYUUv71oBuxGPvSY4Kk/eqgzcIjosXtE0n700YirzlXmQ2S9qOJ4+K1+Zy7
daQ5pZ+Nt9L2d/M9d8gySq8Gsl918WUpgSStTx1JfT6hbypXeksoPQQ4k3X1
mfXXegXU/m0y+oIa0XCjq0dA7dsgCepUd5tQ89f2mCDoecsMm1L9P/aZ+j/N
MJuqjzHMoniA4YMnhK77/GMnup9hR3o+w870foZNaH0MC2j9+0z7O9C/zbCU
zsf3/3nqDP8Gb/qK6g==
           "]]}, 
         {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
          LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAmIQ/TpNqfjOXMUDC/73z+xaqH3gisDOGy/qFQ+caT96
+buv9oEt76zSWbgUDxj7mq4VZdM6MPnMnq/yUxQOaBQvZdTfr3GgeJVdi7Wc
wgG2TENhi0r1A0sEGlXXBcgf2F9T2aFronYg+UyL09MUuQPrDsxSEPqgckC5
oyNeplL2wOSFHLZv1ygfeODcUxPcK3PgzOtn909mKUHdIX3AVzIhc5um4oH4
3ZO3HdwqdWD6msk7Oy7LH5Arn375x0nJAxLOqcuFwmQP3DGa/UH/nsSBSv/L
RQ63pQ7MfjePN/2T+IFlx8IiI5IlDkSvWqQ1j038wIyL/0N2vxM9IJW2zP2q
lNiB+VOiuH7UCh+4obgqhUdf9MDKyW373wgKHph+d22js7PIgS2BqQ7sEbwH
wmZunFcVLnzgzN6WSsu5HAdEQ7fu3pgtdKAp4MzO9t/M0PASPOAWHvK0lPH/
fkj4CBzYn8NW/Lz92/7F4PDgPxD7qfKDyqq3+xXB/uc9oLx0/XOpDQ/2Q/zL
feCc7FvFyWfP7If4j/PA7sT8O2E/1+2H+If9wMr3OWEGn6r3S4Ldz3bg3hNp
hx2Sqvungd3LcqDN+FlLKePEfRD3MR0I1GBgWPB14t6JYPcwHGCAAgWw/X/3
w/lg+37C+WJg87/B+RDzPsH54mD9bxF8sPpncD4bWP4unM8K5p+F89FBIETe
HsbXhOiH8zUg5sP5WhD74XwxiPvgfAWI+xF8iP/Q9P+F86dCwscB1TwmOB8A
CNc9DA==
           "]]}, 
         {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], 
          LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQ3a0m+2B3hdyBBf/7Z3Yt1D6QfKbF6WmK3IFtP+c/
WFWrfUC5oyNeplL2wGeh9f43r2keeODcUxPcK3PgoWDYI1VjDag+6QPihrfF
tSapHYjfPXnbwa1SB1jlhE1XflY5IFc+/fKPk5IHgu+Uf+4PVz5wx2j2B/17
EgeCn+7oer5X8cDsd/N40z+JH7Au4yk5o6ZwIHrVIq15bOIHdOYUaVxRkT0g
lbbM/aqU2IH//QeSfzBKHbihuCqFR1/0QHJrIuv6p2IHpt9d2+jsLHKgeLmQ
xtcLwgfCZm6cVxUufGC5SUp43lGBA6KhW3dvzBY6cNdy8n/BHu4DVwR23nhR
L3ig2iIxqW8D64HJZ/Z8lZ8icOBW9kPVJF6GA4sFGlXXBfAfyFrC/Hv5lK/7
FcH+5z3wb4eL+t6dL/ZD/Mt9YNqUCQZXbK/uh/iP80DYHo3Xx/Zv2Q/xD/uB
eNvqyjXylfslwe5nO2Dd4LtlfS/b/mlg97IcCEnacSFSQ3sfxH1MBxigYCLY
PQxwvgLY/r/74XywfT/hfDGw+d/gfIh5n+B8cbD+twg+WP0zOJ8NLH8XzmcF
88/C+eggECJvD+NrQvTD+RoQ8+F8LYj9cL4YxH1wvgLE/Qg+xH9o+v/C+VMh
4eOAah4TnA8AgNYQRA==
           "]]}}, {}}, {{{}, {}, 
         {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJxdkWssm1Ecxru6j9Kidatq3S+zLpbsopnrB9timW1FFpI2wyzrh32wRdjM
GCFCDMMawlxGCEKUTbD32Y0Sl8kQybD5MJYmqA5BJra9r73CSU5Ofjnn//8/
z3NEt+5dT2AyGIwLf/e/M6a51rvK0ANf1apJCxMXSHJde3qeuaPUv7wju9gZ
9rcbwqbs3cHVDgRNOThjJ9RzWlvvhvAlvYmNehFmRM3xZmI3KJirH2d9RXiz
5/PLo8cVw9KH4rRuIV7MtWaEhrqisvp39GCAEMm9YrZs1AUDQ1ZREQVOiFZ2
VKVGu+BBbacXp1KAM8mnfcsWnHF+pz1F2eQIbmRXb4fCGcZPvKUNXXxs+J29
PLohQrFWr3CJcMAku2fmZ7oIHuuymt1Be6hW/BP1j4sg4fpIk0ftUDLSt+H0
XIgaA518fNwWSc0BWRKBEBOrW8K7YzaoZ2e4tUU4IeZ1XnqJmoe4kayQH/EC
zKk199P6uXDJzZXxUxzRvvw4LrDFGt9D8x/dKODDKnZ+errECi/3CpV5NQ6w
VcxLvJMsIest6X7XZQ/+KflT80scCJLLv2wN2SHhptfnCGs2Zv0qtOJ5W8T2
ac7lN7JQsVLFStTZwGcq7OKgmSmo/7BBtfykeDjKeD9/HtStxmucbIP9vLmI
VK3XLrxgopzM1xqaO5rUlRN7RBSZpxXM1a+UK6xtgsrPEkXyyJYPmzqCyouD
96V86WKIhqDyYaOpNiRYUfeNqCPzsIBRpqCNFTxGiEj/LIQ7el3RBHYSlF9T
NM5d9Yvj5RCUPxO4ha1prWMlBOXHCKxlfmZDjuqtHanfELyRYwx+0qf+MlKv
Phj7i9LHpLmI1MOgWUjO3yVoJudt08wj+28Sh/vpaLYh65cPmHy/SLMheT9H
swHJozQfXdeo+8D/7EXV0+xJ9afZm5pPM4/SR7OQ0n/AlL8j9bs0l1L5BB3u
x6T5D2u5iUg=
           "]]}}, {}}, {
        GraphicsComplexBox[{{-8.517193191416238, -6.319968614080018}, \
{-6.214608098422191, -3.8490482062667577`}, {-3.912023005428146, \
-0.7916424273090445}, {-8.517193191416238, -6.319968614080018}, \
{-6.214608098422191, -3.8490482062667577`}, {-3.912023005428146, \
-0.7916424273090445}}, {
          {GrayLevel[0], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 4], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 5], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 6]}, {}}], {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-11.512925464970229`, -13.815510557964274`},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Exp[
           Part[#, 1]], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Exp[
           Part[#, 1]], 
          Exp[
           Part[#, 2]]}& )},
      Epilog->{
        InsetBox[
         FormBox[
          StyleBox[
          "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
           False], TraditionalForm], 
         Scaled[{0.05, 0.95}]], 
        InsetBox[
         FormBox[
          StyleBox[
           InterpretationBox[
           "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=\\!\\(TraditionalForm\\`\\(-0.2`\\\
)\\)\"", 
            StringForm[
            "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=``", -0.2], Editable -> False], 12, FontFamily -> 
           "Helvetica", StripOnInput -> False], TraditionalForm], 
         NCache[
          Scaled[{
            Rational[1, 5], 0.9500000000000001}], 
          Scaled[{0.2, 0.9500000000000001}]]]},
      Frame->{True, True, False, False},
      FrameLabel->{{
         FormBox["\"Probability of rescue\"", TraditionalForm], ""}, {"", ""}},
      FrameTicks->{{{{-13.815510557964274`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0., 
           FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.716898269296165`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.429216196844383`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.206072645530174`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.02375108873622, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.86960040890896, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.736069016284437`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.618285980628055`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.819778284410283`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.407945608651872, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782616`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, None}, {{{-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0., 
           FormBox["1", TraditionalForm]}, {-10.819778284410283`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.407945608651872, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782616`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, None}},
      FrameTicksStyle->{
       FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
      GridLines->{None, None},
      LabelStyle->Directive[12, FontFamily -> "Helvetica"],
      Method->{},
      PlotRange->{{-11.512925464970229`, 0.}, {-13.815510557964274`, 0.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{None, None}, {None, None}},
      Ticks->{{{-11.512925464970229`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0., 
          FormBox["1", TraditionalForm]}, {-10.819778284410283`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.414313176302118`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.126631103850338`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.903487552536127, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.721165995742174, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.567015315914915, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.433483923290392, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.315700887634009, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.517193191416238, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.111728083308073, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.824046010856292, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.600902459542082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.418580902748127, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.264430222920869, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.1308988302963465`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.013115794639964, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-6.214608098422191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.407945608651872, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782616`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, {{-13.815510557964274`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-11.512925464970229`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0., 
          FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.716898269296165`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.429216196844383`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.206072645530174`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.02375108873622, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.86960040890896, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.736069016284437`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.618285980628055`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.819778284410283`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.414313176302118`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.126631103850338`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.903487552536127, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.721165995742174, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.567015315914915, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.433483923290392, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.315700887634009, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.517193191416238, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.111728083308073, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.824046010856292, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.600902459542082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.418580902748127, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.264430222920869, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.1308988302963465`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.013115794639964, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-6.214608098422191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.407945608651872, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782616`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}}], {189., -357.49223594996215`}, 
     ImageScaled[{0.5, 0.5}], {360., 268.32815729997475`}], InsetBox[
     GraphicsBox[{{{{}, {}, 
         {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwtkAlMk2cYx0vBIgixFXoK5ft60dIhpCgMPNpZ3RQNwZMlW6jDa56oNbIp
8QgFhOCIKYcKMlkJiVVUzNw4tr3/xc6JgrLBCB6oeGxoPJDSwYYF9ev3Jm/e
PHne5//8/z86K3v5ei6Hw5nz7r5/Dft/vqVUaXBqovR4ca0esg31n/wl0yD2
qx8D5xzT43+ztmewTo1WDk5nKPTopZ3rQuLUyJxx32A9G4OmCb07ulmF2uat
179JjMGxvoZDZrMK7otSixM65LTG8S0dSgjtJzy/peqQcbyxZm+GEiMu2t7f
rUViTkJsRb8CXYHZ8d5MLYSrLrU2blEgpdzVI3kaDY8hKbXDQ6PafTF3pjUa
3fzm3oEDNCYFZRvSvRp8/zJlY0AwDcWZ+8+2FGpgb//JE1VGIUzQeKFQoIHV
Oc82W07h3IrIAkeVGnX8Q+pz6VFIyBjbRtRqrG23zX+yTg7Sd37znfMqKA8f
tkR8HYnSD+35I8kqPDCX5K44EoFTUp0rzKVkOU0Hyb0bH5+mhKXV/sOvl2Rw
h1T0LO1VQJ5T2TXaJkXe3j2uTVkK3DVUDcbdk2DJgDK08DmNqpc1oRuHxChN
//1q3R4anzm/i6nhibHYH+GXOTTLX4Qcq170sJhieQvBrZe98RNSqGT4hiO5
zO3/8bworGZ4hqEDw4+Kl8tZftNw88qilV0bIlleAmyyeUzUvgiWDx/Pro3/
uat0OhwMj6nYVt12sN0hA83kD0VCi4SOa5KyeadAOt4ZcLJdwuYLQku3Ryjt
F7N5AiG8Y5uo94ggZfzzMOLlWZYEi1DB+A2ALt/sHxIlZP1x0fn51ZTBhHAc
ZfxwcONeYaLf4jBQzH4vKTjSlJ+aOQ0Us+8/MrmA23jbKoCI0f+XyNKevLlc
xGf1hoj226LmFNNUiJn5F0QS8suCwO2hEDP//yZ59NpXs05OAY/p95EzH9i+
pG8EYRJTd5CuhWnm2X6TwWFPXqyhRJDEwzJf37hzqKR61Y53OXzzxuGi5C8e
N3Ch9ekbvfryBZ2DHMT49hup+aMtt3aPE5HPn5FX73Q1ScYI5fNvHFsTmzT3
jxHC5jMO7Cie8ZFjmPjmvcbtOlpeWfaalPv4mEYbXh00ffqC1eOa1KuDax2P
/iFvAUoi064=
           "]]}, 
         {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
          LineBox[CompressedData["
1:eJxTTMoPSmViYGAwBmIQrbtvpoO3o9KBBf/7Z3Yt1D7w1cjc6+xXxQMl+2w2
KvNrH7gisPPGi3rFA3HTIznnamkd2PLOKp2FS/GA3J5XPoZumgcmn9nzVX6K
woFHStm+DxM1DhSvsmuxllM4UG9qfm1trfqBJQKNqusC5A+cMbh6ZPpMtQPJ
Z1qcnqbIHcipTBFZsFX1gHJHR7xMpeyBiRxsJ45fVDnwwLmnJrhX5gDrYjlJ
gXfKUHdJH1ibYx1TxaV8IH735G0Ht0odaFx2Vp1DXemAXPn0yz9OSh4oO1IU
vttZ8cAdo9kf9O9JHMg/cclpWoLCgdnv5vGmfxI/8DFjObv5b7kD0asWac1j
Ez+wd9fsnPmmsgek0pa5X5USOxCd0OtRUCB94IbiqhQefdEDk84ZLdi2WvLA
9LtrG52dRQ5s9Nx/o/25+IGwmRvnVYULH3DecG8zo4rYAdHQrbs3ZgsdCNT9
eMA/UQQaXoIHbsyfVb9pvhA0fAQOfDgi6tJ1X+DAYnB48B84cnrq+vNOfAcU
wf7nPaBrWunhdYYL6l/uAz/0bNdKxLFD/cd5wMmnq0fmDzPUP+wHtstKaWqu
YTggCXY/2wHvMLPjZ9/+2j8N7F6WA7y5jy2/XfyyH+I+pgNXox7bhgW+2z8R
7B6GAy8/HFxe4PJkvwLY/r/7u5z4Ppo8u75fAWzfz/1NogHidW7H94uBzf+2
3zX14NnOkxug5n3av2HLmapz/3v3i4P1v93/82VY7mmZyP3iYPXP9n92+ej5
6B/nfjaw/N39UqKsvcH8k/axgvln9+cfZGWoUbm9lwEKmMDkiT2BEHl7mLgm
RD+crwExH87XgtgP54tB3AfnK0Dcj+BD/Iem/y+cPxUSPg6o5jHB+QAKMGdh

           "]]}, 
         {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
          LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQnRZcO+H5bLkDC/73z+xaqH0g+UyL09MUuQOxJ2oy
vwdrH1Du6IiXqZQ9cPRD5FlODq0DD5x7aoJ7ZQ5cEMty275HA6pP+gB/r7ow
e5H6gfjdk7cd3Cp1YE6yTS2jhtoBufLpl3+clDzQ7yhzYv09lQN3jGZ/0L8n
cSCgZr+azDTlA7PfzeNN/yR+QE7q04NAP6UD0asWac1jEz8wtWnltFh2xQNS
acvcr0qJHaj/t3D37Cb5AzcUV6Xw6Ise2Hwhuz/jh8yB6XfXNjo7ixzYLz31
kF+B1IGwmRvnVYULH5BMWvq055X4AdHQrbs3ZgsdOBE8f2ZDuuiBKwI7b7yo
FzzQJ2NRuv+50IHJZ/Z8lZ8icOBhtvQklxyBA4sFGlXXBfAfOBj9/mfzW+4D
imD/8x448C7neqoIO9S/3AcirovVbgtngvqP88CKe+pdWyb/3g/xD/uBtNW2
hr4in/dLgt3PdoBllkWNk87z/dPA7mU5oCPtkM6y+Np+iPuYDkiYfzqx/P/e
/RPB7mE4UNPz5Xma6eT9CmD7/+4PmZ10wlbIc78C2L6f+0NtvvGsUzy2Twxs
/rf93vYsDBtrHuyFmPdpPwMUiIP1v0XwweqfwflsYPm7cD4rmH8WzkcHgRB5
exhfE6IfzteAmA/na0Hsh/PFIO6D8xUg7kfwIf5D0/8Xzp8KCR8HVPOY4HwA
T+gh+w==
           "]]}, 
         {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], 
          LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQfcbr+FeJX1IHFvzvn9m1UPtA/O7J2w5ulTpw+qbB
jjWq2gfkyqdf/nFS8sDE9X8VnlVrHrhjNPuD/j2JAxsZpeQPXVY/MPvdPN70
T+IH7Of81QjTVTsQvWqR1jw28QO7lRkD9naoHJBKW+Z+VUrsgLGxJ7P4M6UD
NxRXpfDoix5YnL9TsN1V8cD0u2sbnZ1FDtjI7LDN8ZM/EDZz47yqcOEDCRyf
/q4QkzkgGrp198ZsoQPm3Je7HZ5IHLgisPPGi3rBA8emVZQ/3S56YPKZPV/l
pwgceH8mbe6uSUIHFgs0qq4L4D/wb9otw4Vv+Q4odnTEy1TyHljV/sPb4wIH
1J/cB57mbfQIuMsE9R/ngZyPSc/XZPzaD/EP+wHVponp35U/7JcEu5/twCVP
09mT/tzbPw3sXpYD/QWLD9a0HdoPcR/TgRkzWOTbdSfsnwh2D8OBprO2bue/
a+5XANv/d799hb/Xj9kJ+xTA9v3cz8wAApf2iIHN/7afAQog5n2C88XB+t8i
+GD1z+B8NrD8XTifFcw/C+ejg0CIvD2MrwnRD+drQMyH87Ug9sP5YhD3wfkK
EPcj+BD/oen/C+dPhYSPA6p5THA+AM0fASg=
           "]]}}, {}}, {{{}, {}, 
         {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJxdkXtIU1Ecx2+yZiu11dLlI93d5jZnJln5aM2kJWaQuqysrEb2EHqgVCA+
yqYLRlS+apaGaUnmRKHUTCzv1/0RJGpiL4Ue9sTIRyysqZjZvetKHjgcPpzz
+/2+3+8hk1K2HnIgCEI9vf+eieabyjKuHMFNey07spZDZZQ2N+fL0FrbTZk4
y+Fx+HbUCw8ZVF2hTocu+GNco3j5vdIX3M0BRVUCf/SS5oNOgb44GTrVqi5R
4sGU/w95sxRN3bZCQqTE1Te1eo1GClQmlKDSD2ktgXxdpwS/UoOeblT4IeHa
3bKMBAk+da3URpsVCE5bFWB6L0bBEmfzaaUCrtsbW+4eFSPRJfxL7h05RoNC
NneOkqgr5OWMSOR4zm/uHcgmcdKUsS7yugwNw2uTOfNJ7HKOyZ/gy1DU8XDU
57IIxz+m6rP00zrN4QaVtwh9lrariiEpKvl637o4H0QW67SJ8VIc6DBs+HzQ
G+Pp2edT6yWQGI06r/Rl8DlbeqndSYJ+zYWs+Ite6I3kWl7tE6N8Ku/a+QpP
iOsM427VJHQtRffbGj2wwJb5wP2bCN5pxc9sT9whGK5ozJWK8Dqo9Hvg26VI
7YndxDd7o3S4zDnZKkTmU52x3eYF5j+EuBF37p5ltac9fzd8qp+Yk7/X3Z63
Kwa2fujpOyFEMZ3vEuxbMyg+dsoVO+g8Bcixjo0kJAns+S3GWrJfpVQvsue1
CJmmKsdsJxd7Pnzs1JNf887ycIvOYyFyKlaExfZzQNL+nSEzOGrnqQm73wX4
XS2Teh75RTH+eMirSq7ZYB2iGD+OiPGVb9GGv6Pcaf1cvEs50xCy/zFlovVy
EB69Z7VFXUYx+hwQNlijmtytpQpoPQS2pQdf4SkftYro+ZNURBRBdL8vfySi
541RhH250f1/ssz0s7IspOuHZph+/4VlLn3/huW5NHeyPHtpmfv1/9iPqWdZ
wfRnWcnMZ9mN0ceyiNE/w4y/WfWTLF9h8on4v58Dy38AatyQ2Q==
           "]]}}, {}}, {
        GraphicsComplexBox[{{-6.214608098422191, -8.517193191416238}, \
{-3.912023005428146, -3.6045383056801854`}, {-6.214608098422191, \
-8.517193191416238}, {-3.912023005428146, -3.6045383056801854`}}, {
          {GrayLevel[0], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 3], InsetBox[
            StyleBox["\<\"\[FilledCircle]\"\>",
             StripOnInput->False,
             FontSize->Medium], 4]}, {}}], {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-11.512925464970229`, -13.815510557964274`},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Exp[
           Part[#, 1]], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Exp[
           Part[#, 1]], 
          Exp[
           Part[#, 2]]}& )},
      Epilog->{
        InsetBox[
         FormBox[
          StyleBox[
          "\"C\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
           False], TraditionalForm], 
         Scaled[{0.05, 0.95}]], 
        InsetBox[
         FormBox[
          StyleBox[
           InterpretationBox[
           "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=\\!\\(TraditionalForm\\`\\(-0.3`\\\
)\\)\"", 
            StringForm[
            "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=``", -0.3], Editable -> False], 12, FontFamily -> 
           "Helvetica", StripOnInput -> False], TraditionalForm], 
         NCache[
          Scaled[{
            Rational[1, 5], 0.9500000000000001}], 
          Scaled[{0.2, 0.9500000000000001}]]]},
      Frame->{True, True, False, False},
      FrameLabel->{{
         FormBox["\"Probability of rescue\"", TraditionalForm], ""}, {
         FormBox["\"Mutation probability\"", TraditionalForm], ""}},
      FrameTicks->{{{{-13.815510557964274`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0., 
           FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.716898269296165`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.429216196844383`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.206072645530174`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.02375108873622, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.86960040890896, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.736069016284437`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.618285980628055`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.819778284410283`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.407945608651872, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782616`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, None}, {{{-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0., 
           FormBox["1", TraditionalForm]}, {-10.819778284410283`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.407945608651872, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782616`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, None}},
      GridLines->{None, None},
      LabelStyle->Directive[12, FontFamily -> "Helvetica"],
      Method->{},
      PlotRange->{{-11.512925464970229`, 0.}, {-13.815510557964274`, 0.}},
      PlotRangeClipping->True,
      PlotRangePadding->{{None, None}, {None, None}},
      Ticks->{{{-11.512925464970229`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0., 
          FormBox["1", TraditionalForm]}, {-10.819778284410283`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.414313176302118`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.126631103850338`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.903487552536127, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.721165995742174, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.567015315914915, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.433483923290392, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.315700887634009, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.517193191416238, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.111728083308073, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.824046010856292, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.600902459542082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.418580902748127, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.264430222920869, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.1308988302963465`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.013115794639964, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-6.214608098422191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.407945608651872, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782616`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, {{-13.815510557964274`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-11.512925464970229`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0., 
          FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.716898269296165`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.429216196844383`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.206072645530174`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.02375108873622, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.86960040890896, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.736069016284437`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.618285980628055`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.819778284410283`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.414313176302118`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.126631103850338`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.903487552536127, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.721165995742174, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.567015315914915, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.433483923290392, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.315700887634009, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.517193191416238, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.111728083308073, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.824046010856292, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.600902459542082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.418580902748127, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.264430222920869, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.1308988302963465`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.013115794639964, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-6.214608098422191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.407945608651872, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782616`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}}], {189., -595.8203932499368}, 
     ImageScaled[{0.5, 0.5}], {360., 268.3281572999748}]}, {}},
  ContentSelectable->True,
  ImageSize->350,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.7849011329166403`*^9, 3.784901184136393*^9}, {
  3.784905302172742*^9, 3.784905315952777*^9}}]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Approximating the probability of 1-step rescue\
\>", "Section",
 CellChangeTimes->{{3.743875406539646*^9, 3.743875407611471*^9}, {
  3.751638305368416*^9, 3.751638306024279*^9}, {3.7694315570577183`*^9, 
  3.769431563721818*^9}, {3.769432700195273*^9, 3.769432704954803*^9}}],

Cell[CellGroupData[{

Cell["\<\
Replicating Anciaux et al 2018, Genetics\
\>", "Subsection",
 CellChangeTimes->{{3.743875609625639*^9, 3.743875615361602*^9}, {
  3.769188824476294*^9, 3.769188842267*^9}, {3.769432871288735*^9, 
  3.769432886889248*^9}}],

Cell[CellGroupData[{

Cell["Change of variables", "Subsubsection",
 CellChangeTimes->{{3.745246499379533*^9, 3.7452465062482243`*^9}, {
  3.7452474758667383`*^9, 3.745247478118442*^9}}],

Cell["\<\
We first introduce the variables y = m/mmax, ywt = mwt/mmax, \[Rho]max = \
mmax/\[Lambda], \[Theta] = n/2. The distribution of y among new mutations is \
then\
\>", "Text",
 CellChangeTimes->{{3.7452471143010607`*^9, 3.745247146838443*^9}, {
  3.74524718833484*^9, 3.745247251493306*^9}, {3.745247337203629*^9, 
  3.7452473504186573`*^9}, {3.745247423326323*^9, 3.745247443165576*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fy", "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"2", "-", "y", "-", "ywt"}], ")"}]}], " ", "\[Rho]max"}]], 
    " ", 
    SuperscriptBox["\[Rho]max", "\[Theta]"], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "y"}], ")"}], 
     RowBox[{"\[Theta]", "-", "1"}]], " ", 
    RowBox[{"Hypergeometric0F1Regularized", "[", 
     RowBox[{"\[Theta]", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "y"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "ywt"}], ")"}], " ", 
       SuperscriptBox["\[Rho]max", "2"]}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"fy", "==", 
    FractionBox[
     RowBox[{"fm", "[", 
      RowBox[{
       RowBox[{"y", " ", "mmax"}], ",", 
       RowBox[{"ywt", " ", "mmax"}], ",", "mmax", ",", 
       RowBox[{"mmax", "/", "\[Rho]max"}], ",", 
       RowBox[{"2", "\[Theta]"}]}], "]"}], 
     RowBox[{"D", "[", 
      RowBox[{
       FractionBox["m", "mmax"], ",", "m"}], "]"}]]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Rho]max", ">", "0"}], ",", 
     RowBox[{"0", "<", "y", "<", "1"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"fy", "/.", 
      RowBox[{"y", "\[Rule]", 
       RowBox[{"m", "/", "mmax"}]}]}], "/.", 
     RowBox[{"ywt", "\[Rule]", 
      RowBox[{"mwt", "/", "mmax"}]}]}], "/.", 
    RowBox[{"\[Rho]max", "\[Rule]", 
     RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
   RowBox[{"\[Theta]", "\[Rule]", 
    RowBox[{"n", "/", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"%", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"m", "/", " ", "mmax"}], ",", "m"}], "]"}]}], "\[Equal]", 
    RowBox[{"fm", "[", 
     RowBox[{"m", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"mmax", ">", "0"}], ",", 
     RowBox[{"\[Lambda]", ">", "0"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.745247257275505*^9, 3.74524731458834*^9}, {
   3.745247355245162*^9, 3.7452473883362103`*^9}, {3.7452474294329653`*^9, 
   3.745247430186225*^9}, {3.745247597541729*^9, 3.745247635426157*^9}, {
   3.745258827821107*^9, 3.74525888136119*^9}, {3.745259412432056*^9, 
   3.745259442356039*^9}, {3.7452596225275183`*^9, 3.745259634805797*^9}, {
   3.745260174825264*^9, 3.745260183072871*^9}, {3.745260268996869*^9, 
   3.7452604359581747`*^9}, {3.745260491783841*^9, 3.745260734660577*^9}, {
   3.745265293094472*^9, 3.745265365134179*^9}, {3.745265395138777*^9, 
   3.74526543354792*^9}, 3.7822525555884666`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.745247265237026*^9, 3.745247315220767*^9}, {
   3.745247357962346*^9, 3.745247388812035*^9}, 3.74524744636401*^9, {
   3.745247598204919*^9, 3.745247638657486*^9}, 3.745258486600719*^9, {
   3.7452588483271646`*^9, 3.745258881706067*^9}, 3.745259180138777*^9, 
   3.7452594432247477`*^9, 3.745259635284945*^9, {3.7452601755123663`*^9, 
   3.745260183448007*^9}, {3.7452602699252977`*^9, 3.745260280898835*^9}, 
   3.745260354590597*^9, 3.7452603864001493`*^9, 3.745260436382874*^9, 
   3.745260518341722*^9, {3.745260558705638*^9, 3.7452607351439953`*^9}, 
   3.745265312562344*^9, 3.745265366140059*^9, {3.7452654058680773`*^9, 
   3.745265434085414*^9}, 3.745496924401887*^9, 3.7455872538415956`*^9, 
   3.7510326537802887`*^9, 3.751080095964939*^9, {3.7511186361564074`*^9, 
   3.751118663369678*^9}, 3.751568979368968*^9, 3.7691888020361223`*^9, 
   3.7692625761797333`*^9, {3.7822525472924967`*^9, 3.782252556146768*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.745247265237026*^9, 3.745247315220767*^9}, {
   3.745247357962346*^9, 3.745247388812035*^9}, 3.74524744636401*^9, {
   3.745247598204919*^9, 3.745247638657486*^9}, 3.745258486600719*^9, {
   3.7452588483271646`*^9, 3.745258881706067*^9}, 3.745259180138777*^9, 
   3.7452594432247477`*^9, 3.745259635284945*^9, {3.7452601755123663`*^9, 
   3.745260183448007*^9}, {3.7452602699252977`*^9, 3.745260280898835*^9}, 
   3.745260354590597*^9, 3.7452603864001493`*^9, 3.745260436382874*^9, 
   3.745260518341722*^9, {3.745260558705638*^9, 3.7452607351439953`*^9}, 
   3.745265312562344*^9, 3.745265366140059*^9, {3.7452654058680773`*^9, 
   3.745265434085414*^9}, 3.745496924401887*^9, 3.7455872538415956`*^9, 
   3.7510326537802887`*^9, 3.751080095964939*^9, {3.7511186361564074`*^9, 
   3.751118663369678*^9}, 3.751568979368968*^9, 3.7691888020361223`*^9, 
   3.7692625761797333`*^9, {3.7822525472924967`*^9, 3.782252556151904*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Approximate hypergeometric function", "Subsubsection",
 CellChangeTimes->{{3.7452474898948402`*^9, 3.745247496502068*^9}, {
   3.751045818680722*^9, 3.7510458331111383`*^9}, {3.760645570742907*^9, 
   3.760645579862836*^9}, {3.769191016096796*^9, 3.769191019413124*^9}, 
   3.769433169962475*^9, 3.771008930620603*^9}],

Cell["\<\
We next want to approximate the hypergeometric function in fy.\
\>", "Text",
 CellChangeTimes->{{3.771008548318935*^9, 3.771008619527658*^9}, {
  3.771008665562282*^9, 3.771008665712672*^9}}],

Cell[TextData[{
 "Note first that Hypergeometric0F1Regularized[\[Theta],z] is defined in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " as Hypergeometric0F1[\[Theta],z]/Gamma[\[Theta]]:"
}], "Text",
 CellChangeTimes->{3.771008667680258*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Hypergeometric0F1Regularized", "[", 
   RowBox[{"\[Theta]", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Hypergeometric0F1", "[", 
    RowBox[{"\[Theta]", ",", "z"}], "]"}], "/", 
   RowBox[{"Gamma", "[", "\[Theta]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", "/", "%%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7704042072959642`*^9, 3.770404207298182*^9}, {
  3.770404533314262*^9, 3.770404536083043*^9}, {3.77100867774826*^9, 
  3.771008679276022*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.770404536560014*^9, 3.771008679619217*^9, 
  3.7822525629554033`*^9}]
}, Closed]],

Cell[TextData[{
 "Next note that ",
 "Hypergeometric0F1[\[Theta],z] can be written as ",
 Cell[BoxData[
  RowBox[{
   FractionBox[
    RowBox[{"Gamma", "[", "\[Theta]", "]"}], 
    SuperscriptBox[
     RowBox[{"(", 
      SqrtBox["z"], ")"}], 
     RowBox[{"\[Theta]", "-", "1"}]]], " ", 
   RowBox[{"BesselI", "[", 
    RowBox[{
     RowBox[{"\[Theta]", "-", "1"}], ",", 
     RowBox[{"2", " ", 
      SqrtBox["z"]}]}], "]"}]}]],
  CellChangeTimes->{3.770403578792471*^9}],
 " using 9.6.47 of Abramowitz and Stegun (1964):"
}], "Text",
 CellChangeTimes->{{3.771008622567998*^9, 3.771008624362171*^9}, 
   3.771008655540176*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Hypergeometric0F1", "[", 
   RowBox[{"\[Theta]", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"Gamma", "[", "\[Theta]", "]"}], 
    SuperscriptBox[
     RowBox[{"(", 
      SqrtBox["z"], ")"}], 
     RowBox[{"\[Theta]", "-", "1"}]]], " ", 
   RowBox[{"BesselI", "[", 
    RowBox[{
     RowBox[{"\[Theta]", "-", "1"}], ",", 
     RowBox[{"2", " ", 
      SqrtBox["z"]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", "/", "%%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.770403633457316*^9, 3.77040367051089*^9}, {
  3.7704047471452208`*^9, 3.770404772602268*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.770403639608882*^9, 3.7704036708406563`*^9}, {
   3.770404753126286*^9, 3.770404773057166*^9}, 3.7710086943762197`*^9, 
   3.782252563221484*^9}]
}, Closed]],

Cell[TextData[{
 "Thus, the Hypergeometric0F1Regularized[\[Theta],z] can be written as ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      SqrtBox["z"], ")"}], 
     RowBox[{"\[Theta]", "-", "1"}]]], " ", 
   RowBox[{"BesselI", "[", 
    RowBox[{
     RowBox[{"\[Theta]", "-", "1"}], ",", 
     RowBox[{"2", " ", 
      SqrtBox["z"]}]}], "]"}]}]],
  CellChangeTimes->{3.770403578792471*^9}],
 ":"
}], "Text",
 CellChangeTimes->{{3.770405765727517*^9, 3.770405790766433*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Hypergeometric0F1Regularized", "[", 
   RowBox[{"\[Theta]", ",", "z"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      SqrtBox["z"], ")"}], 
     RowBox[{"\[Theta]", "-", "1"}]]], " ", 
   RowBox[{"BesselI", "[", 
    RowBox[{
     RowBox[{"\[Theta]", "-", "1"}], ",", 
     RowBox[{"2", " ", 
      SqrtBox["z"]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"%", "/", "%%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.770403633457316*^9, 3.77040367051089*^9}, {
  3.7704047471452208`*^9, 3.770404772602268*^9}, {3.7704058119028683`*^9, 
  3.770405813443763*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.770403639608882*^9, 3.7704036708406563`*^9}, {
   3.770404753126286*^9, 3.770404773057166*^9}, 3.770405813924602*^9, 
   3.771008717972077*^9, 3.78225256331528*^9}]
}, Closed]],

Cell["\<\
Finally, 9.7.1 of Abramowitz and Stegun (1964) gives an asymptotic expansion \
for BesselI that holds for large |z|:\
\>", "Text",
 CellChangeTimes->{{3.770404892001648*^9, 3.770404894738852*^9}, {
   3.7704049296932983`*^9, 3.770404932922123*^9}, {3.770404964869906*^9, 
   3.770404994280102*^9}, 3.770405803834969*^9, {3.770406418173901*^9, 
   3.770406440079871*^9}, {3.7704083259362507`*^9, 3.7704083287031384`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BesselI", "[", 
    RowBox[{
     RowBox[{"\[Theta]", "-", "1"}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"Sqrt", "[", "z", "]"}]}]}], "]"}], "/.", 
   RowBox[{"BesselI", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"v", ",", "x"}], "}"}], ",", 
      RowBox[{
       RowBox[{
        FractionBox[
         SuperscriptBox["\[ExponentialE]", "x"], 
         SqrtBox[
          RowBox[{"2", "\[Pi]", " ", "x"}]]], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{"\[Mu]", "-", "1"}], 
           RowBox[{"8", " ", "x"}]], "+", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Mu]", "-", "1"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"\[Mu]", "-", "9"}], ")"}]}], 
           RowBox[{
            RowBox[{"2", "!"}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"8", " ", "x"}], ")"}], "2"]}]], "-", 
          FractionBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Mu]", "-", "1"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"\[Mu]", "-", "9"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"\[Mu]", "-", "25"}], ")"}]}], 
           RowBox[{
            RowBox[{"3", "!"}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"8", " ", "x"}], ")"}], "3"]}]], "+", "added"}], 
         ")"}]}], "/.", 
       RowBox[{"\[Mu]", "\[Rule]", 
        RowBox[{"4", " ", 
         SuperscriptBox["v", "2"]}]}]}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.770405033000969*^9, 3.7704051755680103`*^9}, {
   3.770405242775312*^9, 3.770405340324699*^9}, {3.770405372147517*^9, 
   3.770405378982832*^9}, {3.770405515379429*^9, 3.7704055163705683`*^9}, 
   3.770406073681464*^9, {3.7704061551718187`*^9, 3.7704061611606693`*^9}}],

Cell[TextData[{
 "where the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["k", "th"], TraditionalForm]]],
 " term added to \[OpenCurlyDoubleQuote]1\[CloseCurlyDoubleQuote] is obtained \
by taking the previous term and multiplying by ",
 Cell[BoxData[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"(", 
     RowBox[{"\[Mu]", "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "k"}], "-", "1"}], ")"}], "2"]}], ")"}], 
    RowBox[{"k", 
     RowBox[{"(", 
      RowBox[{"8", " ", "z"}], ")"}]}]]}]],
  CellChangeTimes->{{3.770405033000969*^9, 3.7704051755680103`*^9}, {
   3.770405242775312*^9, 3.770405340324699*^9}, {3.770405372147517*^9, 
   3.770405378982832*^9}, {3.770405515379429*^9, 3.7704055163705683`*^9}}],
 ".  For large z, the Bessel function will be dominated by the leading term:"
}], "Text",
 CellChangeTimes->{{3.7704055105142813`*^9, 3.7704056616103363`*^9}, {
  3.770405697315529*^9, 3.77040573868358*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BesselI", "[", 
   RowBox[{
    RowBox[{"\[Theta]", "-", "1"}], ",", 
    RowBox[{"2", " ", 
     RowBox[{"Sqrt", "[", "z", "]"}]}]}], "]"}], "/.", 
  RowBox[{"BesselI", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"v", ",", "x"}], "}"}], ",", 
     FractionBox[
      SuperscriptBox["\[ExponentialE]", "x"], 
      SqrtBox[
       RowBox[{"2", "\[Pi]", " ", "x"}]]]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.770405033000969*^9, 3.7704051755680103`*^9}, {
   3.770405242775312*^9, 3.770405340324699*^9}, {3.770405372147517*^9, 
   3.770405378982832*^9}, 3.770405709846795*^9, {3.770406164718266*^9, 
   3.77040616971352*^9}}],

Cell[BoxData[
 FractionBox[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"2", " ", 
    SqrtBox["z"]}]], 
  RowBox[{"2", " ", 
   SqrtBox["\[Pi]"], " ", 
   SuperscriptBox["z", 
    RowBox[{"1", "/", "4"}]]}]]], "Output",
 CellChangeTimes->{
  3.770405379852705*^9, 3.7704057113762503`*^9, {3.770406166503181*^9, 
   3.770406174186285*^9}, 3.771008757475857*^9, 3.782252563506036*^9}]
}, Closed]],

Cell[TextData[{
 "This allows us to conclude that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Hypergeometric0F1Regularized", "[", 
    RowBox[{"\[Theta]", ",", "z"}], "]"}], "=", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       SqrtBox["z"], ")"}], 
      RowBox[{"\[Theta]", "-", "1"}]]], " ", 
    RowBox[{"BesselI", "[", 
     RowBox[{
      RowBox[{"\[Theta]", "-", "1"}], ",", 
      RowBox[{"2", " ", 
       SqrtBox["z"]}]}], "]"}]}]}]],
  CellChangeTimes->{3.770403578792471*^9}],
 " can be approximated for z large as ",
 Cell[BoxData[
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      SqrtBox["z"], ")"}], 
     RowBox[{"\[Theta]", "-", "1"}]]], " ", 
   FractionBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"2", " ", 
      SqrtBox["z"]}]], 
    RowBox[{"2", " ", 
     SqrtBox["\[Pi]"], " ", 
     SuperscriptBox["z", 
      RowBox[{"1", "/", "4"}]]}]]}]],
  CellChangeTimes->{3.770403578792471*^9}],
 ", which upon rearranging gives   ",
 Cell[BoxData[
  RowBox[{" ", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2", " ", 
       SqrtBox["z"]}]], 
     SuperscriptBox["z", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "\[Theta]"}]}], ")"}]}]]}], 
    RowBox[{"2", " ", 
     SqrtBox["\[Pi]"]}]]}]],
  CellChangeTimes->{3.770403578792471*^9}],
 "."
}], "Text",
 CellChangeTimes->{{3.770405897773432*^9, 3.770406044442416*^9}, {
  3.7710087959424753`*^9, 3.77100881467979*^9}}],

Cell["\<\
We can therefore use the following approximation as \[Rho]max = \
mmax/\[Lambda] goes to infinity, i.e., mutant growth rates are much less than \
maximal\
\>", "Text",
 CellChangeTimes->{{3.771008820376017*^9, 3.771008821901764*^9}, {
  3.771008891930029*^9, 3.7710089207397137`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"fya", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"fy", "/.", 
      RowBox[{"Hypergeometric0F1Regularized", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\[Theta]", ",", "z"}], "}"}], ",", 
         RowBox[{
          FractionBox["1", 
           RowBox[{"2", " ", 
            SqrtBox["\[Pi]"]}]], 
          SuperscriptBox["z", 
           FractionBox[
            RowBox[{"1", "-", 
             RowBox[{"2", "\[Theta]"}]}], "4"]], 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"2", 
            SqrtBox["z"]}]]}]}], "]"}]}]}], "//", "PowerExpand"}], ",", 
    RowBox[{
     RowBox[{"0", "<", "y", "<", "1"}], "&&", 
     RowBox[{"\[Rho]max", ">", "0"}], "&&", 
     RowBox[{"ywt", "<", "0"}], "&&", 
     RowBox[{"\[Theta]", "\[GreaterEqual]", 
      RowBox[{"1", "/", "2"}]}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"%", "==", 
      FractionBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          RowBox[{"v", "[", "y", "]"}]}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", "y"}], ")"}], 
         RowBox[{
          FractionBox["\[Theta]", "2"], "-", 
          FractionBox["3", "4"]}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", "ywt"}], ")"}], 
         RowBox[{
          FractionBox["1", "4"], "-", 
          FractionBox["\[Theta]", "2"]}]], " ", 
        SqrtBox["\[Rho]max"]}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]]}], "/.", 
     RowBox[{
      RowBox[{"v", "[", "y", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "-", "ywt", "-", 
         RowBox[{"2", 
          SqrtBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "ywt"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "-", "y"}], ")"}]}]]}], "-", "y"}], ")"}], " ", 
       "\[Rho]max"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Rho]max", ">", "0"}], ",", 
      RowBox[{"ywt", "<", "0"}], ",", 
      RowBox[{"0", "<", "y", "<", "1"}], ",", 
      RowBox[{"\[Theta]", "\[GreaterEqual]", 
       RowBox[{"1", "/", "2"}]}]}], "}"}]}], "]"}], " ", 
  RowBox[{"(*", 
   RowBox[{"compare", " ", "to", " ", "eqn", " ", "A9"}], "*)"}]}]}], "Input",\

 CellChangeTimes->{{3.745258521633298*^9, 3.745258620477697*^9}, {
   3.745258661182157*^9, 3.7452587299823008`*^9}, {3.745258889045891*^9, 
   3.7452589023100367`*^9}, {3.745258942800825*^9, 3.745258943143628*^9}, {
   3.7452598045984163`*^9, 3.745259804837476*^9}, {3.7452599365348377`*^9, 
   3.745260003969078*^9}, {3.745260043390573*^9, 3.745260079165122*^9}, {
   3.769209355498699*^9, 3.769209359955578*^9}, 3.769262898863969*^9, {
   3.7710088608346024`*^9, 3.771008864426896*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "y", "+", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "y"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "ywt"}], ")"}]}]]}], "+", "ywt"}], 
       ")"}], " ", "\[Rho]max"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "1"}], "+", "y"}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", "ywt"}]], ")"}], 
     RowBox[{"\[Theta]", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "ywt"}], ")"}], " ", 
    SqrtBox["\[Rho]max"]}], 
   RowBox[{"2", " ", 
    SqrtBox["\[Pi]"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "y"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "ywt"}], ")"}]}], ")"}], 
     RowBox[{"3", "/", "4"}]]}]]}]], "Output",
 CellChangeTimes->{{3.745258579142777*^9, 3.745258621008894*^9}, 
   3.745258678204447*^9, 3.745258720835404*^9, {3.7452588898723593`*^9, 
   3.745258902805806*^9}, 3.745258943615428*^9, 3.745259763880859*^9, 
   3.745259805260127*^9, {3.745259937785351*^9, 3.745260004307413*^9}, {
   3.745260053448618*^9, 3.7452600796066504`*^9}, 3.745260448123726*^9, 
   3.7452607458610764`*^9, 3.7454971220585012`*^9, 3.7455872546983843`*^9, 
   3.751032687575453*^9, 3.751080101542344*^9, 3.751118671179562*^9, 
   3.751568980202278*^9, 3.769188975519449*^9, {3.769262887051529*^9, 
   3.769262899936328*^9}, 3.771008877643343*^9, 3.782252563964691*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.745258579142777*^9, 3.745258621008894*^9}, 
   3.745258678204447*^9, 3.745258720835404*^9, {3.7452588898723593`*^9, 
   3.745258902805806*^9}, 3.745258943615428*^9, 3.745259763880859*^9, 
   3.745259805260127*^9, {3.745259937785351*^9, 3.745260004307413*^9}, {
   3.745260053448618*^9, 3.7452600796066504`*^9}, 3.745260448123726*^9, 
   3.7452607458610764`*^9, 3.7454971220585012`*^9, 3.7455872546983843`*^9, 
   3.751032687575453*^9, 3.751080101542344*^9, 3.751118671179562*^9, 
   3.751568980202278*^9, 3.769188975519449*^9, {3.769262887051529*^9, 
   3.769262899936328*^9}, 3.771008877643343*^9, 3.78225256480309*^9}]
}, Closed]],

Cell["\<\
This does great for large \[Rho]max, especially at the tails\
\>", "Text",
 CellChangeTimes->{{3.745261278838087*^9, 3.7452612920757027`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Theta]", "=", "2"}], ";", 
  RowBox[{"ywt", "=", 
   RowBox[{"-", "0.2"}]}], ";", 
  RowBox[{"\[Rho]max", "=", 
   RowBox[{"{", 
    RowBox[{"3", ",", "10", ",", "20"}], "}"}]}], ";", "fy", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", " ", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"LineLegend", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"StringForm", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[
StyleBox[\"\[Rho]\",
FontSlant->\"Italic\"], \"max\"]\) = ``\>\"", ",", 
          RowBox[{"Round", "[", 
           RowBox[{"\[Rho]max", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "\[Rho]max", "]"}]}], "}"}]}], "]"}], 
      "]"}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"fya", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "3"}], ",", "1"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Black"}], "}"}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%%%", ",", "%", ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"y", ",", "\"\<\!\(\*SubscriptBox[\(f\), \(y\)]\)[y]\>\""}], 
     "}"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  FractionBox["fy", 
   RowBox[{"fy", "/.", 
    RowBox[{"y", "\[Rule]", "0"}]}]], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", " ", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"LineLegend", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"StringForm", "[", 
         RowBox[{"\"\<\!\(\*SubscriptBox[
StyleBox[\"\[Rho]\",
FontSlant->\"Italic\"], \"max\"]\) = ``\>\"", ",", 
          RowBox[{"Round", "[", 
           RowBox[{"\[Rho]max", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "\[Rho]max", "]"}]}], "}"}]}], "]"}], 
      "]"}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  FractionBox["fya", 
   RowBox[{"fya", "/.", 
    RowBox[{"y", "\[Rule]", "0"}]}]], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Black"}], "}"}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"%%%", ",", "%", ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "y", ",", 
      "\"\<\!\(\*FractionBox[\(\(\*SubscriptBox[\(f\), \(y\)]\)[y]\), \
\(\(\*SubscriptBox[\(f\), \(y\)]\)[0]\)]\)\>\""}], "}"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Theta]", "=."}], ";", 
  RowBox[{"ywt", "=."}], ";", 
  RowBox[{"\[Rho]max", "=."}], ";"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJwdylsoQwEAxvFjJZstw/KAJVpEaqEhk82RcmmUS3uYIreWmlxexIMs2sJM
Li1jLi25PSykFMvKgyg2WxORshcrZ1sW1lotzufh61df/6yugeZeBkEQ6fTg
bNjC9ygpMl4YlwkjxU0tUC/RKOCFLnYITtvSRyG/g2uB4cS8Q5g8Ln8/UFFk
fXOZF27vB3rOacNSuRJeBwMhaFKwo1BHpYqstESrqBx+uAvXbmkzZYYNKFy3
u+BnKOsHns0IIlAmkURhpILHuKNVTmRz4PKwlGWnXUycZMNjT5ALJdUPvP8/
xpwGrWpxBlzZ9bc5aPc0Se2wNtedYu+nyK3XzirITFusgY3d5jqo0Imv4NLm
6Q2cW9X6/3uO7wv+7syr+8YocmS4VAtlRQI9NCYIF2AB69EAnfMnJmi7MT5D
h/7+BVrymZdTXop0lbxdQdXRkxMOVn67oSyHx+YJfWSgwcSBf3o55vI=
  "]],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Hue[0.67, 0.6, 0.6], 
       LineBox[CompressedData["
1:eJwV1nk8VV0XB3BTiJLMJRVJmiSiElZJooSoHo+oiCRKhBKKzBlSlFSGUJEy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        "]]}, {
       Hue[0.9060679774997897, 0.6, 0.6], 
       LineBox[CompressedData["
1:eJwVlnc4Vu8fx+1V+RoNInslSWZZH4mi7ChJyE5WQnaSkIhshYSUmcge97Gy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        "]]}, {
       Hue[0.1421359549995791, 0.6, 0.6], 
       LineBox[CompressedData["
1:eJwVl3c4l98bx+2VhIhoiJI0hBbx3GZRVkKFKCNCdpJUsmeZGcnXlj0zy3nI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        "]]}}, {{}, {}, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       LineBox[CompressedData["
1:eJwV1nk4VXsXB3BTcVOUkCGViFJXKCnF6oaKpEIyXikZEpUkZUiDoZAhEiGU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        "]]}, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       LineBox[CompressedData["
1:eJwVl3c41e8bx62DSCUleyVK2ZKsW74qlRGhjCjJyExWVpISUbLJlpEVSrbn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        "]]}, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       LineBox[CompressedData["
1:eJwVl3c8198Xx+2VTSiSWZFsDfI+FIWQkDKKVEjIFqmUEaGvzKhkpSJ7j9x3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        "]]}}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {
      FormBox["y", TraditionalForm], 
      FormBox[
      "\"\\!\\(\\*SubscriptBox[\\(f\\), \\(y\\)]\\)[y]\"", TraditionalForm]}, 
    AxesOrigin -> {0, 0}, Method -> {}, PlotRange -> {All, All}, 
    PlotRangeClipping -> True, PlotRangePadding -> {Automatic, Automatic}],
   TemplateBox[{
     InterpretationBox[
     "\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"\[Rho]\\\",\\nFontSlant->\\\"Italic\\\"], \\\"max\\\"]\\) = \
\\!\\(3\\)\"", 
      StringForm[
      "\!\(\*SubscriptBox[\n StyleBox[\"\[Rho]\",\nFontSlant->\"Italic\"], \
\"max\"]\) = ``", 3], Editable -> False], 
     InterpretationBox[
     "\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"\[Rho]\\\",\\nFontSlant->\\\"Italic\\\"], \\\"max\\\"]\\) = \
\\!\\(10\\)\"", 
      StringForm[
      "\!\(\*SubscriptBox[\n StyleBox[\"\[Rho]\",\nFontSlant->\"Italic\"], \
\"max\"]\) = ``", 10], Editable -> False], 
     InterpretationBox[
     "\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"\[Rho]\\\",\\nFontSlant->\\\"Italic\\\"], \\\"max\\\"]\\) = \
\\!\\(20\\)\"", 
      StringForm[
      "\!\(\*SubscriptBox[\n StyleBox[\"\[Rho]\",\nFontSlant->\"Italic\"], \
\"max\"]\) = ``", 20], Editable -> False]}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.1421359549995791, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.1421359549995791, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.1421359549995791`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.74526111412446*^9, 3.745261224744578*^9, 3.7455872559726*^9, 
   3.751032701616666*^9, 3.7515689816637783`*^9, 3.7691889769183826`*^9, 
   3.782252565377613*^9, {3.782252637983292*^9, 3.782252645688636*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Hue[0.67, 0.6, 0.6], 
       LineBox[CompressedData["
1:eJwVlHs80wsAxSn3xvXJu7RKmvQglBpF5RClPPIhfeKGdWWK3l1kEk3blEd8
tEQIeSWxZHN7KIUKJS20aHnMaNj8cgupG3f9cT7nj/PfOZ/zJQce96LNUlJS
clfol7vQpIInQ3vsDKdqp2ZmCKg4LjzRQ6Kgs2beUOo0gfW5GdlVJCcEdtHZ
5J8EXFuEd3NI3tBtPPrS4TuBvUGTj9JIQSgIVouJ+Urg45p4x2RSGCIpdmyp
lEDePA92AokJv9sxxrECAgzVqpUXSRxctrSuqM4n4OObz/08VgjV8X0a96wI
qM8w/JyXcLF9s1Zu5MtRLPccldYn8uCYrlm5NWAUp1/bIOPrfehRRyMsxHLo
87S7lZVrYfOtz9gkRI5qseOr1s11sIhfueSvXhnqQnMW+coaELUlt5juLcP4
ii2a5UdfYMvjrnq1lhHMmirTWrS8GRGlekMSygisZ/ZX7654BYnps2rlG8N4
xaS8fm7aigvrv59ImzsMw9SRqdLRN9CJoeTfOTiEkcme7o61b1GEc7nMRikK
hx82a1xqw7D/Z0OqvhQaBiWERNKOqHjnhOmgT0gK4QfnGb+DRWbAg44Hg5iw
L5McihXC0pZW6zs9gLB1Dbz59e8h+mJv89VlAD0VDYkCchei6e4V6iwJfoS2
Z5lEfUBT0Z8ZEbX9WO0wZzr4oQg0/uqEKJV+ON8gH6zU74ZnWn7Yqg1inDag
GvX59YDvOxG7O7wPZrI96kL3XoTFNp/K5PdCV/OzasP3XiTJSf4LGnugUpvF
XZbdh66N4b21dt04THnYqeYqhlI2c+xlmghlOwPzHk+I0Skf/iSUd2F8ZKHW
YHo/bnFoQidaJ/i7nWdznCSYl7/Y82yNELE7WLm8QQlKope5VFm+A/mjy/sC
1gA2Fo3ZkCvbYbuBySGtG8TrvnCPON02+C1pnVJuG0SKfq7HlysCjDcni08w
PkE8P8jH9r9WZKgEhHkZS8HefoB5TLMFut38G7MapKjP7AqzRzN+O8vwtjk5
BHmz9X2B4wsolQZwxTrDuPavjKd0qQGnrnGTdeqGcS+bo9PJe4pHqy+oah8b
QWZZk+1tlcfQdjllFqchw/n6OK1J8/sQmb9po9fIYGoTH5xswsOd6zCWBMhR
znS6+/QwF/5ca22DaTloRiweb1UJzrHyGaJbo9j6gZp3nJGDcqlBloab4jeO
b6avfEjGhRzW/u5dBH6/WTlAD0hGkJd8eYUngW8OzgsS+5KwuKbmjvteAr2N
lolW0kQkpOx7nhRIoNRp29uyyYs4ZJ059gedQPG2KMpKQzaMmHo75hQTsKRS
jZzJZzG9MXqu8CaBjuKdqonrohU79b8tLiPAy3AwM3M6g9S9Vf7bKwl8qSqP
Yx+iY8bU629WDYFCges/OfxwiAQp12e3EXBRm+8hqDuCe+zJA20dBCLcSq7q
jYWCs4lqUvBekRtp/dRbGgLXIgve1m4CE9Eqz93P0fAgsqWJMUSgBJwm58t+
SDe3SvGUEeDP1fIs/eGDk+JsbzJBYFdWEzeetger3I70PFFwQ0aYx0WecYOK
cnth6qSiL3sXqxU+29DL3xS6X8GZiLx0Wt7xzagJLVizVsGheOoPlijEDFcN
1cd/cavh2d3MpTdd7f4HzwBx1Q==
        "]]}, {
       Hue[0.9060679774997897, 0.6, 0.6], 
       LineBox[CompressedData["
1:eJwVV3c01o8bNfpGKjtbMpKRUUao3lvIzHilVCRJkkJGiaLISArfvrIbUimK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        "]]}, {
       Hue[0.1421359549995791, 0.6, 0.6], 
       LineBox[CompressedData["
1:eJwVWXk01c8DtRVtypIiyhIhJEUkcysSUiEi+1YpskVFiYTsESFRSmghESUV
2VL4lj0lsj6P571PkiyJn99fc+45M3PuvXPnzD1nJBw9TI5zsLGxNbCzsf1/
NDhOb3o3bEbC9hrS5+cpcGmLeP4Q3g7T+vnO6zMUtt1NSXsurINzDolh6yco
HPjvS2G6sCn0+9Q41UcomDtPvr0h7AxRWf2nVq0UurZc044R9kGpz13XEw8p
ZKw+HBYpHAKztbdiYw9TuMLzfFOEcCJORSeFmqSyYHHsXv7PsQe4z19WWsTB
xLL5K9b71+fDL6V1vvccA9LGLHpVVBFaniQy6UPDOP9JAym/X6EgXsOzQomO
NUV83ezs5dgwtP91eywNL/q0Gz7vqkRXvPOG1PoBVJ5OX3dstBolh69Frhfs
x4SM1sq8M7VY0tTdUR3UC47pJ6vWSddhPEs+dWfuD6jN27848rQBH/j9b5Y9
+o6GkO2f3st/hsaweNCvlq/YEMeYfsRqhHi4aI8HrR2MyR/dbcrN8LH//CzN
pBUPRl7X8ca2ICX/p9t0cRN4xXKogYFWFJ+v3Z/09BOiTxWfyNjYjp/GaXzV
d+rwZ/eTAZfAL8gqkdsRmfYePirVRUJVHRA/94e7TasKP55WRzVJfMNl75ys
kuly/D3delvOvxOuzRNwsSnF5j3ccydef8flVxcdpeuLsf++xMmCNd1QVrmh
uiWkAOfF7CR7rRd0+UWtj9uZC0cj5aPfHX7gtCd1fbFkLg5dZY/8cuIH5B+M
Lo9ZkguZ4cyx/zx/wFbrM19dxxO0FtHflYb8QNyesrucF55A2dDbLnHBp403
56M9Xj0G3T80bf/sD7g9ig1g03sEhVGzZV8O9mBWVc+o8EY2SkwNyyONehDx
nqd256VsaL/de5Yc6cEOd3Wz1uPZsIzd0pll0QPRfLuUnRrZiFBe8sTHqQdH
ORd1NfdkgebzxoDfrwdbJs6e37wtCxn/JCMPPujBG8V/ifsGMiGw8idP9UwP
7pgEXHM4dw/NbyOv6f/rQXZTra3C8Xu44Sa9+PN8D3b5H7HjMr0H/jpLzm9c
vahY5lLZuXUBh9b8o3h7odUtbb2JlYFVf1N/rZPqhcz3Ik2FUxlYPrTv+9kD
vbiu+sEosOkOuMpv50ul9UKF5xDDUPg2vu3S0ftxpxfS+zYGF8+kIr90tCf1
Xi8Kxh32aHxPheULLX7+nF5oVj6dir+bioK8Hz5shb24Ga0dHrYpFbZpUju7
anvBt81A3H3XLZT4PalOGu9F7nyIea1fMmInj9iY/OlFbFrZhK9tMpx8ZydW
TPeiqeLlWy3tZPB6HdwUOrfAr6gyau2KZBx3oSLOLumDW2nLiel7SeA333bY
aEMfjuU6mFs23oTr9tdflxzog0zGklebkYh3jW25JQf74FO79qrJpkSsPvMz
8KRRHxTWDOVeX5mI8ixpmRqzPtg+CB007EmAwJo47yD7Pqx53X+kKTgBr6ed
l0369sGIg9tvov4GlpXzag1k9CH86UlNXfd42FvJrUrI7MPAp4AlYsfiUTyp
3b8nuw+f3om68ejEw07ZL+Lukz44+YS8EBWJx/N7/W2WL/ogX13eplEbB6uQ
Evem+j68iPk5pSEdhyf6jhllf/pwf9n8354fMdiuIEEw3YeLDJMTbG9jUMbb
01n+tw+cK2lpu1Nj0Nhis6aCrR+z968KSZnF4LfNsdiqpf34LijecqYhGsTb
6NKH9f045/xNm7siCo2pxKJZtx+LlktPFlRE4FjAvwkT/X5k7NiZ/e5+BPrs
3iS0HOhHzFYdN+bVCPzeuPNzq1E/qjTs6Rm6ERDOV9X9YtmPz1fdjc78Fw7H
KoXt3937IfbS2Dei5xomGCKraEn9KL5cQbREw5CYPlSbdqsfazK3uqbMhWLb
4aLAI2n9EAn8MiLQGwqvwoPUu3v9WKJocsk1OxTMC0Gfbuf24/VlNaFUlVAM
LqJFG1f240OlbWm3UQjaNhQsecvsR9afQxmmD4Lh0xRQcfbnAr9Pq/rDI4Mh
cNXAT368H0LdS0y+eQbDmNZPT57qx1r++yatWsH4L1fogzfnANDZoyL59Qpq
NC6FyQoPoG2Pkvqq1VdQfGQ/Z6LOAPjPlXau0w5E+IGSUNH9C7hRfckp4UBY
a8vxZOkP4NGavT391GVwbFu24sWhAfzxr/ntkH4Zh/g/C3VYDKBhh2jGxZkA
0BuPyoueGYAOLegy19tLEDl0wvjBzQF48mSPuzr6g7nvS4tCygBcQ7z7ZIg/
3mnpHS1OHUBZphJjqYg/TijKW72/O4Aj9SpvDzb74flyljP90QDSC8MjS3X8
YFjve0GhbAB3cvIJ/9YLCNQLvVtEG8DMP76TH2XOodnWxVp5eAD6kUmnOHjO
YaPvAeFcxgCuRAZ9th32Rd09voTMnwMwnpvVu5LrC8G/6WE3ZgYgJxYfe2q7
Lx7mvTjjyTuIXwJmF3MNfNDIT9dUUBuE12D5Mtk4b0jK1U/lqA8i1E/c5Yav
N3zxtFhKcxA+wd+cRK28IeLms2Xd7kEkrdWtiZXxhnMNm9RSg0G8WCTKPVLm
hanzwkvpNoNwztI87zDhCYkug47M0EHYpUwtXj/mjshKzXyz8EGM7rGqjip3
x68chTDuqEHoXxoo0ox1R6U373bXuEG8SfMUdVBwhzNP83WV24MQEfgQWep6
Bg+3Hdtf8WwQL3Mrc9z+uEIp8uSL7s5BiEmSwH8ap5DkYRET1z0IFOzo2rLq
FOZN9Z339g5i78ygUhrNBY0bNvNn0waRc/RqgUSiC7yKWWfOjA1C7fwLy69j
J1HU4ys9u5gGj/HLS2tensDOHSGJwio0iDz4lz7o6ox2R2G19O00jNeb/6d2
wBlnY59+Ed9Bw0PL7QPP5Z2RO9ghIruLhvNS23i3jjhhfaLiPTVdGtQbe/aq
uDqBY6w974glDUFfjojI+jqi/rFcbUwwDRY775fm5NjDpb3MhS+UhjmdWdH1
0fbg4jBdevMaDRPK2a2lnvYgxy4fTIumIS7ocOqJnfZ4xt3S8jiJhqjLjTWL
7toh0flST+1jGo5LaQ0dYbeF9frP0+wtNAgtW8Un/9cSvMLexa/baIhPz7Pa
8tESFQKrvXw7aLhZ6NESnGwJmSVWdHoXDe2nrKr4VS1BjdPaP9NpEDPLWNxw
9hiCP849T5+jYdXiRB2jeXM89FFy15AfglpM01l+QzNYejTJjSsMwd3BzURG
ygwrTvsM5m4ZwsXrsx8uzZjC267UWlx1CIksM4mfj0yhaaB7gHv3EJx22vAM
LTPFpw22sm1mQ6Bdb+au7zTBRF1Mn+eVITyRvCK96ZERvi9rc5m9OoTdAWu+
ikYaodJQlLoWNoQwK+uH2q5GiPv0+O+dqCE0LbtxR0rJCPLNtYL/3RzCYrZB
RUO3w7D9yr5f7vEQVJKjq+bSD+L9kO+T3uYhnMzLXVehY4Bc2bdbz7QNQacx
MpCH3wAJp7hKpr4MoXaF3Z7MH/qwZ9yoXtk1hBgXe4mmi/qYYeV3aQ0NIaRc
fhdHiR62/Blemfp3CFe6X1+3xH6kcNn6mGyko+VTytn5MB3MOa1RbZKhg/my
w/uZrQ6cqxonDsvRYfTsxfQDNR0oB2ufP7jQE8c8yhXMh7TxYV7WX0+djtpM
mkT7AW1MzowHEkM6lKYjDCnxvTg6FhEl70PHinxG/JFfwBsjbcNH5+hYFxiz
GwWA5LPZ5bJ+dLQtdduf5gmw3D1ipS/TkUwzac/5SRA6ahovHk6HTMuB0+MT
Wiga2pAslEZHSMu9rc2CuyDQXXyfo5oOzoDjEYF31RG7PCDg5Xs6Do8f1OY6
qY6lmjoWbh/pMF397O+kkjo4UppXtH+iQ+FV7C25dzvwy5i68OgrHZvVxYTu
D6mhsUb2sBFFx8qRGL3DBqow/E3JLfpFh2xTWKjXWlV8kHzJVfqbjnPJhxiT
tO0oD9xXKjVDx3Cjxy2l0O14quEoPck1jMb3Ote2vt+G6Lzbf9NFhuFiXnyD
zVIFPN8d203EhtFyOV5bWEkFIUvlC7jFh1H+Plg0mkMFF0+WnPCSHsa/JZF9
AblbcVqirUlHeRjxBZZKV7i2Qu8m70PGvmE0PTVIXBKxBYsCrphqeA1jsRLH
DmX2zSgaG50uPzsMlfqBVdsq5eF8wuKu7rlhnEhI0Sq6Ko/qw1tGjlwcxq2f
33SVeOQRItkV6B46DJ8iDYsRITlwfVB/knlrGJxnd9A+G2xC0a4HRvJpw5CL
r0g1F9gE54KVf57dGcYxVvK00XcZVKfSdpdlDoMeKP7spocMrp5JbO/IG4ZT
bhWvyW1pcAj8ZOetHMbb1qD9vxZvROE1q5zE6mHUL62Y1WyXguPse8N1tcMw
UbR9yciSQuVgerJswzCC5KJ9/XWlEFxyQFG7fRh56X869kRLgt02x+LCyDAk
trw63SsnAbZHtvl9/COYmWI9LzUWw/vRL+53V49AMIHJWMEuhmhlYyXrtSOI
26UQK14gijUl2nltYiOYWJUlfVlAFEq1sk8+yC6sN27LH+sRgfXgr+ynZARu
Uvby/ulrF94btxOue0Zg5vtHao3FWtDdBqVldUZgt366x1pgLc7+/vLgnv4I
vG289Lui1iCS8+39RNMRcAsY10WHCOGVxLU7/qdH0LhXWz00QRCXj7PZ7jgz
ApOPD/n4LQSh88hP7LfHCN68NlXdJiaIRmW3tDO+IyjfWhCq+EgAdBin2geN
YOU+5b6eWn4I2a5L0k0awVWrrdVaG/jgnZofw185gqljfVfFrJfj5Wzqtcrq
Efzz4L3kw70cs7ZhV7xrR3C7uOVr1vNluCZl49vcsODHbk/nON5lSMtdanPj
ywgKffPfGH9agpqy4wr8zBH47dWenzzLjaUSxjKV1Ai2PnY5vl6BG0ZXd4l7
/xpBgOuL1ZyDi/Ftv4Bg8+QIPosXlrAdWwxW47u/8RwMHL5+1uWu/iKs7V9X
z7eWgcjJi+OLDTlhs4+7pkKEAcuTsi+NV3Lifs6vMi8xBmbMH2fuaeGAgtvH
wiZJBlb7K/Ats+HAnolzqfGKDCjoNUetu8CO09zNp/i0Gbhda2A6enOe5J96
61Sxj4HHjHzxxi3z5Hf9QxsvvQWcFXWuqW6OBMYFGjcdZOCFj8QeSa45kiis
qBFvwQC7gPH086uz5O3mcB4+dwY6hONUjxdNE7XWNf/d8GRAY9FkZrbzNHl2
KSde8CwDaysyBMtWT5P7/70XWXuBgVRWjsdJ/ykS7rFIcUMwA0V5D8c8Dk4S
k+fBxopJDISqTJ+sXDtB6q34hfJTGOiZcfAPb/tNdLjuf1O+zYDYRGMvd8Jv
ssOswml7BgPOZgKTm1f9JqKT876ajxl4aLfoxzf+cTK0MyBVv4yBCWtJ1mn1
MWLfv9yu/h0DR1wrxDjZxsi3qDSpg1UMBJIuac0PP0nD99e5Rh8YyPXT/xhi
+ZMUXp4pM29mwGSCL/Txcopcqjzff5zGwA7+Z0NHxxlk4jT3wyE6A+vtrjrJ
3mQQd4Fkt1MMBr5+NnZbrs4gDs4vJtx+MuCyYctt9isjRHfxBLfPDANywksb
zTcMEz4Db4Vg3lGszzwVExhFIxkVK5ft5BuFtecitddqNKKskTc8JjAKuTvk
9tL+QXJIlp7tIDyK0HC/+g4ySCIX20rs2TiKtgRGcC/HAOGq0hdi2zkK4+By
1y2lvSRh59Dvl7tGETbf1mvs20skC0NaPDAKRZGx11Zbe8nue+VxP3RGMZzv
Y7sut4cEBKouKz88it1Tjkxuix/kj6YE2+XjCzifw7Eou5OEPi/rVnUZRX3V
a4vkHZ1EcLP1W+bpUejosGxmP34j20SS/W08R9F9MIq+c/wr8ZxaPrHr4ihQ
w31nlXkHGS6aGv4bN4re8vUGvvZt5IJC0ofnCaMLPTUv9BJ3G+F5sC3HNWkU
64hvbVV+K5FJcHfuvD2KOw8Ct3NytRJHr4Hu0uxR6Os6ZHSVNpPvio0tfm9G
MVClLNpt20juMvgCOMtHcVinekOnaCNxfHREJqZiFHO9q+cuvvxMhjd+uZDx
fhSXf6TEmJV8In/WdYvVNo7CRjpR8dmnBsK3dPSk4OAoBBjtCVn6H0lrrSLf
naGF+R/1nWZ/fCApoR6lm0ZGMe25XK7x/Aeynn18uSY1itGXhVe/P6klClPT
BQ7To+CYeWyzXPo90aVxzz5dwQTcTpcts6giSx7oZ6mvYoKiiTvIc1WRBoeo
Q5X8TLR/tUkJLqgkR7p477WtYWL6hv6xxpWVxL51te6sBBP9wlwO57+9Ixtv
mFOhG5noNJdLn7r+jgwdvpWychMTa1ddTLqp+46414syJBWY2PL+kZCcezm5
WCkVp6/GxIPYQxKR+m8JCTqu0aLORHpSy/LQmjeEg+T0WWsyobCl+WKQ9hsS
/kpe1XM3E36r+8ps970mSc+2fksyYKIq+NL9RfavyLM72Dhgy0Tt+KL6VEYx
Gfcf53ZwYGLT+ZS6wrBiomaew+hyWtCzXtXAUqqYvF658vkXFyYel51crO1Q
RN4Hde+p92ZCkb9DmckqJDw2N6T1fJlQn6JH/LpZSA5o6C6pOc+EnJP8fjtS
SBrH8hrLLi3oqd/fb5VQQDodA+wKw5jokZxStTv4jKzHVu0tEUwMuhs3aMzl
E/t1gzK5UUykUK/cdzrnE1qLISsrjomXo4dSH+54Sn7qiAbcSmXi8InpRv2/
T8jiTa9Tg54yEeDjsu8CK4foc3pc/vdsQc+NnpNO53JI9A9JR//nC/v58Qge
YcshfCmRcj4lTHAtpv2WFMkmokssS05WMvFxh8T4W+cHxG5wRdpANRN2m8UH
Fs1mkvsVFYEOtUyoqZhbitzMJJv85fZbNTDBnWBvFdtwn6gwptoOtTOxckz+
IfPwvYXU576q72CiJe+pwsDvDFKSaZ+u18lERfcq4nM7g2hZf3De28METVaZ
Gf/tLtH7L3lcdYSJ6nbR9N266cQmX41PbI6JZoasnmZWCnlhOcXbyMbCneze
B1F8KYR3cenyq5wsJB7Pufg5KJm8s9biGeZhoW5Ca9f8ySQiuVRnvkiAhY2f
rAUemicS/+JF/04KseBXmbpy17cE0mJfOyMizMKLwYtKTnYJJOSlwZ+g9Sy4
rn5VqeV1g9CcjZmGcixsahILHyuII2SVAGN+M2uhVxW+HtkfR5Jft9ILlVhg
2R/r3fPuOtHjtxhYu52FWp24A+pKseRxuW3nAGGh50iJxYVdUYTDVfxr8h4W
ok99frA6MpJYCfW1G+iwsIs57JTQGUGWnzne/EyfhZYCxyx6RDhxF3H7eMmU
hWMNJ14I8IeR9zWKtVvMWbjl6qLecCmUbPCiqvuOLejVOFj4fSSENNZ6v9Oz
Y2HaUH7F+8arRMXX76Xg6QU+0tKbllVeIZHimsW1bixMdbw837zvCumvny30
92Dh1xup9gsNQSRRMuhpjw8L/T7/FM2qA8nk57Cs3EAW/PUunzGwukSMLupl
2gUv+BUlONQQc5E8lFl6jz+UBeFZ3T87avyJZUBM2oVIFtpKNgw67/Ujb+QT
E3RusmA1yGt+8ew5IthuFj+ZzMLLLcbTGXW+5MyVNdcfp7LQZF1jNi7tS9Z3
pEauymBhsG7KqZZ+lgSF3rvy/TELEjYv83rSvMiK89wGDnks6Mxpn9wh6kVS
Xc7w0/JZ8Ehb4XP/jid5fkAjkypiwcv0nCtl4UFofE3VHOUsqESYmk+2uhJv
zh0x1ypYOM3utSGD3ZXM/04zW17Nwpo9//LDtp0maztcaKs/LvhVHBqUke1C
Dtxh45FrYeFcllmFTO1x0nH9RGNeGwtXy4OCvokcJ85XGlJUOhb8Zk9j/vN2
JpedU+R2dbFwNNOyYLuyE3kmr3zg8BALq1pn1nd32hMt0SSB1mEWHErm8sKN
7EnditlOi9GFPNXOJXTF25H+n7VujmMsVH285qcaYUOEXtrF+v5l4bd3GUdw
3TGS+bDm6Mw/Fm5y+j+RY1gQ5dTNGwLZKMRZevzi5bcg+gGT+eGLKORPdHlx
eB8ll7SvN91eSeHbtX0xFeeOkCWqE7fE+SmUCUZ0hNaYkCQZK8csQQpval/s
uSBsQvKXbBp/KkyhRuWxvGujEen7XCZYKUWBkbC6I4xlSDwqNnbpylAQ95KS
sek4QGYLI7PqZSl4722pf11nQFYnHVVrU6SgayCQu+uDHrl/7c3cMWVqoWdz
v/3TvJ8o+UnWdqtQCOArq3MZ1CV61ixz+g4Kgg/e+OeL7yOtB03Fz+ykUNX+
pU1KX4c4oJQ+touC5SmulOsXtIm/ZJjf3z0Uru1V4k9m7CF5dLHbvIYU7Nfc
E9PQJCQ8PdS++xCFzTXhx0837CLOJkzpp8YLfpR0/rnlqklE37x5dtCcgs/n
q5n7m9XJlOfGc2KWFHgPRddNpOwgLdLRmkxrCqle23ZxuKmRyOtW76MdKfB8
dDr/THU7OaFTFWV9nMLJ8uc6NzdvI3un5Y0VXCgcfSp02FZBhUw7znTWn6Hg
tQL5mgeVSesax3u3PSlYHA2y1f+qRJ41fDzhepaC4+ewY2qbFYmL2q2xpX4U
ovlGI3oXyRMdBtvLbxcpPBiI/XEqRpZsyHC59PgyBYOQtwb3pDeR9iXq3AYh
FJxDnCc7QzeSwrK7DcLXKAiMf6quNZQisWe5bwxHUFjbln17m6Qk2dfVLhpx
nULTCuYJbuYGIn6D9FncoHDM8L75V7oYmdXNzpG9SaHuv/jfb/+tI0XPfFU+
pFIYKrBJEPFYS+KOd00mp1M4OD+5pvGjEHEV2ff2ZAaFw4taVgjsXE0kQwT1
uLMp7A04Q+bN+cmc+qUVXx5SiElw5BHi4iNfmf3N2U8ozN3aZyAfupLEmT+3
0S2gsFIhXKVuaClxW75OSqiIAnud6qW7dTxEryKYPviCAqeMr1Juw2IyL29y
NvQNhUXcakd05DjJtx+v1M3KKYS2r803vcJOXiRKzG2spLCfTaXowNC81g39
iKrf1RSWOvZNS83NarnP/QyvrqWQ6MBROqUzo2Xw3OJQYh2FnWZsJvdfTWpJ
u7wTcP6PwoG/rOillhNa35uu3+FsobC6t4TOLzSmVRI26dTSRiHI3DmlyIql
lahpJ5fZsXA+E5PK1i0jWp4/37O8OxfyIrGUN+H6kNaBLKWivd0UnocfY2dF
D2jJWCb58fdS2LYmNGzDh14tjpVzpK+fwh3VbgnWxW6t7qrjXIU0Cquypkve
tX/VKr3w38crwxSYxWbBNaltWkmKqteNRyl0zXTx76ls0vLqSzOVoCicjgxU
PHa9QcswmUtkbIyCRp8b/6kD77VkDd1+vPu9kMe8qH73p++0uNhbH8RNUugI
N7rNb/NSq6dY87T9zEKe7DNzO3jytN6cztyi/G/hft5WHw/iuK2VvGHZxP//
Ke/+O2vf51ay6388fx7I
        "]]}}, {{}, {}, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       LineBox[CompressedData["
1:eJwVlX88FHYDx4+uR812fjXt/Mgu9INUo4l65vN4KHV+tJRsPZVmEkpceFpG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        "]]}, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       LineBox[CompressedData["
1:eJwVV2k01Q0fVClbyZJdCSWUJRWJ7hTKcpWtorKUkCRbiWRJWRIeKsmSUiok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        "]]}, {
       GrayLevel[0], 
       Dashing[{Small, Small}], 
       LineBox[CompressedData["
1:eJwVWXc8198XTpRkFFpCQmaU9pD7FJJVEQpZZaRsUfGtRPYoJIRIhDKz2vao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        "]]}}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {
      FormBox["y", TraditionalForm], 
      FormBox[
      "\"\\!\\(\\*FractionBox[\\(\\(\\*SubscriptBox[\\(f\\), \
\\(y\\)]\\)[y]\\), \\(\\(\\*SubscriptBox[\\(f\\), \\(y\\)]\\)[0]\\)]\\)\"", 
       TraditionalForm]}, AxesOrigin -> {0, 0}, Method -> {}, 
    PlotRange -> {All, All}, PlotRangeClipping -> True, 
    PlotRangePadding -> {Automatic, Automatic}],TemplateBox[{
     InterpretationBox[
     "\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"\[Rho]\\\",\\nFontSlant->\\\"Italic\\\"], \\\"max\\\"]\\) = \
\\!\\(3\\)\"", 
      StringForm[
      "\!\(\*SubscriptBox[\n StyleBox[\"\[Rho]\",\nFontSlant->\"Italic\"], \
\"max\"]\) = ``", 3], Editable -> False], 
     InterpretationBox[
     "\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"\[Rho]\\\",\\nFontSlant->\\\"Italic\\\"], \\\"max\\\"]\\) = \
\\!\\(10\\)\"", 
      StringForm[
      "\!\(\*SubscriptBox[\n StyleBox[\"\[Rho]\",\nFontSlant->\"Italic\"], \
\"max\"]\) = ``", 10], Editable -> False], 
     InterpretationBox[
     "\"\\!\\(\\*SubscriptBox[\\n \
StyleBox[\\\"\[Rho]\\\",\\nFontSlant->\\\"Italic\\\"], \\\"max\\\"]\\) = \
\\!\\(20\\)\"", 
      StringForm[
      "\!\(\*SubscriptBox[\n StyleBox[\"\[Rho]\",\nFontSlant->\"Italic\"], \
\"max\"]\) = ``", 20], Editable -> False]}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.1421359549995791, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.1421359549995791, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.1421359549995791`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.74526111412446*^9, 3.745261224744578*^9, 3.7455872559726*^9, 
   3.751032701616666*^9, 3.7515689816637783`*^9, 3.7691889769183826`*^9, 
   3.782252565377613*^9, {3.782252637983292*^9, 3.782252645813014*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Change of variables", "Subsubsection",
 CellChangeTimes->{{3.7452613140548677`*^9, 3.745261316365437*^9}}],

Cell[TextData[{
 "We now consider the variable \[Psi] = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SqrtBox[
       RowBox[{"1", "-", "y"}]]}], ")"}]}], TraditionalForm]]],
 ", which varies between 0 and 2 as y varies between 0 and 1, and is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", 
    FractionBox["A", "B"]}], TraditionalForm]]],
 ", where A is the phenotypic distance to the closest critical phenotype and \
B is the distance from a critical phenotype to the optimal"
}], "Text",
 CellChangeTimes->{{3.745264864848322*^9, 3.7452650352838593`*^9}, {
   3.745265097335023*^9, 3.745265097781509*^9}, 3.7510327548388863`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      SqrtBox[
       RowBox[{"1", "-", "y"}]], "-", "1"}], ")"}]}], "/.", 
   RowBox[{"y", "\[Rule]", 
    FractionBox["m", "mmax"]}]}], "//", "Expand"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"2", 
       FractionBox[
        RowBox[{
         SubscriptBox["x", "0"], "-", 
         SubscriptBox["x", "c"]}], 
        SubscriptBox["x", "c"]]}], "==", "%"}], "/.", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SqrtBox[
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{"mmax", "-", "m"}], ")"}]}]], "\[Equal]", 
           SubscriptBox["x", "0"]}], ",", 
          RowBox[{
           SqrtBox[
            RowBox[{"2", "mmax"}]], "\[Equal]", 
           SubscriptBox["x", "c"]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"mmax", ",", "m"}], "}"}]}], "]"}], "]"}]}], "//", 
    "Expand"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["x", "0"], ">", "0"}], "&&", 
    RowBox[{
     SubscriptBox["x", "c"], ">", "0"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7452651046348267`*^9, 3.7452651798714314`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], "+", 
  RowBox[{"2", " ", 
   SqrtBox[
    RowBox[{"1", "-", 
     FractionBox["m", "mmax"]}]]}]}]], "Output",
 CellChangeTimes->{3.7452652066937113`*^9, 3.745587256146192*^9, 
  3.751032749181465*^9, 3.751568981804566*^9, 3.76918898226989*^9, 
  3.782252663318602*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.7452652066937113`*^9, 3.745587256146192*^9, 
  3.751032749181465*^9, 3.751568981804566*^9, 3.76918898226989*^9, 
  3.782252663321855*^9}]
}, Closed]],

Cell["\<\
The pdf of \[Psi] is then approximately\
\>", "Text",
 CellChangeTimes->{{3.7452654840194883`*^9, 3.745265495577587*^9}, {
  3.745265819061891*^9, 3.745265820660473*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SqrtBox[
           RowBox[{"1", "-", "y"}]]}], ")"}]}], "\[Equal]", "\[Psi]"}], ",", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SqrtBox[
           RowBox[{"1", "-", "ywt"}]]}], ")"}]}], "\[Equal]", "\[Psi]wt"}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "ywt"}], "}"}]}], "]"}], "//", 
  "Flatten"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Abs", "[", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"y", "/.", "%"}], ",", "\[Psi]"}], "]"}], "]"}], "fya"}], "/.",
     "%"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0", "<", "\[Psi]", "<", "2"}], ",", 
     RowBox[{"\[Psi]wt", "<", "0"}], ",", 
     RowBox[{"\[Rho]max", ">", "0"}], ",", 
     RowBox[{"\[Theta]", "\[GreaterEqual]", 
      RowBox[{"1", "/", "2"}]}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"%", "==", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}]], " ", 
       SqrtBox["\[Rho]max"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{"2", "-", "\[Psi]"}], 
          RowBox[{"2", "-", "\[Psi]wt"}]], ")"}], 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], "+", "\[Theta]"}]]}], 
      RowBox[{"2", " ", 
       SqrtBox["\[Pi]"]}]]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"0", "<", "\[Psi]", "<", "2"}], ",", 
      RowBox[{"\[Psi]wt", "<", "0"}], ",", 
      RowBox[{"\[Rho]max", ">", "0"}], ",", 
      RowBox[{"\[Theta]", "\[GreaterEqual]", 
       RowBox[{"1", "/", "2"}]}]}], "}"}]}], "]"}], 
  RowBox[{"(*", 
   RowBox[{"compare", " ", "to", " ", "eqn", " ", "A10"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f\[Psi]", "=", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}]], " ", 
     SqrtBox["\[Rho]max"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"2", "-", "\[Psi]"}], 
        RowBox[{"2", "-", "\[Psi]wt"}]], ")"}], 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], "+", "\[Theta]"}]]}], 
    RowBox[{"2", " ", 
     SqrtBox["\[Pi]"]}]]}], ";"}]}], "Input",
 CellChangeTimes->{{3.745265504066985*^9, 3.745265524520954*^9}, {
  3.745265563605978*^9, 3.745265740224304*^9}, {3.7452658075303173`*^9, 
  3.745265808545301*^9}, {3.7452659693837423`*^9, 3.745265972943873*^9}, {
  3.745540123409357*^9, 3.745540125274845*^9}, {3.745540187823557*^9, 
  3.745540188284267*^9}, {3.745540681282627*^9, 3.745540689922513*^9}, {
  3.745540926660768*^9, 3.7455409321956873`*^9}, {3.745541023023507*^9, 
  3.745541041535585*^9}, {3.745541199854237*^9, 3.7455412024775887`*^9}, {
  3.745541302790167*^9, 3.745541462891932*^9}, {3.7455415144210052`*^9, 
  3.7455416333600616`*^9}, {3.751138932206368*^9, 3.751138954791067*^9}, {
  3.751139024018099*^9, 3.751139054449299*^9}, {3.7692094168109617`*^9, 
  3.7692094801542883`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"y", "\[Rule]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "\[Psi]"}], "-", 
       SuperscriptBox["\[Psi]", "2"]}], ")"}]}]}], ",", 
   RowBox[{"ywt", "\[Rule]", 
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "\[Psi]wt"}], "-", 
       SuperscriptBox["\[Psi]wt", "2"]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.745265623867634*^9, 3.745265644048588*^9}, {
   3.745265690787167*^9, 3.745265740793837*^9}, 3.745265808880968*^9, 
   3.745265973429275*^9, 3.745497160457313*^9, 3.7455401257503967`*^9, 
   3.74554018877277*^9, {3.745540684094468*^9, 3.745540690350642*^9}, {
   3.745540929235718*^9, 3.7455409361167097`*^9}, {3.7455410317124023`*^9, 
   3.7455410419651203`*^9}, 3.745541202994773*^9, {3.745541304597149*^9, 
   3.74554133282957*^9}, {3.745541374097273*^9, 3.745541463176594*^9}, {
   3.7455415152880697`*^9, 3.745541633751247*^9}, 3.7455872562964478`*^9, 
   3.751032764991241*^9, 3.751080108214697*^9, 3.7511186836843977`*^9, {
   3.751138941785359*^9, 3.751138956401848*^9}, {3.75113902860528*^9, 
   3.751139054935425*^9}, 3.751568981921986*^9, 3.7691889837876673`*^9, 
   3.782252663572447*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}]], " ", 
    SqrtBox["\[Rho]max"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "2"}], "+", "\[Psi]"}], 
       RowBox[{
        RowBox[{"-", "2"}], "+", "\[Psi]wt"}]], ")"}], 
     RowBox[{"1", "+", "\[Theta]"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "\[Psi]wt"}], ")"}], "3"]}], 
   RowBox[{"2", " ", 
    SqrtBox["\[Pi]"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Psi]"}], ")"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Psi]wt"}], ")"}], "2"]}], ")"}], 
     RowBox[{"3", "/", "4"}]]}]]}]], "Output",
 CellChangeTimes->{{3.745265623867634*^9, 3.745265644048588*^9}, {
   3.745265690787167*^9, 3.745265740793837*^9}, 3.745265808880968*^9, 
   3.745265973429275*^9, 3.745497160457313*^9, 3.7455401257503967`*^9, 
   3.74554018877277*^9, {3.745540684094468*^9, 3.745540690350642*^9}, {
   3.745540929235718*^9, 3.7455409361167097`*^9}, {3.7455410317124023`*^9, 
   3.7455410419651203`*^9}, 3.745541202994773*^9, {3.745541304597149*^9, 
   3.74554133282957*^9}, {3.745541374097273*^9, 3.745541463176594*^9}, {
   3.7455415152880697`*^9, 3.745541633751247*^9}, 3.7455872562964478`*^9, 
   3.751032764991241*^9, 3.751080108214697*^9, 3.7511186836843977`*^9, {
   3.751138941785359*^9, 3.751138956401848*^9}, {3.75113902860528*^9, 
   3.751139054935425*^9}, 3.751568981921986*^9, 3.7691889837876673`*^9, 
   3.7822526636800613`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.745265623867634*^9, 3.745265644048588*^9}, {
   3.745265690787167*^9, 3.745265740793837*^9}, 3.745265808880968*^9, 
   3.745265973429275*^9, 3.745497160457313*^9, 3.7455401257503967`*^9, 
   3.74554018877277*^9, {3.745540684094468*^9, 3.745540690350642*^9}, {
   3.745540929235718*^9, 3.7455409361167097`*^9}, {3.7455410317124023`*^9, 
   3.7455410419651203`*^9}, 3.745541202994773*^9, {3.745541304597149*^9, 
   3.74554133282957*^9}, {3.745541374097273*^9, 3.745541463176594*^9}, {
   3.7455415152880697`*^9, 3.745541633751247*^9}, 3.7455872562964478`*^9, 
   3.751032764991241*^9, 3.751080108214697*^9, 3.7511186836843977`*^9, {
   3.751138941785359*^9, 3.751138956401848*^9}, {3.75113902860528*^9, 
   3.751139054935425*^9}, 3.751568981921986*^9, 3.7691889837876673`*^9, 
   3.782252664585647*^9}]
}, Closed]],

Cell[TextData[{
 "Note that this is a normal distribution, with mean \[Psi]wt and variance ",
 Cell[BoxData[
  FormBox[
   FractionBox["2", "\[Rho]max"], TraditionalForm]]],
 ", as ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "2"}], "+", "\[Psi]"}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", "\[Psi]wt"}]], ")"}], 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], "+", "\[Theta]"}]], "\[Rule]", " ", "1"}]],
  CellChangeTimes->{{3.745265623867634*^9, 3.745265644048588*^9}, {
    3.745265690787167*^9, 3.745265740793837*^9}, 3.745265808880968*^9, 
    3.7452659735435333`*^9}],
 " (which is reasonable when the absolute values of \[Psi] and \[Psi]wt are \
much less than 2, i.e., growth rates small relative to max, or when \[Theta] \
is 1/2, i.e., when dimensionality is low)."
}], "Text",
 CellChangeTimes->{{3.745265830740891*^9, 3.745265890752537*^9}, {
  3.74526598024067*^9, 3.745266004839877*^9}, {3.745266070977841*^9, 
  3.745266229808916*^9}, {3.7455407064637117`*^9, 3.745540706696865*^9}, {
  3.745540742710033*^9, 3.745540745901998*^9}, {3.7455410593458*^9, 
  3.7455410860214787`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f\[Psi]", "/.", " ", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"2", "-", "\[Psi]"}], 
       RowBox[{"2", "-", "\[Psi]wt"}]], ")"}], 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], "+", "\[Theta]"}]], "\[Rule]", "1"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "==", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"PDF", "[", 
       RowBox[{
        RowBox[{"NormalDistribution", "[", 
         RowBox[{"\[Psi]wt", ",", 
          SqrtBox[
           FractionBox["2", "\[Rho]max"]]}], "]"}], ",", "\[Psi]"}], "]"}], 
      ",", 
      RowBox[{"\[Rho]max", ">", "0"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0", "<", "\[Psi]", "<", "2"}], ",", 
     RowBox[{"\[Psi]wt", "<", "0"}], ",", 
     RowBox[{"\[Rho]max", ">", "0"}], ",", 
     RowBox[{"\[Theta]", ">", 
      RowBox[{"1", "/", "2"}]}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.745265897723577*^9, 3.7452659607803698`*^9}, {
   3.745266014638712*^9, 3.74526603227984*^9}, {3.7455407502437*^9, 
   3.745540760265053*^9}, {3.745541088490345*^9, 3.745541095481492*^9}, {
   3.745541130728813*^9, 3.745541154547071*^9}, {3.745541254162479*^9, 
   3.745541264167532*^9}, 3.7455416515263567`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.745265921388877*^9, 3.745265961216874*^9}, {
   3.7452660237895412`*^9, 3.745266033009838*^9}, {3.745540751392737*^9, 
   3.7455407606942883`*^9}, 3.745541095992161*^9, {3.745541146274046*^9, 
   3.745541155007728*^9}, {3.7455412570202703`*^9, 3.745541264937439*^9}, 
   3.745541652816585*^9, 3.7455872574407*^9, 3.7510328074669323`*^9, 
   3.751568983238875*^9, 3.769188985958932*^9, 3.782252664742597*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Laplace approximation and compact form (equations 19 and 20)\
\>", "Subsubsection",
 CellChangeTimes->{{3.7455000097019987`*^9, 3.745500015317354*^9}, {
   3.769265797663456*^9, 3.769265802597842*^9}, {3.769265842912586*^9, 
   3.7692659198575573`*^9}, {3.769265964205243*^9, 3.769265969870408*^9}, {
   3.76926606331619*^9, 3.7692660766447773`*^9}, 3.76926735384263*^9, {
   3.769433327584454*^9, 3.769433327821643*^9}, 3.771008118389718*^9, {
   3.7717617254704847`*^9, 3.771761731421008*^9}}],

Cell["\<\
Anciaux et al\[CloseCurlyQuote]s equation A5 is the integral of the following \
over y from 0 to 1\
\>", "Text",
 CellChangeTimes->{{3.769262468479608*^9, 3.769262470830893*^9}, {
  3.769262519488442*^9, 3.7692625239111013`*^9}, {3.769262584802679*^9, 
  3.7692625945215893`*^9}, {3.769434016326571*^9, 3.769434018131361*^9}, {
  3.771242245968287*^9, 3.771242253069284*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["U", 
    RowBox[{"-", "mwt"}]], 
   RowBox[{"pest", "[", "m", "]"}], " ", "fy"}], "/.", 
  RowBox[{"m", "\[Rule]", 
   RowBox[{"mmax", " ", "y"}]}]}]], "Input",
 CellChangeTimes->{{3.769262600713657*^9, 3.769262604411851*^9}, {
  3.769262695248024*^9, 3.769262730055621*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", "mwt"], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "y", "+", "ywt"}], ")"}], " ", 
      "\[Rho]max"}]], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "mmax", " ", "y"}]]}], ")"}], " ", "U", " ", 
    
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", "y"}], ")"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Theta]"}]], " ", 
    SuperscriptBox["\[Rho]max", "\[Theta]"], " ", 
    RowBox[{"HeavisideTheta", "[", 
     RowBox[{"mmax", " ", "y"}], "]"}], " ", 
    RowBox[{"Hypergeometric0F1Regularized", "[", 
     RowBox[{"\[Theta]", ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "y"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", "ywt"}], ")"}], " ", 
       SuperscriptBox["\[Rho]max", "2"]}]}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.769262605662694*^9, 3.7692626790037394`*^9, {3.7692627140989943`*^9, 
   3.769262731544836*^9}, 3.782252674643812*^9}]
}, Closed]],

Cell["\<\
which, using the approximation in equation A9, is nearly\
\>", "Text",
 CellChangeTimes->{{3.7692628567787323`*^9, 3.7692628742818947`*^9}, {
  3.769262915258267*^9, 3.769262917083358*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["U", 
    RowBox[{"-", "mwt"}]], 
   RowBox[{"pest", "[", "m", "]"}], " ", "fya"}], "/.", 
  RowBox[{"m", "\[Rule]", 
   RowBox[{"mmax", " ", "y"}]}]}]], "Input",
 CellChangeTimes->{3.769262909863324*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "y", "+", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "y"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "ywt"}], ")"}]}]]}], "+", "ywt"}], ")"}],
      " ", "\[Rho]max"}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "mmax", " ", "y"}]]}], ")"}], " ", "U", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{
       RowBox[{"-", "1"}], "+", "y"}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", "ywt"}]], ")"}], 
    RowBox[{"\[Theta]", "/", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "ywt"}], ")"}], " ", 
   SqrtBox["\[Rho]max"], " ", 
   RowBox[{"HeavisideTheta", "[", 
    RowBox[{"mmax", " ", "y"}], "]"}]}], 
  RowBox[{"2", " ", "mwt", " ", 
   SqrtBox["\[Pi]"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "y"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "ywt"}], ")"}]}], ")"}], 
    RowBox[{"3", "/", "4"}]]}]]], "Output",
 CellChangeTimes->{3.769262910651952*^9, 3.7822526747639217`*^9}]
}, Closed]],

Cell["\<\
which is roughly the integral of the following over \[Psi] from 0 to 2 (A10)\
\>", "Text",
 CellChangeTimes->{{3.769263144259595*^9, 3.769263164802691*^9}, {
  3.769263729259253*^9, 3.7692637427221603`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox["U", 
   RowBox[{"-", "mwt"}]], 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}]], " ", 
    SqrtBox["\[Rho]max"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"2", "-", "\[Psi]"}], 
       RowBox[{"2", "-", "\[Psi]wt"}]], ")"}], 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], "+", "\[Theta]"}]]}], 
   RowBox[{"2", " ", 
    SqrtBox["\[Pi]"]}]]}]], "Input",
 CellChangeTimes->{{3.769263171460038*^9, 3.7692632100646353`*^9}, 
   3.769263260524242*^9, 3.769263722784925*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}]], " ", "U", " ", 
    SqrtBox["\[Rho]max"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"2", "-", "\[Psi]"}], 
       RowBox[{"2", "-", "\[Psi]wt"}]], ")"}], 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], "+", "\[Theta]"}]]}], 
   RowBox[{"2", " ", "mwt", " ", 
    SqrtBox["\[Pi]"]}]]}]], "Output",
 CellChangeTimes->{3.7822526748452387`*^9}]
}, Closed]],

Cell["\<\
Anciuaux et al 2018 say we can write this as (A11)\
\>", "Text",
 CellChangeTimes->{{3.7692632901599083`*^9, 3.769263292436451*^9}, {
  3.769263697225124*^9, 3.769263709137442*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"h", "[", "\[Psi]_", "]"}], ":=", "  ", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"1", "-", 
        RowBox[{"\[Psi]", "/", "2"}]}], 
       RowBox[{"1", "-", 
        RowBox[{"\[Psi]wt", "/", "2"}]}]], ")"}], 
     RowBox[{"\[Theta]", "-", 
      FractionBox["1", "2"]}]], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "mmax", " ", "y"}]]}], ")"}]}], "/.", 
   RowBox[{"y", "\[Rule]", 
    RowBox[{"\[Psi]", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"\[Psi]", "/", "4"}]}], ")"}]}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"q", "[", "\[Psi]_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], 
    "2"]}]}], "\[IndentingNewLine]", 
 RowBox[{
  FractionBox["U", 
   RowBox[{"-", "mwt"}]], 
  FractionBox[
   RowBox[{" ", 
    SqrtBox["\[Rho]max"], " "}], 
   RowBox[{"2", " ", 
    SqrtBox["\[Pi]"]}]], 
  RowBox[{"h", "[", "\[Psi]", "]"}], 
  RowBox[{"Exp", "[", 
   RowBox[{
    RowBox[{"-", "\[Rho]max"}], " ", 
    RowBox[{"q", "[", "\[Psi]", "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.769263006334848*^9, 3.769263079279368*^9}, {
  3.7692632965932903`*^9, 3.769263350887651*^9}, {3.7692634556505117`*^9, 
  3.769263490266707*^9}, {3.769263615974329*^9, 3.769263631406828*^9}, {
  3.769263763663683*^9, 3.7692637916717873`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}]], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "mmax", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox["\[Psi]", "4"]}], ")"}], " ", "\[Psi]"}]]}], ")"}], " ",
     "U", " ", 
    SqrtBox["\[Rho]max"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"1", "-", 
        FractionBox["\[Psi]", "2"]}], 
       RowBox[{"1", "-", 
        FractionBox["\[Psi]wt", "2"]}]], ")"}], 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], "+", "\[Theta]"}]]}], 
   RowBox[{"2", " ", "mwt", " ", 
    SqrtBox["\[Pi]"]}]]}]], "Output",
 CellChangeTimes->{{3.7692637885225067`*^9, 3.7692637921847057`*^9}, 
   3.782252674989974*^9}]
}, Closed]],

Cell["\<\
which appears to be true only when we ignore this second term they have in h \
(but this will drop out anyway when we take the leading order in the next \
step)\
\>", "Text",
 CellChangeTimes->{{3.769264801095446*^9, 3.769264847120904*^9}, {
  3.7712745960012712`*^9, 3.771274599502142*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}]], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", "mmax", " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             FractionBox["\[Psi]", "4"]}], ")"}], " ", "\[Psi]"}]]}], ")"}], 
       " ", "U", " ", 
       SqrtBox["\[Rho]max"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{"1", "-", 
           FractionBox["\[Psi]", "2"]}], 
          RowBox[{"1", "-", 
           FractionBox["\[Psi]wt", "2"]}]], ")"}], 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], "+", "\[Theta]"}]]}], 
      RowBox[{"2", " ", "mwt", " ", 
       SqrtBox["\[Pi]"]}]]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["U", 
      RowBox[{"-", "mwt"}]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}]], " ", 
       SqrtBox["\[Rho]max"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{"2", "-", "\[Psi]"}], 
          RowBox[{"2", "-", "\[Psi]wt"}]], ")"}], 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], "+", "\[Theta]"}]]}], 
      RowBox[{"2", " ", 
       SqrtBox["\[Pi]"]}]]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769264740588388*^9, 3.769264782140161*^9}}],

Cell[BoxData[
 RowBox[{"1", "-", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    FractionBox["1", "2"], " ", "mmax", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "4"}], "+", "\[Psi]"}], ")"}], " ", 
    "\[Psi]"}]]}]], "Output",
 CellChangeTimes->{{3.769264745856915*^9, 3.769264752064961*^9}, 
   3.7692647827256804`*^9, 3.782252675133316*^9}]
}, Closed]],

Cell["\<\
As \[Rho]max=mmax/\[Lambda] goes to \[Infinity] the Exp term dominates and we \
take the leading order of h \
\>", "Text",
 CellChangeTimes->{{3.7692638217890167`*^9, 3.76926391825566*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"h0", "=", 
  RowBox[{"Normal", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"h", "[", "\[Psi]", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Psi]", ",", "0", ",", "1"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.76926392257509*^9, 3.7692639572514772`*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", "mmax", " ", "\[Psi]", " ", 
  SuperscriptBox[
   RowBox[{"(", 
    FractionBox["1", 
     RowBox[{"1", "-", 
      FractionBox["\[Psi]wt", "2"]}]], ")"}], 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], "+", "\[Theta]"}]]}]], "Output",
 CellChangeTimes->{{3.7692639319841747`*^9, 3.769263957990611*^9}, 
   3.782252675274358*^9}]
}, Closed]],

Cell["\<\
Now taking the integral over \[Psi] from 0 to \[Infinity] we get A12\
\>", "Text",
 CellChangeTimes->{{3.769263977850973*^9, 3.76926399243393*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      FractionBox["U", 
       RowBox[{"-", "mwt"}]], 
      FractionBox[
       RowBox[{" ", 
        SqrtBox["\[Rho]max"], " "}], 
       RowBox[{"2", " ", 
        SqrtBox["\[Pi]"]}]], "h0", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "\[Rho]max"}], " ", 
        RowBox[{"q", "[", "\[Psi]", "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Psi]", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Rho]max", ">", "0"}], ",", 
        RowBox[{"\[Psi]wt", "<", "0"}]}], "}"}]}]}], "]"}], "/.", 
   RowBox[{"mwt", "\[Rule]", 
    RowBox[{"\[Psi]wt", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"\[Psi]wt", "/", "4"}]}], ")"}], "mmax"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"%", "==", 
     RowBox[{"U", " ", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox["\[Psi]wt", "2"]}], ")"}], 
        RowBox[{
         FractionBox["1", "2"], "-", "\[Theta]"}]], 
       RowBox[{"1", "-", 
        FractionBox["\[Psi]wt", "4"]}]], 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"Exp", "[", 
          RowBox[{"-", "\[Alpha]"}], "]"}], 
         SqrtBox[
          RowBox[{"\[Pi]", " ", "\[Alpha]"}]]], "-", 
        RowBox[{"Erfc", "[", 
         SqrtBox["\[Alpha]"], "]"}]}], ")"}]}]}], "/.", 
    RowBox[{"\[Alpha]", "->", 
     FractionBox[
      RowBox[{"\[Rho]max", " ", 
       SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Psi]wt", "<", "0"}], ",", 
     RowBox[{"\[Rho]max", ">", "0"}], ",", 
     RowBox[{"U", ">", "0"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.769264008135*^9, 3.76926412458362*^9}, {
  3.769264263261939*^9, 3.769264308599042*^9}, {3.76926436180765*^9, 
  3.7692645269127913`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7692640104357157`*^9, 3.7692640551768103`*^9}, 
   3.769264130853438*^9, 3.769264353021562*^9, {3.769264397640376*^9, 
   3.769264527997957*^9}, 3.782252677783023*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"AnciauxEqnA12", "=", 
   RowBox[{"U", " ", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", 
        FractionBox["\[Psi]wt", "2"]}], ")"}], 
      RowBox[{
       FractionBox["1", "2"], "-", "\[Theta]"}]], 
     RowBox[{"1", "-", 
      FractionBox["\[Psi]wt", "4"]}]], 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"Exp", "[", 
        RowBox[{"-", "\[Alpha]"}], "]"}], 
       SqrtBox[
        RowBox[{"\[Pi]", " ", "\[Alpha]"}]]], "-", 
      RowBox[{"Erfc", "[", 
       SqrtBox["\[Alpha]"], "]"}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.769266113027079*^9, 3.7692661242404127`*^9}}],

Cell["\<\
As m0 and thus \[Psi]wt gets small, the rate of 1-step rescue becomes \
\>", "Text",
 CellChangeTimes->{{3.771761763367838*^9, 3.7717617754383707`*^9}, {
  3.77176188134582*^9, 3.771761895682233*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"m0", " ", "AnciauxEqnA12"}], "/.", 
         RowBox[{"m0", "\[Rule]", 
          RowBox[{"mmax", " ", "\[Psi]wt", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"\[Psi]wt", "/", "4"}]}], ")"}]}]}]}], "/.", 
        RowBox[{"\[Alpha]", "\[Rule]", 
         FractionBox[
          RowBox[{"\[Rho]max", " ", 
           SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Psi]wt", ",", "0", ",", "0"}], "}"}]}], "]"}], "/.", 
     RowBox[{"\[Rho]max", "\[Rule]", 
      RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "//", "Normal"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"mmax", ">", "0"}], ",", 
     RowBox[{"\[Lambda]", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.771761783257677*^9, 3.771761869093574*^9}, {
  3.771761902374486*^9, 3.771761910975473*^9}, {3.7717620593074207`*^9, 
  3.771762085277081*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "U", " ", 
   SqrtBox[
    RowBox[{"mmax", " ", "\[Lambda]"}]]}], 
  SqrtBox["\[Pi]"]]], "Output",
 CellChangeTimes->{
  3.7717617813324633`*^9, {3.771761853367361*^9, 3.7717618696326923`*^9}, 
   3.771761917407586*^9, {3.771762060335886*^9, 3.771762085772485*^9}, 
   3.782252678077161*^9}]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Approximating the probability of 2-step rescue\
\>", "Section",
 CellChangeTimes->{{3.743875410300206*^9, 3.743875412315507*^9}, {
  3.751638308176227*^9, 3.7516383087362347`*^9}, {3.7694315663220387`*^9, 
  3.769431569787286*^9}, {3.76943270890695*^9, 3.76943271277894*^9}}],

Cell[CellGroupData[{

Cell["\<\
Defining \[OpenCurlyDoubleQuote]sufficiently critical\[CloseCurlyDoubleQuote] \
and \[OpenCurlyDoubleQuote]sufficiently non-critical\[CloseCurlyDoubleQuote] \
regimes (equation 8)\
\>", "Subsection",
 CellChangeTimes->{{3.7510538143527613`*^9, 3.751053827281575*^9}, {
   3.7510541547480373`*^9, 3.7510541774260263`*^9}, {3.751059126627554*^9, 
   3.7510591314548798`*^9}, {3.76064556445606*^9, 3.760645589622892*^9}, {
   3.7691908018258944`*^9, 3.76919080417839*^9}, {3.769266939338019*^9, 
   3.769266941504633*^9}, {3.769267535870129*^9, 3.769267537918261*^9}, 
   3.769433174833284*^9, {3.769433434921927*^9, 3.769433456993409*^9}, 
   3.7711644270930777`*^9, 3.771761990615203*^9}],

Cell["\<\
The probability of rescue from a new lineage with growth rate m and rescue \
rate \[CapitalLambda] is\
\>", "Text",
 CellChangeTimes->{{3.769200240135722*^9, 3.769200283704969*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prescuem", "[", 
  RowBox[{"m", ",", "\[CapitalLambda]"}], "]"}]], "Input",
 CellChangeTimes->{{3.769200226228524*^9, 3.76920023241777*^9}}],

Cell[BoxData[
 RowBox[{"1", "-", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SqrtBox[
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{"2", " ", "\[CapitalLambda]"}], 
         SuperscriptBox[
          RowBox[{"Abs", "[", "m", "]"}], "2"]]}]]}], ")"}], " ", 
    RowBox[{"Abs", "[", "m", "]"}]}]]}]], "Output",
 CellChangeTimes->{3.769200233035111*^9, 3.782252692205502*^9}]
}, Closed]],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s now consider single mutants with growth rates far \
from 0, such that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[CapitalLambda]", "(", "m", ")"}], 
    RowBox[{"<<", " "}]}], TraditionalForm]]],
 Cell[BoxData[
  SuperscriptBox["m", "2"]],
  CellChangeTimes->{
   3.751052884628395*^9, {3.7510529300584*^9, 3.751052932045746*^9}}],
 ". We can then approximate this by"
}], "Text",
 CellChangeTimes->{{3.751052892619514*^9, 3.751052903866177*^9}, {
  3.7510529618937073`*^9, 3.7510530141417522`*^9}, {3.7510530956101723`*^9, 
  3.75105310300062*^9}, {3.7510531567481117`*^9, 3.7510531617143993`*^9}, {
  3.751661758098403*^9, 3.751661784306394*^9}, {3.769200305374457*^9, 
  3.769200326530224*^9}, {3.7692003838909893`*^9, 3.769200384412053*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Normal", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"prescuem", "[", 
       RowBox[{"m", ",", "\[CapitalLambda]"}], "]"}], "/.", 
      RowBox[{"\[CapitalLambda]", "\[Rule]", 
       RowBox[{"\[Epsilon]", " ", 
        SuperscriptBox[
         RowBox[{"Abs", "[", "m", "]"}], "2"]}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/.", 
  RowBox[{"\[Epsilon]", "\[Rule]", 
   FractionBox["\[CapitalLambda]", 
    RowBox[{" ", 
     SuperscriptBox[
      RowBox[{"Abs", "[", "m", "]"}], "2"]}]]}]}]], "Input",
 CellChangeTimes->{{3.751053016496187*^9, 3.751053132421134*^9}, {
  3.769200332489695*^9, 3.7692003573108873`*^9}}],

Cell[BoxData[
 FractionBox["\[CapitalLambda]", 
  RowBox[{"Abs", "[", "m", "]"}]]], "Output",
 CellChangeTimes->{{3.7510530743550787`*^9, 3.7510531175946407`*^9}, 
   3.7692003580301332`*^9, 3.782252692368113*^9}]
}, Closed]],

Cell[TextData[{
 "Alternatively, consider single mutants with growth rates sufficiently near \
0, such that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[CapitalLambda]", "(", "m", ")"}], ">>", " "}], 
   TraditionalForm]]],
 Cell[BoxData[
  SuperscriptBox["m", "2"]],
  CellChangeTimes->{
   3.751052884628395*^9, {3.7510529300584*^9, 3.751052932045746*^9}}],
 ". We then have approximately"
}], "Text",
 CellChangeTimes->{{3.751052892619514*^9, 3.751052903866177*^9}, {
  3.7510529618937073`*^9, 3.7510530141417522`*^9}, {3.7510530956101723`*^9, 
  3.75105310300062*^9}, {3.7510531567481117`*^9, 3.7510531617143993`*^9}, {
  3.75105325755166*^9, 3.751053265951189*^9}, {3.7510538475622263`*^9, 
  3.751053855560033*^9}, {3.7516617672858763`*^9, 3.751661797234432*^9}, {
  3.769200379326119*^9, 3.7692003956923656`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"prescuem", "[", 
    RowBox[{"m", ",", "\[CapitalLambda]"}], "]"}], ",", 
   RowBox[{"m", "\[Rule]", "0"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Normal", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"%", "/.", 
      RowBox[{"\[CapitalLambda]", "\[Rule]", 
       SuperscriptBox["x", "2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], "/.", 
  RowBox[{"x", "\[Rule]", 
   SqrtBox["\[CapitalLambda]"]}]}]}], "Input",
 CellChangeTimes->{{3.751053016496187*^9, 3.751053132421134*^9}, {
  3.751053275240528*^9, 3.751053322947394*^9}, {3.7510533891272917`*^9, 
  3.7510534880875*^9}, {3.75105356117332*^9, 3.751053601493807*^9}, {
  3.769200403204021*^9, 3.769200458324965*^9}}],

Cell[BoxData[
 RowBox[{"1", "-", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox["2"]}], " ", 
    SqrtBox["\[CapitalLambda]"]}]]}]], "Output",
 CellChangeTimes->{{3.7510530743550787`*^9, 3.7510531175946407`*^9}, {
   3.75105327951046*^9, 3.751053323311935*^9}, 3.7510534064752617`*^9, 
   3.751053437565189*^9, {3.751053479084955*^9, 3.75105349240945*^9}, {
   3.751053569487167*^9, 3.751053601759468*^9}, 3.769200411360327*^9, {
   3.769200441572051*^9, 3.7692004590477343`*^9}, 3.7822526925947523`*^9}],

Cell[BoxData[
 RowBox[{
  SqrtBox["2"], " ", 
  SqrtBox["\[CapitalLambda]"]}]], "Output",
 CellChangeTimes->{{3.7510530743550787`*^9, 3.7510531175946407`*^9}, {
   3.75105327951046*^9, 3.751053323311935*^9}, 3.7510534064752617`*^9, 
   3.751053437565189*^9, {3.751053479084955*^9, 3.75105349240945*^9}, {
   3.751053569487167*^9, 3.751053601759468*^9}, 3.769200411360327*^9, {
   3.769200441572051*^9, 3.7692004590477343`*^9}, 3.782252692598597*^9}]
}, Closed]],

Cell["\<\
So we should transition from one approx to the other at\
\>", "Text",
 CellChangeTimes->{{3.7510538970012836`*^9, 3.751053944594819*^9}, {
  3.769200476185259*^9, 3.769200476350492*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{"2", "\[CapitalLambda]"}]], "\[Equal]", 
     RowBox[{"\[CapitalLambda]", "/", "m"}]}], ",", "m"}], "]"}], "//", 
  "Flatten"}]], "Input",
 CellChangeTimes->{{3.751053970862706*^9, 3.751053997338517*^9}, {
  3.769200479289877*^9, 3.769200486017618*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"m", "\[Rule]", 
   FractionBox[
    SqrtBox["\[CapitalLambda]"], 
    SqrtBox["2"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.751053977061392*^9, 3.751053997656343*^9}, 
   3.769200486379072*^9, 3.782252692724751*^9}]
}, Closed]],

Cell[TextData[{
 "Check approximations and transition point (for given ",
 Cell[BoxData[
  FormBox["\[CapitalLambda]", TraditionalForm]]],
 ")"
}], "Text",
 CellChangeTimes->{{3.7510536736682673`*^9, 3.751053675890382*^9}, {
  3.7510538617362003`*^9, 3.751053863752227*^9}, {3.751054005570067*^9, 
  3.751054007956653*^9}, {3.7510547428678913`*^9, 3.751054747715788*^9}, {
  3.769200510105237*^9, 3.76920051010533*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"prescuem", "[", 
    RowBox[{"m", ",", "\[CapitalLambda]"}], "]"}], "/.", 
   RowBox[{"\[CapitalLambda]", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]], ",", 
      SuperscriptBox["10", 
       RowBox[{"-", "4"}]], ",", 
      SuperscriptBox["10", 
       RowBox[{"-", "5"}]]}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"LogLogPlot", "[", 
    RowBox[{"%", ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "0.0001", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], 
    RowBox[{"(*", 
     RowBox[{",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"LineLegend", "[", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(U\), \(R\)]\) = \
\!\(\*SuperscriptBox[\(10\), \(-3\)]\)\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[\(U\), \(R\)]\) = \!\(\*SuperscriptBox[\(10\
\), \(-4\)]\)\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[\(U\), \(R\)]\) = \!\(\*SuperscriptBox[\(10\
\), \(-5\)]\)\>\""}], "}"}], "]"}]}]}], "*)"}], "]"}], ",", 
   RowBox[{"LogLogPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"m", "<", 
          SqrtBox[
           RowBox[{"#", "/", "2"}]]}], ",", 
         SqrtBox[
          RowBox[{"2", " ", "#"}]], ",", 
         FractionBox["#", 
          RowBox[{"Abs", "[", "m", "]"}]]}], "]"}], "&"}], "/@", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "3"}]], ",", 
        SuperscriptBox["10", 
         RowBox[{"-", "4"}]], ",", 
        SuperscriptBox["10", 
         RowBox[{"-", "5"}]]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "0.0001", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Black"}], "}"}]}]}], "]"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<|m|\>\"", ",", "\"\<\!\(\*SubscriptBox[\(p\), \(2\)]\)\>\""}], 
     "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.751053682056943*^9, 3.751053731020088*^9}, {
   3.751054020040584*^9, 3.751054121454955*^9}, 3.751054759788166*^9, {
   3.751665907075897*^9, 3.751665924002795*^9}, {3.769200495337141*^9, 
   3.7692005286279507`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk0VV0bAHBJdO7NdOd7D3ciypQoRcVbeOmWhKvJFJWIosiQqYhIvcak
QcYyFA1IUc6TKSSVkkwlUlSkQWTq298fZ531W2vvs87ez7C3wM3Hdp+khITE
AHr+/15e4V5+20sI7d5ztj2yGNQcMjpqckAIeq4aSe+QbdXkVj71EMLV+Jsv
+pH9z5WXDe0Twg2blp3DyPf8pMp4u4VwPSEi5jeysW7OnbNiIXC3bbVTlMNA
VNh703OdELIf/mmwRHa7JC4SyAuBEXo7jEB++cPbPFFWCD2Ydlktspkoum+O
LAQzn4mRx8iL/5QzehYKYVAtyus58tA2ZlSapBC+RBP/vUf2oXQ5kH8L4FSJ
UpCUPAahcS6y4z0CWHrecXgz8vnAA76NRQJocIEPQ8i+QdhVm0IB7Fp0u3gE
WRRc0NmVLwDzapVjP5Dnjn3cMJIngLCwC8ozyO7hbnRKpgCCBuQS5BUwWBG9
q9IhRQAdLl7cVcjPk0VS30IEEHsje14c8sISjXS6lQAmvOwCViti0Pj3g9q1
TQJQ/+nKMkaOtcksNxAJoHY4tNoUWWac+nK7hQAsnwwwrJGl187KXlwvAEnn
x5P7kKWan0VxDQTwrjA0KhVZ4qO/jzpPAFoajU2/kCeViX8Nv/Nh69eA5hoK
Buny1beKvvHhqcN+TjPy6nkPOUqjfDh/gOz7AjnwQ+Xo3Gc+2Okd1+pD/l10
N63uAx/qay58nkUeX1Xy0foNH0Z1oyKMqBj8sMmIcSfQ/CMZWveQv0SHNKSc
5UPTy5TcBhoGv/jzmnln+PDatnakFXmmKubp9dN8UJaYXteBLPcj6VXtKT6I
AlPHPiHrOhf0/zzBh7zYL1cwOgYBBu1zdgF88N1OUd2CLPlJZxXNhQ/3XXXH
upE5lv35qbp8cAnfdJHMxGB+1I2YecvQ/0dc2s1A/vowYN8hbfT9tweWCZAf
6pNVLDX4EHo656MB8m7eiivTKnyYSdJ74Iac/zs61Y3JB5nsVuwB8n6RnaTr
DA80vN65HGVhcFGqvyz9PA9Y2eZJUhy0f0rFaidSedBuuueIInK7flC6ZxIP
TlYFO3GRFfbIhRrF82AX5ZbNauSYR0amPeE8eIwplXoj+4WnvOC58yDLsW13
B/LmSbPRayt4EOYinVWGo3z7kq9e/oILkUV/TyYqY3Bo2/GWtlYubDwzwMxE
7oUdh8eecEFUYVVejPzgHFal2cAFf/uX8k+Qj5l4bcmp5IJ9b7CZNBfFL1nn
aEIuF+YXT9wJR/5qWF7jeZQLbXHT3YE8DLpO1Thx2VzIGInUPCvAgKSnen+W
zgXazXFWFrJhTzStl8IFc5M19FLkdN2NTy4t4sJJs4NGncjbOp+tZktw4bZ2
2Wo1IapfjV4q7ZMyKGJq8rXILU8nmrByZejoFwUtVEXxoGobjG9VhvYr+Lx6
NQyqFS7XYVuUwXq0NLQLGWTJdtxNyoCVSywcQ66RGfaxMFeG2kuDVrg6qp/p
vMILhsrAs+anH0F+NaCkbCxUBgvNJF3VJRh8Ll0kdeqnEmSoDtalLMWAJf76
gpWmBOWLO1bka2Hw8UcSbW2KEriuCQ8B5NKkVdtdEpVAevuGV53IW55F9lw9
rQQuyfYPFmljECVif9KLUAKPR3QPP+TRf/6d2eyhBM6MOEMzHQzqtLPUThgp
AU0/WfhrGeonMuKQ4bc4yL5x5Cfqo3gORvq3duPg3Ok9cgs5vu72wdI3OGhY
zb18gXzthPzusDYcgj/9GqGuwKBnutlMsQEHWoPL9gvIlmPr5QyLcXhp8lqx
cCUG/M5l2bEhOJyc6ijvWYX6TRH5sToLh8O5T/0vrEX11GPxcz0dh1ufnTKq
kRNkT/IcKTgonO/vG0De4jsTmLgIBxkx877OOgyerBxZ8kcCh8Bh8a165AZo
Pd08zAGt+1FPJo1Rfr1O2nKwigN3O+s2+K/HoECS9fqOMwciBX2v6/5F8fDr
vfefAwc8b53gjiN/+pBz6cAODozj7DOLLTBQe6ztKrTlgGlvVmcMcl686dck
cw4o+Dmu32SJQRbNR/KwFgeSbtKcuzei/FJr0Fk2xQbJb7NX2VaoP4r8T10/
x4bhQJOzdDE6b5x8uWnJbHB4pWtojezi611+PIENmptzFOOQDdL2DtjHsWFx
5X+Ws8gf3otNJMLYYB9t1/bJHgOT4JUT4r1s8Eik+tdvR/0u/7f7nB4bCmy0
P+c6YLBvQfC/Ns9ZoH3vRvP4HgyEXpEKh5+y4Ev+1KzBXgz6nsd3JTazUF5r
7Q5C3nX5yqHndSy4K6q7PY28Vb8uzfo+C0w1/c5KuWNg5Cr/ySqHBaLSe2Y8
D9QfHl49JfJnwZrlmvnB3hhU+rc1mrJYkO5DW958FPUXzr6Ni+ks8CSJ27gB
GJQTE03SFBb0uJ4t90O+RVJ+0kRmwWbNyg3cQJQ/WfufWv9lwtj0lbCAIAyS
WmZeOHxkgvVP7Vz9EAw8VNW7/cqYMCyzT9h/HAPGq5CR3K1MSOdQhUpn0Xpb
8OxKKyZUsCYoochldVXiFyIm3BtI2diDbFc+XTVnxoQ8nUexGf9hkJgWcnqn
IRMyw/3EKokYkHeGqMsLmTCS/dNqbQo6j94ecz32kwF3iioNrl5A58On4Pat
aQxgi5bWO+djMMXLNVmawoDBCIpHNzJpR0vhvEQGSHtPee8owGBJIzf8ThwD
/A5MZNgVovO2oFaNFsYAjSvY1S3XMej3kA3q2MOA19ae8dtvYtA5nMVxXs6A
uPDvA3crMHj85bGLVwsdeq0z3z9swiCnXj3ctokOne8Mq22bMQjPPHXZsIEO
d5UOyQ4hr7Cz6JQBOow+m5OitaDxlQ22eaV0+KNk5Xa4FY2PqzfvvUiH5G/N
wg0v0Xj1Wk1rTzpcTCSWG/ei/HWrntCTpoNVqkix/AcGVgmaG63n02Fowljk
9BOttyr9opcEHWjFMdMLfmFgT/dblzdFA41nLo07xtH6G9Wj6N9ocH6hH01q
EuW3dpLcZAcNUrdmwuFZVP+TexY/LKSB3m6bxusLSfD9LGZnYUWDv43d5iV8
EjhP/d21WEQD7yP6JrECErS4/3abb0GDlJ6SPjchCa6ZDBwh/qEBY0iKy1El
geP3B8mrVtBAzu1LQqI6CRrFvm3qOA3exFwkMnRIcAXvsFk4TIVJda2OtetI
6L6Wt7XpJBWquuWMrzuSIM6jIL7nBBUaWCo12U5ovvqNhm/hVDBuX/E73ZkE
FtdK1zKCqdD0XNM3bjcJzHJrluw5SIVVAr97R/aSwDijT2LWngqx7mnz93uT
QC9J6bauOhWcL/zq6gwlAR6cqpjeRAGNGApLKosEal2tEpUNFDBzLs1WzUbj
12Bj3bUU+Cv34Yd5DgksZ8NaedUUSOoaGzmdRwL/E/vj8+9QQPJBvphbSILW
OKMFFZcowNWvEXvdIUHkxb7J9oMUKH48dCO7ngTDVVp9VAoF5FcHdV4eJUGZ
41j0hBwFCi+f81IYI8Hx2VLNbjIFGiy+yUd/JwHDZE1gzgIKOBqrJB/+hdZX
s1Fu+R9FOKajk7h9Cu1fo/vaLX2KYO6SpbBDmgzi9qz02BJFsLhUrKzLIwMx
SrOZFSlCjZPdyF4xGWRf20TrJylA28z8aw71ZKjb9bCiJEEe3HZVfTXbtgg8
vqkf3yolBwf2Sq8jzy2Cma9rnsWnLIKidimaQ6ksZDZ/c8uZTwboaF7qmyoH
eopWYbaoTluy0r/4nZAHWDd9x5G/EJLP1KtJrVcAJ9FG7Q0p0rA4tSwk640C
fCb+0XnEXwALnU9fM/BVhBj6Gz88YT54KkfKFClTgPKK9Y88SxJ2t1e88kFx
uBBUpO5UIAFlMR2fn/qiuE1V5C/SnyNiKDTyXW0aHGg/KJssmiZaVWU/dPah
PPbdM/NUZZKAlON+ulfpUNoxJagmjxMymWR23H4GlCoMit8v+UE8Iu+IeanM
hGwqVxggP0poRCQ8MvnAhIxCZnnCqiHi94gpSFxhQWSHuFwxrJ8YOdP2wlfM
BkuySuK8M2+Iqv1PvPM4HGA7P2vfPthELF/A31/3kgMnqxtCa8KaiCslO8R/
X3NgjFutos1oIlq8fpsadXGg8d2Nw5IWjYQP1U7jVh8HAl1PyxYXNBDjQ8uo
l0c40L7X3FzSu5bo3Rxh6y+Dg0pHgOfOwfuErlulr9oaHKbO76vQYdwnzOWX
5Lka49C2Q7xAyuIe4Sid2nl5PQ4nupZnlxTcJQJXOoiolji86/36Zr53KWFq
us1Uwh4Hg6b6RMfBQiKp+nRi1yEcBkW5WjIWBURAflw//QgOqS3HG28XXCPM
du4ysDmKw49nayRkvHOJ/DPuA4/RPcCpeM87t8ELBE/1vW15LA5Vt7jMewVp
RLjB4tKxeBzYZZ1bZL1TCGMHNbpWAg5FRzNDfQbjiE2t9m9zzuHgHkr/yvaO
IqqUIszfpuNgLs2siB0MJkojHErYl3E4pi6tVTXoSTAjh1j2mThcvXwxMdAo
rpp3WyU6MQeH/wGXDqfj
      "]]}, 
    {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8VfkbB3BbJMS5XPdyuRvRVESiYbTJ1m3IFiWRdbKUirKlEgotyJL2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      "]]}, 
    {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1Xs4lHkbB3DGqdZhcngexoyZZwaj9iWVklOH7SRqJdlSIgmt6OClEFqH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      "]]}}, {{}, {}, 
    {GrayLevel[0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJxN0Hs0lHkcBvBpcpkxvcO4zO0tudSZcmSTItuxaXOdaNG0tQ6yg3bVuCw2
IZtVuYvNZSYqt20bKteEbH7fdGE6FTlk0tFEzaYMRZysLNv+8777x3Oe8/nz
eczFUX5hVAqFEvA5/7Vty8HmhsMWIG6td+x8RgNh9XBduBNpcamoxlyftDT+
UHR3jTlhWq2VzMSb9Nwq5OY4ZUZ4/FTSvYJc0nyP0UuFG0mXaI1ek0lXE14c
vyRofmxKeCi9M9CUR/qm0Qb7WZ9VhLkizWNu8UrC0bqipDfPccK9NYwuAZe0
nMp90hjEJ5whjEu/XMQjHKad4ObbyyV8I66veyeXNLs/aaLKh0Pue50w4FPM
Jtw13nXg8AMTwuXijo+bdEhP5dL3uHsb/+/v330UJ40I4wmFLJnCkPCbdusX
Roak0aSx7z9CFmHsie8pu98MCN/xv9lSm6dPeGJpcP2gNWn2xenSJQWTcPDu
hFbPBtI1H5f6C2Skv/Ha+XJrDumZ8rSp4eOk3XfJj9YnkC6ZVSylxpLWlI2n
7Y0gvV2IMdf9wARqs+Haic8+M2NTNB/MhFq9qfP8URq8uuCz8qE/EwKDe9ge
YzTI+lBgFbObCdcZObSqGRr0n+O7/7mFCRKxtmY/Rocf3wlSfLSYoNSfa7zz
FR2CtodG5C5i8BK13013oYMor9z//hwGE1HHlUIhHXZ8wdviMoEBpVdnsXcv
HfhRem8dnmAgyDfxHJbQ4eGkZs9qOQZxBnaq2RI6bJpsEEzuwoDJimQIPtJh
QbOtJ7tgBbgYvgrJrNODsvvvxJXLGVC5eWNvzPYVsInlnex3mg7Myb7mzmsY
gNOnxgAzGqTcWpPSaqEPgULPDV8X6ECM/3jqm30G8BY529wy04bLZVFUKxYL
0kyUsXjechieqVItPGWBYT/XWZ9LBWnRib9Tiwzh7NEaQaCcAqLbN7QDvI0g
aL7l0gq7RURfVhnVZWwMhwYisDPCT8gtazP7r0fGUBgdsvDQcg4lWcbzpTIT
aBqcN+9gzKImTxarNIgNTQZq0ci6aRTb/q2LH4cDFUamFkf0J5G1k9dAqYoD
56s5zXkOYyhCb6JSVsKF1EFRMyt5FNWHqsVjvjzwYFjmL8tRIs2j3JT7XD7w
gnoG9qkVqO7kyNCBPj6c7Lh3rDNZga4oqk+dG+DDe9MOyw1sBapmxmx8quRD
t+rKT1T3blQpo6b5qfgQ/30WdlV+DxVdsbR11fBhINTVlSq5jRL7w9KtdHCw
HDwS/p26DbmseWs364jDvDSsxYbdhpzDG5/bOuHQt1+kreXeipxqEzMjnXH4
dci2olZ+HdlvZaheu+GgGtYol0ua0Hov66yhPTjYK+7mB6irETMu8gWKwEEt
rLLWdZcjvTb77IVoHAofpHQ3yP9AuouLWxzjcJju2UbRlVQhSkZedmMiDoFX
Q1Ri9Vn0obTe/mI6Du31ppxWeTF6/+LoyEgWDrxrT3djkgKkWbsjx/Q0DjU/
lx2LUmcidd3jEWkhDgePmWh4khNodOZsTr8UB1cdTkuGOgGpHMUOrFIcEgU6
1u3qcPTsF6tR7ws4XDxXkh//ZWaH8vZ0TlYFDv8C5uHu/Q==
      "]], 
     LineBox[CompressedData["
1:eJxF1Gs01HkYB/Bp3MmOv3/m0jDN/O0xnZa2JIlUWw01GxmN7caY3JI4KcVO
VLrntm6DsinSZqhkjGkqx/yeFcNsRB1DdCHbbCxp2TprS+22L3bmxXOe83n5
Ped7vpyIvcHRZBKJtOPz/fcXq2KU8j0EpMhbszotMeBXP7u529foiB+FNRyK
0SUpcYntNRyDLWsXnHMIMHraCfktn2QbPHYqVVOYY/Tc9cNV0kVGl5oON5wr
mWfwp7EqrvIhy+CBM81hLIbRTbib57sgJ4PpwvGH9GJHgxMthKmjz5kGd9fY
tHHpRsvI9N560VyDz/IPnLlWxDA42kziJ+imG3z3wKP2tXSjqT2pryuDaMZ8
ryS6oGKqwW1jbeF7OhwMLo9Q/+VubvRkjtVm/4A5BrcLEx9xmUZfZPYJLEdx
g4WddfvSnxptdTQzf7rL6OSx9PO9HTgo1aPPsq0xeLklpaJBi4N/8J+6WlsM
BC0J1QUaHAb0M53ddhioF0XJE+/hkCAx10zhGBwY9n04cgsHVZvr1UNsDIYD
Pfo1Chw27PC8eMEZg02NC15cqcPh6cSqYrULBguktElxDQ6zqJtPk90wGORN
2vWX4bAxShKTufy//lwJ0p7E4QVJ41IajEFGrCzr6TEcLn/TPHY65HNe7nXN
myM4RB5X1yVtxcD/qmIFVYLDSxOVd4AIg3WVzfMjE3B4ZS4LJMVhsLJsiPQx
BIfXszOTY45h4J7vKF/ExeFveqDGvQ4DpkSKndPag93i3uj7tvYw2ug6hNvb
w5oJ35JNrfaAJuYIPvIxiG8McYnJxsG2V3BqSb4dsHroU1/7zYGW7U2q2lwK
aGeymNkUB4h9w00PMv0CUuq/W+ajc4CZcZ+urMLZcEPRkVuWQ4VLv7yJuGxi
A09apngFITRwxwIOB/9gBQWcFi9vOzqA74f6ULYlfGvz2mlpGx3C+Bvc1hSa
w4ypRtycw4Df0eqFP7PNwJPPHyL7z4XTDo+TmLkmEHvpSJOOwgT7HvpqCp0M
xGpR3477TDj/fQ03TEaC5wlFv3qccATRe1XV7CWfUOG1tIByvhPE6RJsC/gf
ULcH5a3alAXSxMiZTudpZP5AML33AQsUfe85apt3aOXbsYkk6TxQ2OmFL+ZP
oX/q6flFLmyowFlEMmUCPUkq3HY3kw1l1TRl7rIRlDYQCV4jbDjeJ1Rih4dR
mYW4fGgtB9bbOOfNyn6MGld43BRUcYAh6tJt0WtRGU0U6mhKwEm1Jq35sBYx
vZvld80I+IOldnajalFpqIvFNgsC2gev7yP7t6Piigl5kfXnXdmZaXtDpkF5
Xx21oGAE6KJ4PHL8PXR8VXn9LBYBzn3Ju7fp76Bdu4YtXy0j4H1JtGoh9Q76
LcNPdGo5AY+2Cs1M/W+jqOs1CmcfAo4NLK6old1C4sn9IvFKAgafjT82iVeg
7akmDf3rCPDUtuaF6qvRxtwvwzsEBOj5la4W/jJ0X362IW4zAdKO9Ha57Cra
0DNuZRVCwFSXD8kivhL5MZQNvK0EhN2IHIzQn0erKnnWSERAYx2LdltWjJpa
q8PDxAQwGvoDbeMLkc+IrfLDTgJqDl5K26vPQF5uveFe0QTEpDmMM+JPoFub
vJW9MQTwzGmqs3oJWrr/ovXBWAIOcc1dG/W7kUJKFuNxBPx0oTQvxTtD/f9O
/wvVD8vn
      "]], LineBox[CompressedData["
1:eJxF0ms41HkUB/AxGCzW9T/zR5gL/7G76cJT21K7yro0rRrtbNo2ChGZSsWI
aKVCVCqKdCH3S5EQlvwOipnVuOVSLo1VU4lFSgnVzr6ZeXGe83xenOc55/sc
hs/+zX5kEom0Q1b/9+VV/pVlQUyoo5TP1WRjwCkcKg1co7DPFV4RQ0fh1LA9
wcIihtzqJd+mYW4Kz5oi5x/e0OUeO3mkOfmMwsauI/kpyxROVxmpSEs1l/vz
WD67stNM7v64Rk8zI4XvGVivnOGayo3zxjvxS4vkDlbjHRl9aiJ3R5FmCxtX
uICM997xMpY7nhMSV3zRSG4/1XBn9w5cbjtvnZduWQrr3suN44QoLGaWuu85
oHBCfLVJwj6FXScapIVBCqvyWktFATiUkSJyD+Zg0FjTHT7qh8O79OCBzfkY
RJs/ddTwxWHlit16tkUYzL2e6nP1lM0H8qLelmJQzZ27EbANh8/KG8of3cEg
9K4yP94Dh7XX146WV2IwdYxKErrj8KBryW8htRhI8dVWLs44dNprWM80Y5B1
1Gna3xEHw94vPj0iDHY+31gX64DDluD3aZUPZXmXenOb7XAYzHmmIuiS5ecc
d9hpKQ4vtOsH3w9h8FdIl9ARx2FBcvD07DsMVhn7rbfEcDhqN6xJm8WgEn0Q
UfRxULrolrhiHoPbX5m2ijRxoHCsEg4qUSEvc7d40xca6FYMxY1rU+H8w4XO
P17QwDLe9fgwQYUAC/bAoQoabFxmFiHcSgVq95F/s7k0yIwW7U6ro8LYy/Ae
7iUqtPJb/xwT0KBlrGVHkGzvyYComQ7ZHZk+9R9sKBhQp2M9NdSM4M0ZjV9d
3AzhQbM9eQYZyf47hys6YQD84kyVQ/HGYBKeopcm0ocrA7cdcxxNYLR28bCB
vj6I0/BQq3kTQBOG7p84evDBb5nKT42LQLvX/aTteV0oPPq2XT3SFO5vu1dV
kqQDvHz/j7uczCBgkh3NVfkayJ7LMUNNc1gYt29PTNaCVV75ewVN5pDx96RP
lrImlFe9OF/pRAcbPbeozWc14Gv/TYka2XSANfN3ttPVYaz/2afYz3Tw5Ky3
XpdMgfse3AyxNwNeI4clDXRV2BmhL9lbz4BY7PEhkyRl+Jhz062PyQT9btxB
ByfDltCr29KjmXD5cBHbs4AEK7Sqh2MHmeA1V5WvZfsZ6RQXX1ztwII9PXu1
L3DmUcnku1cbrrEgJdh3QcyaRa6rqUEWZAso75tj1GvOoF2bfP0JP5l1pbx/
rKbRz+oUUkyDBdwwMGMKdCYQQxQtzLO0hGuFtMqk71+hhqXuSy2PW0JMH69S
L2oEPdvupiN+agmumqxzSqcfI6ULDLMf1xFg5NXe4yEVoRH+hlb1DAJO1DdH
NkaJkHdSKT0/k4Aps3qWNVWEJGUGAqcsAoSSmwfILkI0+H6AHpNLQJh3gvat
gmbUE80XzBcT0LPLyYnMb0ItKWcYE9UEsPoEgb9La9CtuvawR10EzKX6VS2h
1qDvJLbiA90EdG3lqaq4VKNCpTSmbi8Bx/qX3ygpuIvynHeKf3lCgGRo/LEy
vxxldEwxmyUErBQ9OLddWoguPNdrqx4nQMrJXqzmUoB01QQsjwkCUh5GC8sK
8tDZb/oPz0wSMN1uT1LjZ6PEfVksm7cEeN7ylfhIL6MTszbhxR8JqL1tRqsu
uISUTVLb1s/L8qh4slGbn4yOrZlnvVogoCg0I3K/9BSKimlqsyCxwT8SGzfi
H0cLOWyLJiU2OFFoVfHScBTRkhjurcyGCDZlca00EM2OTrZ9UWFD7tX0c2F2
p+rDtHgW1yls+A8xzAO9
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"|m|\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"", TraditionalForm]},
  AxesOrigin->{-9.210340371976182, -11.512935276951964`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {-9.210340371976182, 
       FormBox["\"\"", TraditionalForm]}, {-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {{{-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-9.210340371976182, 
       FormBox["\"\"", TraditionalForm]}, {-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{-9.210340371976182, 
     0}, {-11.512935276951964`, -3.1317678913015734`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{{{-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, {{-11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {-10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.414313176302118`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.126631103850338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.721165995742174, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.567015315914915, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.433483923290392, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.315700887634009, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{
  3.751053731793603*^9, {3.751054022006871*^9, 3.751054091628747*^9}, 
   3.7510541219720793`*^9, 3.751054760201281*^9, {3.75166589671824*^9, 
   3.751665924505939*^9}, 3.769200529257921*^9, 3.782252692894858*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Approximate probability of rescue: sufficiently critical single mutants\
\>", "Subsection",
 CellChangeTimes->{{3.7438754316118402`*^9, 3.7438754680052223`*^9}, {
   3.743875503590057*^9, 3.7438755299029627`*^9}, {3.743875693004032*^9, 
   3.7438756957235518`*^9}, {3.745607074821949*^9, 3.7456070749359827`*^9}, {
   3.751059305956018*^9, 3.7510593278531027`*^9}, {3.751060788094961*^9, 
   3.751060788196854*^9}, {3.751060832982252*^9, 3.751060844042348*^9}, {
   3.7510748669887342`*^9, 3.75107487202873*^9}, 3.7510749125766373`*^9}],

Cell[CellGroupData[{

Cell["\<\
House of Cards approximation (equation 9)\
\>", "Subsubsection",
 CellChangeTimes->{{3.751296262508972*^9, 3.751296296136323*^9}, {
  3.769190764968842*^9, 3.76919080963428*^9}, {3.769267783149569*^9, 
  3.76926778869374*^9}, {3.771762011381824*^9, 3.7717620130696917`*^9}, {
  3.7717621531935883`*^9, 3.77176216727433*^9}}],

Cell[TextData[{
 "When ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", 
    RowBox[{"<<", 
     SqrtBox[
      RowBox[{"\[CapitalLambda]", "/", "2"}]]}]}], TraditionalForm]]],
 " the probability of 2-step rescue from this single mutant lineage, as \
calculated above, is ",
 Cell[BoxData[
  SqrtBox[
   RowBox[{"2", "\[CapitalLambda]"}]]],
  CellChangeTimes->{{3.7510530743550787`*^9, 3.7510531175946407`*^9}, {
    3.75105327951046*^9, 3.751053323311935*^9}, 3.7510534064752617`*^9, 
    3.751053437565189*^9, {3.751053479084955*^9, 3.75105349240945*^9}, {
    3.751053569487167*^9, 3.751053601762877*^9}}],
 ". In this circumstance we can further approximate, since ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[CapitalLambda]", "[", "m", "]"}], " ", "~", " ", 
    RowBox[{"\[CapitalLambda]", "[", "0", "]"}]}], TraditionalForm]]],
 ", f(m|m0) ~ f(0|m0), and pest(m)~0. So the rate of 2-step \
\[OpenCurlyDoubleQuote]sufficiently critical\[CloseCurlyDoubleQuote] rescue \
from single mutants is roughly"
}], "Text",
 CellChangeTimes->{{3.7510593328253183`*^9, 3.751059387414235*^9}, {
  3.7510595206997747`*^9, 3.75105963596378*^9}, {3.751059688159315*^9, 
  3.7510597254626513`*^9}, {3.7510602586473217`*^9, 3.7510602663543453`*^9}, {
  3.751060442136313*^9, 3.751060447200469*^9}, {3.769202544757123*^9, 
  3.769202584173317*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", " ", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"0", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      SqrtBox[
       RowBox[{"2", "\[CapitalLambda]0"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"-", 
        SqrtBox[
         RowBox[{"\[CapitalLambda]0", "/", "2"}]]}], ",", 
       SqrtBox[
        RowBox[{"\[CapitalLambda]0", "/", "2"}]]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"%", "==", 
  RowBox[{"2", "U", " ", 
   RowBox[{"fm", "[", 
    RowBox[{"0", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], "]"}], 
   "\[CapitalLambda]0"}]}]}], "Input",
 CellChangeTimes->{{3.751059639258409*^9, 3.751059668527986*^9}, {
  3.751059733822184*^9, 3.751059795781056*^9}, {3.751059847705192*^9, 
  3.751059933819684*^9}, {3.769202593425589*^9, 3.7692026008796253`*^9}, {
  3.769202638436227*^9, 3.7692027169438*^9}, {3.76920341395004*^9, 
  3.769203414652607*^9}, {3.769205247116005*^9, 3.769205270413028*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.751059753149495*^9, {3.751059839379463*^9, 3.751059881461617*^9}, {
   3.751059914012149*^9, 3.751059934231105*^9}, {3.769202624373766*^9, 
   3.769202641926998*^9}, {3.76920269950526*^9, 3.769202718250198*^9}, 
   3.769203415012562*^9, {3.769205262970529*^9, 3.76920527072373*^9}, 
   3.7822527013943987`*^9}]
}, Closed]],

Cell["with \[CapitalLambda]0 = \[CapitalLambda]1[0,mmax,\[Lambda],n,U].", \
"Text",
 CellChangeTimes->{{3.769202721218844*^9, 3.7692027275070887`*^9}}],

Cell["Check integration bounds:", "Text",
 CellChangeTimes->{{3.76920307436728*^9, 3.7692030813838253`*^9}, {
  3.769203337432002*^9, 3.7692033440626593`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "5"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "4"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"mneg", "=", 
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"2", 
        SuperscriptBox["m", "2"]}], "-", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
   RowBox[{"mpos", "=", 
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"2", 
        SuperscriptBox["m", "2"]}], "-", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "0.1"}], "}"}]}], "]"}]}]}], 
  "}"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Abs", "[", "m", "]"}], ",", "pr0", ",", 
      SqrtBox[
       RowBox[{
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}], "/", "2"}]]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", 
      RowBox[{
       RowBox[{"2", "m"}], "/.", "mneg"}], ",", 
      RowBox[{
       RowBox[{"2", "m"}], "/.", "mpos"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"1.2", " ", "pr0"}]}], "}"}]}], ",", 
    RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "n0", ",", "U"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.751061494578252*^9, 3.75106159048705*^9}, {
  3.7510616482525454`*^9, 3.751061679695148*^9}, {3.751061745487522*^9, 
  3.751061779401127*^9}, {3.7510618543975763`*^9, 3.75106197968237*^9}, {
  3.769203454230563*^9, 3.7692035747368917`*^9}, {3.782252735289312*^9, 
  3.782252739056716*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"m", "\[Rule]", 
     RowBox[{"-", "0.0006552852266181729`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"m", "\[Rule]", "0.0006630903632434137`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.751061549137912*^9, 3.751061593019477*^9}, {
   3.751061674680121*^9, 3.75106168273033*^9}, {3.751061763450457*^9, 
   3.751061783889574*^9}, 3.751061866996788*^9, {3.7510619079712143`*^9, 
   3.7510619307081223`*^9}, 3.7510619828806257`*^9, 3.751296242731148*^9, 
   3.7692034595369177`*^9, {3.769203554382658*^9, 3.769203577097726*^9}, 
   3.782252703400715*^9, 3.782252763615432*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQPff72anBrz33Q2n7g/83bXTm99wPpe0vnJznv3mK
634oba+9I3Pa5POO+6G0/aL1dj3SFjb7obR9672uvzkBpvuhtP3f1VqN9su1
90Npe+svTGH7IqT3Q2l7vshkzQWvxfdDaftHew//aawT2Q+l7QX5Od27Pbj3
Q2n7HTdOvvXLY9kPpe33uYhqqmr83gel7SQ26L6NeP5qH5S2W6D59Cef8QQ4
HfHg0lQW+3dweqP360iLf3/hdFzjd+tLd3ntYbTJnL8688/KwumiU/saTx/T
gdPnpA6mNL0whdNncs+aZXvZwulZGTXV1WJOcJr526ZNAZdc4fQC7p8J5X6e
cBoWDzAaAIQEzMA=
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQvb7vscG7itD96xZrBxXMdLW/wmbDGjI7BM7/VTfl
5s69wXB+NuPWa7Z3A+H8Q/t9JWbKBMD5tWu3z2k66QPnH/y/aaMzvyecf+Hk
PP/NU1zhfO0dmdMmn3eE8xett+uRtrCB81vvdf3NCTCF8/+u1mq0X64N51t/
YQrbFyEN5y/QfPqTz3iCHYxvMuevzvyzsvYwftGpfY2nj+nA+eekDqY0vTCF
88/knjXL9rKF82dl1FRXiznB+czfNm0KuOQK5y/g/plQ7ucJ53/6E5+mK+oL
59fI5R1USQ1AmMdk0n1bPgjOnxTSxXDrfzCcvzo19IzC3RA4/0iZwoz0XaFw
PgAEi8Wz
     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJwBMQLO/SFib1JlAgAAACIAAAACAAAAr47jMO54Vb+ZF6t1flhFP7is+aWH
QVW/Dx2kqCVZRT/Cyg8bIQpVvymaht3MWUU/1AY8BVSbVL/sfwdNG1tFP/p+
lNm5vVO/gZn1QrhdRT9rAbXWPd1Rv2ijlCFjY0U/wr9NGJkcUL9MJ/9brmhF
P32tt5yCyUy/x5/eed9tRT/B/7KxQw9Jv1Fa/cWBc0U/0MmeT7OURb/8xUNQ
xHhFPyu4aZaTz0G/Xj2LIHh+RT+irz6MGzg8v+sCeNwRhEU/hd6K/WxQNb8g
rmK4S4lFP/2rKoE/pyu/JQWM9/aORT879AJWvlgbv/bhR0dClEU/oCnl+Q4z
kD6akdFjc5lFPzSc/SyfzR0/Uj3x/xWfRT9yyr6By8YsP465jo9YpEU/zhrB
ZILoNT+T7gq2DKpFP8xtzTZrSj0/eu9WsaavRT+aaHx7exZCPxgriYLgtEU/
A/ayslDSRT+IPkEHjLpFP6AL+WB3Tkk/RuW+Ute/RT/y/F9mLRVNP+oS4miU
xUU/fB5uwSRlUD9AlUNHN8tFP5oCNIvbH1I/mTz+znnQRT+SVIoA2v9TP/vD
0D0u1kU/2Bh9sys3VD//UBaX1tZFPx7db2Z9blQ/FpIs8n7XRT+rZVXMIN1U
P8Oxyq3P2EU/8ilIf3IUVT9uUVIOeNlFPzjuOjLES1U/BieqcCDaRT9+si3l
FYNVP7QS0tTI2kU/xHYgmGe6VT9L9ck6cdtFPwpy/7o=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Method->{},
  PlotRange->{{-0.0013105704532363459`, 0.0013261807264868274`}, {
    0, 0.0007909925585491865}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{{3.751061549137912*^9, 3.751061593019477*^9}, {
   3.751061674680121*^9, 3.75106168273033*^9}, {3.751061763450457*^9, 
   3.751061783889574*^9}, 3.751061866996788*^9, {3.7510619079712143`*^9, 
   3.7510619307081223`*^9}, 3.7510619828806257`*^9, 3.751296242731148*^9, 
   3.7692034595369177`*^9, {3.769203554382658*^9, 3.769203577097726*^9}, 
   3.782252703400715*^9, 3.7822527645674067`*^9}]
}, Closed]],

Cell["\<\
Now check the contribution of single mutant growth rates to 2-step \
sufficiently critical rescue\
\>", "Text",
 CellChangeTimes->{{3.75106209545363*^9, 3.751062099763571*^9}, {
   3.751062143875153*^9, 3.751062179866688*^9}, 3.7692037874784403`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"m0", "=", 
    RowBox[{"-", "0.3"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
      RowBox[{"prescuem", "[", 
       RowBox[{"m", ",", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
      SqrtBox[
       RowBox[{"2", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}]], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m", "-", 
          RowBox[{"(", 
           RowBox[{"m", "/.", "mneg"}], ")"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"m", "/.", "mpos"}], ")"}], "-", "m"}], ")"}]}], "]"}]}], 
     ",", "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"0", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      SqrtBox[
       RowBox[{"2", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}]], " ", 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m", "+", "pr0"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"pr0", "-", "m"}], ")"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"0", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
      RowBox[{"prescuem", "[", 
       RowBox[{"m", ",", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "]"}]}]}], "\[IndentingNewLine]", "}"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", 
      RowBox[{
       RowBox[{"10", "m"}], "/.", "mneg"}], ",", 
      RowBox[{
       RowBox[{"10", "m"}], "/.", "mpos"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "All"}], "}"}]}], ",", 
    RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"LineLegend", "[", 
      RowBox[{"{", 
       RowBox[{
       "\"\<exact\>\"", ",", "\"\<critical\>\"", ",", 
        "\"\<critical approx.\>\"", ",", "\"\<HoC\>\""}], "}"}], "]"}]}], ",", 
    RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "m0"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7510622484477882`*^9, 3.7510623899214077`*^9}, {
   3.751062473276165*^9, 3.751062530490876*^9}, 3.751062563427968*^9, {
   3.751062594941642*^9, 3.7510626740085497`*^9}, {3.751062706742158*^9, 
   3.7510627719753103`*^9}, {3.751062825650064*^9, 3.751062839069113*^9}, {
   3.751062891684408*^9, 3.7510628936156187`*^9}, {3.751062951583514*^9, 
   3.7510629518293257`*^9}, {3.7692036847357597`*^9, 3.7692036999079247`*^9}, 
   3.769203787479937*^9, {3.769203858745409*^9, 3.769203860524778*^9}, {
   3.7692039210642014`*^9, 3.769203928666194*^9}, {3.769203963250435*^9, 
   3.769203998437386*^9}, {3.76920403488875*^9, 3.769204084203209*^9}, {
   3.769204115804134*^9, 3.7692042073553*^9}, {3.7692042397212677`*^9, 
   3.769204359716403*^9}, 3.769204451058157*^9, {3.7692047952257*^9, 
   3.769204803697855*^9}, {3.76996817705648*^9, 3.7699681817445383`*^9}, 
   3.7822527465943213`*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJzd13k0lmu/B/DHWCgks3ZIKaWErbKr6wqFHhpEUSEUpYHImBQiQ8g8T5kz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     "], {{{}, {
        Hue[0.67, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[CompressedData["
1:eJwt0udXDQAYBvAbJUlCUhoISQpNmlYqVOQWRVmXptyGipaUhjRon/5bv87x
4fe8z3k+vxmh/mD4QCAQiGDv/10XG5zRd3m/v5HPI8ZI5h1/yeMh30jiLX+4
QS1fOc0b1rhODaMk8ppVrlHNCKdoZ4VcHjBMAm0sk0MVXzjJK35zlfsMcYKX
LJHNPQY5Tiu/uMIOdxkgnhYWyWKbO/RzjBcscJktbhMmjufMk8kmlXzmKM3M
cYkK+oiliZ9cZINyPnGEILNcoIxeYnjGDBmU0sNhGvnBeUroJpqnTHOOW3Rx
iCd85yw36SSKBqZIp5gOIqlnkjSK+MhB6pgglUI+sP9XjxknhQJC/AMDuzBI

          "]]]}, {}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[{{184, 205, 191, 201, 180, 204, 186, 196, 164, 190, 200, 
          179, 185, 195, 163, 189, 199, 178, 203}}]]}, {}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[{{239, 244, 250, 235, 240, 219, 234, 218, 243, 233, 
          252}}]]}, {}, {
        Hue[0.37820393249936934`, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[CompressedData["
1:eJwl0lc3FgAAgOHvQ1kZycyOqGwNOyoqGvho2HuUIpRZkcyMnP5wPed08Vy8
92/++EJoPiwQCAT5w19+i3PSOKOfPSp4whKplPOYRVIoo41PJFNKKwtcoYRH
zJNEH7vc4iEfucxbfnKTB3wgkTfscIMW5kjgNT8oppn3xPOKbYo44T7viKOX
La5zTBOzXKKH7xTyi0ZmiOWUEN8o4IgGpomhm69c45B6poimi03yOaCOSaLo
ZIM89qllgkhesk4uNYxzkReskcM9xrjAc1bJ5i6jRPCMFbK4wwjhdPCFTG4z
TBjtfOYq1QwR5CnLZFDFYPD/QOlUMsA/Cb8soA==
          
          "]]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}}, {{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        LineBox[{1, 98, 50, 26, 122, 74, 2, 99, 51, 27, 123, 75, 3, 100, 52, 
         28, 124, 76, 4, 101, 53, 29, 125, 77, 5, 102, 54, 30, 126, 78, 6, 
         103, 55, 31, 127, 79, 7, 104, 56, 32, 128, 80, 8, 105, 57, 33, 129, 
         81, 9, 106, 58, 34, 130, 82, 10, 107, 59, 146, 35, 131, 83, 11, 108, 
         60, 36, 132, 84, 12, 109, 61, 147, 37, 133, 85, 13, 110, 62, 148, 38,
          134, 86, 14, 111, 63, 149, 39, 135, 87, 15, 112, 64, 150, 40, 136, 
         88, 16, 113, 65, 41, 137, 89, 17, 114, 66, 42, 138, 90, 18, 115, 67, 
         43, 139, 91, 19, 116, 68, 44, 140, 92, 20, 117, 69, 45, 141, 93, 21, 
         118, 70, 46, 142, 94, 22, 119, 71, 47, 143, 95, 23, 120, 72, 48, 144,
          96, 24, 121, 73, 49, 145, 97, 151, 25}]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        LineBox[{152, 193, 183, 177, 153, 154, 155, 156, 157, 158, 159, 160, 
         161, 162, 194, 184, 203, 178, 199, 189, 163, 195, 185, 179, 200, 190,
          164, 196, 186, 204, 180, 201, 191, 205, 165, 197, 187, 181, 166, 
         167, 168, 169, 170, 171, 172, 173, 174, 175, 198, 188, 182, 202, 192,
          206, 176}]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        LineBox[{207, 246, 238, 232, 208, 209, 210, 211, 212, 213, 214, 215, 
         216, 217, 247, 239, 252, 233, 243, 218, 234, 219, 240, 235, 250, 244,
          253, 220, 248, 241, 236, 221, 222, 223, 224, 225, 226, 227, 228, 
         229, 230, 249, 242, 237, 251, 245, 254, 231}]}, {
        Hue[0.37820393249936934`, 0.6, 0.6], 
        LineBox[CompressedData["
1:eJwV0Vk7FAAAheFBEclSKETGll1CKYrsu0hZijQhhabslERlrR7/uN65eC++
c3uCofDIx6hAIHDOP16KO9yIjLyihkxW6SaKKe6SxRo9RDNNLdms00sMr6nj
Jhv0cYEZ6slhk34u8oZ75LLFALGEuM8tthkkjrc0cEgeOwxxiVkecESQLzwl
njkeckw+XxkmgXkaOaGAXUb4w2Xe0cQphXzjGYks8IgzithjlCu85zG/KeY7
z0niA83cZp8XJLNICyUcMEYKSzyhlB+Mk8oyrZTxkwmuEjm7jXKuEaadCtL4
RAeVpPOZTqrIYIUuqvnFJH+5zn8Geyt7
         "]]}}}], AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
    Method -> {"AxesInFront" -> True}, 
    PlotRange -> {{-0.04475049004772709, 0.04866257535817323}, {0, All}}, 
    PlotRangeClipping -> True, PlotRangePadding -> {
      Scaled[0.02], Automatic}],
   TemplateBox[{
    "\"exact\"", "\"critical\"", "\"critical approx.\"", "\"HoC\""}, 
    "LineLegend", DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.1421359549995791, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.1421359549995791, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.37820393249936934`, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.37820393249936934`, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.1421359549995791`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.37820393249936934`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.769203889143692*^9, 3.769203925519352*^9, {3.769203961452889*^9, 
   3.7692040104285097`*^9}, {3.769204045568795*^9, 3.769204106144562*^9}, 
   3.7692043152919903`*^9, 3.7692043505571537`*^9, 3.769204428648582*^9, 
   3.769204523686432*^9, 3.769204872483037*^9, {3.7822527590453043`*^9, 
   3.78225277777251*^9}}]
}, Closed]],

Cell["\<\
Finally, let\[CloseCurlyQuote]s check the total rates of rescue across all m\
\>", "Text",
 CellChangeTimes->{{3.7510630366769114`*^9, 3.751063040284843*^9}, {
   3.751063169314378*^9, 3.751063175934472*^9}, {3.7510636161298027`*^9, 
   3.75106362244626*^9}, 3.769205058464156*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "4"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"fm", "[", 
            RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}],
             "]"}], 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
           SqrtBox[
            RowBox[{"2", 
             RowBox[{"\[CapitalLambda]1", "[", 
              RowBox[{
              "m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
              "]"}]}]]}], ",", 
          RowBox[{"{", 
           RowBox[{"m", ",", 
            RowBox[{"m", "/.", "mneg"}], ",", 
            RowBox[{"m", "/.", "mpos"}]}], "}"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{
         RowBox[{"-", "0.8"}], "mmax"}], ",", 
        RowBox[{
         RowBox[{"-", "0.1"}], "mmax"}], ",", 
        RowBox[{"0.1", "mmax"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "}"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ListLogPlot", "[", "%", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"LogPlot", "[", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"fm", "[", 
        RowBox[{"0", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
        "]"}], 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{
         RowBox[{"-", "0.8"}], "mmax"}], ",", 
        RowBox[{
         RowBox[{"-", "0.1"}], "mmax"}]}], "}"}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "n0"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.751063189929034*^9, 3.751063195260857*^9}, {
   3.751063251777727*^9, 3.751063315775334*^9}, {3.751063345833967*^9, 
   3.7510634151982183`*^9}, {3.75106350691444*^9, 3.7510635766974697`*^9}, {
   3.7510636416522617`*^9, 3.7510636671136007`*^9}, {3.751063706981538*^9, 
   3.751063818145526*^9}, {3.751063878393749*^9, 3.751063918090982*^9}, {
   3.769204898536935*^9, 3.769205013163015*^9}, {3.769205045621026*^9, 
   3.769205109267722*^9}, 3.769968187161944*^9, 3.782252756006061*^9}],

Cell[BoxData[
 GraphicsBox[{{{{}, 
     {Hue[0.67, 0.6, 0.6], 
      PointBox[{{-0.4, -19.7345142246272}, {-0.35000000000000003`, \
-17.25336399518836}, {-0.30000000000000004`, -14.995060244299024`}, {-0.25, \
-12.980762883407316`}, {-0.2, -11.235212640824798`}, {-0.15000000000000002`, \
-9.787642112955197}, {-0.09999999999999998, -8.673008577749778}, \
{-0.04999999999999999, -7.933699478735981}}]}, {}}, {}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwBYQKe/SFib1JlAgAAACUAAAACAAAAwPbwiZmZ2b8v05LSELwzwLSS4bff
fNm/VKiGhd2kM8CpLtLlJWDZv3c8TMS6jTPAkmazQbIm2b8ts+YWp18zwGTW
dfnKs9i/4O/4bkgEM8A5Urbmp7rXv0iTMqnQQTLA49rvWwfS1r9ppEVo1JAx
wNdKYwD37dW/82pHuLvnMMD8VpIikvbUv/sInXRgNTDA9m+6zK8P1L88Aw0M
nicvwCIlnvR4FdO/O/Zb/F7ULcCXwbtL0h/Sv7G9+HqxkizA4WrSKq460b+l
YDJ4FnErwF2wpIc1QtC/P+Xl5cdCKsBcBeDYfrTOv/ACn2HkMynAkXjqALPt
zL+gPrt4QzUowCkkbCQ+AMu/fT65gpgtJ8Br6d9XzjPJv06gMePCQybAEOfK
hrVAx78G1hEeAlQlwEizKRS9VsW/mz2SF/h2JMAqmXqxyY3Dv2zIeFILtiPA
b7dCSi2ewb/X73PDtPMiwL3e+eUrn7+/YCsYzslMIsBiv1wuq7S7v+hxJYJC
qCHALD2nM2vct7/jTkp43RchwEvu1Vg1RrS/95maiAqhIMCIkllcxMmzv1aH
KfElkiDAxDbdX1NNs7/JRip5jIMgwD5/5GZxVLK/q+iWYzxnIMAwEPN0rWKw
vzeECjMyMiDAYjKFz+Lfr79/QY8FqCYgwGNEJLVq+q6/WDSQRWAbIMBmaGKA
ei+tv3kREUyZBSDAaHoBZgJKrL8B/khmNfYfwGmMoEuKZKu/H1W9kb/hH8Bq
nj8xEn+qvxw5P77RzR/AbLDeFpqZqb/tPdqQbLofwLUKOCU=
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-0.4, -19.7345142246272},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-20.72326583694641, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {-18.238359187158412`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.58777162101726, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.196905312330248`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.916603347176093`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.69791414621126, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.518573217555446`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.36655701025682, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.234629467214273`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.633189001170319`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.98260143502917, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.591735126342158`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.311433161188, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.09274396022317, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.913403031567354`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.761386824268728`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.629459281226179`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.028018815182229, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.377431249041079, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.986564940354067, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.706262975199909, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.487573774235079, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.308232845579262, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.156216638280637, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.024289095238088, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.422848629194137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.7722610630529876`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.3813947543659757`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.101092789211817, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.882403588246988, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.703062659591171, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.551046452292545, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.419118909249997, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-20.72326583694641, 
       FormBox["\"\"", TraditionalForm]}, {-16.11809565095832, 
       FormBox["\"\"", TraditionalForm]}, {-11.512925464970229`, 
       FormBox["\"\"", TraditionalForm]}, {-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {-18.238359187158412`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.58777162101726, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.196905312330248`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.916603347176093`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.69791414621126, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.518573217555446`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.36655701025682, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.234629467214273`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.633189001170319`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.98260143502917, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.591735126342158`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.311433161188, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.09274396022317, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.913403031567354`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.761386824268728`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.629459281226179`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.028018815182229, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.377431249041079, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.986564940354067, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.706262975199909, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.487573774235079, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.308232845579262, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.156216638280637, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.024289095238088, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.422848629194137, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.7722610630529876`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.3813947543659757`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.101092789211817, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.882403588246988, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.703062659591171, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.551046452292545, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.419118909249997, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{-0.4, 0.}, {-19.7345142246272, 0}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, {{-20.72326583694641, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-16.11809565095832, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {-18.238359187158412`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-17.58777162101726, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-17.196905312330248`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-16.916603347176093`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-16.69791414621126, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-16.518573217555446`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-16.36655701025682, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-16.234629467214273`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-13.633189001170319`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.98260143502917, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.591735126342158`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.311433161188, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.09274396022317, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.913403031567354`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.761386824268728`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.629459281226179`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.028018815182229, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.377431249041079, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.986564940354067, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.706262975199909, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.487573774235079, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.308232845579262, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.156216638280637, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.024289095238088, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.422848629194137, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.7722610630529876`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.3813947543659757`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.101092789211817, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.882403588246988, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.703062659591171, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.551046452292545, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.419118909249997, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{
  3.7510634886257*^9, 3.751063593683093*^9, 3.7510636897762117`*^9, 
   3.751063814157774*^9, 3.751063846318844*^9, 3.751063897768283*^9, 
   3.7510640120826483`*^9, 3.7692050692465353`*^9, {3.769205104040963*^9, 
   3.7692051243899593`*^9}, 3.7822527928903027`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Closed form approximation (equations 10 and 11)\
\>", "Subsubsection",
 CellChangeTimes->{{3.751296329056678*^9, 3.751296346478345*^9}, {
   3.75129776961401*^9, 3.7512977717824383`*^9}, {3.769190708122199*^9, 
   3.769190751144589*^9}, 3.769190789497635*^9, {3.76920545142106*^9, 
   3.769205511180996*^9}, 3.7692666104362297`*^9, {3.7693462165467052`*^9, 
   3.769346241913962*^9}, {3.769379713438807*^9, 3.769379715205846*^9}, 
   3.771256259234386*^9, {3.7717620201819677`*^9, 3.7717620393981953`*^9}}],

Cell["\<\
OK, so a good approximation for sufficiently critical rescue from a mutant is\
\
\>", "Text",
 CellChangeTimes->{{3.751296370216578*^9, 3.7512963833243847`*^9}, {
  3.769205314167111*^9, 3.769205333999217*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "\[CapitalLambda]0", " ", 
   RowBox[{"fm", "[", 
    RowBox[{"0", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.751296385705707*^9, {3.769205138517701*^9, 3.7692052176258297`*^9}}],

Cell["with \[CapitalLambda]0=\[CapitalLambda]1[0,mmax,\[Lambda],n,U]", "Text",
 CellChangeTimes->{{3.769205219829567*^9, 3.769205230656188*^9}}],

Cell[TextData[{
 "but note that, while this has reduced a lot of complexity, \
\[CapitalLambda]0 = U \[Integral] ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", 
     RowBox[{"m", "|", "0"}], ")"}], " ", 
    RowBox[{
     SubscriptBox["p", "est"], "(", "m", ")"}], " ", "dm"}], 
   TraditionalForm]]],
 " is still an integral we have to compute. Fortunately however, we can just \
use the approximations Anciaux et al used (and we replicated above), so that \
when we take m=mmax \[Psi](1-\[Psi]/4) to zero we have \[CapitalLambda]0 as \
roughly"
}], "Text",
 CellChangeTimes->{{3.7512963886159477`*^9, 3.751296503744617*^9}, {
   3.751296632226259*^9, 3.7512966323860598`*^9}, {3.769205338544627*^9, 
   3.7692054342742147`*^9}, 3.7692058334794407`*^9, {3.769206685688588*^9, 
   3.769206689438526*^9}, {3.769206994715023*^9, 3.769206995618651*^9}, {
   3.7692664316900177`*^9, 3.7692664479437237`*^9}, {3.76926648223295*^9, 
   3.7692665052100363`*^9}, {3.771274742211916*^9, 3.7712747430582533`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "multiply", " ", "by", " ", "m", " ", "because", " ", "anciaux", " ", 
     "A12", " ", "accounts", " ", "for", " ", "number", " ", "of", " ", 
     "individuals", " ", "in", " ", "lineage"}], ",", " ", 
    RowBox[{"which", " ", "they", " ", "estimate", " ", "as", " ", 
     RowBox[{"1", "/", "m"}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"m", " ", "AnciauxEqnA12"}], "/.", 
       RowBox[{"\[Psi]wt", "\[Rule]", "\[Psi]"}]}], "/.", 
      RowBox[{"m", "\[Rule]", 
       RowBox[{"mmax", " ", "\[Psi]", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[Psi]", "/", "4"}]}], ")"}]}]}]}], "/.", 
     RowBox[{"\[Alpha]", "\[Rule]", 
      FractionBox[
       RowBox[{"\[Rho]max", " ", 
        SuperscriptBox["\[Psi]", "2"]}], "4"]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Limit", "[", 
     RowBox[{"%", ",", 
      RowBox[{"\[Psi]", "\[Rule]", "0"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"%", "/.", 
      RowBox[{"\[Rho]max", "\[Rule]", 
       RowBox[{"mmax", "/", "\[Lambda]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"mmax", ">", "0"}], ",", 
       RowBox[{"\[Lambda]", ">", "0"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.769266182284343*^9, 3.7692662174115143`*^9}, {
  3.769266250654468*^9, 3.769266282387299*^9}, {3.7692663240907803`*^9, 
  3.769266345769806*^9}, {3.769266398661002*^9, 3.769266411942132*^9}, {
  3.769266458822486*^9, 3.769266467606831*^9}, {3.76926653650562*^9, 
  3.769266587994961*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "U", " ", 
   SqrtBox[
    RowBox[{"mmax", " ", "\[Lambda]"}]]}], 
  SqrtBox["\[Pi]"]]], "Output",
 CellChangeTimes->{{3.769266264249179*^9, 3.769266282725506*^9}, {
   3.769266325019684*^9, 3.769266346103775*^9}, {3.769266407801237*^9, 
   3.7692664124064693`*^9}, 3.769266468041161*^9, {3.76926658134415*^9, 
   3.7692665884928217`*^9}, 3.782252813659232*^9}]
}, Closed]],

Cell["\<\
so that when we include mutation rate from the wildtype we have\
\>", "Text",
 CellChangeTimes->{{3.7716036983034782`*^9, 3.771603699781767*^9}, {
  3.771605982979075*^9, 3.7716059919292297`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", " ", 
   SuperscriptBox["U", "2"], " ", 
   RowBox[{"fm", "[", 
    RowBox[{"0", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], "]"}], 
   
   SqrtBox[
    RowBox[{"mmax", " ", 
     RowBox[{"\[Lambda]", "/", "\[Pi]"}]}]]}], ";"}]], "Input",
 CellChangeTimes->{{3.771603709435956*^9, 3.771603756619506*^9}, {
  3.771605994588292*^9, 3.771605994786978*^9}}],

Cell["\<\
We can further approximate fm to give a simpler analytic form. Using the \
approximation over \[Psi] above (and incorporating the change in scale as we \
have integrated over fm above) we get\
\>", "Text",
 CellChangeTimes->{{3.771603761127152*^9, 3.7716038075530787`*^9}, {
  3.771603908717689*^9, 3.771603909611867*^9}, {3.7716040202407846`*^9, 
  3.771604030383497*^9}, {3.771605627715042*^9, 3.771605630977091*^9}, {
  3.771606174303672*^9, 3.771606225512454*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"U", " "}], "2"], 
         SqrtBox[
          RowBox[{"mmax", " ", 
           RowBox[{"\[Lambda]", "/", "\[Pi]"}]}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"2", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 SqrtBox[
                  RowBox[{"1", "-", 
                   RowBox[{"m", "/", "mmax"}]}]]}], ")"}]}], ",", "m"}], 
             "]"}], "f\[Psi]"}], "/.", 
           RowBox[{"\[Psi]", "\[Rule]", "0"}]}], ")"}]}], "/.", 
        RowBox[{"mmax", "\[Rule]", 
         RowBox[{"\[Rho]max", " ", "\[Lambda]"}]}]}], "/.", 
       RowBox[{"m", "\[Rule]", "0"}]}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Lambda]", ">", "0"}], ",", 
        RowBox[{"\[Theta]", ">", 
         RowBox[{"1", "/", "2"}]}], ",", 
        RowBox[{"\[Psi]wt", "<", "0"}]}], "}"}]}], "]"}], "/.", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[Rho]max", " ", 
        SuperscriptBox["\[Psi]wt", "2"]}], "4"]}], "\[Rule]", 
     RowBox[{"-", "\[Alpha]"}]}]}], 
   RowBox[{"(*", 
    RowBox[{"/.", 
     RowBox[{"\[Theta]", "\[Rule]", 
      RowBox[{"n", "/", "2"}]}]}], "*)"}], "/.", 
   RowBox[{"\[Psi]wt", "\[Rule]", 
    SubscriptBox["\[Psi]", "0"]}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["U", "2"], "  ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox[
        SubscriptBox["\[Psi]", "0"], "2"]}], ")"}], 
     RowBox[{
      FractionBox["1", "2"], "-", "\[Theta]"}]], 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "\[Alpha]"}]], 
    FractionBox[
     RowBox[{" ", "2"}], "\[Pi]"]}], "\[Equal]", "%"}], "]"}]}], "Input",
 CellChangeTimes->{{3.771604083884618*^9, 3.771604241529847*^9}, {
  3.7716049448521*^9, 3.771604955690733*^9}, {3.771605123168353*^9, 
  3.771605184319378*^9}, {3.7716060459667587`*^9, 3.771606058196437*^9}, {
  3.77160614143118*^9, 3.771606142742277*^9}, {3.771606236104085*^9, 
  3.771606284663033*^9}, {3.771606326173538*^9, 3.771606402793227*^9}, {
  3.771606435728916*^9, 3.77160644443095*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{
     FractionBox["1", "2"], "+", "\[Theta]"}]], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", "\[Alpha]"}]], " ", 
   SuperscriptBox["U", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"2", "-", 
      SubscriptBox["\[Psi]", "0"]}], ")"}], 
    RowBox[{
     FractionBox["1", "2"], "-", "\[Theta]"}]]}], "\[Pi]"]], "Output",
 CellChangeTimes->{
  3.771604032642283*^9, {3.771604100072507*^9, 3.771604126592845*^9}, {
   3.771604168377371*^9, 3.7716042423190727`*^9}, {3.771604948993239*^9, 
   3.771604956207488*^9}, {3.7716051266417923`*^9, 3.7716051846481333`*^9}, 
   3.771606060103634*^9, 3.771606144183104*^9, {3.7716062763973494`*^9, 
   3.771606285313919*^9}, {3.7716063265887136`*^9, 3.7716063395749598`*^9}, {
   3.7716063803005943`*^9, 3.771606403711845*^9}, 3.77160644551565*^9, 
   3.782252813820812*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.771604032642283*^9, {3.771604100072507*^9, 3.771604126592845*^9}, {
   3.771604168377371*^9, 3.7716042423190727`*^9}, {3.771604948993239*^9, 
   3.771604956207488*^9}, {3.7716051266417923`*^9, 3.7716051846481333`*^9}, 
   3.771606060103634*^9, 3.771606144183104*^9, {3.7716062763973494`*^9, 
   3.771606285313919*^9}, {3.7716063265887136`*^9, 3.7716063395749598`*^9}, {
   3.7716063803005943`*^9, 3.771606403711845*^9}, 3.77160644551565*^9, 
   3.7822528138975143`*^9}]
}, Closed]],

Cell["Check contributions across m", "Text",
 CellChangeTimes->{{3.751297754520838*^9, 3.751297761494711*^9}, 
   3.769266598479333*^9, {3.7692667721847*^9, 3.769266773896751*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", "m0", "]"}]], "Input",
 CellChangeTimes->{{3.7716047340447063`*^9, 3.77160473672698*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"m0", "=", 
    RowBox[{"-", "0.3"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
      RowBox[{"prescuem", "[", 
       RowBox[{"m", ",", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
      SqrtBox[
       RowBox[{"2", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}]], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m", "-", 
          RowBox[{"(", 
           RowBox[{"m", "/.", "mneg"}], ")"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"m", "/.", "mpos"}], ")"}], "-", "m"}], ")"}]}], "]"}]}], 
     ",", "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"0", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      SqrtBox[
       RowBox[{"2", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}]], " ", 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m", "+", "pr0"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"pr0", "-", "m"}], ")"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"0", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
      RowBox[{"prescuem", "[", 
       RowBox[{"m", ",", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"0", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      SqrtBox[
       RowBox[{"2", " ", 
        FractionBox[
         RowBox[{"2", " ", "U", " ", 
          SqrtBox[
           RowBox[{"mmax", " ", "\[Lambda]"}]]}], 
         SqrtBox["\[Pi]"]]}]], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m", "+", 
          SqrtBox[
           RowBox[{" ", 
            FractionBox[
             RowBox[{" ", 
              RowBox[{"U", " ", 
               SqrtBox[
                RowBox[{"mmax", " ", "\[Lambda]"}]]}]}], 
             SqrtBox["\[Pi]"]]}]]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          SqrtBox[
           RowBox[{" ", 
            FractionBox[
             RowBox[{" ", 
              RowBox[{"U", " ", 
               SqrtBox[
                RowBox[{"mmax", " ", "\[Lambda]"}]]}]}], 
             SqrtBox["\[Pi]"]]}]], "-", "m"}], ")"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"2", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  SqrtBox[
                   RowBox[{"1", "-", 
                    RowBox[{"m", "/", "mmax"}]}]]}], ")"}]}], ",", "m"}], 
              "]"}], "f\[Psi]"}], "/.", 
            RowBox[{"\[Psi]", "\[Rule]", "0"}]}], "/.", 
           RowBox[{"\[Psi]wt", "\[Rule]", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SqrtBox[
                RowBox[{"1", "-", 
                 RowBox[{"m0", "/", "mmax"}]}]]}], ")"}]}]}]}], "/.", 
          RowBox[{"\[Rho]max", "\[Rule]", 
           RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
         RowBox[{"\[Theta]", "\[Rule]", 
          RowBox[{"n", "/", "2"}]}]}], "/.", 
        RowBox[{"m", "\[Rule]", "0"}]}], ")"}], 
      SqrtBox[
       RowBox[{"2", " ", 
        FractionBox[
         RowBox[{"2", " ", "U", " ", 
          SqrtBox[
           RowBox[{"mmax", " ", "\[Lambda]"}]]}], 
         SqrtBox["\[Pi]"]]}]], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"m", "+", 
          SqrtBox[
           RowBox[{" ", 
            FractionBox[
             RowBox[{" ", 
              RowBox[{"U", " ", 
               SqrtBox[
                RowBox[{"mmax", " ", "\[Lambda]"}]]}]}], 
             SqrtBox["\[Pi]"]]}]]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          SqrtBox[
           RowBox[{" ", 
            FractionBox[
             RowBox[{" ", 
              RowBox[{"U", " ", 
               SqrtBox[
                RowBox[{"mmax", " ", "\[Lambda]"}]]}]}], 
             SqrtBox["\[Pi]"]]}]], "-", "m"}], ")"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "}"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", 
      RowBox[{
       RowBox[{"10", "m"}], "/.", "mneg"}], ",", 
      RowBox[{
       RowBox[{"10", "m"}], "/.", "mpos"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "All"}], "}"}]}], ",", 
    RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"LineLegend", "[", 
      RowBox[{"{", 
       RowBox[{
       "\"\<exact\>\"", ",", "\"\<critical\>\"", ",", 
        "\"\<critical approx.\>\"", ",", "\"\<HoC\>\"", ",", " ", 
        "\"\<critical closed form\>\"", ",", "\"\<simpler closed form\>\""}], 
       "}"}], "]"}]}], ",", 
    RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "m0"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7510622484477882`*^9, 3.7510623899214077`*^9}, {
   3.751062473276165*^9, 3.751062530490876*^9}, 3.751062563427968*^9, {
   3.751062594941642*^9, 3.7510626740085497`*^9}, {3.751062706742158*^9, 
   3.7510627719753103`*^9}, {3.751062825650064*^9, 3.751062839069113*^9}, {
   3.751062891684408*^9, 3.7510628936156187`*^9}, {3.751062951583514*^9, 
   3.7510629518293257`*^9}, {3.751297415397956*^9, 3.751297553490384*^9}, {
   3.751297635777727*^9, 3.751297659076786*^9}, {3.7517317639311934`*^9, 
   3.751731771797432*^9}, {3.751731851516823*^9, 3.751731870161189*^9}, {
   3.7692666188081427`*^9, 3.7692666240312147`*^9}, {3.7692666872748117`*^9, 
   3.769266734175846*^9}, {3.769266768195052*^9, 3.7692667689693747`*^9}, {
   3.7699669606473*^9, 3.7699669652310467`*^9}, {3.7716042846327667`*^9, 
   3.771604298428529*^9}, {3.771604340722253*^9, 3.771604405162125*^9}, 
   3.77160444612866*^9, {3.771604537204504*^9, 3.771604537618739*^9}, 
   3.771605648882443*^9, 3.771605860455431*^9, {3.771605924870777*^9, 
   3.771605934149919*^9}, {3.782252791952487*^9, 3.782252792627965*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJzd13k0llvfB3CZCoVjHjohpUgJh3KqvaNCUhGFQihKA5ExKaQMIWSeM49H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     "], {{{}, {
        Hue[0.67, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[CompressedData["
1:eJwt0ulWDQAABOAbSVGiEIWEJEmLNtImRRG5rVRoT1pJVFpUSiIqcnrMeoK+
zvHjm5kHmKSO4eDQgUAgEML2/94Ru5y1/9HOOllUMcEZXvObTB7yiThe8YsM
HvCR07xkjZtUMs4p2vhJOhV84CSt/OAG9xkjlhZWSaOc98Twgu9c5x7vOMFz
VkiljFGO08w3rrFFKSNE08QyKfylhGGO0cgSV/lDMUNE0cBXktmkiEEiqWeR
K9xlgKPUscBlNijkLUcIMs8l7tBPBM/4QhK3eUM4tcxxkQL6OMxTZkkkn17C
eMIMF8ijh0PUMM15cukmlMd85hw5dHGQR0yRwC062f9VNZPEk00He8pKMQg=

          "]]]}, {}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[{{184, 205, 191, 201, 180, 204, 186, 196, 164, 190, 200, 
          179, 185, 195, 163, 189, 199, 178, 203}}]]}, {}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[{{239, 244, 250, 235, 240, 219, 234, 218, 243, 233, 
          252}}]]}, {}, {
        Hue[0.37820393249936934`, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[CompressedData["
1:eJwl0lc7FQAAgOFzUFZGMrMjKlvDjoqKBg4Ne49ShDIrkplx0R/VP6j3ebp4
L777L398ITQfFggEgvzmL+fiD2mc0c8eFTxhiVTKecwiKZTRxieSKaWVBa5Q
wiPmSaKPXW7xkI9c5i0/uckDPpDIG3a4QQtzJPCaHxTTzHviecU2RZxwn3fE
0csW1zmmiVku0cN3CvlFIzPEckqIbxRwRAPTxNDNV65xSD1TRNPFJvkcUMck
UXSyQR771DJBJC9ZJ5caxrnIC9bI4R5jXOA5q2Rzl1EieMYKWdxhhHA6+EIm
txkmjHY+c5VqhgjylGUyqGIw+H+gdCoZ4B+7Ti1g
          "]]]}, {}, {
        Hue[0.6142719099991583, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[{{439, 412, 445, 436, 442, 427, 432, 411, 426, 410, 435, 
          425, 444, 431}}]]}, {}, {
        Hue[0.8503398874989481, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[{{487, 460, 493, 484, 490, 475, 480, 459, 474, 458, 483, 
          473, 492, 
          479}}]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        LineBox[{1, 98, 50, 26, 122, 74, 2, 99, 51, 27, 123, 75, 3, 100, 52, 
         28, 124, 76, 4, 101, 53, 29, 125, 77, 5, 102, 54, 30, 126, 78, 6, 
         103, 55, 31, 127, 79, 7, 104, 56, 32, 128, 80, 8, 105, 57, 33, 129, 
         81, 9, 106, 58, 34, 130, 82, 10, 107, 59, 146, 35, 131, 83, 11, 108, 
         60, 36, 132, 84, 12, 109, 61, 147, 37, 133, 85, 13, 110, 62, 148, 38,
          134, 86, 14, 111, 63, 149, 39, 135, 87, 15, 112, 64, 150, 40, 136, 
         88, 16, 113, 65, 41, 137, 89, 17, 114, 66, 42, 138, 90, 18, 115, 67, 
         43, 139, 91, 19, 116, 68, 44, 140, 92, 20, 117, 69, 45, 141, 93, 21, 
         118, 70, 46, 142, 94, 22, 119, 71, 47, 143, 95, 23, 120, 72, 48, 144,
          96, 24, 121, 73, 49, 145, 97, 151, 25}]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        LineBox[{152, 193, 183, 177, 153, 154, 155, 156, 157, 158, 159, 160, 
         161, 162, 194, 184, 203, 178, 199, 189, 163, 195, 185, 179, 200, 190,
          164, 196, 186, 204, 180, 201, 191, 205, 165, 197, 187, 181, 166, 
         167, 168, 169, 170, 171, 172, 173, 174, 175, 198, 188, 182, 202, 192,
          206, 176}]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        LineBox[{207, 246, 238, 232, 208, 209, 210, 211, 212, 213, 214, 215, 
         216, 217, 247, 239, 252, 233, 243, 218, 234, 219, 240, 235, 250, 244,
          253, 220, 248, 241, 236, 221, 222, 223, 224, 225, 226, 227, 228, 
         229, 230, 249, 242, 237, 251, 245, 254, 231}]}, {
        Hue[0.37820393249936934`, 0.6, 0.6], 
        LineBox[CompressedData["
1:eJwV0Vk7FAAAheFBEclSKETGll1CKYrsu0hZijQhhabslERlrR7/uN65eC++
c3uCofDIx6hAIHDOP16KO9yIjLyihkxW6SaKKe6SxRo9RDNNLdms00sMr6nj
Jhv0cYEZ6slhk34u8oZ75LLFALGEuM8tthkkjrc0cEgeOwxxiVkecESQLzwl
njkeckw+XxkmgXkaOaGAXUb4w2Xe0cQphXzjGYks8IgzithjlCu85zG/KeY7
z0niA83cZp8XJLNICyUcMEYKSzyhlB+Mk8oyrZTxkwmuEjm7jXKuEaadCtL4
RAeVpPOZTqrIYIUuqvnFJH+5zn8Geyt7
         "]]}, {
        Hue[0.6142719099991583, 0.6, 0.6], 
        LineBox[{399, 438, 430, 424, 400, 401, 402, 403, 404, 405, 406, 407, 
         408, 409, 439, 431, 444, 425, 435, 410, 426, 411, 432, 427, 442, 436,
          445, 412, 440, 433, 428, 413, 414, 415, 416, 417, 418, 419, 420, 
         421, 422, 441, 434, 429, 443, 437, 446, 423}]}, {
        Hue[0.8503398874989481, 0.6, 0.6], 
        LineBox[{447, 486, 478, 472, 448, 449, 450, 451, 452, 453, 454, 455, 
         456, 457, 487, 479, 492, 473, 483, 458, 474, 459, 480, 475, 490, 484,
          493, 460, 488, 481, 476, 461, 462, 463, 464, 465, 466, 467, 468, 
         469, 470, 489, 482, 477, 491, 485, 494, 471}]}}}], AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
    Method -> {"AxesInFront" -> True}, 
    PlotRange -> {{-0.04475049004772709, 0.04866257535817323}, {0, All}}, 
    PlotRangeClipping -> True, PlotRangePadding -> {
      Scaled[0.02], Automatic}],
   TemplateBox[{
    "\"exact\"", "\"critical\"", "\"critical approx.\"", "\"HoC\"", 
     "\"critical closed form\"", "\"simpler closed form\""}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.1421359549995791, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.1421359549995791, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.37820393249936934`, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.37820393249936934`, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.6142719099991583, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.6142719099991583, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.8503398874989481, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.8503398874989481, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.1421359549995791`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.37820393249936934`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.6142719099991583`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.8503398874989481`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6}], "}"}], 
         ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.751297554504073*^9, 3.751297603551052*^9, 
  3.7512977111102467`*^9, 3.751731815360368*^9, 3.751731909217635*^9, 
  3.769266730054665*^9, 3.769266841562665*^9, 3.7716045213207006`*^9, 
  3.771605715565546*^9, 3.77160600392877*^9, 3.782252826017692*^9}]
}, Closed]],

Cell["And check total rate", "Text",
 CellChangeTimes->{{3.751296735461693*^9, 3.75129673590377*^9}, {
  3.76926677569658*^9, 3.769266781112752*^9}, {3.769458695273716*^9, 
  3.769458695622252*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "4"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{"U", " ", 
           RowBox[{"fm", "[", 
            RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}],
             "]"}], 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
           SqrtBox[
            RowBox[{"2", 
             RowBox[{"\[CapitalLambda]1", "[", 
              RowBox[{
              "m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
              "]"}]}]]}], ",", 
          RowBox[{"{", 
           RowBox[{"m", ",", 
            RowBox[{"m", "/.", "mneg"}], ",", 
            RowBox[{"m", "/.", "mpos"}]}], "}"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{
         RowBox[{"-", "0.8"}], "mmax"}], ",", 
        RowBox[{
         RowBox[{"-", "0.1"}], "mmax"}], ",", 
        RowBox[{"0.1", "mmax"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
    "}"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LogPlot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"U", " ", "2", " ", "\[CapitalLambda]0approx", " ", 
         RowBox[{"fm", "[", 
          RowBox[{"0", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
          "]"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["U", "2"], "  ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "-", 
                FractionBox[
                 SubscriptBox["\[Psi]", "0"], "2"]}], ")"}], 
              RowBox[{
               FractionBox["1", "2"], "-", "\[Theta]"}]], 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{"-", "\[Alpha]"}]], 
             FractionBox[
              RowBox[{" ", "2"}], "\[Pi]"]}], "/.", 
            RowBox[{"\[Alpha]", "\[Rule]", 
             RowBox[{"\[Rho]max", " ", 
              RowBox[{
               SuperscriptBox[
                SubscriptBox["\[Psi]", "0"], "2"], "/", "4"}]}]}]}], "/.", 
           RowBox[{
            SubscriptBox["\[Psi]", "0"], "\[Rule]", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SqrtBox[
                RowBox[{"1", "-", 
                 RowBox[{"m0", "/", "mmax"}]}]]}], ")"}]}]}]}], "/.", 
          RowBox[{"\[Rho]max", "\[Rule]", 
           RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
         RowBox[{"\[Theta]", "\[Rule]", 
          RowBox[{"n", "/", "2"}]}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{
         RowBox[{"-", "0.8"}], "mmax"}], ",", 
        RowBox[{
         RowBox[{"-", "0.1"}], "mmax"}]}], "}"}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Frame", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Wildtype growth rate\>\"", ",", ",", ",", 
         "\"\<Rate of rescue\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"FrameTicks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{"\"\<approx\>\"", ",", "\"\<simpler approx\>\""}], 
            "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "/", "4"}], ",", 
            RowBox[{"1", "/", "4"}]}], "}"}]}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotMarkers", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "Medium"}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7510622484477882`*^9, 3.7510623899214077`*^9}, {
   3.751062473276165*^9, 3.751062530490876*^9}, 3.751062563427968*^9, {
   3.751062594941642*^9, 3.7510626740085497`*^9}, {3.751062706742158*^9, 
   3.7510627719753103`*^9}, {3.751062825650064*^9, 3.751062839069113*^9}, {
   3.751062891684408*^9, 3.7510628936156187`*^9}, {3.751062951583514*^9, 
   3.7510629518293257`*^9}, {3.751297415397956*^9, 3.751297553490384*^9}, {
   3.751297635777727*^9, 3.751297659076786*^9}, {3.7517317639311934`*^9, 
   3.751731771797432*^9}, {3.751731851516823*^9, 3.751731870161189*^9}, {
   3.7692666188081427`*^9, 3.7692666240312147`*^9}, {3.7692666872748117`*^9, 
   3.769266734175846*^9}, {3.769266768195052*^9, 3.7692667689693747`*^9}, {
   3.769353114315281*^9, 3.7693531150417147`*^9}, {3.769353180777421*^9, 
   3.7693534947696238`*^9}, {3.769353555676795*^9, 3.76935361837928*^9}, 
   3.7699669415117903`*^9, {3.771606490791703*^9, 3.771606638914682*^9}, {
   3.771606754918335*^9, 3.771606774952923*^9}, {3.7822528029834633`*^9, 
   3.7822528062860613`*^9}, {3.782252842425775*^9, 3.7822528431608553`*^9}}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwBYQKe/SFib1JlAgAAACUAAAACAAAAwPbwiZmZ2b9yEWO1lGE6wLSS4bff
fNm/mOZWaGFKOsCpLtLlJWDZv7p6HKc+MzrAkmazQbIm2b9w8bb5KgU6wGTW
dfnKs9i/Iy7JUcypOcA5Urbmp7rXv4vRAoxU5zjA49rvWwfS1r+s4hVLWDY4
wNdKYwD37dW/N6kXmz+NN8D8VpIikvbUvz5HbVfk2jbA9m+6zK8P1L/hv9bo
Ujk2wCIlnvR4FdO/YTn+YLOPNcCXwbtL0h/SvxydTKDc7jTA4WrSKq460b+W
bukeD140wF2wpIc1QtC/4zDD1efGM8BcBeDYfrTOv7u/nxN2PzPAkXjqALPt
zL+T3S2fJcAywCkkbCQ+AMu/gt0sJFA8MsBr6d9XzjPJv2oOaVRlxzHAEOfK
hrVAx79GKdnxhE8xwEizKRS9VsW/EV2Z7v/gMMAqmXqxyY3Dv3miDIyJgDDA
b7dCSi2ewb8vNopEXh8wwL3e+eUrn7+/5qe4k9GXL8Biv1wuq7S7v2/uxUdK
8y7ALD2nM2vct79qy+o95WIuwEvu1Vg1RrS/fRY7ThLsLcCIkllcxMmzv9wD
yrYt3S3AxDbdX1NNs79Qw8o+lM4twD5/5GZxVLK/MWU3KUSyLcAwEPN0rWKw
v74Aq/g5fS3AYjKFz+Lfr78Gvi/Lr3EtwGNEJLVq+q6/3rAwC2hmLcBmaGKA
ei+tvwCOsRGhUC3AaHoBZgJKrL+H+8R4IkYtwGmMoEuKZKu/Fid/juc7LcBq
nj8xEn+qvxQZwKTwMS3AbLDeFpqZqb99mw0OPigtwBqAOig=
        "]]}, 
      {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
       LineBox[CompressedData["
1:eJwBYQKe/SFib1JlAgAAACUAAAACAAAAwPbwiZmZ2b+1Sa7yOGE6wLSS4bff
fNm/JP+sjgVKOsCpLtLlJWDZv2kybLbiMjrAkmazQbIm2b+dzcXazgQ6wGTW
dfnKs9i/pIOD1W+pOcA5Urbmp7rXv7qGg0H35jjA49rvWwfS1r/zCxY7+jU4
wNdKYwD37dW/1QaixOCMN8D8VpIikvbUv9eyCqSE2jbA9m+6zK8P1L/lTL1h
8jg2wCIlnvR4FdO//fQk7lGPNcCXwbtL0h/SvwDLUD967jTA4WrSKq460b8w
u4rZq100wF2wpIc1QtC/5YeVkYPGM8BcBeDYfrTOv9mahdoQPzPAkXjqALPt
zL9KXQpvv78ywCkkbCQ+AMu/DxnZ3+g7MsBr6d9XzjPJv73wVAb9xjHAEOfK
hrVAx7/z0XV6G08xwEizKRS9VsW/5uR3SZXgMMAqmXqxyY3Dvz06NMQdgDDA
b7dCSi2ewb8w8aU28R4wwL3e+eUrn7+/f+T4AfWWL8Biv1wuq7S7vzdVw/Jq
8i7ALD2nM2vct78zzwgYA2IuwEvu1Vg1RrS/PLOtbi3rLcCIkllcxMmzv+Jp
u3ZI3C3AxDbdX1NNs7/ukMCdrs0twD5/5GZxVLK/mMvCxF2xLcAwEPN0rWKw
v6medwdSfC3AYjKFz+Lfr7/ecGV9x3AtwGNEJLVq+q6/Z1RgYH9lLcBmaGKA
ei+tvzUnhKu3Ty3AaHoBZgJKrL9z1D60OEUtwGmMoEuKZKu/d5Ata/06LcBq
nj8xEn+qv9x6LyIGMS3AbLDeFpqZqb+9cckrUyctwAVFQ5g=
        "]]}}, {
      GraphicsComplexBox[{{-0.4, -26.64226950360934}, {-0.35000000000000003`, \
-24.1611192741705}, {-0.30000000000000004`, -21.902815523281163`}, {-0.25, \
-19.888518162389452`}, {-0.2, -18.142967919806935`}, {-0.15000000000000002`, \
-16.695397391937334`}, {-0.09999999999999998, -15.580763856731915`}, \
{-0.04999999999999999, -14.841454757718118`}, {-0.4, -26.64226950360934}, \
{-0.35000000000000003`, -24.1611192741705}, {-0.30000000000000004`, \
-21.902815523281163`}, {-0.25, -19.888518162389452`}, {-0.2, \
-18.142967919806935`}, {-0.15000000000000002`, -16.695397391937334`}, \
{-0.09999999999999998, -15.580763856731915`}, {-0.04999999999999999, \
-14.841454757718118`}}, {
        {GrayLevel[0], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 9], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 10], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 11], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 12], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 13], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 14], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 15], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 16]}, {}}], {}}}, InsetBox[
     TemplateBox[{
      StyleBox["\"approx\"", StripOnInput -> False, FontFamily -> "Helvetica",
         FontSize -> 12],StyleBox[
       "\"simpler approx\"", StripOnInput -> False, FontFamily -> "Helvetica",
         FontSize -> 12]},
      "LineLegend",
      DisplayFunction->(StyleBox[
        StyleBox[
         PaneBox[
          TagBox[
           GridBox[{{
              TagBox[
               GridBox[{{
                  GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                   ImageSize -> {20, 10}, PlotRangePadding -> None, 
                   ImagePadding -> 1, 
                   BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                  GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                   ImageSize -> {20, 10}, PlotRangePadding -> None, 
                   ImagePadding -> 1, 
                   BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                GridBoxAlignment -> {
                 "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                AutoDelete -> False, 
                GridBoxDividers -> {
                 "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
                GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}],
                "Grid"]}}, 
            GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
            AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
           "Grid"], Alignment -> Left, AppearanceElements -> None, 
          ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"],
          LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
        Background -> Automatic, StripOnInput -> False]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                    ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], "}"}],
            ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
     NCache[Scaled[{Rational[3, 4], Rational[1, 4]}], Scaled[{0.75, 0.25}]], 
     ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesOrigin->{-0.4, -26.381175362288054`},
   CoordinatesToolOptions:>{"DisplayFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& ), "CopiedValueFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& )},
   Frame->{True, False, False, True},
   FrameLabel->{{"", 
      FormBox["\"Rate of rescue\"", TraditionalForm]}, {
      FormBox["\"Wildtype growth rate\"", TraditionalForm], ""}},
   FrameTicks->{{None, {{-25.328436022934504`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
          TraditionalForm]}, {-23.025850929940457`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
          TraditionalForm]}, {-20.72326583694641, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-18.420680743952367`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-16.11809565095832, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-13.815510557964274`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-24.635288842374557`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-24.229823734266393`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.942141661814613`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.7189981105004, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.536676553706446`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.38252587387919, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.248994481254666`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.131211445598282`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-22.33270374938051, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.927238641272346`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.639556568820566`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.416413017506358`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.234091460712403`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.079940780885142`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.94640938826062, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.82862635260424, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.030118656386467`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.624653548278303`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.33697147582652, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.11382792451231, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.931506367718356`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.7773556878911, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.643824295266576`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.526041259610192`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.72753356339242, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.322068455284256`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.034386382832476`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.811242831518264`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.62892127472431, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.474770594897052`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.34123920227253, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.223456166616145`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-15.424948470398375`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-15.01948336229021, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.73180128983843, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.508657738524219`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.326336181730264`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.172185501903007`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.038654109278484`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-13.9208710736221, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {True, False}},
   GridLines->{None, None},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.4, -0.05}, {-26.381175362288054`, -14.576806419697158`}},
   PlotRangeClipping->True,
   PlotRangePadding->{
     Scaled[0.02], 
     Scaled[0.02]},
   Ticks->{Automatic, {{-25.328436022934504`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-23.025850929940457`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-20.72326583694641, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-18.420680743952367`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-24.635288842374557`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-24.229823734266393`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.942141661814613`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.7189981105004, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.536676553706446`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.38252587387919, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.248994481254666`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.131211445598282`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-22.33270374938051, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-21.927238641272346`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-21.639556568820566`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-21.416413017506358`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-21.234091460712403`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-21.079940780885142`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-20.94640938826062, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-20.82862635260424, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-20.030118656386467`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-19.624653548278303`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-19.33697147582652, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-19.11382792451231, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-18.931506367718356`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-18.7773556878911, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-18.643824295266576`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-18.526041259610192`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.72753356339242, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.322068455284256`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.034386382832476`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.811242831518264`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.62892127472431, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.474770594897052`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.34123920227253, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.223456166616145`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.424948470398375`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.01948336229021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.73180128983843, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.508657738524219`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.326336181730264`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.172185501903007`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.038654109278484`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.9208710736221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Thickness[Large], 
         Line[CompressedData["
1:eJwBYQKe/SFib1JlAgAAACUAAAACAAAAwPbwiZmZ2b9yEWO1lGE6wLSS4bff
fNm/mOZWaGFKOsCpLtLlJWDZv7p6HKc+MzrAkmazQbIm2b9w8bb5KgU6wGTW
dfnKs9i/Iy7JUcypOcA5Urbmp7rXv4vRAoxU5zjA49rvWwfS1r+s4hVLWDY4
wNdKYwD37dW/N6kXmz+NN8D8VpIikvbUvz5HbVfk2jbA9m+6zK8P1L/hv9bo
Ujk2wCIlnvR4FdO/YTn+YLOPNcCXwbtL0h/SvxydTKDc7jTA4WrSKq460b+W
bukeD140wF2wpIc1QtC/4zDD1efGM8BcBeDYfrTOv7u/nxN2PzPAkXjqALPt
zL+T3S2fJcAywCkkbCQ+AMu/gt0sJFA8MsBr6d9XzjPJv2oOaVRlxzHAEOfK
hrVAx79GKdnxhE8xwEizKRS9VsW/EV2Z7v/gMMAqmXqxyY3Dv3miDIyJgDDA
b7dCSi2ewb8vNopEXh8wwL3e+eUrn7+/5qe4k9GXL8Biv1wuq7S7v2/uxUdK
8y7ALD2nM2vct79qy+o95WIuwEvu1Vg1RrS/fRY7ThLsLcCIkllcxMmzv9wD
yrYt3S3AxDbdX1NNs79Qw8o+lM4twD5/5GZxVLK/MWU3KUSyLcAwEPN0rWKw
v74Aq/g5fS3AYjKFz+Lfr78Gvi/Lr3EtwGNEJLVq+q6/3rAwC2hmLcBmaGKA
ei+tvwCOsRGhUC3AaHoBZgJKrL+H+8R4IkYtwGmMoEuKZKu/Fid/juc7LcBq
nj8xEn+qvxQZwKTwMS3AbLDeFpqZqb99mw0OPigtwBqAOig=
          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Thickness[Large], 
         Line[CompressedData["
1:eJwBYQKe/SFib1JlAgAAACUAAAACAAAAwPbwiZmZ2b+1Sa7yOGE6wLSS4bff
fNm/JP+sjgVKOsCpLtLlJWDZv2kybLbiMjrAkmazQbIm2b+dzcXazgQ6wGTW
dfnKs9i/pIOD1W+pOcA5Urbmp7rXv7qGg0H35jjA49rvWwfS1r/zCxY7+jU4
wNdKYwD37dW/1QaixOCMN8D8VpIikvbUv9eyCqSE2jbA9m+6zK8P1L/lTL1h
8jg2wCIlnvR4FdO//fQk7lGPNcCXwbtL0h/SvwDLUD967jTA4WrSKq460b8w
u4rZq100wF2wpIc1QtC/5YeVkYPGM8BcBeDYfrTOv9mahdoQPzPAkXjqALPt
zL9KXQpvv78ywCkkbCQ+AMu/DxnZ3+g7MsBr6d9XzjPJv73wVAb9xjHAEOfK
hrVAx7/z0XV6G08xwEizKRS9VsW/5uR3SZXgMMAqmXqxyY3Dvz06NMQdgDDA
b7dCSi2ewb8w8aU28R4wwL3e+eUrn7+/f+T4AfWWL8Biv1wuq7S7vzdVw/Jq
8i7ALD2nM2vct78zzwgYA2IuwEvu1Vg1RrS/PLOtbi3rLcCIkllcxMmzv+Jp
u3ZI3C3AxDbdX1NNs7/ukMCdrs0twD5/5GZxVLK/mMvCxF2xLcAwEPN0rWKw
v6medwdSfC3AYjKFz+Lfr7/ecGV9x3AtwGNEJLVq+q6/Z1RgYH9lLcBmaGKA
ei+tvzUnhKu3Ty3AaHoBZgJKrL9z1D60OEUtwGmMoEuKZKu/d5Ata/06LcBq
nj8xEn+qv9x6LyIGMS3AbLDeFpqZqb+9cckrUyctwAVFQ5g=
          "]]}}}, {
       GraphicsComplex[{{-0.4, -26.64226950360934}, {-0.35000000000000003`, \
-24.1611192741705}, {-0.30000000000000004`, -21.902815523281163`}, {-0.25, \
-19.888518162389452`}, {-0.2, -18.142967919806935`}, {-0.15000000000000002`, \
-16.695397391937334`}, {-0.09999999999999998, -15.580763856731915`}, \
{-0.04999999999999999, -14.841454757718118`}, {-0.4, -26.64226950360934}, \
{-0.35000000000000003`, -24.1611192741705}, {-0.30000000000000004`, \
-21.902815523281163`}, {-0.25, -19.888518162389452`}, {-0.2, \
-18.142967919806935`}, {-0.15000000000000002`, -16.695397391937334`}, \
{-0.09999999999999998, -15.580763856731915`}, {-0.04999999999999999, \
-14.841454757718118`}}, {{{
           Hue[0.67, 0.6, 0.6], 
           GrayLevel[0], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 9], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 10], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 11], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 12], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 13], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 14], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 15], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 16]}, {}}}], {}}}, {
     Ticks -> {Automatic, {{-25.328436022934504`, 
          Superscript[10, -11]}, {-23.025850929940457`, 
          Superscript[10, -10]}, {-20.72326583694641, 
          Superscript[10, -9]}, {-18.420680743952367`, 
          Superscript[10, -8]}, {-16.11809565095832, 
          Superscript[10, -7]}, {-13.815510557964274`, 
          Superscript[10, -6]}, {-24.635288842374557`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-24.229823734266393`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.942141661814613`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.7189981105004, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.536676553706446`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.38252587387919, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.248994481254666`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.131211445598282`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-22.33270374938051, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-21.927238641272346`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-21.639556568820566`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-21.416413017506358`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-21.234091460712403`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-21.079940780885142`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-20.94640938826062, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-20.82862635260424, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-20.030118656386467`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-19.624653548278303`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-19.33697147582652, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-19.11382792451231, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-18.931506367718356`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-18.7773556878911, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-18.643824295266576`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-18.526041259610192`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-17.72753356339242, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-17.322068455284256`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-17.034386382832476`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.811242831518264`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.62892127472431, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.474770594897052`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.34123920227253, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.223456166616145`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-15.424948470398375`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-15.01948336229021, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-14.73180128983843, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-14.508657738524219`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-14.326336181730264`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-14.172185501903007`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-14.038654109278484`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-13.9208710736221, "", {0.00375, 0.}, {
           Thickness[0.001]}}}}, GridLines -> {None, None}, 
      FrameTicks -> {{None, {{-25.328436022934504`, 
           Superscript[10, -11]}, {-23.025850929940457`, 
           Superscript[10, -10]}, {-20.72326583694641, 
           Superscript[10, -9]}, {-18.420680743952367`, 
           Superscript[10, -8]}, {-16.11809565095832, 
           Superscript[10, -7]}, {-13.815510557964274`, 
           Superscript[10, -6]}, {-24.635288842374557`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-24.229823734266393`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.942141661814613`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.7189981105004, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.536676553706446`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.38252587387919, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.248994481254666`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.131211445598282`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-22.33270374938051, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-21.927238641272346`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-21.639556568820566`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-21.416413017506358`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-21.234091460712403`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-21.079940780885142`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-20.94640938826062, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-20.82862635260424, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-20.030118656386467`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-19.624653548278303`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-19.33697147582652, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-19.11382792451231, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-18.931506367718356`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-18.7773556878911, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-18.643824295266576`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-18.526041259610192`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-17.72753356339242, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-17.322068455284256`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-17.034386382832476`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.811242831518264`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.62892127472431, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.474770594897052`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.34123920227253, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.223456166616145`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-15.424948470398375`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-15.01948336229021, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-14.73180128983843, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-14.508657738524219`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-14.326336181730264`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-14.172185501903007`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-14.038654109278484`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-13.9208710736221, "", {0.00375, 0.}, {
            Thickness[0.001]}}}}, {True, False}}, 
      AxesOrigin -> {-0.4, -26.381175362288054`}, 
      PlotRange -> {{-0.4, -0.05}, {-26.381175362288054`, \
-14.576806419697158`}}, AspectRatio -> GoldenRatio^(-1), Axes -> True, 
      AxesOrigin -> {-0.4, -26.5}, 
      CoordinatesToolOptions -> {"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )}, Frame -> {True, False, False, True}, 
      FrameLabel -> {{Null, "Rate of rescue"}, {
        "Wildtype growth rate", Null}}, 
      FrameTicks -> {True, False, False, True}, LabelStyle -> 
      Directive[12, FontFamily -> "Helvetica"], Method -> {}, 
      PlotRange -> {{-0.4, -0.05}, {-26.381175362288054`, \
-14.576806419697158`}}, PlotRangeClipping -> True, PlotRangePadding -> {
        Scaled[0.02], 
        Scaled[0.02]}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          Thickness[Large]], 
         Directive[
          RGBColor[0.6, 0.24, 0.4428931686004542], 
          Thickness[Large]]}, {
         Style["approx", 12, FontFamily -> "Helvetica"], 
         Style["simpler approx", 12, FontFamily -> "Helvetica"]}, 
        LegendLayout -> "Column"]], 
      Scaled[{
        Rational[3, 4], 
        Rational[1, 4]}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{{3.7693534369036016`*^9, 3.7693534855567827`*^9}, {
   3.769353556438634*^9, 3.7693535632597857`*^9}, {3.769353595331696*^9, 
   3.769353613432356*^9}, {3.771606514468543*^9, 3.771606532933457*^9}, {
   3.771606570979768*^9, 3.771606601260322*^9}, 3.771606640177038*^9, {
   3.7716067478929043`*^9, 3.771606789781802*^9}, 3.78225283946729*^9}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Approximate probability of rescue: sufficiently non-critical single mutants\
\>", "Subsection",
 CellChangeTimes->{{3.7438754316118402`*^9, 3.7438754680052223`*^9}, {
   3.743875503590057*^9, 3.7438755299029627`*^9}, {3.743875693004032*^9, 
   3.7438756957235518`*^9}, {3.745607074821949*^9, 3.7456070749359827`*^9}, {
   3.751059305956018*^9, 3.7510593278531027`*^9}, {3.751060788094961*^9, 
   3.751060788196854*^9}, {3.751060832982252*^9, 3.751060844042348*^9}, {
   3.7510748669887342`*^9, 3.75107487202873*^9}, 3.7510749125766373`*^9, {
   3.751075017284211*^9, 3.751075017799418*^9}}],

Cell[CellGroupData[{

Cell["Approximation 1", "Subsubsection",
 CellChangeTimes->{{3.751297826628758*^9, 3.751297838657942*^9}, {
   3.769267756190926*^9, 3.769267757757966*^9}, 3.771762197075107*^9}],

Cell[TextData[{
 "When ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", ">>", 
    SqrtBox[
     RowBox[{"\[CapitalLambda]", "/", "2"}]]}], TraditionalForm]]],
 " the probability of 2-step rescue from this single mutant lineage, as \
calculated above, is roughly ",
 Cell[BoxData[
  FormBox[
   FractionBox["\[CapitalLambda]", 
    RowBox[{"Abs", "[", "m", "]"}]], TraditionalForm]]],
 ". "
}], "Text",
 CellChangeTimes->{{3.7510593328253183`*^9, 3.751059387414235*^9}, {
  3.7510595206997747`*^9, 3.75105963596378*^9}, {3.751059688159315*^9, 
  3.7510597254626513`*^9}, {3.7510602586473217`*^9, 3.7510602663543453`*^9}, {
  3.751060442136313*^9, 3.751060447200469*^9}, {3.751075027103059*^9, 
  3.7510750580413857`*^9}, {3.769267557699291*^9, 3.769267570482304*^9}}],

Cell[TextData[{
 "We have seen above that the solutions to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["m", "2"], "="}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{"\[CapitalLambda]", "[", "m", "]"}], "/", "2"}]}], 
   TraditionalForm]]],
 " can be approximated well by ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "=", 
    RowBox[{"\[PlusMinus]", 
     SqrtBox[
      RowBox[{
       RowBox[{"\[CapitalLambda]", "[", "0", "]"}], "/", "2"}]]}]}], 
   TraditionalForm]]],
 ".  "
}], "Text",
 CellChangeTimes->{{3.751061306860725*^9, 3.751061462931612*^9}, {
   3.7510750917377377`*^9, 3.751075109029397*^9}, {3.769267573673771*^9, 
   3.769267586414703*^9}, 3.771274783002818*^9}],

Cell["\<\
Check the contribution of single mutant growth rates to 2-step sufficiently \
critical rescue\
\>", "Text",
 CellChangeTimes->{{3.75106209545363*^9, 3.751062099763571*^9}, {
   3.751062143875153*^9, 3.751062179866688*^9}, 3.7510751228026323`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.3"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
      RowBox[{"prescuem", "[", 
       RowBox[{"m1", ",", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
      FractionBox[
       RowBox[{" ", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], 
       RowBox[{"Abs", "[", "m1", "]"}]], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "pr0"}], "-", "m1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"pr0", "-", "m1"}], ")"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"m1", ",", 
      RowBox[{
       RowBox[{"50", "m1"}], "/.", "mneg"}], ",", 
      RowBox[{
       RowBox[{"10", "m1"}], "/.", "mpos"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "All"}], "}"}]}], ",", 
    RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"LineLegend", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<exact\>\"", ",", "\"\<non-critical\>\""}], "}"}], "]"}]}],
     ",", 
    RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7510622484477882`*^9, 3.7510623899214077`*^9}, {
   3.751062473276165*^9, 3.751062530490876*^9}, 3.751062563427968*^9, {
   3.751062594941642*^9, 3.7510626740085497`*^9}, {3.751062706742158*^9, 
   3.7510627719753103`*^9}, {3.751062825650064*^9, 3.751062839069113*^9}, {
   3.751062891684408*^9, 3.7510628936156187`*^9}, {3.751062951583514*^9, 
   3.7510629518293257`*^9}, {3.7510751327453938`*^9, 3.751075187438393*^9}, {
   3.751075227865163*^9, 3.751075253129315*^9}, {3.751075331833404*^9, 
   3.751075338861655*^9}, {3.751075400453147*^9, 3.7510754285434923`*^9}, {
   3.751683979498103*^9, 3.751683979880788*^9}, {3.769267618996566*^9, 
   3.769267716256198*^9}, {3.7699685924844303`*^9, 3.769968594644225*^9}, 
   3.782252859303173*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJyF1nk01VsbB3AK6coUdeskw61Eozj3OuQ+v44GGTOUbpJKKWQ+ZUpSkhQS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     "], {{{}, {
        Hue[0.67, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[CompressedData["
1:eJwt0lVTFgAUBNCPkJROCelGQJAGSaW7QVpCaZRuhh/OYYaHs3ff9+ZtHE0e
BgcCgSBe3m+YCOeT/swIR1RwRTurpPPEMIeUc0kbK6TxyBAHlHFBK8uk8sAg
+5RyTgu/SOGeAfYo4Yxmlkjmjn7+Usx/mlgkiVv6+EMR/2hkgURu+MkuhZzS
wDwJXPODHQo4oZ454ullm3y+MUscPWyRxzF1zBBLN7/JpZZpYuhikxy+MsVH
OtngMzVMEk0UkUQQ/rYbH8immglCyaKKcULoYJ1MvjDG2w98Z40MKhnlFcKR
I4w=
          "]]]}, {}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[{
          
          PolygonBox[{{151, 261, 155, 259, 207, 241, 173, 251, 191, 225, 154, 
           258, 206, 240, 172, 250, 190, 224, 153, 257, 205, 239, 171, 249, 
           189, 223, 152, 256, 204, 238, 170, 248, 188, 222}}], 
          PolygonBox[CompressedData["
1:eJwNx8k2ggEAgNGf04v0Sh7AwgPkIQwhY2glhYoVmaeNIeNKyGxDZivjpugu
7vnOF25qbojUB0FQRyMthMyvrnNLgn8OeWeKH9a4YZg/Dnhjkm9WuWaIKvu8
kuOLFa4YpMIeL2T5ZJlL4uzyTIYlLhhghycm+GCRc/op8Mg4C5zRxzYPjDFP
iV62KJNmjlN66CZGF510ECXFLCe0M0qeY9rY5J4kMxRpZYM7RpjmiBqpsUb8

           "]]}]}, {}, {}, {}, {}, {}, {}}, {{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        LineBox[{1, 78, 44, 26, 96, 62, 2, 79, 45, 27, 97, 63, 3, 80, 46, 28, 
         4, 81, 47, 29, 5, 6, 7, 8, 9, 10, 11, 82, 48, 30, 98, 64, 12, 83, 49,
          31, 99, 65, 13, 84, 50, 32, 100, 66, 14, 85, 51, 112, 33, 101, 67, 
         15, 86, 52, 34, 102, 68, 16, 87, 53, 113, 35, 103, 69, 122, 17, 88, 
         54, 114, 36, 104, 70, 123, 18, 89, 55, 115, 37, 105, 71, 124, 19, 90,
          56, 116, 38, 106, 72, 125, 20, 91, 57, 117, 39, 107, 73, 126, 21, 
         92, 58, 118, 40, 108, 74, 127, 22, 93, 59, 119, 41, 109, 75, 128, 23,
          94, 60, 120, 42, 110, 76, 129, 24, 95, 61, 121, 43, 111, 77, 130, 
         25}]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        LineBox[CompressedData["
1:eJwV0dc60AEAxuE/rsQtuQQXwDV4bLJFtmyyGlb23puyK5uEUCHF6+B9fgff
4RceGR0RFRIEQQyxLNBMMbsMEMciLZSwxyDxLNFKKQks85YyEkkimRRSeUEa
K7yjnH2GSGeV97zmgGEy+MQHKjhkhEw+08YVlRwxShZrtFPFMWNks04H11Rz
wjgP5LBBJzfUcMoE/8hlky5+Uct3JvnPS7b4yG/qOGOKR/LYpps/1PODafLZ
oYdbGjhnhsBJr+QLvdzxhgtmn2d7gX6lj3sauWSOUHuhfqOfvzTxk3nC7EX6
BDs+YHw=
         "]]}}}], AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
    Method -> {"AxesInFront" -> True}, 
    PlotRange -> {{-0.22375245023863546`, 0.04866257535817323}, {0, All}}, 
    PlotRangeClipping -> True, PlotRangePadding -> {
      Scaled[0.02], Automatic}],
   TemplateBox[{"\"exact\"", "\"non-critical\""}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.7510622758402033`*^9, 3.751062287300033*^9}, {
   3.7510623285961533`*^9, 3.751062392798016*^9}, 3.751062530149672*^9, 
   3.751062677958152*^9, 3.7510627542474623`*^9, 3.7510628110695887`*^9, 
   3.7510628776003532`*^9, 3.751062930710997*^9, 3.751062998904624*^9, 
   3.7510752324366627`*^9, 3.751075296585766*^9, 3.751075377152327*^9, 
   3.7516840268054256`*^9, 3.751685277716069*^9, 3.7692677021570683`*^9, 
   3.769267751692905*^9, 3.782252871296193*^9}]
}, Closed]],

Cell["\<\
And let\[CloseCurlyQuote]s check the total rates of rescue across all m1\
\>", "Text",
 CellChangeTimes->{{3.7510630366769114`*^9, 3.751063040284843*^9}, {
  3.751063169314378*^9, 3.751063175934472*^9}, {3.7510636161298027`*^9, 
  3.75106362244626*^9}, {3.751075434904291*^9, 3.751075435260522*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"n0", "=", 
   SuperscriptBox["10", "4"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "4"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"mwt", ",", 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"fm", "[", 
             RowBox[{
             "m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
             "]"}], 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
            RowBox[{"prescuem", "[", 
             RowBox[{"m1", ",", 
              RowBox[{"\[CapitalLambda]1", "[", 
               RowBox[{
               "m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
               "]"}]}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"m1", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"mwt", ",", 
         RowBox[{
          RowBox[{"-", "0.8"}], "mmax"}], ",", 
         RowBox[{
          RowBox[{"-", "0.1"}], "mmax"}], ",", 
         RowBox[{"0.1", "mmax"}]}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"mwt", ",", 
         RowBox[{
          RowBox[{"NIntegrate", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"fm", "[", 
              RowBox[{
              "m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
              "]"}], 
             FractionBox[
              RowBox[{" ", 
               RowBox[{"\[CapitalLambda]1", "[", 
                RowBox[{
                "m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
                "]"}]}], 
              RowBox[{"Abs", "[", "m1", "]"}]]}], "\[IndentingNewLine]", ",", 
            
            RowBox[{"{", 
             RowBox[{"m1", ",", "mwt", ",", 
              RowBox[{"-", "pr0"}]}], "}"}]}], "]"}], "+", 
          RowBox[{"NIntegrate", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"fm", "[", 
              RowBox[{
              "m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
              "]"}], 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
             FractionBox[
              RowBox[{" ", 
               RowBox[{"\[CapitalLambda]1", "[", 
                RowBox[{
                "m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
                "]"}]}], 
              RowBox[{"Abs", "[", "m1", "]"}]]}], "\[IndentingNewLine]", ",", 
            
            RowBox[{"{", 
             RowBox[{"m1", ",", "pr0", ",", "mmax"}], "}"}]}], "]"}]}]}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"mwt", ",", 
         RowBox[{
          RowBox[{"-", "0.8"}], "mmax"}], ",", 
         RowBox[{
          RowBox[{"-", "0.1"}], "mmax"}], ",", 
         RowBox[{"0.1", "mmax"}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "}"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{"ListLogPlot", "[", 
    RowBox[{"%", ",", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"LineLegend", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<exact\>\"", ",", "\"\<non-critical\>\""}], "}"}], 
       "]"}]}]}], "]"}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "n0"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.751063189929034*^9, 3.751063195260857*^9}, {
  3.751063251777727*^9, 3.751063315775334*^9}, {3.751063345833967*^9, 
  3.7510634151982183`*^9}, {3.75106350691444*^9, 3.7510635766974697`*^9}, {
  3.7510636416522617`*^9, 3.7510636671136007`*^9}, {3.751063706981538*^9, 
  3.751063818145526*^9}, {3.751063878393749*^9, 3.751063918090982*^9}, {
  3.7510754524207277`*^9, 3.751075515053173*^9}, {3.7510758146376743`*^9, 
  3.751075849277143*^9}, {3.769267809372196*^9, 3.769267839627472*^9}, {
  3.769968599633926*^9, 3.7699686028987827`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {
       Hue[0.67, 0.6, 0.6], 
       PointBox[{{-0.4, -16.43552134008686}, {-0.35000000000000003`, \
-14.715596947707956`}, {-0.30000000000000004`, -13.027482007673905`}, {-0.25, \
-11.409588281632345`}, {-0.2, -9.921167772922393}, {-0.15000000000000002`, \
-8.626058208197255}, {-0.09999999999999998, -7.5835492285794865`}, \
{-0.04999999999999999, -6.85450399706718}}]}, {
       Hue[0.9060679774997897, 0.6, 0.6], 
       PointBox[{{-0.4, -16.45357356867548}, {-0.35000000000000003`, \
-14.755530530822778`}, {-0.30000000000000004`, -13.100352727155963`}, {-0.25, \
-11.52100263320676}, {-0.2, -10.06835087049367}, {-0.15000000000000002`, \
-8.799360567021573}, {-0.09999999999999998, -7.769399842720846}, \
{-0.04999999999999999, -7.039074166667154}}]}, {}}, {}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {-0.4, -16.45357356867548}, 
    CoordinatesToolOptions :> {"DisplayFunction" -> ({
        Part[#, 1], 
        Exp[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Part[#, 1], 
        Exp[
         Part[#, 2]]}& )}, FrameTicks -> {{{{-16.11809565095832, 
         FormBox[
          TemplateBox[{"10", 
            RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
           TraditionalForm]}, {-11.512925464970229`, 
         FormBox[
          TemplateBox[{"10", 
            RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
           TraditionalForm]}, {-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {-13.633189001170319`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-12.98260143502917, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-12.591735126342158`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-12.311433161188, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-12.09274396022317, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-11.913403031567354`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-11.761386824268728`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-11.629459281226179`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-9.028018815182229, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.377431249041079, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.986564940354067, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.706262975199909, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.487573774235079, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.308232845579262, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.156216638280637, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.024289095238088, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.422848629194137, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.7722610630529876`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.3813947543659757`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.101092789211817, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.882403588246988, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.703062659591171, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.551046452292545, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.419118909249997, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{-16.11809565095832, 
         FormBox["\"\"", TraditionalForm]}, {-11.512925464970229`, 
         FormBox["\"\"", TraditionalForm]}, {-6.907755278982137, 
         FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["\"\"", TraditionalForm]}, {-13.633189001170319`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-12.98260143502917, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-12.591735126342158`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-12.311433161188, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-12.09274396022317, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-11.913403031567354`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-11.761386824268728`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-11.629459281226179`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-9.028018815182229, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.377431249041079, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.986564940354067, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.706262975199909, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.487573774235079, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.308232845579262, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.156216638280637, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.024289095238088, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.422848629194137, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.7722610630529876`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.3813947543659757`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.101092789211817, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.882403588246988, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.703062659591171, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.551046452292545, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.419118909249997, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}, {Automatic, Automatic}}, 
    GridLines -> {None, None}, Method -> {}, 
    PlotRange -> {{-0.4, 0.}, {-16.45357356867548, 0}}, PlotRangeClipping -> 
    True, PlotRangePadding -> {
      Scaled[0.02], {
       Scaled[0.02], 
       Scaled[0.02]}}, Ticks -> {Automatic, {{-16.11809565095832, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-11.512925464970229`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-6.907755278982137, 
        FormBox["0.001`", TraditionalForm]}, {-2.3025850929940455`, 
        FormBox["0.1`", TraditionalForm]}, {-13.633189001170319`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.98260143502917, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.591735126342158`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.311433161188, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.09274396022317, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.913403031567354`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.761386824268728`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.629459281226179`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.028018815182229, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-8.377431249041079, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.986564940354067, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.706262975199909, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.487573774235079, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.308232845579262, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.156216638280637, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.024289095238088, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.422848629194137, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.7722610630529876`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.3813947543659757`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.101092789211817, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.882403588246988, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.703062659591171, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.551046452292545, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.419118909249997, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}],
   TemplateBox[{"\"exact\"", "\"non-critical\""}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], {}}}, 
                 AspectRatio -> Full, ImageSize -> {20, 10}, PlotRangePadding -> 
                 None, ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542]], {}}}, 
                 AspectRatio -> Full, ImageSize -> {20, 10}, PlotRangePadding -> 
                 None, ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"RGBColor", "[", 
                 RowBox[{"0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                 "]"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"RGBColor", "[", 
                 RowBox[{"0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.7510634886257*^9, 3.751063593683093*^9, 
  3.7510636897762117`*^9, 3.751063814157774*^9, 3.751063846318844*^9, 
  3.751063897768283*^9, 3.7510640120826483`*^9, 3.7510757332639713`*^9, 
  3.7510760047877007`*^9, 3.769267967551639*^9, 3.782252997111169*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Approximation 2", "Subsubsection",
 CellChangeTimes->{{3.751297852543672*^9, 3.751297874251048*^9}, {
  3.769269178870277*^9, 3.769269217245685*^9}, {3.769433247403956*^9, 
  3.769433248427067*^9}, {3.771762208387211*^9, 3.771762209139366*^9}}],

Cell["\<\
We can next borrow the approximation of \[CapitalLambda]1 from Anciaux et al. \
(their eqn A12 without the 1/mwt term)\
\>", "Text",
 CellChangeTimes->{{3.751298365607855*^9, 3.751298378172474*^9}, {
  3.769267909545982*^9, 3.769267935161127*^9}, {3.769268097088586*^9, 
  3.769268106495183*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Abs", "[", "mwt", "]"}], "AnciauxEqnA12"}]], "Input",
 CellChangeTimes->{{3.751298431527297*^9, 3.751298451614417*^9}, {
   3.751298494328712*^9, 3.7512985774951553`*^9}, 3.751298650253852*^9, {
   3.751299039773719*^9, 3.751299065717457*^9}, 3.751299319311005*^9, {
   3.769267941269005*^9, 3.769267943264698*^9}, {3.7692680024800167`*^9, 
   3.769268004775441*^9}, {3.769268042306395*^9, 3.7692680885852337`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"U", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox["\[Psi]wt", "2"]}], ")"}], 
    RowBox[{
     FractionBox["1", "2"], "-", "\[Theta]"}]], " ", 
   RowBox[{"Abs", "[", "mwt", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "\[Alpha]"}]], 
      RowBox[{
       SqrtBox["\[Pi]"], " ", 
       SqrtBox["\[Alpha]"]}]], "-", 
     RowBox[{"Erfc", "[", 
      SqrtBox["\[Alpha]"], "]"}]}], ")"}]}], 
  RowBox[{"1", "-", 
   FractionBox["\[Psi]wt", "4"]}]]], "Output",
 CellChangeTimes->{
  3.751298420647848*^9, {3.7512984964328737`*^9, 3.751298577834381*^9}, 
   3.751298650821396*^9, 3.751299073167441*^9, 3.7512993210738277`*^9, 
   3.769267967687941*^9, 3.7692680054902477`*^9, {3.769268047859935*^9, 
   3.769268089240568*^9}, 3.782253015880797*^9}]
}, Closed]],

Cell["Check contributions of m1", "Text",
 CellChangeTimes->{{3.75129858402555*^9, 3.751298584471786*^9}, {
  3.769268902309002*^9, 3.7692689074753428`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.3"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
      RowBox[{"prescuem", "[", 
       RowBox[{"m1", ",", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
      FractionBox[
       RowBox[{" ", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], 
       RowBox[{"Abs", "[", "m1", "]"}]], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "pr0"}], "-", "m1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"pr0", "-", "m1"}], ")"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"fm", "[", 
                RowBox[{
                "m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
                "]"}], 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
               FractionBox[
                RowBox[{" ", 
                 RowBox[{
                  RowBox[{"Abs", "[", "m1", "]"}], " ", "AnciauxEqnA12"}]}], 
                RowBox[{"Abs", "[", "m1", "]"}]]}], "/.", 
              RowBox[{"\[Psi]wt", "\[Rule]", "\[Psi]"}]}], "/.", 
             RowBox[{"m", "\[Rule]", 
              RowBox[{"mmax", " ", "\[Psi]", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"\[Psi]", "/", "4"}]}], ")"}]}]}]}], "/.", 
            RowBox[{"\[Alpha]", "\[Rule]", 
             FractionBox[
              RowBox[{"\[Rho]max", " ", 
               SuperscriptBox["\[Psi]", "2"]}], "4"]}]}], "/.", 
           RowBox[{"\[Psi]", "\[Rule]", 
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SqrtBox[
                RowBox[{"1", "-", 
                 FractionBox["m", "mmax"]}]]}], ")"}]}]}]}], "/.", 
          RowBox[{"\[Rho]max", "\[Rule]", 
           RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
         RowBox[{"\[Theta]", "\[Rule]", 
          RowBox[{"n", "/", "2"}]}]}], "/.", 
        RowBox[{"m", "\[Rule]", "m1"}]}], ")"}], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "pr0"}], "-", "m1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"pr0", "-", "m1"}], ")"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"m1", ",", 
      RowBox[{
       RowBox[{"50", "m1"}], "/.", "mneg"}], ",", 
      RowBox[{
       RowBox[{"10", "m1"}], "/.", "mpos"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "All"}], "}"}]}], ",", 
    RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"LineLegend", "[", 
      RowBox[{"{", 
       RowBox[{
       "\"\<exact\>\"", ",", "\"\<non-critical\>\"", ",", 
        "\"\<non-critical anciaux\>\""}], "}"}], "]"}]}], ",", 
    RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7510622484477882`*^9, 3.7510623899214077`*^9}, {
   3.751062473276165*^9, 3.751062530490876*^9}, 3.751062563427968*^9, {
   3.751062594941642*^9, 3.7510626740085497`*^9}, {3.751062706742158*^9, 
   3.7510627719753103`*^9}, {3.751062825650064*^9, 3.751062839069113*^9}, {
   3.751062891684408*^9, 3.7510628936156187`*^9}, {3.751062951583514*^9, 
   3.7510629518293257`*^9}, {3.7510751327453938`*^9, 3.751075187438393*^9}, {
   3.751075227865163*^9, 3.751075253129315*^9}, {3.751075331833404*^9, 
   3.751075338861655*^9}, {3.751075400453147*^9, 3.7510754285434923`*^9}, {
   3.751298603496088*^9, 3.751298619644992*^9}, {3.751298666312831*^9, 
   3.751298685790444*^9}, {3.7512987560965652`*^9, 3.75129876078164*^9}, 
   3.751298882585372*^9, {3.751299095508382*^9, 3.7512991099339523`*^9}, 
   3.7512991595807037`*^9, {3.769268148632958*^9, 3.769268191326717*^9}, {
   3.769268274695397*^9, 3.769268334384335*^9}, {3.7692683680850058`*^9, 
   3.7692683689144506`*^9}, {3.769268420749902*^9, 3.7692684229390297`*^9}, {
   3.769268853037169*^9, 3.769268869150824*^9}, 3.76926892183434*^9, {
   3.7699686201557913`*^9, 3.769968623947817*^9}, 3.78225290707362*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJyl2Gk01VvYAHCUocyRGwndQqRIpwy5++/QZAzNxhIlmZUhEsk8JFOmMmae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     "], {{{}, {
        Hue[0.67, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[CompressedData["
1:eJwt0tVSFQAABNBLIx3SIN0liDTSHUp3SJqU0kgNL/jVHGZ4OLv7AZu/eTC1
HxwIBIJ4fO0n8Z8M+4FxDqjkgg7WSeeeMfap4Jx21kjjjlF+U84ZbaySyi0j
/KKMU1pZIYUbhvlJKSe0sMxb/jHED0r4SzNLJHPNIN8p5g9NLJLEFQN8o4hj
GlkgkUv62aOQIz4yTwJ97FJAA3PE08sO+RzygVni6GGbPOqZIZZutsiljmli
6GKTd7xnimiieEMkEYQTRg61TBJKNjV8IYROvpJFNZ95+cAnNsikigmeAdjr
JJI=
          "]]]}, {}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[{
          
          PolygonBox[{{151, 392, 155, 259, 207, 241, 173, 251, 191, 225, 154, 
           258, 206, 240, 172, 250, 190, 224, 153, 257, 205, 239, 171, 249, 
           189, 223, 152, 256, 204, 238, 170, 248, 188, 222}}], 
          PolygonBox[CompressedData["
1:eJwV0Ek6wgEAxuE/N+lKHcCiA+gQppAxrJJCZYXMw8aUaUXIvEHmlXGjeC3e
5/d82y8UiYYb64MgqKOBJtqMb13lmiF+2eeVCb5Y4YpBauzxQp5PlrlkgCq7
PJPjgyUuSPDDDk9keWeRc/rZ5pFxFjijjyIPjPHGPKf0ssU9o8xRpodNKmSY
5YRuNrgjzQzHdBGnkw7aif1/xAgFjmglxTQlWljnlmGmOKSZNW5IMskBf2gc
R38=
           "]]}]}, {}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[{
          
          PolygonBox[{{280, 390, 284, 388, 337, 371, 303, 380, 322, 356, 283, 
           387, 336, 370, 302, 379, 321, 355, 282, 386, 335, 369, 301, 378, 
           320, 354, 281, 385, 334, 368, 300, 377, 319, 353}}], 
          PolygonBox[CompressedData["
1:eJwNxjVTggEAANBPDkQMDIzJQERiEjAwFzsmTFTQ885WXAwWxcX/7Rve3Uve
vFUaoSAI2qgTlj+arHHNCL8c0CDPF6tcMUyLfV7J8ckKdYb4YY8XsnywTI1B
vtnlmQzvLHFJgh2emGaRCwbY5pE0Zc7pZ4sHpligSh+b3JNinjN6mWSOU+L0
0E0XncRIMssJHUxQ4pgo4xQ5op0N7hijwCER1rlllBkq/AOvURmY
           
           "]]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, {
       
        Hue[0.67, 0.6, 0.6], 
        LineBox[{1, 78, 44, 26, 96, 62, 2, 79, 45, 27, 97, 63, 3, 80, 46, 28, 
         4, 81, 47, 29, 5, 6, 7, 8, 9, 10, 11, 82, 48, 30, 98, 64, 12, 83, 49,
          31, 99, 65, 13, 84, 50, 32, 100, 66, 14, 85, 51, 112, 33, 101, 67, 
         15, 86, 52, 34, 102, 68, 16, 87, 53, 113, 35, 103, 69, 122, 17, 88, 
         54, 114, 36, 104, 70, 123, 18, 89, 55, 115, 37, 105, 71, 124, 19, 90,
          56, 116, 38, 106, 72, 125, 20, 91, 57, 117, 39, 107, 73, 126, 21, 
         92, 58, 118, 40, 108, 74, 127, 22, 93, 59, 119, 41, 109, 75, 128, 23,
          94, 60, 120, 42, 110, 76, 129, 24, 95, 61, 121, 43, 111, 77, 130, 
         25}]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        LineBox[CompressedData["
1:eJwV0dc60AEAxuE/rsQtuQQXwDV4bLJFtmyyGlb23puyK5uEUCHF6+B9fgff
4RceGR0RFRIEQQyxLNBMMbsMEMciLZSwxyDxLNFKKQks85YyEkkimRRSeUEa
K7yjnH2GSGeV97zmgGEy+MQHKjhkhEw+08YVlRwxShZrtFPFMWNks04H11Rz
wjgP5LBBJzfUcMoE/8hlky5+Uct3JvnPS7b4yG/qOGOKR/LYpps/1PODafLZ
oYdbGjhnhsBJr+QLvdzxhgtmn2d7gX6lj3sauWSOUHuhfqOfvzTxk3nC7EX6
BDs+YHw=
         "]]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        LineBox[CompressedData["
1:eJwV0NVSFAAAQNF1BpCUFKW7REBSurtZSgUBl27pbj6cw8OZuc83L3QYPPgQ
CASeCBNBfpDFOj2EM0012WzQSwQz1JDDR2apJZdI5qgjjyiiiSGWOD4xTz35
xPOLBgrYpI8EfvOTQrboJ5E/NFLENgMksUATxewwSDKLNHNKCbsMcUcKf2nh
jFL2GOaezyzRyjll7DPCA6ks08YF33gfPMojX1ihnUvKOWSMr/yjgyu+859x
nkgjRCfXVHDEBM+ks0oXN1RyzCQvZLBGN7dUccIUr2TyBnlZJPo=
         "]]}}}], 
    AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True,
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
    Method -> {"AxesInFront" -> True}, 
    PlotRange -> {{-0.22375245023863546`, 0.04866257535817323}, {0, All}}, 
    PlotRangeClipping -> True, PlotRangePadding -> {
      Scaled[0.02], Automatic}],
   TemplateBox[{"\"exact\"", "\"non-critical\"", "\"non-critical anciaux\""}, 
    "LineLegend", DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.1421359549995791, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.1421359549995791, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.1421359549995791`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.751298732398884*^9, 3.7512987996695213`*^9, 3.751298923805999*^9, 
   3.751299154270103*^9, 3.7512992011476307`*^9, {3.769268163670035*^9, 
   3.769268193467567*^9}, {3.769268277383369*^9, 3.769268293989855*^9}, 
   3.76926835776435*^9, 3.769268394963409*^9, 3.769268453390215*^9, 
   3.7692689103585367`*^9, 3.769268959816298*^9, 3.7822530275191307`*^9}]
}, Closed]],

Cell["and try with smaller mwt", "Text",
 CellChangeTimes->{{3.769268941669229*^9, 3.769268951948618*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
      RowBox[{"prescuem", "[", 
       RowBox[{"m1", ",", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
      FractionBox[
       RowBox[{" ", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], 
       RowBox[{"Abs", "[", "m1", "]"}]], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "pr0"}], "-", "m1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"pr0", "-", "m1"}], ")"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"fm", "[", 
                RowBox[{
                "m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
                "]"}], 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
               FractionBox[
                RowBox[{" ", 
                 RowBox[{
                  RowBox[{"Abs", "[", "m1", "]"}], " ", "AnciauxEqnA12"}]}], 
                RowBox[{"Abs", "[", "m1", "]"}]]}], "/.", 
              RowBox[{"\[Psi]wt", "\[Rule]", "\[Psi]"}]}], "/.", 
             RowBox[{"m", "\[Rule]", 
              RowBox[{"mmax", " ", "\[Psi]", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"\[Psi]", "/", "4"}]}], ")"}]}]}]}], "/.", 
            RowBox[{"\[Alpha]", "\[Rule]", 
             FractionBox[
              RowBox[{"\[Rho]max", " ", 
               SuperscriptBox["\[Psi]", "2"]}], "4"]}]}], "/.", 
           RowBox[{"\[Psi]", "\[Rule]", 
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SqrtBox[
                RowBox[{"1", "-", 
                 FractionBox["m", "mmax"]}]]}], ")"}]}]}]}], "/.", 
          RowBox[{"\[Rho]max", "\[Rule]", 
           RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
         RowBox[{"\[Theta]", "\[Rule]", 
          RowBox[{"n", "/", "2"}]}]}], "/.", 
        RowBox[{"m", "\[Rule]", "m1"}]}], ")"}], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "pr0"}], "-", "m1"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"pr0", "-", "m1"}], ")"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"m1", ",", 
      RowBox[{
       RowBox[{"50", "m1"}], "/.", "mneg"}], ",", 
      RowBox[{
       RowBox[{"10", "m1"}], "/.", "mpos"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "All"}], "}"}]}], ",", 
    RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"LineLegend", "[", 
      RowBox[{"{", 
       RowBox[{
       "\"\<exact\>\"", ",", "\"\<non-critical\>\"", ",", 
        "\"\<non-critical anciaux\>\""}], "}"}], "]"}]}], ",", 
    RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7510622484477882`*^9, 3.7510623899214077`*^9}, {
   3.751062473276165*^9, 3.751062530490876*^9}, 3.751062563427968*^9, {
   3.751062594941642*^9, 3.7510626740085497`*^9}, {3.751062706742158*^9, 
   3.7510627719753103`*^9}, {3.751062825650064*^9, 3.751062839069113*^9}, {
   3.751062891684408*^9, 3.7510628936156187`*^9}, {3.751062951583514*^9, 
   3.7510629518293257`*^9}, {3.7510751327453938`*^9, 3.751075187438393*^9}, {
   3.751075227865163*^9, 3.751075253129315*^9}, {3.751075331833404*^9, 
   3.751075338861655*^9}, {3.751075400453147*^9, 3.7510754285434923`*^9}, {
   3.751298603496088*^9, 3.751298619644992*^9}, {3.751298666312831*^9, 
   3.751298685790444*^9}, {3.7512987560965652`*^9, 3.75129876078164*^9}, 
   3.751298882585372*^9, {3.751299095508382*^9, 3.7512991099339523`*^9}, 
   3.7512991595807037`*^9, {3.751682917353448*^9, 3.751682917589669*^9}, 
   3.7692689620872183`*^9, {3.7699686332376537`*^9, 3.76996863681141*^9}, 
   3.7822529132883043`*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJyl2Hkw1V34AHC7souEZO1NuPYra99ji1SWbrak7LK+FSJLllAou4gs2Smy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     "], {{{}, {
        Hue[0.67, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[CompressedData["
1:eJwt0mc7FQAABeBrVUjILjKyEtKwK1vZXJVsXYrCNVJCZojHz+CH9vY8Przn
nB9w8kMrwXBkIBCI4OK6L8UVWfY579imkiPa+EomZwyzRQWHtLJABn8J8oty
DmhhnnROGWKTx+zTzBfSOGGQn5SxRxOfSeWYAX7wiF1eM0cKf+hng1J+84pZ
7tLHd0p4SYhkelmnmEY+kUQPaxTRwAyJ3CGB2xRSzzTxPKSOKeIooJZJYsmn
hglu0c0qeVQzzk26WCGXF4xxg7eEecBzRonhDcvk8IyPRNPJEtk8ZYQoOljk
PjtU8YH//2jnG/d4wnv+ASLAKHc=
          "]]]}, {}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[{
          
          PolygonBox[{{158, 418, 162, 274, 221, 259, 183, 268, 204, 242, 161, 
           273, 220, 258, 182, 267, 203, 241, 160, 272, 219, 257, 181, 266, 
           202, 240, 159, 271, 218, 256, 180, 265, 201, 239}}], 
          PolygonBox[CompressedData["
1:eJwN0Lc2w2Ecx+E/R1viHtySSzAYuQ/RW0RicBIlOpNeIsqiRJ/03hZdcDzD
cz7v9/y2t6yiurwqPwiCPCqpodsoYd37mS5K7SP9Y4Jie02fiBOyD/WXcYrs
VX0kxgE/jFHotqIPdLJPjlEy3BNlj29GWOaODiK008YwaW5pZYglbmhhkEWu
aWaABa5oYpcvUsxzSSM7fNLPHBc0kOWDPmY5p55t3ullhjPq2OKNHqY5pZZN
XklS4D+m9IQwG7yQYJJj/gH/Ikq2
           "]]}]}, {}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[{
          
          PolygonBox[{{295, 416, 299, 414, 359, 398, 320, 408, 341, 380, 298, 
           413, 358, 397, 319, 407, 340, 379, 297, 412, 357, 396, 318, 406, 
           339, 378, 296, 411, 356, 395, 317, 405, 338, 377}}], 
          PolygonBox[CompressedData["
1:eJwNxrc2QwEAANDHLwjRiZJJr8GkRRB10GsmQRLRYtH7pC4sftUd7jk3ksot
ZouDICgiTYn88c0CF0T5JcUrQ3wxT4FmftjlhUE+meOcJnZ4ZoAPZjmjkW2e
iDHDKQ1s8Ug/SU6IUE8dtfQxzTE19DJFnmp6mOSIKjZ5oJsEOSrZ4J4uJshS
wTp3dBInQzlr3NLBOIeEWeWGdsY4oIwVrmljlH1KWeaKVt4ZIU2IJS5p4Y1h
9vgHhMck0Q==
           
           "]]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, {
       
        Hue[0.67, 0.6, 0.6], 
        LineBox[{1, 85, 47, 26, 106, 68, 2, 86, 48, 123, 27, 107, 69, 3, 87, 
         49, 28, 108, 70, 4, 88, 50, 29, 109, 71, 5, 89, 51, 30, 110, 72, 6, 
         90, 52, 31, 111, 73, 7, 91, 53, 32, 112, 74, 8, 92, 54, 33, 9, 93, 
         55, 34, 10, 94, 56, 35, 11, 95, 57, 36, 12, 13, 14, 15, 96, 58, 37, 
         113, 75, 16, 97, 59, 38, 114, 76, 17, 98, 60, 39, 115, 77, 18, 99, 
         61, 124, 40, 116, 78, 131, 19, 100, 62, 125, 41, 117, 79, 132, 20, 
         101, 63, 126, 42, 118, 80, 133, 21, 102, 64, 127, 43, 119, 81, 134, 
         22, 103, 65, 128, 44, 120, 82, 135, 23, 104, 66, 129, 45, 121, 83, 
         136, 24, 105, 67, 130, 46, 122, 84, 137, 25}]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        LineBox[CompressedData["
1:eJwV0Gk2kGEch+GXpFBUO7AlS2gBrINMSabMJHOIypxCReZZlLGEDMkYcvlw
nfv8zv/59MQ+TIiLDwmCIJEkvvGWMg4Y4hHfaSXM43L9yzDJLNHGcw4ZIYVl
2qngiFFSWaGDFxwzRhqrdFLJCeOks0YXVZwywWPW6aaaDH7wjhqe8JMeaslk
g/fU8ZQsssnhFx+o54xJctmkl5f8Y4o8tujjpv9o0HOmecY2/YS7NeoFM9y1
8/U3H7llN+kls0TbBbrDJ27br/Q/cxSyy2ci3Jo10HmJ0SLdY4BIu+X6rF/1
nhbrPoNE2a81VBf0vpboH75wx36jN3RRH2ipXgFIHF2O
         "]]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        LineBox[CompressedData["
1:eJwVzlc7FgAAQOHPb7CyMyJkR8hKVsoODcRnN4xC9iqirEJl/lavi/d5zuVJ
DE62T4QEAoE9QsUYTzjkASt0EcY41RyRxSrdhPOep2Szxisi+EANOazzmkg+
UksuG7zhDp+oI49N3hLF7WQ9+Xyjh2gmaaCA7/QSwxTPeEgs0zRSSByfeU4R
8SRwl0S+8IJHbNFHEjM0Ucw270hmlmZ+U8IP+klhjhb+UMoOA5xxj6+0csxj
dglyTirztHFCGT8ZJI0F2jmlnF8MccF9FungLxXsMcwl6Szxkn9Uss8IV2Sw
TCf/qeKAUa7J5Ab7JzMy
         "]]}}}], AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
    Method -> {"AxesInFront" -> True}, 
    PlotRange -> {{-0.22375245023863546`, 0.04866257535817323}, {0, All}}, 
    PlotRangeClipping -> True, PlotRangePadding -> {
      Scaled[0.02], Automatic}],
   TemplateBox[{"\"exact\"", "\"non-critical\"", "\"non-critical anciaux\""}, 
    "LineLegend", DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.1421359549995791, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.1421359549995791, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.1421359549995791`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.751682956069047*^9, 3.7692690008854837`*^9, 
  3.7822530372554626`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Closed form approximation - subcriticals (equations 12 and 13)\
\>", "Subsubsection",
 CellChangeTimes->{{3.751298225457127*^9, 3.7512982432758417`*^9}, {
   3.7516364473386917`*^9, 3.751636452802126*^9}, {3.760645633002554*^9, 
   3.760645642928447*^9}, {3.769343895272121*^9, 3.7693438984544277`*^9}, {
   3.769346363126889*^9, 3.769346371215301*^9}, {3.769361863330435*^9, 
   3.769361876650732*^9}, {3.76937971946196*^9, 3.769379721518043*^9}, {
   3.7694291954926367`*^9, 3.769429209573209*^9}, 3.76943321251698*^9, 
   3.771256261032995*^9, {3.771762223572268*^9, 3.771762225652261*^9}}],

Cell["\<\
For the subcriticals our approximation for \[CapitalLambda]2 is now the \
integral of \
\>", "Text",
 CellChangeTimes->{{3.769269287704006*^9, 3.769269324512836*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fm", "[", 
   RowBox[{"m", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], "]"}], 
  "AnciauxEqnA12"}]], "Input",
 CellChangeTimes->{{3.769269247899362*^9, 3.769269254921452*^9}, 
   3.769269346276268*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     FractionBox[
      RowBox[{"m", "-", 
       RowBox[{"2", " ", "mmax"}], "+", "mwt"}], "\[Lambda]"]], " ", "U", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "m"}], "+", "mmax"}], "\[Lambda]"], ")"}], 
     RowBox[{"n", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox["\[Psi]wt", "2"]}], ")"}], 
     RowBox[{
      FractionBox["1", "2"], "-", "\[Theta]"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "\[Alpha]"}]], 
       RowBox[{
        SqrtBox["\[Pi]"], " ", 
        SqrtBox["\[Alpha]"]}]], "-", 
      RowBox[{"Erfc", "[", 
       SqrtBox["\[Alpha]"], "]"}]}], ")"}], " ", 
    RowBox[{"Hypergeometric0F1Regularized", "[", 
     RowBox[{
      FractionBox["n", "2"], ",", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "m"}], "+", "mmax"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"mmax", "-", "mwt"}], ")"}]}], 
       SuperscriptBox["\[Lambda]", "2"]]}], "]"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"m", "-", "mmax"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox["\[Psi]wt", "4"]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.7692692501316357`*^9, 3.769269255562914*^9}, 
   3.769269346681357*^9, 3.769351983768845*^9, 3.7693573622356977`*^9, 
   3.7822530467208853`*^9}]
}, Closed]],

Cell["\<\
over m from -\[Infinity] to -m*, with \[Alpha] dependent on m. \
\>", "Text",
 CellChangeTimes->{{3.769269338922679*^9, 3.769269392148407*^9}}],

Cell["\<\
As before we can approximately write fm in the \[Psi] scale, leaving us with \
the integral of\
\>", "Text",
 CellChangeTimes->{{3.769269467806487*^9, 3.769269469817292*^9}, {
  3.7692695137057056`*^9, 3.769269560553678*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"f\[Psi]", " ", "AnciauxEqnA12"}], "/.", 
  RowBox[{"\[Alpha]", "\[Rule]", 
   FractionBox[
    RowBox[{"\[Rho]max", " ", 
     SuperscriptBox["\[Psi]", "2"]}], "4"]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"constant", "=", 
   FractionBox[
    RowBox[{"U", " ", 
     SqrtBox["\[Rho]max"]}], 
    RowBox[{"2", " ", 
     SqrtBox["\[Pi]"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"\[Psi]wt", "/", "4"}]}], ")"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"\[Psi]wt", "/", "2"}]}], ")"}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", "\[Theta]"}]}]]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Psi]term", "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}]], "  ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"\[Psi]", "/", "2"}]}], ")"}], 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], "+", "\[Theta]"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"\[Rho]max", " ", 
            SuperscriptBox["\[Psi]", "2"]}], "4"]}]]}], 
       RowBox[{
        SqrtBox["\[Pi]"], " ", 
        SqrtBox[
         RowBox[{"\[Rho]max", " ", 
          SuperscriptBox["\[Psi]", "2"]}]]}]], "-", 
      RowBox[{"Erfc", "[", 
       FractionBox[
        SqrtBox[
         RowBox[{"\[Rho]max", " ", 
          SuperscriptBox["\[Psi]", "2"]}]], "2"], "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}]], " ", "U", " ", 
      
      SqrtBox["\[Rho]max"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"2", "-", "\[Psi]"}], 
         RowBox[{"2", "-", "\[Psi]wt"}]], ")"}], 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], "+", "\[Theta]"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox["\[Psi]wt", "2"]}], ")"}], 
       RowBox[{
        FractionBox["1", "2"], "-", "\[Theta]"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[Rho]max", " ", 
              SuperscriptBox["\[Psi]", "2"]}], "4"]}]]}], 
         RowBox[{
          SqrtBox["\[Pi]"], " ", 
          SqrtBox[
           RowBox[{"\[Rho]max", " ", 
            SuperscriptBox["\[Psi]", "2"]}]]}]], "-", 
        RowBox[{"Erfc", "[", 
         FractionBox[
          SqrtBox[
           RowBox[{"\[Rho]max", " ", 
            SuperscriptBox["\[Psi]", "2"]}]], "2"], "]"}]}], ")"}]}], 
     RowBox[{"2", " ", 
      SqrtBox["\[Pi]"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        FractionBox["\[Psi]wt", "4"]}], ")"}]}]], "\[Equal]", 
    RowBox[{"constant", " ", "\[Psi]term"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]wt", "<", "0"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7692695463482113`*^9, 3.769269546643938*^9}, {
  3.769269589412332*^9, 3.7692696131737823`*^9}, {3.769270161835973*^9, 
  3.7692701637123632`*^9}, {3.769270264363809*^9, 3.76927035274962*^9}, {
  3.769270384838574*^9, 3.769270406987526*^9}, {3.769270441383189*^9, 
  3.769270490654406*^9}, {3.7693439553512897`*^9, 3.7693439797545843`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}]], " ", "U", " ", 
   SqrtBox["\[Rho]max"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"2", "-", "\[Psi]"}], 
      RowBox[{"2", "-", "\[Psi]wt"}]], ")"}], 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], "+", "\[Theta]"}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox["\[Psi]wt", "2"]}], ")"}], 
    RowBox[{
     FractionBox["1", "2"], "-", "\[Theta]"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[Rho]max", " ", 
           SuperscriptBox["\[Psi]", "2"]}], "4"]}]]}], 
      RowBox[{
       SqrtBox["\[Pi]"], " ", 
       SqrtBox[
        RowBox[{"\[Rho]max", " ", 
         SuperscriptBox["\[Psi]", "2"]}]]}]], "-", 
     RowBox[{"Erfc", "[", 
      FractionBox[
       SqrtBox[
        RowBox[{"\[Rho]max", " ", 
         SuperscriptBox["\[Psi]", "2"]}]], "2"], "]"}]}], ")"}]}], 
  RowBox[{"2", " ", 
   SqrtBox["\[Pi]"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox["\[Psi]wt", "4"]}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.769269520085327*^9, 3.769269547982418*^9}, {
   3.7692695914744997`*^9, 3.769269613888485*^9}, 3.769270164140708*^9, 
   3.769270210373291*^9, {3.769270267815881*^9, 3.769270320969038*^9}, {
   3.769270397392211*^9, 3.769270407532835*^9}, {3.7692704611320877`*^9, 
   3.76927049088759*^9}, 3.769343981187142*^9, 3.76935198389608*^9, 
   3.7693573624176292`*^9, 3.769429062101634*^9, 3.782253048549181*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.769269520085327*^9, 3.769269547982418*^9}, {
   3.7692695914744997`*^9, 3.769269613888485*^9}, 3.769270164140708*^9, 
   3.769270210373291*^9, {3.769270267815881*^9, 3.769270320969038*^9}, {
   3.769270397392211*^9, 3.769270407532835*^9}, {3.7692704611320877`*^9, 
   3.76927049088759*^9}, 3.769343981187142*^9, 3.76935198389608*^9, 
   3.7693573624176292`*^9, 3.769429062101634*^9, 3.7822530492280817`*^9}]
}, Closed]],

Cell["over \[Psi] between -\[Infinity] and \[Psi]*", "Text",
 CellChangeTimes->{{3.769269570697753*^9, 3.769269582578092*^9}, {
  3.769269966216556*^9, 3.7692699672227583`*^9}, {3.769340979728405*^9, 
  3.769341001168212*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["m", "mmax"]}]]}], ")"}]}], "/.", 
    RowBox[{"m", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "\[Infinity]"}], ",", 
       RowBox[{"-", 
        SuperscriptBox["m", "*"]}]}], "}"}]}]}], ",", 
   RowBox[{"mmax", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769269969568224*^9, 3.7692700128115387`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "\[Infinity]"}], ",", 
   RowBox[{"2", "-", 
    RowBox[{"2", " ", 
     SqrtBox[
      FractionBox[
       RowBox[{"mmax", "+", 
        SuperscriptBox["m", "*"]}], "mmax"]]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7692699833537207`*^9, 3.7692700133159657`*^9}, 
   3.76935198471729*^9, 3.769357363541239*^9, 3.7822530507133713`*^9}]
}, Closed]],

Cell[TextData[{
 "We make 2 different approximations. When \[Psi]-\[Psi]wt and \[Psi] \
\[Rho]max = \[Psi] ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["mmax", "\[Lambda]"], "=", 
    RowBox[{"\[Psi]", 
     FractionBox[
      RowBox[{"mmax", "*", "n"}], 
      RowBox[{"2", "Es"}]]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " are really small we have"
}], "Text",
 CellChangeTimes->{{3.769276156742867*^9, 3.769276188448271*^9}, 
   3.7692763508205967`*^9, {3.7692770530894833`*^9, 3.769277105013369*^9}, {
   3.769292103911941*^9, 3.769292107786969*^9}, {3.7692936540731773`*^9, 
   3.769293658441058*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Psi]term", "/.", 
    RowBox[{
     RowBox[{"\[Psi]", "-", "\[Psi]wt"}], "\[Rule]", 
     RowBox[{"\[Psi]wt", "+", 
      RowBox[{"d\[Psi]", " ", "\[Epsilon]"}]}]}]}], " ", "/.", 
   RowBox[{"\[Psi]", "\[Rule]", 
    RowBox[{"\[Psi]", " ", "\[Epsilon]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Normal", "[", 
     RowBox[{"Series", "[", 
      RowBox[{"%", ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "]"}], "]"}], "/.", 
    RowBox[{"\[Epsilon]", "\[Rule]", "1"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]", "<", "0"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7692772011446047`*^9, 3.769277229634632*^9}, {
  3.769277284984087*^9, 3.769277298183468*^9}, {3.769277330057776*^9, 
  3.769277393567109*^9}, {3.769277431894062*^9, 3.7692774365548286`*^9}, {
  3.769292118743289*^9, 3.7692921204549847`*^9}, {3.769343989015789*^9, 
  3.769343990642921*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[Rho]max", " ", 
        SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]]}], 
   RowBox[{
    SqrtBox["\[Pi]"], " ", 
    SqrtBox["\[Rho]max"], " ", "\[Psi]"}]]}]], "Output",
 CellChangeTimes->{{3.7692772132348948`*^9, 3.769277230040106*^9}, {
   3.769277286920164*^9, 3.769277298828497*^9}, {3.7692773398242197`*^9, 
   3.769277393776143*^9}, 3.7692774373802347`*^9, 3.769292120866961*^9, 
   3.769343992163577*^9, 3.769351984864554*^9, 3.7693573637074213`*^9, 
   3.7822530560216217`*^9}]
}, Closed]],

Cell["\<\
And when \[Psi] is small but \[Rho]max is really large we have\
\>", "Text",
 CellChangeTimes->{{3.769277480912125*^9, 3.7692774822303333`*^9}, {
   3.769293619455532*^9, 3.7692936399368343`*^9}, {3.769293677164077*^9, 
   3.76929370700242*^9}, 3.769342734608337*^9, {3.769342780729642*^9, 
   3.76934278348032*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Psi]term", "/.", 
   RowBox[{"\[Rho]max", "->", 
    RowBox[{"\[Rho]max", " ", "/", "\[Epsilon]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Normal", "[", 
       RowBox[{"Series", "[", 
        RowBox[{"%", ",", 
         RowBox[{"{", 
          RowBox[{"\[Epsilon]", ",", "0", ",", "2"}], "}"}]}], "]"}], "]"}], "/.", 
      RowBox[{"\[Epsilon]", "\[Rule]", "1"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Psi]", "<", "0"}], "}"}]}], "]"}], "/.", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox["\[Psi]", "2"]}], ")"}], "\[Theta]"], "\[Rule]", "1"}]}], "/.",
   " ", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", "\[Pi]"}], "-", 
    RowBox[{"\[Pi]", " ", "\[Psi]"}]}], "\[Rule]", " ", 
   RowBox[{"2", " ", "\[Pi]"}]}]}]}], "Input",
 CellChangeTimes->{{3.76927639221686*^9, 3.7692764265764914`*^9}, {
   3.7692764645946417`*^9, 3.769276474137558*^9}, {3.769293523537623*^9, 
   3.769293534421026*^9}, {3.76929361415921*^9, 3.76929363385607*^9}, {
   3.769293713966752*^9, 3.7692937494749117`*^9}, {3.769342602531843*^9, 
   3.76934263105807*^9}, {3.769342677131432*^9, 3.769342701326943*^9}, {
   3.769342736722982*^9, 3.7693427368907213`*^9}, {3.769342789725562*^9, 
   3.769342800465663*^9}, 3.769343998075592*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Psi]", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}], ")"}]}]]}], 
   RowBox[{
    SqrtBox["\[Pi]"], " ", 
    SuperscriptBox["\[Rho]max", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["\[Psi]", "3"]}]]}]], "Output",
 CellChangeTimes->{
  3.769293505230237*^9, 3.769293536021103*^9, 3.76929363480674*^9, {
   3.769293723120592*^9, 3.769293750302417*^9}, {3.769342627385401*^9, 
   3.769342631360833*^9}, {3.769342677770432*^9, 3.769342703554227*^9}, 
   3.769342737679368*^9, 3.769342801613276*^9, 3.769343999438878*^9, 
   3.769351985382393*^9, 3.7693573641088467`*^9, 3.782253058476639*^9}]
}, Closed]],

Cell["\<\
Compare numerically over m (from \[Psi]wt to \[Psi]*)\
\>", "Text",
 CellChangeTimes->{{3.769296346987358*^9, 3.7692963508008947`*^9}, {
  3.769340865982284*^9, 3.7693408666846952`*^9}, {3.769340959968884*^9, 
  3.769340972511922*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", 
   RowBox[{"-", "0.1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["m", "*"], "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Psi]term", ",", " ", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[Rho]max", " ", 
              SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]]}], 
         RowBox[{
          SqrtBox["\[Pi]"], " ", 
          SqrtBox["\[Rho]max"], " ", "\[Psi]"}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[Psi]", "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}], 
             ")"}]}]]}], 
         RowBox[{
          SqrtBox["\[Pi]"], " ", 
          SuperscriptBox["\[Rho]max", 
           RowBox[{"3", "/", "2"}]], " ", 
          SuperscriptBox["\[Psi]", "3"]}]]}]}], "}"}], "/.", 
     RowBox[{"\[Rho]max", "\[Rule]", 
      RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
    RowBox[{"\[Theta]", "\[Rule]", 
     RowBox[{"n", "/", "2"}]}]}], "/.", 
   RowBox[{"\[Psi]wt", "\[Rule]", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"\[Psi]", ",", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SqrtBox[
          RowBox[{"1", "-", 
           FractionBox["mwt", "mmax"]}]]}], ")"}]}], ",", 
      RowBox[{"2", "-", 
       RowBox[{"2", " ", 
        SqrtBox[
         FractionBox[
          RowBox[{"mmax", "+", 
           SuperscriptBox["m", "*"]}], "mmax"]]}]}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "Automatic"}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.769270549006225*^9, 3.769270772247712*^9}, {
   3.769270807479823*^9, 3.7692708823499727`*^9}, {3.769270925970708*^9, 
   3.769270959774927*^9}, {3.769273351169366*^9, 3.769273365230863*^9}, {
   3.76927380712691*^9, 3.769274156416095*^9}, {3.769274488074574*^9, 
   3.769274492761969*^9}, {3.7692746989262753`*^9, 3.769274740030373*^9}, {
   3.769274958673862*^9, 3.7692750111745462`*^9}, {3.769275050710329*^9, 
   3.769275063313828*^9}, {3.7692751173673563`*^9, 3.769275210883506*^9}, {
   3.769275253620021*^9, 3.7692753578877563`*^9}, {3.7692753889978743`*^9, 
   3.76927541017268*^9}, {3.7692755165649357`*^9, 3.769275524990265*^9}, {
   3.769275762279347*^9, 3.769275924331658*^9}, {3.76927599392747*^9, 
   3.769276067279429*^9}, {3.769276141506316*^9, 3.7692761486131897`*^9}, 
   3.7692762729029207`*^9, {3.7692763185748568`*^9, 3.7692763655695467`*^9}, {
   3.7692764462024508`*^9, 3.769276511080594*^9}, 3.7692765560873632`*^9, {
   3.769276656965499*^9, 3.769276679749097*^9}, {3.769276885651223*^9, 
   3.769277039267682*^9}, {3.769277145020173*^9, 3.769277182234398*^9}, {
   3.769277242206854*^9, 3.7692772565256042`*^9}, {3.769277408387829*^9, 
   3.769277412005639*^9}, {3.769277516745583*^9, 3.769277576037252*^9}, {
   3.769293560638755*^9, 3.76929357395599*^9}, {3.7692936819626427`*^9, 
   3.769293694987109*^9}, {3.769340953864324*^9, 3.7693409540217123`*^9}, 
   3.769342637355796*^9, 3.7693427080958843`*^9, {3.7693427550147467`*^9, 
   3.769342756606144*^9}, 3.7693428058760223`*^9, 3.769344003130699*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVyXk8FHgfwPFxDqYsoxTJHZEcuXLU77eoHFuxKR0qmySUo9ZRVtRYQq7c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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwVk2k4FGofh2fsS/Vayl7ZSkoUKls9T+UklDZSUjoihULoVY4lM419i7GM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     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJwBkQRu+yFib1JlAgAAAEgAAAACAAAAuO2SRxdvyL8TNw0fJ7PAP2euYxdE
bci/HMYX3Su5wD8WbzTncGvIv2k1Dbcyv8A/dPDVhspnyL9iDsLBRsvAPzDz
GMZ9YMi/ukGmR4jjwD+o+J5E5FHIv+0j8MBxFME/mAOrQbE0yL890aHW43fB
P3gZwztL+se/IbZCA3FFwj/tZTsorHvHv/2PQOhgI8Q/JtdNLHEFx7/vX3mA
zQzGP8lrNOiHkca/z83fTSMZyD8gIWOcyxPGv/8kZcrNiMo/PPsraHOexb+D
5XW+rQfNPwz2PCxIH8W/VhPzV1gA0D9GFCKobqLEv5hzowB3nNE/RFehO/kt
xL9DOR2mK0PTP/e6aMewr8O/5n7ZRA881T9uQ8pqzDnDv3Z+VlUWRNc/T+//
xTnGwr8QNibZ13TZP+S7fRnUSMK/jW4p+CYV3D8+rZWE0tPBv3Z+eE/Ey94/
TL/15/1Uwb/hOYgrzQfhP8T0KQN72MC/csaehJ3R4j8AT/g1XGTAv5j4YT7U
rOQ/4ZMdwtTMv794Kkq0UezmP0vTfke54b6/+Nr9b+pF6T8eVHC99+K9vyU0
RwrAIuw/xRsKo9novL+fgZ+lFlHvP/Qs2LeD/7u/ouP4cKhV8T+Mfza9hwK7
vyKLiLq3ZfM/rRvJ8VMWur8xcSId5Zf1P6H+A5bDLrm/kA7LJ2sL+D/+Is8q
jTO4v5PxOgmgGfs/5JDO7h5Jt7/+9HGIOWX+PzNAXqMKS7a/4jpq6LFGAUBV
NpbHmVG1v6KfGnWIrQNAAHYCG/FotL8ZKlBKiVAGQARoEuD/ZLS/4PkXrfFc
BkAIWiKlDmG0vxTLJfFiaQZAET5CLyxZtL/KQJQ9YIIGQCIGgkNnSbS/pyhB
zca0BkBFlgFs3Sm0v4qJcRJLGwdAirYAvcnqs780TO5/bO8HQBT3/l6ibLO/
Amoq1xa2CUA+ustE9Gizv2suaaL/wwlAaX2YKkZls780dDc08tEJQL4DMvbp
XbO/KXOwzvTtCUBoEGWNMU+zv+EPdddwJgpAuynLu8Axs79GzqkbTJkKQGJc
lxjf9rK/e+MboNCGC0CwwS/SG4Gyv3Yr0cA+gw1A9iW7RYB9sr/aomj1kJMN
QDyKRrnkebK/a1qB/O6jDUDHUl2grXKyv5kzGa7OxA1A3uOKbj9ksr+Kxs/U
HQcOQAwG5gpjR7K/trRhCQWODkBoSpxDqg2yv/gCdodIpQ9AINMItTiasb+9
nf/GLv4QQGx4VpBOlrG/wJIx/dcIEUC3HaRrZJKxvxSSKgeKExFATmg/IpCK
sb9iX+27CCkRQHv9dY/nerG/z2DCsXFUEUDWJ+Nplluxvxh3zD/6rBFAjHy9
HvQcsb9iaVkTLGUSQPklcoivn7C/OlnKrXH0E0BqnHyECJywv0alJXq/ABRA
3BKHgGGYsL8VK8dcFw0UQMD/m3gTkbC/SndHj+UlFECG2cVod4Kwv38XI9X8
VxRAEo0ZST9lsL9UTRVxIL4UQCr0wAnPKrC/TozARYuSFUD+ZTaVhhOwvwMj
BM4x7hVAuMw7Zw==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-0.15, 0},
  Method->{},
  PlotRange->{{-0.1908902300206643, -0.009300312746010064}, {
    0, 5.482611865046013}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {Automatic, 
     Scaled[0.02]}}]], "Output",
 CellChangeTimes->{{3.769270582302558*^9, 3.769270636678232*^9}, 
   3.769270671667871*^9, {3.7692707208117037`*^9, 3.769270773167664*^9}, {
   3.769270822228413*^9, 3.769270882631742*^9}, {3.769270926736253*^9, 
   3.7692709607734947`*^9}, {3.7692733521882343`*^9, 3.769273365550647*^9}, {
   3.769273825527163*^9, 3.769274157143916*^9}, {3.769274488793068*^9, 
   3.769274493075068*^9}, {3.7692746994059362`*^9, 3.769274740257278*^9}, {
   3.769274959843853*^9, 3.7692750120372066`*^9}, 3.769275065287446*^9, {
   3.769275118744227*^9, 3.769275211386838*^9}, {3.769275254340517*^9, 
   3.769275358168097*^9}, {3.769275389698197*^9, 3.769275410746758*^9}, {
   3.76927551859298*^9, 3.769275525588455*^9}, {3.769275767440014*^9, 
   3.7692759249037523`*^9}, {3.769276017800255*^9, 3.769276067519147*^9}, {
   3.769276142299191*^9, 3.769276149205813*^9}, 3.769276273718959*^9, {
   3.7692763115919533`*^9, 3.769276366374851*^9}, {3.769276446524666*^9, 
   3.769276511525003*^9}, 3.7692765563873672`*^9, {3.769276658740637*^9, 
   3.7692766801267853`*^9}, {3.769276886025506*^9, 3.769276892841444*^9}, {
   3.76927693387462*^9, 3.769277039627535*^9}, {3.7692771457388678`*^9, 
   3.769277182680792*^9}, {3.769277244231783*^9, 3.7692772569378223`*^9}, 
   3.769277412551964*^9, {3.7692775173027573`*^9, 3.769277576301126*^9}, {
   3.769293564218171*^9, 3.769293574347364*^9}, {3.769293682413096*^9, 
   3.769293695691597*^9}, 3.7693409549002247`*^9, 3.769342638418071*^9, 
   3.769342709035014*^9, 3.76934280684976*^9, 3.7693440073884993`*^9, 
   3.7693519855333843`*^9, 3.769357364276711*^9, 3.78225306088031*^9}]
}, Closed]],

Cell["\<\
And compare integrals across range of mwt. We see the nice transition from \
the small \[Psi] approx to the large \[Rho]max approx as we increase \[Rho]max:

For \[Rho]max = 10\
\>", "Text",
 CellChangeTimes->{{3.769340870188957*^9, 3.7693408812966747`*^9}, {
  3.7693415597656593`*^9, 3.7693416011827393`*^9}, {3.769341720906212*^9, 
  3.769341735538785*^9}, {3.769341785414688*^9, 3.7693418090454082`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SuperscriptBox["m", "*"], "=", 
   SqrtBox[
    RowBox[{
     RowBox[{"\[CapitalLambda]1", "[", 
      RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], "]"}],
      "/", "2"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "/", "\[Lambda]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Psi]term", ",", " ", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[Rho]max", " ", 
              SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]]}], 
         RowBox[{
          SqrtBox["\[Pi]"], " ", 
          SqrtBox["\[Rho]max"], " ", "\[Psi]"}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[Psi]", "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}], 
             ")"}]}]]}], 
         RowBox[{
          SqrtBox["\[Pi]"], " ", 
          SuperscriptBox["\[Rho]max", 
           RowBox[{"3", "/", "2"}]], " ", 
          SuperscriptBox["\[Psi]", "3"]}]]}]}], "}"}], "/.", 
     RowBox[{"\[Rho]max", "\[Rule]", 
      RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
    RowBox[{"\[Theta]", "\[Rule]", 
     RowBox[{"n", "/", "2"}]}]}], "/.", 
   RowBox[{"\[Psi]wt", "\[Rule]", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mwt", ",", 
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{"%", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Psi]", ",", 
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SqrtBox[
                RowBox[{"1", "-", 
                 FractionBox["mwt", "mmax"]}]]}], ")"}]}], ",", 
            RowBox[{"2", "-", 
             RowBox[{"2", " ", 
              SqrtBox[
               FractionBox[
                RowBox[{"mmax", "+", 
                 SuperscriptBox["m", "*"]}], "mmax"]]}]}]}], "}"}]}], "]"}]}],
        "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"mwt", ",", 
        RowBox[{"-", "0.3"}], ",", 
        RowBox[{"-", "0.1"}], ",", "0.01"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "%", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListLogPlot", "[", 
   RowBox[{"%", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.769270549006225*^9, 3.769270772247712*^9}, {
   3.769270807479823*^9, 3.7692708823499727`*^9}, {3.769270925970708*^9, 
   3.769270959774927*^9}, {3.769273351169366*^9, 3.769273365230863*^9}, {
   3.76927380712691*^9, 3.769274156416095*^9}, {3.769274488074574*^9, 
   3.769274492761969*^9}, {3.7692746989262753`*^9, 3.769274740030373*^9}, {
   3.769274958673862*^9, 3.7692750111745462`*^9}, {3.769275050710329*^9, 
   3.769275063313828*^9}, {3.7692751173673563`*^9, 3.769275210883506*^9}, {
   3.769275253620021*^9, 3.7692753578877563`*^9}, {3.7692753889978743`*^9, 
   3.76927541017268*^9}, {3.7692755165649357`*^9, 3.769275524990265*^9}, {
   3.769275762279347*^9, 3.769275924331658*^9}, {3.76927599392747*^9, 
   3.769276067279429*^9}, {3.769276141506316*^9, 3.7692761486131897`*^9}, 
   3.7692762729029207`*^9, {3.7692763185748568`*^9, 3.7692763655695467`*^9}, {
   3.7692764462024508`*^9, 3.769276511080594*^9}, 3.7692765560873632`*^9, {
   3.769276656965499*^9, 3.769276679749097*^9}, {3.769276885651223*^9, 
   3.769277039267682*^9}, {3.769277145020173*^9, 3.769277182234398*^9}, {
   3.769277242206854*^9, 3.7692772565256042`*^9}, {3.769277408387829*^9, 
   3.769277412005639*^9}, {3.769277516745583*^9, 3.769277576037252*^9}, {
   3.769293560638755*^9, 3.76929357395599*^9}, {3.7692936819626427`*^9, 
   3.769293694987109*^9}, {3.769340896684823*^9, 3.76934091255446*^9}, {
   3.769341009929846*^9, 3.7693411870876503`*^9}, {3.7693412261303577`*^9, 
   3.769341227017324*^9}, {3.769341261180797*^9, 3.76934144417833*^9}, {
   3.769341488626583*^9, 3.76934153522892*^9}, {3.769341606854577*^9, 
   3.7693416094110527`*^9}, {3.769341664064722*^9, 3.769341686427981*^9}, 
   3.769342641808112*^9, 3.769342711665489*^9, 3.769342760680629*^9, 
   3.769342809851919*^9, 3.769344012187282*^9}],

Cell[BoxData["10.`"], "Output",
 CellChangeTimes->{3.7693416870867987`*^9, 3.769342642492485*^9, 
  3.769342712474774*^9, 3.7693428102999697`*^9, 3.769344013285987*^9, 
  3.769351985615144*^9, 3.769357364357897*^9, 3.782253066489809*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbQwGl/drzr910dzq3v7+Q181Yvov7fd77ffrd8ad
/a8Dd8i1vr64/9Cd6csCV93a7/GwSmSd+8X9RoleCt/+3di/pMCW6/riC/vT
c94Y7Ei/vp8BDC7snzDxPX/106v7QboDd5zb75Mz66dl5ZX9YOUFZ/fn/Yie
x6NyeT/QMqCNZ/YnFquv0nl+cT/Y+Ien9jcVqO76c/jC/plgcHK/wKyuPKWK
8/uDwAae2H9nnlhZ+aKz+0Gm2XId3799S8pFY+4z+8HOP3R0/9OTkhJB20/t
BxtXdWS/cuzi2wfWnNwP8e/h/Veip3St+nQC6r+D+xMP2NXdnHhi/2KwAw/s
7/U54e829QTU/fv266ecLnrOdRLq3j37zQ3mP37Bcmr/DLD7du7/wMqvPmH2
6f0AMxu9Mw==
      "]]}, 
    {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbQwGl/dbfO9/55J0a3//oa8aMf2X9gt7Llu13fHG
/teBO+RaX1/cr3MiXe65+bX9Hg+rRNa5X9z/8GKVzjrXK/uXFNhyXV98Yf+9
mduZ/2Rf2s8ABhf2x1ZfDby++sJ+kO7AHef2h7FdCTjCc24/WHnB2f0zPV91
7f15aj/QMqCNZ/ZPEZ7HlK14Yj/Y+Ien9t8w/FD6o+3o/plgcHJ/yqKPlf91
D+8PAht4Yr9Zu2fnfKmD+0Gm2XId31/9e06+1eJ9+8HOP3R0f478r2qxjbv3
g42rOrK/4c7yRUw5O/dD/Ht4v9eH13lnH2+H+u/g/jnPpkdv1t6+fzHYgQf2
y6me/N8cvR3q/n37o3MEvXwm7oC6d8/+SW1aVVc+79o/A+y+nfs/x9Vy1Gzb
tx8AH0O9HQ==
      "]]}, 
    {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbQwGl/ermvf8PKAg7NB/6KtGTP+l/aUrUkW4PIUd
XgfukGt9fXG/mK98gkeBsIPHwyqRde4X9xv/6J9WNk3YYUmBLdf1xRf21z2b
6NC/W9iBAQwu7F+sX7Wp576wA0h34I5z+1eE/2TPZBJxACsvOLv/Z6a5vJyK
iAPQMqCNZ/bb9r2etNRFxAFs/MNT++9OEt78I1nEYSYYnNzvkH6sWqBJxCEI
bOCJ/XMnxXQ+nSfiADLNluv4/ge2RzkKdok4gJ1/6Oh+I2bbRcuviDiAjas6
sj9LYlJ081sRB4h/D+9vykrI/ckiCvXfwf39wYuY/0uJOiwGO/DA/pVTi+60
64tC3b9vv4fV5LWtTqJQ9+7Zr7LRXPV5sKjDDLD7du7fVxthOC1Z1AEAWk+d
gg==
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-0.3, -0.47230334752610986`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{0., 
       FormBox["1", TraditionalForm]}, {0.6931471805599453, 
       FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["5", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {2.995732273553991, 
       FormBox["20", TraditionalForm]}, {3.912023005428146, 
       FormBox["50", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {5.298317366548036, 
       FormBox["200", TraditionalForm]}, {6.214608098422191, 
       FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{0., 
       FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm]}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{-0.3, -0.09999999999999998}, {-0.47230334752610986`, 
   5.347252627397607}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, {{0., 
      FormBox["1", TraditionalForm]}, {0.6931471805599453, 
      FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
      FormBox["5", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {2.995732273553991, 
      FormBox["20", TraditionalForm]}, {3.912023005428146, 
      FormBox["50", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {5.298317366548036, 
      FormBox["200", TraditionalForm]}, {6.214608098422191, 
      FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{3.7693416870867987`*^9, 3.769342642492485*^9, 
  3.769342712474774*^9, 3.7693428102999697`*^9, 3.769344013285987*^9, 
  3.769351985615144*^9, 3.769357364357897*^9, 3.7822530668295*^9}]
}, Closed]],

Cell["For \[Rho]max=100", "Text",
 CellChangeTimes->{{3.769341725602521*^9, 3.76934172961821*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SuperscriptBox["m", "*"], "=", 
   SqrtBox[
    RowBox[{
     RowBox[{"\[CapitalLambda]1", "[", 
      RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], "]"}],
      "/", "2"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "/", "\[Lambda]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Psi]term", ",", " ", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[Rho]max", " ", 
              SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]]}], 
         RowBox[{
          SqrtBox["\[Pi]"], " ", 
          SqrtBox["\[Rho]max"], " ", "\[Psi]"}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[Psi]", "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}], 
             ")"}]}]]}], 
         RowBox[{
          SqrtBox["\[Pi]"], " ", 
          SuperscriptBox["\[Rho]max", 
           RowBox[{"3", "/", "2"}]], " ", 
          SuperscriptBox["\[Psi]", "3"]}]]}]}], "}"}], "/.", 
     RowBox[{"\[Rho]max", "\[Rule]", 
      RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
    RowBox[{"\[Theta]", "\[Rule]", 
     RowBox[{"n", "/", "2"}]}]}], "/.", 
   RowBox[{"\[Psi]wt", "\[Rule]", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mwt", ",", 
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{"%", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Psi]", ",", 
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SqrtBox[
                RowBox[{"1", "-", 
                 FractionBox["mwt", "mmax"]}]]}], ")"}]}], ",", 
            RowBox[{"2", "-", 
             RowBox[{"2", " ", 
              SqrtBox[
               FractionBox[
                RowBox[{"mmax", "+", 
                 SuperscriptBox["m", "*"]}], "mmax"]]}]}]}], "}"}]}], "]"}]}],
        "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"mwt", ",", 
        RowBox[{"-", "0.3"}], ",", 
        RowBox[{"-", "0.1"}], ",", "0.01"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "%", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListLogPlot", "[", 
   RowBox[{"%", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.769270549006225*^9, 3.769270772247712*^9}, {
   3.769270807479823*^9, 3.7692708823499727`*^9}, {3.769270925970708*^9, 
   3.769270959774927*^9}, {3.769273351169366*^9, 3.769273365230863*^9}, {
   3.76927380712691*^9, 3.769274156416095*^9}, {3.769274488074574*^9, 
   3.769274492761969*^9}, {3.7692746989262753`*^9, 3.769274740030373*^9}, {
   3.769274958673862*^9, 3.7692750111745462`*^9}, {3.769275050710329*^9, 
   3.769275063313828*^9}, {3.7692751173673563`*^9, 3.769275210883506*^9}, {
   3.769275253620021*^9, 3.7692753578877563`*^9}, {3.7692753889978743`*^9, 
   3.76927541017268*^9}, {3.7692755165649357`*^9, 3.769275524990265*^9}, {
   3.769275762279347*^9, 3.769275924331658*^9}, {3.76927599392747*^9, 
   3.769276067279429*^9}, {3.769276141506316*^9, 3.7692761486131897`*^9}, 
   3.7692762729029207`*^9, {3.7692763185748568`*^9, 3.7692763655695467`*^9}, {
   3.7692764462024508`*^9, 3.769276511080594*^9}, 3.7692765560873632`*^9, {
   3.769276656965499*^9, 3.769276679749097*^9}, {3.769276885651223*^9, 
   3.769277039267682*^9}, {3.769277145020173*^9, 3.769277182234398*^9}, {
   3.769277242206854*^9, 3.7692772565256042`*^9}, {3.769277408387829*^9, 
   3.769277412005639*^9}, {3.769277516745583*^9, 3.769277576037252*^9}, {
   3.769293560638755*^9, 3.76929357395599*^9}, {3.7692936819626427`*^9, 
   3.769293694987109*^9}, {3.769340896684823*^9, 3.76934091255446*^9}, {
   3.769341009929846*^9, 3.7693411870876503`*^9}, {3.7693412261303577`*^9, 
   3.769341227017324*^9}, {3.769341261180797*^9, 3.76934144417833*^9}, {
   3.769341488626583*^9, 3.76934153522892*^9}, {3.769341606854577*^9, 
   3.7693416094110527`*^9}, {3.769341664064722*^9, 3.769341664380163*^9}, 
   3.7693426455190907`*^9, 3.769342715821494*^9, 3.769342762924378*^9, {
   3.7693428124446363`*^9, 3.769342815168913*^9}, 3.769344016913319*^9}],

Cell[BoxData["100.`"], "Output",
 CellChangeTimes->{
  3.7693411457863626`*^9, 3.769341188294477*^9, {3.7693412550961018`*^9, 
   3.769341446411147*^9}, 3.7693414894902782`*^9, {3.769341530807078*^9, 
   3.769341536022251*^9}, 3.769341610087285*^9, 3.769341664778882*^9, 
   3.769342646517942*^9, 3.769342716738092*^9, 3.769342815569406*^9, 
   3.769344018127613*^9, 3.769351986132474*^9, 3.769357364890189*^9, 
   3.782253069440847*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbQwGl/c7iMon/euVOtB/6KtGTP+l/dPXdqowxEse
eB24Q6719cX9bnKq7H0mEgc8HlaJrHO/uP/PIp1aUX7xA0sKbLmuL76wX8Rl
y0rO96IHGMDgwn6m7dPqH10ROQDSHbjj3P6PGhffSB8UPgBWXnB2v+nSe9Km
W4QOAC0D2nhmP4OOx5X16wQPgI1/eGr/2qhsJoGNAgdmgsHJ/fsvTrq9rZz/
QBDYwBP79ZRPeBnP5z0AMs2W6/j+SwdKwlbc5D4Adv6ho/vvsPy5pqvBdQBs
XNWR/T5MBqqPujkOQPx7eL+mYuqBN6zsUP8d3B+2OTOgaTrrgcVgBx7Yf/bL
zCWvHFmg7t+3n2GW6v5ONmaoe/fs/+bsf+DtM8YDM8Du27n/pmHclydPGA4A
AAayqd0=
      "]]}, 
    {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbQwGl/ebST/N/Wcqf6D/0FeNmP5L+0PyzwU+myp7
4HXgDrnW1xf3s5o1B1UyyBzweFglss794v4vTS3yn0qlDiwpsOW6vvjCfv8T
Abx93yQOMIDBhf0BlpNCepvED4B0B+44t7+NXSPGWErsAFh5wdn9nkpnBI7v
FTkAtAxo45n9Bgv++k7OFT4ANv7hqf1JZyVjn2sKHZgJBif3fz0WOlH8s8CB
ILCBJ/ZvnbdV+M8k/gMg02y5ju+PtBL0+x7FewDs/ENH9/Ou+Nb1yY77ANi4
qiP7Tx34ufmSPecBiH8P778bt013Shw71H8H9+sG3twQMIf1wGKwAw/sD9wb
Vuz+ixnq/n373/7Vuf2ikgnq3j37zwhkH38uw3hgBth9O/ev+dDLsuLU//0A
ctSuHw==
      "]]}, 
    {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQbQwGl/d/P9X/4ZgB/4H+Q181Yvov7W98YvRfS4Ln
wOvAHXKtry/ud/eeqFshyHnA42GVyDr3i/t5JDZXF8iyHVhSYMt1ffGF/W+m
l9ucsWE+wAAGF/bzyFao2BQwHADpDtxxbv/UK7eMrxX83g9WXnB2/7cimxn/
tb/tB1oGtPHM/sf6D41shD/uBxv/8NT+CHF23YX+L/bPBIOT+6deCixmXHN3
fxDYwBP7Px64/77hw7H9INNsuY7vN/hZ7dtze7s92PmHju5fl59313LONXuw
cVVH9js9Xm9mZ/nYHuLfw/vlRFuylXa9sof47+D+XWozuJmef7BfDHbggf0v
7LZcYLb8Yg9x/779UqeXlM8O/G4Pce+e/aGKr07Z6v+ynwF23879K2RPqHlf
+GMPAOx8sCY=
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-0.3, -7.80272838316778},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{-0.3, -0.09999999999999998}, {-7.80272838316778, 
   1.8008529200468306`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, {{-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{
  3.7693411457863626`*^9, 3.769341188294477*^9, {3.7693412550961018`*^9, 
   3.769341446411147*^9}, 3.7693414894902782`*^9, {3.769341530807078*^9, 
   3.769341536022251*^9}, 3.769341610087285*^9, 3.769341664778882*^9, 
   3.769342646517942*^9, 3.769342716738092*^9, 3.769342815569406*^9, 
   3.769344018127613*^9, 3.769351986132474*^9, 3.769357364890189*^9, 
   3.782253069830583*^9}]
}, Closed]],

Cell["for \[Rho]max=1000", "Text",
 CellChangeTimes->{{3.769341669090405*^9, 3.769341676552948*^9}, {
  3.7693417667959223`*^9, 3.769341768219657*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.001"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SuperscriptBox["m", "*"], "=", 
   SqrtBox[
    RowBox[{
     RowBox[{"\[CapitalLambda]1", "[", 
      RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], "]"}],
      "/", "2"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "/", "\[Lambda]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Psi]term", ",", " ", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[Rho]max", " ", 
              SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]]}], 
         RowBox[{
          SqrtBox["\[Pi]"], " ", 
          SqrtBox["\[Rho]max"], " ", "\[Psi]"}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[Psi]", "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}], 
             ")"}]}]]}], 
         RowBox[{
          SqrtBox["\[Pi]"], " ", 
          SuperscriptBox["\[Rho]max", 
           RowBox[{"3", "/", "2"}]], " ", 
          SuperscriptBox["\[Psi]", "3"]}]]}]}], "}"}], "/.", 
     RowBox[{"\[Rho]max", "\[Rule]", 
      RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
    RowBox[{"\[Theta]", "\[Rule]", 
     RowBox[{"n", "/", "2"}]}]}], "/.", 
   RowBox[{"\[Psi]wt", "\[Rule]", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mwt", ",", 
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{"%", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Psi]", ",", 
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SqrtBox[
                RowBox[{"1", "-", 
                 FractionBox["mwt", "mmax"]}]]}], ")"}]}], ",", 
            RowBox[{"2", "-", 
             RowBox[{"2", " ", 
              SqrtBox[
               FractionBox[
                RowBox[{"mmax", "+", 
                 SuperscriptBox["m", "*"]}], "mmax"]]}]}]}], "}"}]}], "]"}]}],
        "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"mwt", ",", 
        RowBox[{"-", "0.3"}], ",", 
        RowBox[{"-", "0.01"}], ",", "0.01"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "%", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListLogPlot", "[", 
   RowBox[{"%", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7693416214895487`*^9, 3.769341657996111*^9}, {
   3.7693426501051397`*^9, 3.769342659852552*^9}, 3.769342720145535*^9, 
   3.769342766730276*^9, 3.76934281907511*^9, 3.769344021995221*^9}],

Cell[BoxData["1000.`"], "Output",
 CellChangeTimes->{{3.769341622984318*^9, 3.769341658753543*^9}, {
   3.769342650916984*^9, 3.769342660452045*^9}, 3.769342721045363*^9, 
   3.769342767975196*^9, 3.769342819840057*^9, 3.7693440228554907`*^9, 
   3.769351986631673*^9, 3.769357365477858*^9, 3.782253075959022*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQbQwGl/en+Orz9Ta4Hug/9FUjpv/S/qo3TLVLc1wO
vA7cIdf6+uJ+4eis+H1xzgc8HlaJrHO/uL/otf/ad2FOB5YU2HJdX3xh/yYH
XV/fUMcDDGBwYf+lv+def4h0OADSHbjj3P4LW+x775+0OwBWXnB2/42sa0f3
vbE5ALQMaOOZ/WKX1gStkLE+ADb+4an9P+5NXXcw0vLATDA4ud+jyT1We4n5
gSCwgSf2P2ZoqPr32/QAyDRbruP7m31mcHgmmhwAO//Q0f37521o5rhidABs
XNWR/bYvODYohRgegPj38P7rk59s23NIH+q/g/v/us67cvibzoHFYAce2F+Q
xH263VkL6v59+7XueGdWr1CHunfP/sCM+8f41FQPzAC7b+f+1IntlV37lKDu
2b5fMGXrpbllClD7t+x/LBrZWrpK5sArsH0b94d5eU2YfFQCav66/SUn9ORj
A0Sh5q3cn64VruERI3SgAqx/yX7Ve8qa4V/5D2wAq5+3v5PTbc+fep4DBWD5
KftnqH/eG7mU60ADmN+yfzH3Hd2567kPAADpLfuI
      "]]}, 
    {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQbQwGl/c7/pE8yskQdKD/0FeNmP5L+4ObNTqnfA84
8Dpwh1zr64v7lWWnTNN57X/A42GVyDr3i/tPLlaaEffF98CSAluu64sv7L/6
/9VRRm6fAwxgcGG/1PcDktH6XgdAugN3nNsfmv31+8ZEjwNg5QVn98eePh0Y
sMjtANAyoI1n9pcGe55u+uhyAGz8w1P7N+f+fTLD3/nATDA4uf/x40laT/c4
HggCG3hi/8xMh/S9lg4HQKbZch3fP+mr3OGvPbYHwM4/dHT/v3p+x6/HrA6A
jas6sl9ivV+VtZLFAYh/D+9v+HK+Y/J8U6j/Du43ex2TcMne+MBisAMP7Hde
95bxBrMh1P379n+0mSSvdFMX6t49+9uCg958/Kp5YAbYfTv3B+x6y2SVoAZ1
z/b9TmsesTpJKUPt37L/3OOO3F41hQOvwPZt3G/9PrjyJb801Px1+4tF+z8t
bxaDmrdyf+eiqaGXNggdqADrX7I/UeXn5V1u/Ac2gNXP218r5yp9/x7XgQKw
/JT9+zaH3Z/VynGgAcxv2Z9VPNOzciPnAQDqvP7c
      "]]}, 
    {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQbQwGl/fX/tw1TaHH9UD/oa8aMf2X9q/Mv/T0SJnL
gdeBO+RaX1/c/z6r+lhguvMBj4dVIuvcL+6/WDqn7las04ElBbZc1xdf2L/G
Ki+zMMrxAAMYXNg/ldu0Uz3W4QBId+COc/uN1PSuip+xOwBWXnB2v6nRnbLQ
VzYHgJYBbTyzP4Zl4TpxUesDYOMfnto/JfJVU4KP5YGZYHBy/wR52c1SE8wP
BIENPLG/V+5LNtsD0wMg02y5ju83+nigdJK1yQGw8w8d3b/7bfibyQuNDoCN
qzqyP6Py7IXr/IYHIP49vH/DkZeCzaz6UP8d3O8R2mgX/Fr7wGKwAw/s/9yh
JnXnpAbU/fv2H7xV+MV1kSrUvXv2BzQ0317foHRgBth9O/crL4u/JP9eDuqe
7ftP8jZc+W4oCbV/y/5FPc5Smc+ED7wC27dxv9bN6j8vHPmg5q/bb/T/WVTb
A1aoeSv3m/2I8Eir/bu/Aqx/yf7oje+lX935uH8DWP28/fMu5p9uYnq0vwAs
P2W//fcVX4K2n9jfAOa37Jdfp9s7XWrNfgDkBwDD
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-0.3, -72.00059630906709},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-71.38013788281542, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "31"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-57.564627324851145`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "25"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-43.74911676688687, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "19"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-29.933606208922594`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {-59.76184390221936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-59.06870122163354, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-58.663237613521254`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-58.37555629106825, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-58.15241318975358, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-57.970091932959434`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-57.8159414674178, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-57.68241023550753, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-45.94633334425509, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-45.253190663669265`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-44.84772705555698, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-44.560045733103976`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-44.33690263178931, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-44.15458137499516, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-44.00043090945353, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-43.86689967754326, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-32.130822786290814`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-31.43768010570499, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-31.032216497592703`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-30.744535175139703`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-30.521392073825034`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-30.339070817030883`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-30.184920351489254`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-30.051389119578985`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-18.31531222832654, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.622169547740718`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.21670593962843, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.92902461717543, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.70588151586076, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.52356025906661, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.36940979352498, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.23587856161471, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.499801670362265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.806658989776445, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.4011953816641554`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.1135140592111554`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8903709578964847`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.7080497011023352`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.553899235560707, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4203680036504367`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-71.38013788281542, 
       FormBox["\"\"", TraditionalForm]}, {-57.564627324851145`, 
       FormBox["\"\"", TraditionalForm]}, {-43.74911676688687, 
       FormBox["\"\"", TraditionalForm]}, {-29.933606208922594`, 
       FormBox["\"\"", TraditionalForm]}, {-16.11809565095832, 
       FormBox["\"\"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {-59.76184390221936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-59.06870122163354, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-58.663237613521254`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-58.37555629106825, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-58.15241318975358, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-57.970091932959434`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-57.8159414674178, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-57.68241023550753, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-45.94633334425509, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-45.253190663669265`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-44.84772705555698, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-44.560045733103976`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-44.33690263178931, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-44.15458137499516, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-44.00043090945353, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-43.86689967754326, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-32.130822786290814`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-31.43768010570499, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-31.032216497592703`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-30.744535175139703`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-30.521392073825034`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-30.339070817030883`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-30.184920351489254`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-30.051389119578985`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-18.31531222832654, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.622169547740718`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.21670593962843, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.92902461717543, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.70588151586076, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.52356025906661, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.36940979352498, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.23587856161471, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.499801670362265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.806658989776445, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.4011953816641554`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.1135140592111554`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8903709578964847`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.7080497011023352`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.553899235560707, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4203680036504367`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{-0.3, 0.}, {-72.00059630906709, -0.05489038084382635}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, {{-71.38013788281542, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "31"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-57.564627324851145`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "25"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-43.74911676688687, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "19"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-29.933606208922594`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-16.11809565095832, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {-59.76184390221936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-59.06870122163354, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-58.663237613521254`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-58.37555629106825, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-58.15241318975358, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-57.970091932959434`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-57.8159414674178, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-57.68241023550753, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-45.94633334425509, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-45.253190663669265`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-44.84772705555698, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-44.560045733103976`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-44.33690263178931, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-44.15458137499516, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-44.00043090945353, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-43.86689967754326, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-32.130822786290814`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-31.43768010570499, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-31.032216497592703`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-30.744535175139703`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-30.521392073825034`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-30.339070817030883`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-30.184920351489254`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-30.051389119578985`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-18.31531222832654, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-17.622169547740718`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-17.21670593962843, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-16.92902461717543, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-16.70588151586076, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-16.52356025906661, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-16.36940979352498, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-16.23587856161471, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.499801670362265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.806658989776445, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.4011953816641554`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.1135140592111554`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8903709578964847`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.7080497011023352`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.553899235560707, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.4203680036504367`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.769341622984318*^9, 3.769341658753543*^9}, {
   3.769342650916984*^9, 3.769342660452045*^9}, 3.769342721045363*^9, 
   3.769342767975196*^9, 3.769342819840057*^9, 3.7693440228554907`*^9, 
   3.769351986631673*^9, 3.769357365477858*^9, 3.782253076462481*^9}]
}, Closed]],

Cell["and for \[Rho]max=10000", "Text",
 CellChangeTimes->{{3.769341756699089*^9, 3.76934176186764*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.0001"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SuperscriptBox["m", "*"], "=", 
   SqrtBox[
    RowBox[{
     RowBox[{"\[CapitalLambda]1", "[", 
      RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], "]"}],
      "/", "2"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "/", "\[Lambda]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Psi]term", ",", " ", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[Rho]max", " ", 
              SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]]}], 
         RowBox[{
          SqrtBox["\[Pi]"], " ", 
          SqrtBox["\[Rho]max"], " ", "\[Psi]"}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"4", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[Psi]", "2"], "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}], 
             ")"}]}]]}], 
         RowBox[{
          SqrtBox["\[Pi]"], " ", 
          SuperscriptBox["\[Rho]max", 
           RowBox[{"3", "/", "2"}]], " ", 
          SuperscriptBox["\[Psi]", "3"]}]]}]}], "}"}], "/.", 
     RowBox[{"\[Rho]max", "\[Rule]", 
      RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
    RowBox[{"\[Theta]", "\[Rule]", 
     RowBox[{"n", "/", "2"}]}]}], "/.", 
   RowBox[{"\[Psi]wt", "\[Rule]", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mwt", ",", 
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{"%", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Psi]", ",", 
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SqrtBox[
                RowBox[{"1", "-", 
                 FractionBox["mwt", "mmax"]}]]}], ")"}]}], ",", 
            RowBox[{"2", "-", 
             RowBox[{"2", " ", 
              SqrtBox[
               FractionBox[
                RowBox[{"mmax", "+", 
                 SuperscriptBox["m", "*"]}], "mmax"]]}]}]}], "}"}]}], "]"}]}],
        "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"mwt", ",", 
        RowBox[{"-", "0.3"}], ",", 
        RowBox[{"-", "0.01"}], ",", "0.01"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "%", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ListLogPlot", "[", 
   RowBox[{"%", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.76934174971218*^9, {3.76934253032803*^9, 3.769342559328599*^9}, 
   3.7693428229883327`*^9, 3.7693440269076967`*^9}],

Cell[BoxData["10000.`"], "Output",
 CellChangeTimes->{
  3.769341750236237*^9, {3.7693425308800287`*^9, 3.769342564727848*^9}, 
   3.769342823839346*^9, 3.769344027941996*^9, 3.7693519873637037`*^9, 
   3.769357366131237*^9, 3.782253080712988*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQbQwGl/cfKDO4X7+t7ED/oa8aMf2X9l/P8ZzInFV6
4HXgDrnW1xf3P16ceKZdteSAx8MqkXXuF/e77HrqZ/yy6MCSAluu64sv7D+Y
mcSit7XwAAMYXNh/tYdJYGFnwQGQ7sAd5/Zr/Pq2Nvds3gGw8oKz+xULC0TN
ZuYcAFoGtPHM/rV7GVO/lmUdABv/8NT+zrjmDI70jAMzweDk/oi197afy0w7
EAQ28MR+150LD66qTzkAMs2W6/j+xWHB5xlXJh0AO//Q0f2/3aYx2DxLOAA2
rurIfukn8wo78uMOQPx7eH8p782P/DbRUP8d3B/XYGr+zijiwGKwAw/sn7Nk
20m20FCo+/ftX10wdab94iCoe/fsnyh2aledXMCBGWD37dx/1uZaiW+/N9Q9
2/cvjE0VVbR3h9q/ZX/Bl4I/jH7OB16B7du4f4fLWubQKnuo+ev2P93T35Uu
ZQk1b+V+rud+aS1VxgcqwPqX7L91ksU5RUX3wAaw+nn7dd5lPU/drnKgACw/
ZT9TT+XjUAeZAw1gfsv+5r6w2TeWihwAAOOt/C8=
      "]]}, 
    {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQbQwGl/eXfTlnK8PadqD/0FeNmP5L+8XTwkV4drUc
eB24Q6719cX9ComOP7nKmw94PKwSWed+cb/zPp3DDjZNB5YU2HJdX3xh/6y3
jNOucTYeYACDC/s1OLmfvt1ffwCkO3DHuf1Clqd7Z9fWHgArLzi7/2zvGgZB
3+oDQMuANp7ZX2O/ynqNXuUBsPEPT+2PvRvXcU6p/MBMMDi5v1nw6rI7mqUH
gsAGnth/3zX9t51L8QGQabZcx/efZ2U/kFhUeADs/ENH98cmbizKysw/ADau
6sj+v7PCH0SL5xyA+Pfw/vw4xged7zOg/ju4f6u4kPiHT6kHFoMdeGD/wgUP
A6YoJUPdv2//jq0bNdrrE6Du3bO/sfPh9JOiMQdmgN23c//6hod7VneHQ92z
ff/P2klKisnBUPu37HcJNdDNsPU/8Aps38b9rWtMmxSbPKDmr9t/KONFpdgs
J6h5K/fr/ZhaulLM+kAFWP+S/Tfm7875scPowAaw+nn7lU/uX3UiRONAAVh+
yv5zEZ9W5v+VPdAA5rfs3zLv4fkn/cIHADbY/uk=
      "]]}, 
    {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQbQwGl/dn1j7+FLqz7ED/oa8aMf2X9jvrTjp+MKf0
wOvAHXKtry/uj1udv1FXo+SAx8MqkXXuF/f/7N2ecuB10YElBbZc1xdf2J8s
8/fAwu2FBxjA4ML+wzo2t391FxwA6Q7ccW6/9P18/jcX8w6AlRec3X+U6eax
2rk5B4CWAW08s99tXcNOluqsA2DjH57aL7OXsexuVsaBmWBwcr97JJdHem7a
gSCwgSf2OzSL2rE0pxwAmWbLdXz/V993apJrkg6AnX/o6P7zMsLNvC8TDoCN
qzqyf52v3YlpJXEHIP49vP855/SkOodoqP8O7l/Owdy2ziziwGKwAw/st74z
p5YtIhTq/n37N/uKSKctDYK6d8/+rtNbAlbJBxyYAXbfzv2sZhy//Pq9oe7Z
vn/9qs2X7WzcofZv2V/ndZcl1t35wCuwfRv3L9/9NXNikj3U/HX7bxQu/J//
yQJq3sr9Xbc/RIsYGx+oAOtfsn9+Tcs6uxfaBzaA1c/bv0j05Lvt6koHCsDy
U/bbmns1HT0jcqABzG/ZL8z4a9W/LPYDAEbF/QU=
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-0.3, -704.638789765201},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-704.591038456178, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "306"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {-587.1591987134816, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "255"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {-469.7273589707853, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "204"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {-352.295519228089, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "153"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {-234.86367948539265`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "102"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {-117.43183974269633`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "51"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}}, {{-704.591038456178, 
       FormBox["\"\"", TraditionalForm]}, {-587.1591987134816, 
       FormBox["\"\"", TraditionalForm]}, {-469.7273589707853, 
       FormBox["\"\"", TraditionalForm]}, {-352.295519228089, 
       FormBox["\"\"", TraditionalForm]}, {-234.86367948539265`, 
       FormBox["\"\"", TraditionalForm]}, {-117.43183974269633`, 
       FormBox["\"\"", TraditionalForm]}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{-0.3, 0.}, {-704.638789765201, -2.9272435529275156`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, {{-704.591038456178, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "306"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-587.1591987134816, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "255"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-469.7273589707853, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "204"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-352.295519228089, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "153"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-234.86367948539265`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "102"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-117.43183974269633`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "51"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}}}]], "Output",
 CellChangeTimes->{
  3.769341750236237*^9, {3.7693425308800287`*^9, 3.769342564727848*^9}, 
   3.769342823839346*^9, 3.769344027941996*^9, 3.7693519873637037`*^9, 
   3.769357366131237*^9, 3.782253081178865*^9}]
}, Closed]],

Cell["\<\
Right, so for the small \[Psi] approx we need to integrate\
\>", "Text",
 CellChangeTimes->{{3.76934181920712*^9, 3.769341834717923*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"small\[Psi]approx", "=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[Rho]max", " ", 
          SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]]}], 
     RowBox[{
      SqrtBox["\[Pi]"], " ", 
      SqrtBox["\[Rho]max"], " ", "\[Psi]"}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.769341848722046*^9, 3.7693418551624928`*^9}}],

Cell["\<\
which has a simple expression if we do not integrate all the way back to -\
\[Infinity]\
\>", "Text",
 CellChangeTimes->{{3.769342301045445*^9, 3.769342302773172*^9}, {
  3.769342430637306*^9, 3.769342448350012*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{"small\[Psi]approx", ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]", ",", "a", ",", "b"}], "}"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"a", "<", "b", "<", "0"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.76934225708386*^9, 3.769342292894826*^9}, {
  3.769342423096365*^9, 3.769342428770508*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[Rho]max", " ", 
        SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]], " ", 
    RowBox[{"Log", "[", 
     FractionBox["b", "a"], "]"}]}], 
   RowBox[{
    SqrtBox["\[Pi]"], " ", 
    SqrtBox["\[Rho]max"]}]]}]], "Output",
 CellChangeTimes->{{3.7693422781982203`*^9, 3.7693422938193417`*^9}, {
   3.769342424959627*^9, 3.7693424526717033`*^9}, 3.7693519883767643`*^9, 
   3.7693573671544456`*^9, 3.7822530856872883`*^9}]
}, Closed]],

Cell["\<\
And for the large \[Rho]max we need to integrate\
\>", "Text",
 CellChangeTimes->{{3.769341858662673*^9, 3.7693418681763906`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"large\[Rho]approx", "=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"4", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Psi]", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}], ")"}]}]]}], 
     RowBox[{
      SqrtBox["\[Pi]"], " ", 
      SuperscriptBox["\[Rho]max", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["\[Psi]", "3"]}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7693418801037283`*^9, 3.769341889805275*^9}, {
   3.7693425038691177`*^9, 3.7693425096219397`*^9}, 3.769342828840803*^9, {
   3.7693430206595716`*^9, 3.769343056292419*^9}, 3.769343099741818*^9}],

Cell["here we can again use the Laplace approx with", "Text",
 CellChangeTimes->{{3.769343536224642*^9, 3.769343566267877*^9}, {
   3.769343824532254*^9, 3.769343824836315*^9}, 3.771274830736244*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"q", "[", "\[Psi]_", "]"}], ":=", 
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Psi]", "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}], 
    ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"h", "[", "\[Psi]_", "]"}], ":=", 
  RowBox[{"-", 
   FractionBox["4", 
    RowBox[{
     SqrtBox["\[Pi]"], " ", 
     SuperscriptBox["\[Rho]max", 
      RowBox[{"3", "/", "2"}]], " ", 
     SuperscriptBox["\[Psi]", "3"]}]]}]}]}], "Input",
 CellChangeTimes->{{3.769343567391309*^9, 3.769343608689774*^9}, 
   3.769343711271929*^9}],

Cell["\<\
and we know that q is peaked at\
\>", "Text",
 CellChangeTimes->{{3.769343622110366*^9, 3.76934362711032*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"q", "[", "\[Psi]", "]"}], ",", "\[Psi]"}], "]"}], "\[Equal]", 
    "0"}], ",", "\[Psi]"}], "]"}]], "Input",
 CellChangeTimes->{{3.76934362947373*^9, 3.769343643337367*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\[Psi]", "\[Rule]", 
    FractionBox["\[Psi]wt", "2"]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.769343643834055*^9, 3.769343713071087*^9, 
  3.769351993884047*^9, 3.7693573724972143`*^9, 3.782253092539995*^9}]
}, Closed]],

Cell["where h equals", "Text",
 CellChangeTimes->{{3.7693436490467854`*^9, 3.7693436572391243`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"h", "[", 
  RowBox[{"\[Psi]wt", "/", "2"}], "]"}]], "Input",
 CellChangeTimes->{3.769343718582479*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["32", 
   RowBox[{
    SqrtBox["\[Pi]"], " ", 
    SuperscriptBox["\[Rho]max", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["\[Psi]wt", "3"]}]]}]], "Output",
 CellChangeTimes->{{3.769343707642309*^9, 3.769343719489315*^9}, 
   3.769351993968452*^9, 3.769357372600025*^9, 3.7822530939717083`*^9}]
}, Closed]],

Cell["giving", "Text",
 CellChangeTimes->{{3.769343687609798*^9, 3.769343689136178*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"h", "[", 
   RowBox[{"\[Psi]wt", "/", "2"}], "]"}], 
  RowBox[{"Exp", "[", 
   RowBox[{"q", "[", "\[Psi]", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"verylarge\[Rho]approx", "=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"32", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Psi]", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}], ")"}]}]]}], 
     RowBox[{
      SqrtBox["\[Pi]"], " ", 
      SuperscriptBox["\[Rho]max", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["\[Psi]wt", "3"]}]]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.769343727588868*^9, 3.769343742860176*^9}, {
  3.771274853473178*^9, 3.771274853612505*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"32", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Psi]", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}], ")"}]}]]}], 
   RowBox[{
    SqrtBox["\[Pi]"], " ", 
    SuperscriptBox["\[Rho]max", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["\[Psi]wt", "3"]}]]}]], "Output",
 CellChangeTimes->{{3.7693437363461943`*^9, 3.7693437432852716`*^9}, 
   3.769351994052849*^9, 3.7693573727011642`*^9, 3.782253095187269*^9}]
}, Closed]],

Cell["Numerical check", "Text",
 CellChangeTimes->{{3.769343757212043*^9, 3.7693437592984257`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"large\[Rho]approx", ",", "verylarge\[Rho]approx"}], "}"}], "/.", 
    RowBox[{"\[Rho]max", "\[Rule]", "10000"}]}], "/.", 
   RowBox[{"\[Psi]wt", "\[Rule]", 
    RowBox[{"-", "0.2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]", ",", 
     RowBox[{"-", "0.2"}], ",", 
     RowBox[{"-", "0.01"}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.769343752454953*^9, 3.769343778103793*^9}, 
   3.769343852781999*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAAz+RFkZmZyb826vndrawuNrQw+b2w
l8m/oE07GoFFMDaafKzqx5XJv42XgZsWQzE2ZhQTRPaRyb+uqxF1AW0zNvxD
4PZSism/VLtDuUqXODYoo3pcDHvJv0mG/aDmq0M2gWGvJ39cyb/rqiDiiANZ
NjPeGL5kH8m/jeAawrS0gzYKLUxo6JrIvxGZCxIund02nGJ8pjMfyL9yL515
vb0tN9Gjyhvspce/ux1FxY9TeDd5OnkOXSLHv7V8tKKAgcY33LcklZWnxr+u
nPWPYsIMOLKKMJmGIsa/bQu3Wj44VDgraVrU5J/Fv1RcdGcG65Y4Xy6Bowom
xb/6LS+Cw43SOAZJCPDoocS//KCeyn7yDzloSozQjibEvzlMdYhW/EM5bVcu
6KGtw79THgJmd9x0OeW5MH1tKsO/Y06faI5mpjkYAzCmALDCv44uBfhwD9I5
vqGPTEwrwr87VjlxSCf9OQdMDSoFqcG/hKcJ3QtvIzoL3YebhS/Bv7HB/3QT
HkQ6gsNiir6rwL8rqgL3LyhkOrSQOg2/MMC/EzW/hSrofzqwZuUa8Fa/v6+Y
ZpTSyZc6PsORiTxRvr8zMCih5bKtOkPtNyAYXb2/u5DmuA1Lvjotwp6xZFS8
v55Y1nF5Jsw6jmT/akBdu78guoUt7L7VOjUenJL2arq/6FNNfAEf3TrBgvm0
HWS5v6twtUlTM+E6xLRQ/9NuuL/fwLnOB3XhOqyRaET7ZLe/dOgwsmty3jra
hbz3/F+2vzht7kuvz9Y6f0cK041stb94obJWBmHOOgm0GKmPZLS/+vTkcgDW
wDoK7iCnIG6zv8SLYS5y4bA6UT9lE4x8sr9Xb54p4SCeOn07anpodrG/yvQX
z6G3hTogBWkJ1IGwvzTOHY5sSm06UfNQJmHxrr/BNcIC6ihPOk93w4k4Aq2/
lAcbbMGYLzrZKa7JxByrv1JReG5wBw06LjIa/zIOqb/copcxroDkOXDVeYS/
Iqe/bpT9wqCfvDl9zlr/LQ6lvxgtsfPrKY45FvazVlEDo7/fUBX6cOdcOZy4
AP6SG6G/t0YNh5KMLDnZoZ01bRWev23O/spqGPU4UwghD/E5mr/x2pFdlJfA
OObLlKHecZa/PVfhvFZdiTgPOwsfkFeSv84e7JvPDE44JMDRePwGjb+rgomb
kQYVOKgeIg7M5Iy/q3rfT2IoFDgsfXKjm8KMv5FFITt6UxM4NDoTzjp+jL/j
JvOV9cMROES0VCN59Yu/f1KDEmcIDjhkqNfN9eOKv5zhatQmfAU4pJDdIu/A
iL/xfI5qHCL2NyjvLbi+noi/W7v6xNc99TesTX5NjnyIv1os/3UCY/Q3tAof
eC04iL9E4OYpFsjyN8SEYM1rr4e/CKm1qFnm7zfkeON36J2Gv9PwsTLnEOc3
aNczDbh7hr9Nx1Zf4CfmN+w1hKKHWYa/1IhjDGRI5Tf08iTNJhWGv8hSY5h4
pOM3BG1mImWMhb+W6cVmu77gN4jLtrc0aoW/dPTUV80X4DcMKgdNBEiFv2X8
VR9V7943FOend6MDhb/kno+dUpXcN5hF+Axz4YS/fsaxBYd62zccpEiiQr+E
v4G+4y40a9o3oAKZNxKdhL8ituCJ4GbZNyVh6czheoS/9T1Hnxdt2Dc6wm2V

     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAAz+RFkZmZyb/LIQvAraxeNrQw+b2w
l8m/43kxNt1BYDaafKzqx5XJvwzSjAFeO2E2ZhQTRPaRyb+gpY5mo1tjNvxD
4PZSism/2LlgeV9raDYoo3pcDHvJv8Nm2Z7MZXM2gWGvJ39cyb+CVmpIFlKI
NjPeGL5kH8m/L5Yv+LmfsjYKLUxo6JrIvwSEDlI0Swo3nGJ8pjMfyL90nq3r
l+FYN9Gjyhvspce/x/BhqfMsozd5OnkOXSLHv7tU/aLhm/A33LcklZWnxr/P
mADZVu4zOLKKMJmGIsa/t005Wf4jejgraVrU5J/Fv++6L415oLs4Xy6Bowom
xb918D4M1ev0OAZJCPDoocS/6Nj215q5MDloSozQjibEv5ZchXJjfmM5bVcu
6KGtw792NOUuMvOSOeW5MH1tKsO/1NHT8KvMwjkYAzCmALDCvxyh5rHSGew5
vqGPTEwrwr8WzOpKVNgUOgdMDSoFqcG/3zVM8DWFOToL3YebhS/Bv+3Wiu1T
WFg6gsNiir6rwL+u1vAdFER2OrSQOg2/MMC/WOL9qnUkkDqwZuUa8Fa/v48x
Bapw0qU6PsORiTxRvr+Essin9qm4OkPtNyAYXb2/CF50Ynjbxjotwp6xZFS8
vxt0VeUdE9M6jmT/akBdu7+AXHZIBo/aOjUenJL2arq/qUQTykYA4DrBgvm0
HWS5v83XMGZlyOA6xLRQ/9NuuL83KmAwg1reOqyRaET7ZLe/GPxEOnA81zra
hbz3/F+2v5TCcXQMds46f0cK041stb91qhCoPs7BOgm0GKmPZLS/loRbT1EF
sToK7iCnIG6zv1TBoYPhhZ06UT9lE4x8sr+C8ASM3rCGOn07anpodrG/bKfw
p2ySazogBWkJ1IGwvznJZkFKaU86UfNQJmHxrr+JkkgYKYMrOk93w4k4Aq2/
5ByPmZT8BjrZKa7JxByrv/w9ACnvPeE5LjIa/zIOqb8hikx60jizOXDVeYS/
Iqe/YLuY2LQghTl9zlr/LQ6lv1M5FaVOyFA5FvazVlEDo7+5eWoil64XOZy4
AP6SG6G/y96nOlQK4TjZoZ01bRWev/b8hJ38HaE4UwghD/E5mr9Yz1UpCddh
OObLlKHecZa/63HWHy8YITgPOwsfkFeSv4r7pEL7GtY3JMDRePwGjb/ir537
vKaON6geIg7M5Iy/Cw7SWHr7jDcsfXKjm8KMv1QRLxUvZ4s3NDoTzjp+jL99
2om8r36IN0S0VCN59Yu/bt/ngciPgzdkqNfN9eOKv55Sd0OO5ng3pJDdIu/A
iL8FTku1ggJkNyjvLbi+noi/GDs98//kYjesTX5NjnyIv918Rks112E3tAof
eC04iL8CCF4d0s5fN8SEYM1rr4e/Csup7ZJDWTfkeON36J2Gv0NLdA6hz083
aNczDbh7hr8CR+BngARON+w1hKKHWYa/Ly/jYvNSTDf08iTNJhWGv2edgdsG
N0k3BG1mImWMhb8w3WiVFPlDN4jLtrc0aoW/bbT5lyvXQjcMKgdNBEiFv2ZY
IiiBxUE3FOend6MDhb/3h2q1t54/N5hF+Axz4YS/z39ua3PSPTccpEiiQr+E
v7kmA3sMIDw3oAKZNxKdhL8ep9JSE4Y6NyVh6czheoS/nccnhywDOTdKaWXZ

     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{-0.2, 0},
  Method->{},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.769343753098773*^9, 3.769343779348171*^9}, 
   3.769343853522756*^9, 3.7693519941688547`*^9, 3.769357372833041*^9, 
   3.7822530993570137`*^9}]
}, Closed]],

Cell["\<\
which we can integrate over all \[Psi] with little error (because exponential \
tails)\
\>", "Text",
 CellChangeTimes->{{3.769344445959054*^9, 3.7693444836643047`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{"verylarge\[Rho]approx", ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]", ",", 
     RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Rho]max", ">", "0"}], ",", 
      RowBox[{"\[Psi]wt", "<", "0"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7693444542816973`*^9, 3.7693444978849583`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"32", " ", 
    SqrtBox["2"], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[Rho]max", " ", 
        SuperscriptBox["\[Psi]wt", "2"]}], "8"]}]]}], 
   RowBox[{
    SuperscriptBox["\[Rho]max", "2"], " ", 
    SuperscriptBox["\[Psi]wt", "3"]}]]}]], "Output",
 CellChangeTimes->{3.7693444713505383`*^9, 3.769344503773312*^9, 
  3.769351994669842*^9, 3.769357373283703*^9, 3.7822531081931*^9}]
}, Closed]],

Cell["\<\
OK, so our small \[Rho]max approx for the probability of 2-step subcritical \
rescue is\
\>", "Text",
 CellChangeTimes->{{3.7693440421893387`*^9, 3.769344061340617*^9}, {
  3.769344407464089*^9, 3.7693444108469477`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"small\[Psi]approxRescue\[Psi]", "=", 
  RowBox[{"constant", " ", 
   RowBox[{"Integrate", "[", 
    RowBox[{"small\[Psi]approx", ",", 
     RowBox[{"{", 
      RowBox[{"\[Psi]", ",", "a", ",", "b"}], "}"}], ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"a", "<", "b", "<", "0"}], "}"}]}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"small\[Psi]approxRescue", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"%", "/.", 
        RowBox[{"a", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SqrtBox[
             RowBox[{"1", "-", 
              FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}], "/.", 
       RowBox[{"b", "\[Rule]", " ", 
        RowBox[{"2", 
         RowBox[{"(", 
          RowBox[{"1", "-", " ", 
           SqrtBox[
            RowBox[{"1", "+", 
             FractionBox["mstar", "mmax"]}]]}], ")"}]}]}]}], "/.", 
      RowBox[{"mstar", "\[Rule]", 
       SqrtBox[
        RowBox[{"\[CapitalLambda]0approx", "/", "2"}]]}]}], "/.", 
     RowBox[{"\[Rho]max", "\[Rule]", 
      RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
    RowBox[{"\[Theta]", "\[Rule]", 
     RowBox[{"n", "/", "2"}]}]}], "/.", 
   RowBox[{"\[Psi]wt", "\[Rule]", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}]}]}], "Input",
 CellChangeTimes->{{3.769344076056356*^9, 3.769344138219789*^9}, {
  3.769344314630602*^9, 3.769344395421007*^9}, {3.769351953292069*^9, 
  3.7693519589549437`*^9}, {3.769356678279675*^9, 3.7693566914316587`*^9}, {
  3.769357700897208*^9, 3.7693577035820436`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[Rho]max", " ", 
        SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]], " ", "U", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox["\[Psi]wt", "2"]}], ")"}], 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "\[Theta]"}]}]], " ", 
    RowBox[{"Log", "[", 
     FractionBox["b", "a"], "]"}]}], 
   RowBox[{"\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox["\[Psi]wt", "4"]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.769344074058526*^9, 3.769344078236953*^9}, {
   3.769344113074533*^9, 3.7693441318488493`*^9}, {3.769344315825962*^9, 
   3.769344397262492*^9}, 3.769351962203622*^9, 3.769351995223811*^9, 
   3.769357373828759*^9, 3.769357705141485*^9, {3.769429070627803*^9, 
   3.769429089390896*^9}, 3.7822531100396557`*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"mmax", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SqrtBox[
            RowBox[{"1", "-", 
             FractionBox["mwt", "mmax"]}]]}], ")"}], "2"]}], "\[Lambda]"]}]], 
    " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox["mwt", "mmax"]}], ")"}], 
     FractionBox[
      RowBox[{"1", "-", "n"}], "2"]], " ", "U", " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          SqrtBox[
           RowBox[{"U", " ", 
            SqrtBox[
             RowBox[{"mmax", " ", "\[Lambda]"}]]}]], 
          RowBox[{"mmax", " ", 
           SuperscriptBox["\[Pi]", 
            RowBox[{"1", "/", "4"}]]}]]}]]}], 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["mwt", "mmax"]}]]}]], "]"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SqrtBox[
          RowBox[{"1", "-", 
           FractionBox["mwt", "mmax"]}]]}], ")"}]}]}], ")"}], " ", 
    "\[Pi]"}]]}]], "Output",
 CellChangeTimes->{{3.769344074058526*^9, 3.769344078236953*^9}, {
   3.769344113074533*^9, 3.7693441318488493`*^9}, {3.769344315825962*^9, 
   3.769344397262492*^9}, 3.769351962203622*^9, 3.769351995223811*^9, 
   3.769357373828759*^9, 3.769357705141485*^9, {3.769429070627803*^9, 
   3.769429089390896*^9}, 3.782253110042918*^9}]
}, Closed]],

Cell["\<\
and our very large \[Rho]max approx for the probability of 2-step subcritical \
rescue is\
\>", "Text",
 CellChangeTimes->{{3.7693444152137833`*^9, 3.769344435330826*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"verylarge\[Rho]approxRescue\[Psi]", "=", 
  RowBox[{"constant", " ", 
   RowBox[{"Integrate", "[", 
    RowBox[{"verylarge\[Rho]approx", ",", 
     RowBox[{"{", 
      RowBox[{"\[Psi]", ",", 
       RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Rho]max", ">", "0"}], ",", 
        RowBox[{"\[Psi]wt", "<", "0"}]}], "}"}]}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"verylarge\[Rho]approxRescue", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{"\[Rho]max", "\[Rule]", 
      RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
    RowBox[{"\[Theta]", "\[Rule]", 
     RowBox[{"n", "/", "2"}]}]}], "/.", 
   RowBox[{"\[Psi]wt", "\[Rule]", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}]}]}], "Input",
 CellChangeTimes->{{3.769344511166485*^9, 3.769344524400169*^9}, {
  3.769351971061849*^9, 3.769351973672997*^9}, {3.769357321492117*^9, 
  3.7693573251199913`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"16", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"\[Rho]max", " ", 
        SuperscriptBox["\[Psi]wt", "2"]}], "8"]}]], " ", 
    SqrtBox[
     FractionBox["2", "\[Pi]"]], " ", "U", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox["\[Psi]wt", "2"]}], ")"}], 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "\[Theta]"}]}]]}], 
   RowBox[{
    SuperscriptBox["\[Rho]max", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox["\[Psi]wt", "4"]}], ")"}], " ", 
    SuperscriptBox["\[Psi]wt", "3"]}]]}]], "Output",
 CellChangeTimes->{
  3.76934452574259*^9, {3.769351975313179*^9, 3.769351995506876*^9}, {
   3.769357352547307*^9, 3.76935737411373*^9}, 3.7694291060370827`*^9, 
   3.782253112329226*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"mmax", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SqrtBox[
            RowBox[{"1", "-", 
             FractionBox["mwt", "mmax"]}]]}], ")"}], "2"]}], 
       RowBox[{"2", " ", "\[Lambda]"}]]}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox["mwt", "mmax"]}], ")"}], 
     FractionBox[
      RowBox[{"1", "-", "n"}], "2"]], " ", 
    SqrtBox[
     FractionBox["2", "\[Pi]"]], " ", "U"}], 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["mwt", "mmax"]}]]}], ")"}], "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SqrtBox[
          RowBox[{"1", "-", 
           FractionBox["mwt", "mmax"]}]]}], ")"}]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["mmax", "\[Lambda]"], ")"}], 
     RowBox[{"3", "/", "2"}]]}]]}]], "Output",
 CellChangeTimes->{
  3.76934452574259*^9, {3.769351975313179*^9, 3.769351995506876*^9}, {
   3.769357352547307*^9, 3.76935737411373*^9}, 3.7694291060370827`*^9, 
   3.782253112332144*^9}]
}, Closed]],

Cell["Check formula for text", "Text",
 CellChangeTimes->{{3.769357657113393*^9, 3.7693576602971077`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"small\[Psi]approxRescue\[Psi]", "\[Equal]", 
     RowBox[{"U", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox["\[Psi]wt", "2"]}], ")"}], 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "\[Theta]"}]}]], 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox["\[Psi]wt", "4"]}], ")"}]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "\[Alpha]"}]], 
      FractionBox[
       RowBox[{"  ", 
        RowBox[{"Log", "[", 
         FractionBox["a", "b"], "]"}]}], 
       RowBox[{"\[Pi]", " "}]]}]}], "/.", 
    RowBox[{"\[Alpha]", "\[Rule]", 
     RowBox[{"\[Rho]max", " ", 
      RowBox[{
       SuperscriptBox["\[Psi]wt", "2"], "/", "4"}]}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"a", "<", "b", "<", "0"}], "}"}]}], "]"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"verylarge\[Rho]approxRescue\[Psi]", "==", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "U"}], 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox["\[Psi]wt", "2"]}], ")"}], 
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "\[Theta]"}]}]], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox["\[Psi]wt", "4"]}], ")"}]], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", "\[Alpha]"}]], 
          FractionBox["1", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"\[Alpha]", "/", "2"}], " ", ")"}], "3"], "\[Pi]"}]]}], 
         ")"}], 
        RowBox[{"1", "/", "2"}]]}], "/.", 
      RowBox[{"\[Alpha]", "\[Rule]", 
       RowBox[{"\[Rho]max", " ", 
        RowBox[{
         SuperscriptBox["\[Psi]wt", "2"], "/", "4"}]}]}]}], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Rho]max", ">", "0"}], ",", 
     RowBox[{"\[Psi]wt", ">", "0"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.769357224535054*^9, 3.76935734827182*^9}, {
  3.7693573868286943`*^9, 3.769357409855579*^9}, {3.769357547925452*^9, 
  3.769357653191647*^9}, {3.769357799637146*^9, 3.769357801671088*^9}, {
  3.769359490357843*^9, 3.769359591412189*^9}, {3.76935964383075*^9, 
  3.769359701823406*^9}, {3.769359815450259*^9, 3.769359858690977*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.769357349325036*^9, 3.769357410571665*^9}, {
   3.7693575485436707`*^9, 3.769357554584426*^9}, {3.769357585390606*^9, 
   3.769357653563849*^9}, 3.76935780233497*^9, {3.7693594928038816`*^9, 
   3.769359505942483*^9}, {3.769359553024963*^9, 3.7693595918666773`*^9}, {
   3.769359647631649*^9, 3.769359660706328*^9}, {3.769359691552788*^9, 
   3.7693597023153477`*^9}, {3.7693598189849577`*^9, 3.769359859079417*^9}, 
   3.7694291081240873`*^9, 3.782253114286359*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.769357349325036*^9, 3.769357410571665*^9}, {
   3.7693575485436707`*^9, 3.769357554584426*^9}, {3.769357585390606*^9, 
   3.769357653563849*^9}, 3.76935780233497*^9, {3.7693594928038816`*^9, 
   3.769359505942483*^9}, {3.769359553024963*^9, 3.7693595918666773`*^9}, {
   3.769359647631649*^9, 3.769359660706328*^9}, {3.769359691552788*^9, 
   3.7693597023153477`*^9}, {3.7693598189849577`*^9, 3.769359859079417*^9}, 
   3.7694291081240873`*^9, 3.782253114357113*^9}]
}, Closed]],

Cell["\<\
Compare to better approximation\
\>", "Text",
 CellChangeTimes->{{3.769344560330846*^9, 3.7693445649473047`*^9}, {
  3.769344675526155*^9, 3.7693446777862988`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"n0", "=", 
   SuperscriptBox["10", "4"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "4"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mwt", ",", 
        RowBox[{"U", " ", 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"fm", "[", 
             RowBox[{
             "m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
             "]"}], 
            FractionBox[
             RowBox[{" ", 
              RowBox[{"\[CapitalLambda]1", "[", 
               RowBox[{
               "m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
               "]"}]}], 
             RowBox[{"Abs", "[", "m1", "]"}]]}], "\[IndentingNewLine]", ",", 
           RowBox[{"{", 
            RowBox[{"m1", ",", "mwt", ",", 
             RowBox[{"-", "pr0"}]}], "}"}]}], "]"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"mwt", ",", 
        RowBox[{
         RowBox[{"-", "0.8"}], "mmax"}], ",", 
        RowBox[{
         RowBox[{"-", "0.1"}], "mmax"}], ",", 
        RowBox[{"0.1", "mmax"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
    "}"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LogPlot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"U", " ", "small\[Psi]approxRescue"}], ",", 
        RowBox[{"U", " ", "verylarge\[Rho]approxRescue"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"mwt", ",", 
        RowBox[{
         RowBox[{"-", "0.8"}], "mmax"}], ",", 
        RowBox[{
         RowBox[{"-", "0.1"}], "mmax"}]}], "}"}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Frame", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Wildtype growth rate\>\"", ",", ",", ",", 
         "\"\<Rate of rescue\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"FrameTicks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{"\"\<small \!\(\*
StyleBox[\"\[Psi]\",
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<large \!\(\*
StyleBox[SubscriptBox[\"\[Rho]\", \"max\"],
FontSlant->\"Italic\"]\)\>\""}], "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "/", "4"}], ",", 
            RowBox[{"1", "/", "4"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotMarkers", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "Medium"}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "n0"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.751063189929034*^9, 3.751063195260857*^9}, {
   3.751063251777727*^9, 3.751063315775334*^9}, {3.751063345833967*^9, 
   3.7510634151982183`*^9}, {3.75106350691444*^9, 3.7510635766974697`*^9}, {
   3.7510636416522617`*^9, 3.7510636671136007`*^9}, {3.751063706981538*^9, 
   3.751063818145526*^9}, {3.751063878393749*^9, 3.751063918090982*^9}, {
   3.7510754524207277`*^9, 3.751075515053173*^9}, {3.7510758146376743`*^9, 
   3.751075849277143*^9}, {3.769267809372196*^9, 3.769267839627472*^9}, {
   3.769344609666925*^9, 3.7693447688709307`*^9}, {3.769352055143111*^9, 
   3.769352067327169*^9}, {3.769352107343092*^9, 3.7693521435992327`*^9}, {
   3.769352213092353*^9, 3.7693522195278254`*^9}, {3.769352258848256*^9, 
   3.7693523712321653`*^9}, {3.769352555917631*^9, 3.769352561187896*^9}, {
   3.7693527428624687`*^9, 3.76935274334965*^9}, {3.769352839938251*^9, 
   3.769352851831604*^9}, 3.769353762585099*^9, {3.769359155547913*^9, 
   3.769359219855771*^9}, {3.7693593100731277`*^9, 3.769359415382304*^9}, {
   3.769429122237439*^9, 3.7694291247304363`*^9}, {3.7822531491739473`*^9, 
   3.7822531702061787`*^9}}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwVzHs81Pkex3GbbltZToVFK7ntYX1nxphhTLlsqamOiEpCEcK6JaJc2kXJ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        "]]}, 
      {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
       LineBox[CompressedData["
1:eJwVxX041AccAPBDQ0kaXeZKXuJ+SNyr8yRCxlhdTTqvk+omyyVNlJcUkkp5
KS9dj9ZSmbvrJBNJ+X47Euq8nNdTmHRSLSmVQtn2x+f5mO3Y6/uLOolE2vif
/6+2H88VCpVgk+PoUT/GQW7hQl5voRLksN+06zkHn321oZALlFCvoyCpRjmo
37qrOOeMEj6HvZFrqjgYJRiuyMhUwryecqHPMActRF2dsYeUUMpbPaVQcjDX
vJbsu10JXLXZptEWDkaSjwsXWCvBhWcFFCkHN/hXD2pc74Py6eDkagEHlcsJ
LwPnPliTLqAN0Dg4FvD741B5L3xcevtD1EcHtHgrljL8euGlZGbKt9oBdXU/
FS8f6YGd6yI6pUkOuDK9vzsrogf4XW5DfGcHrI1pYDlPdEOIab8sY46Nc6rx
KrUj3VCgnZ6zqJGN0ZVlcVzNbtC0ojrOZLAxS/N64I28LjiqdXiRG5eNdm1V
EZstu8AjaZvPAJmNM5Nbbh641gk/jS1uUfWxcH8R3fKmUyfEkaYNWH+wkHLp
iiLhngK8rwr573aw0H25ybUkbwVE4CvjOSoLDZf1l+YpOyDH3cHI+Q0TjeJs
RlhhHVAXNK/kRQUTH/jVur4abwePoJS82wlMLM4efmy9vx2uh5W5f3Rm4peU
FZ7eU21QRs2l8NWZqPfPNCVyaRs0C2aTh1oYmLhIPfKCeSs0H+hgVWUx0NXx
pNqsixyc2D+mnuQxcP4mswnFtkdgef4bw30mDLRdMRJ4e89D2K0wExeO0LH0
veWC1swWkH0QuV2S0DE57Sz7XUEz1Erulcij6Bgwp1eTVdIEe3f7Gfcz6JiZ
qpvm3/gATgcrNcTTNPyujt1E62yE0nW+tSF3afiVNLTFYeI+PGnfU16VRsMx
WiGn8tv7sPOut9ctHxraGiUUuJs2gB69nOm0kIbN2oNOX1zqwTHA+fPuYnvE
ckFIk48M/tT+2yXf1B4XhyXVQ/g9eLBVkfT9VTvkz55Ptc9A8Bw6mLvExg4t
ipvit1kDGMuCzkVeWo30oJ8Tb/HvwlV9D0HqitU4meoVw0ioBVvuxnqvU7Z4
J33TsgvnasD84ujZ6KlVyCkM3BzWWw2HjsbrvA1fheFGNYkeEzchb97rujaZ
DXqJKawU60oIPDs6QjazQRr5fFFZZAUcFlOqGw9ao3wiamY2oxz2yopN8iut
kFOV2ep1QgrP3Dzuh78mkBQsXXoiXgqzQ6Hl9S8IbJlrDW35VQoLWFkLTUYJ
DPXWf7PBRwr+AwOLOwYJPPbknJ6vjhR84pPJ5u0E9qiXbA45fQ2OXr4cHldB
YOwmVETnSuBp97hzfyyBLu+HKRUpEjCrgGNqvxGoLdTYOblPAndWkklEFIFF
Tz0nY30lsO44N1EQTmBDrNwg0UAC2cEWfsM8ApcU9ful54uBqxucFs0hcNB1
tqgxXQxr1zvWxTMJLFUZq7TixKA81KCRYk/gWvvtsSd5Yjg8PHjlBEEgX/Y8
P9tQDHNprVOphgTa7Zo/2K4lhpzpD65JBgR+0llF1f8kgphjLkdi9Ag8tTWq
Kq9PBJcZZ3qCtQjkTWd/7W4SwUyT69gGDQJNL97wNKwRwZMf/FVOc1R8ub4z
K0AkgjUayx5azVDxr7H3PUKhCIqcHhUYTFHxX0ZCiK0=
        "]]}}, {
      GraphicsComplexBox[{{-0.4, -23.380293460982386`}, \
{-0.35000000000000003`, -21.709920097164687`}, {-0.30000000000000004`, \
-20.10593573091527}, {-0.25, -18.606806847939144`}, {-0.2, \
-17.266052603347124`}, {-0.15000000000000002`, -16.144606351791783`}, \
{-0.09999999999999998, -15.310722179244417`}, {-0.04999999999999999, \
-14.879549145442892`}, {-0.4, -23.380293460982386`}, {-0.35000000000000003`, \
-21.709920097164687`}, {-0.30000000000000004`, -20.10593573091527}, {-0.25, \
-18.606806847939144`}, {-0.2, -17.266052603347124`}, {-0.15000000000000002`, \
-16.144606351791783`}, {-0.09999999999999998, -15.310722179244417`}, \
{-0.04999999999999999, -14.879549145442892`}}, {
        {GrayLevel[0], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 9], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 10], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 11], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 12], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 13], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 14], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 15], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 16]}, {}}], {}}}, InsetBox[
     TemplateBox[{
      StyleBox["\"small \
\\!\\(\\*\\nStyleBox[\\\"\[Psi]\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"", 
        StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 12],
       StyleBox[
       "\"large \\!\\(\\*\\nStyleBox[SubscriptBox[\\\"\[Rho]\\\", \
\\\"max\\\"],\\nFontSlant->\\\"Italic\\\"]\\)\"", StripOnInput -> False, 
        FontFamily -> "Helvetica", FontSize -> 12]},
      "LineLegend",
      DisplayFunction->(StyleBox[
        StyleBox[
         PaneBox[
          TagBox[
           GridBox[{{
              TagBox[
               GridBox[{{
                  GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                   ImageSize -> {20, 10}, PlotRangePadding -> None, 
                   ImagePadding -> 1, 
                   BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                  GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                   ImageSize -> {20, 10}, PlotRangePadding -> None, 
                   ImagePadding -> 1, 
                   BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                GridBoxAlignment -> {
                 "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                AutoDelete -> False, 
                GridBoxDividers -> {
                 "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
                GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}],
                "Grid"]}}, 
            GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
            AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
           "Grid"], Alignment -> Left, AppearanceElements -> None, 
          ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"],
          LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
        Background -> Automatic, StripOnInput -> False]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                    ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], "}"}],
            ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
     NCache[Scaled[{Rational[3, 4], Rational[1, 4]}], Scaled[{0.75, 0.25}]], 
     ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesOrigin->{-0.4, -26.244372881021604`},
   CoordinatesToolOptions:>{"DisplayFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& ), "CopiedValueFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& )},
   Frame->{True, False, False, True},
   FrameLabel->{{"", 
      FormBox["\"Rate of rescue\"", TraditionalForm]}, {
      FormBox["\"Wildtype growth rate\"", TraditionalForm], ""}},
   FrameTicks->{{None, {{-25.328436022934504`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
          TraditionalForm]}, {-23.025850929940457`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
          TraditionalForm]}, {-20.72326583694641, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-18.420680743952367`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-16.11809565095832, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-13.815510557964274`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-11.512925464970229`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-24.635288842374557`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-24.229823734266393`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.942141661814613`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.7189981105004, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.536676553706446`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.38252587387919, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.248994481254666`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.131211445598282`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-22.33270374938051, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.927238641272346`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.639556568820566`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.416413017506358`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.234091460712403`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.079940780885142`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.94640938826062, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.82862635260424, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.030118656386467`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.624653548278303`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.33697147582652, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.11382792451231, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.931506367718356`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.7773556878911, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.643824295266576`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.526041259610192`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.72753356339242, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.322068455284256`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.034386382832476`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.811242831518264`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.62892127472431, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.474770594897052`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.34123920227253, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.223456166616145`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-15.424948470398375`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-15.01948336229021, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.73180128983843, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.508657738524219`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.326336181730264`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.172185501903007`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.038654109278484`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-13.9208710736221, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-13.122363377404328`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.716898269296165`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.429216196844383`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.206072645530174`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.02375108873622, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.86960040890896, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.736069016284437`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.618285980628055`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {True, False}},
   GridLines->{None, None},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.4, -0.05}, {-26.244372881021604`, -11.482571327620285`}},
   PlotRangeClipping->True,
   PlotRangePadding->{
     Scaled[0.02], 
     Scaled[0.02]},
   Ticks->{Automatic, {{-25.328436022934504`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-23.025850929940457`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-20.72326583694641, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-18.420680743952367`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-24.635288842374557`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-24.229823734266393`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.942141661814613`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.7189981105004, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.536676553706446`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.38252587387919, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.248994481254666`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.131211445598282`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-22.33270374938051, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-21.927238641272346`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-21.639556568820566`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-21.416413017506358`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-21.234091460712403`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-21.079940780885142`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-20.94640938826062, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-20.82862635260424, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-20.030118656386467`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-19.624653548278303`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-19.33697147582652, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-19.11382792451231, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-18.931506367718356`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-18.7773556878911, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-18.643824295266576`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-18.526041259610192`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.72753356339242, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.322068455284256`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.034386382832476`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.811242831518264`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.62892127472431, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.474770594897052`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.34123920227253, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.223456166616145`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.424948470398375`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.01948336229021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.73180128983843, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.508657738524219`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.326336181730264`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.172185501903007`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.038654109278484`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.9208710736221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.716898269296165`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.429216196844383`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.02375108873622, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.86960040890896, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.736069016284437`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.618285980628055`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Thickness[Large], 
         Line[CompressedData["
1:eJwVzHs81Pkex3GbbltZToVFK7ntYX1nxphhTLlsqamOiEpCEcK6JaJc2kXJ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          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Thickness[Large], 
         Line[CompressedData["
1:eJwVxX041AccAPBDQ0kaXeZKXuJ+SNyr8yRCxlhdTTqvk+omyyVNlJcUkkp5
KS9dj9ZSmbvrJBNJ+X47Euq8nNdTmHRSLSmVQtn2x+f5mO3Y6/uLOolE2vif
/6+2H88VCpVgk+PoUT/GQW7hQl5voRLksN+06zkHn321oZALlFCvoyCpRjmo
37qrOOeMEj6HvZFrqjgYJRiuyMhUwryecqHPMActRF2dsYeUUMpbPaVQcjDX
vJbsu10JXLXZptEWDkaSjwsXWCvBhWcFFCkHN/hXD2pc74Py6eDkagEHlcsJ
LwPnPliTLqAN0Dg4FvD741B5L3xcevtD1EcHtHgrljL8euGlZGbKt9oBdXU/
FS8f6YGd6yI6pUkOuDK9vzsrogf4XW5DfGcHrI1pYDlPdEOIab8sY46Nc6rx
KrUj3VCgnZ6zqJGN0ZVlcVzNbtC0ojrOZLAxS/N64I28LjiqdXiRG5eNdm1V
EZstu8AjaZvPAJmNM5Nbbh641gk/jS1uUfWxcH8R3fKmUyfEkaYNWH+wkHLp
iiLhngK8rwr573aw0H25ybUkbwVE4CvjOSoLDZf1l+YpOyDH3cHI+Q0TjeJs
RlhhHVAXNK/kRQUTH/jVur4abwePoJS82wlMLM4efmy9vx2uh5W5f3Rm4peU
FZ7eU21QRs2l8NWZqPfPNCVyaRs0C2aTh1oYmLhIPfKCeSs0H+hgVWUx0NXx
pNqsixyc2D+mnuQxcP4mswnFtkdgef4bw30mDLRdMRJ4e89D2K0wExeO0LH0
veWC1swWkH0QuV2S0DE57Sz7XUEz1Erulcij6Bgwp1eTVdIEe3f7Gfcz6JiZ
qpvm3/gATgcrNcTTNPyujt1E62yE0nW+tSF3afiVNLTFYeI+PGnfU16VRsMx
WiGn8tv7sPOut9ctHxraGiUUuJs2gB69nOm0kIbN2oNOX1zqwTHA+fPuYnvE
ckFIk48M/tT+2yXf1B4XhyXVQ/g9eLBVkfT9VTvkz55Ptc9A8Bw6mLvExg4t
ipvit1kDGMuCzkVeWo30oJ8Tb/HvwlV9D0HqitU4meoVw0ioBVvuxnqvU7Z4
J33TsgvnasD84ujZ6KlVyCkM3BzWWw2HjsbrvA1fheFGNYkeEzchb97rujaZ
DXqJKawU60oIPDs6QjazQRr5fFFZZAUcFlOqGw9ao3wiamY2oxz2yopN8iut
kFOV2ep1QgrP3Dzuh78mkBQsXXoiXgqzQ6Hl9S8IbJlrDW35VQoLWFkLTUYJ
DPXWf7PBRwr+AwOLOwYJPPbknJ6vjhR84pPJ5u0E9qiXbA45fQ2OXr4cHldB
YOwmVETnSuBp97hzfyyBLu+HKRUpEjCrgGNqvxGoLdTYOblPAndWkklEFIFF
Tz0nY30lsO44N1EQTmBDrNwg0UAC2cEWfsM8ApcU9ful54uBqxucFs0hcNB1
tqgxXQxr1zvWxTMJLFUZq7TixKA81KCRYk/gWvvtsSd5Yjg8PHjlBEEgX/Y8
P9tQDHNprVOphgTa7Zo/2K4lhpzpD65JBgR+0llF1f8kgphjLkdi9Ag8tTWq
Kq9PBJcZZ3qCtQjkTWd/7W4SwUyT69gGDQJNL97wNKwRwZMf/FVOc1R8ub4z
K0AkgjUayx5azVDxr7H3PUKhCIqcHhUYTFHxX0ZCiK0=
          "]]}}}, {
       GraphicsComplex[{{-0.4, -23.380293460982386`}, {-0.35000000000000003`, \
-21.709920097164687`}, {-0.30000000000000004`, -20.10593573091527}, {-0.25, \
-18.606806847939144`}, {-0.2, -17.266052603347124`}, {-0.15000000000000002`, \
-16.144606351791783`}, {-0.09999999999999998, -15.310722179244417`}, \
{-0.04999999999999999, -14.879549145442892`}, {-0.4, -23.380293460982386`}, \
{-0.35000000000000003`, -21.709920097164687`}, {-0.30000000000000004`, \
-20.10593573091527}, {-0.25, -18.606806847939144`}, {-0.2, \
-17.266052603347124`}, {-0.15000000000000002`, -16.144606351791783`}, \
{-0.09999999999999998, -15.310722179244417`}, {-0.04999999999999999, \
-14.879549145442892`}}, {{{
           Hue[0.67, 0.6, 0.6], 
           GrayLevel[0], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 9], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 10], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 11], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 12], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 13], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 14], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 15], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 16]}, {}}}], {}}}, {
     Ticks -> {Automatic, {{-25.328436022934504`, 
          Superscript[10, -11]}, {-23.025850929940457`, 
          Superscript[10, -10]}, {-20.72326583694641, 
          Superscript[10, -9]}, {-18.420680743952367`, 
          Superscript[10, -8]}, {-16.11809565095832, 
          Superscript[10, -7]}, {-13.815510557964274`, 
          Superscript[10, -6]}, {-11.512925464970229`, 
          Superscript[10, -5]}, {-24.635288842374557`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-24.229823734266393`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.942141661814613`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.7189981105004, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.536676553706446`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.38252587387919, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.248994481254666`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.131211445598282`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-22.33270374938051, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-21.927238641272346`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-21.639556568820566`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-21.416413017506358`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-21.234091460712403`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-21.079940780885142`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-20.94640938826062, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-20.82862635260424, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-20.030118656386467`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-19.624653548278303`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-19.33697147582652, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-19.11382792451231, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-18.931506367718356`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-18.7773556878911, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-18.643824295266576`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-18.526041259610192`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-17.72753356339242, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-17.322068455284256`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-17.034386382832476`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.811242831518264`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.62892127472431, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.474770594897052`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.34123920227253, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.223456166616145`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-15.424948470398375`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-15.01948336229021, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-14.73180128983843, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-14.508657738524219`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-14.326336181730264`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-14.172185501903007`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-14.038654109278484`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-13.9208710736221, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-13.122363377404328`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
           Thickness[0.001]}}}}, GridLines -> {None, None}, 
      FrameTicks -> {{None, {{-25.328436022934504`, 
           Superscript[10, -11]}, {-23.025850929940457`, 
           Superscript[10, -10]}, {-20.72326583694641, 
           Superscript[10, -9]}, {-18.420680743952367`, 
           Superscript[10, -8]}, {-16.11809565095832, 
           Superscript[10, -7]}, {-13.815510557964274`, 
           Superscript[10, -6]}, {-11.512925464970229`, 
           Superscript[10, -5]}, {-24.635288842374557`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-24.229823734266393`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.942141661814613`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.7189981105004, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.536676553706446`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.38252587387919, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.248994481254666`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.131211445598282`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-22.33270374938051, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-21.927238641272346`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-21.639556568820566`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-21.416413017506358`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-21.234091460712403`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-21.079940780885142`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-20.94640938826062, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-20.82862635260424, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-20.030118656386467`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-19.624653548278303`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-19.33697147582652, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-19.11382792451231, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-18.931506367718356`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-18.7773556878911, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-18.643824295266576`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-18.526041259610192`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-17.72753356339242, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-17.322068455284256`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-17.034386382832476`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.811242831518264`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.62892127472431, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.474770594897052`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.34123920227253, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.223456166616145`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-15.424948470398375`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-15.01948336229021, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-14.73180128983843, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-14.508657738524219`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-14.326336181730264`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-14.172185501903007`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-14.038654109278484`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-13.9208710736221, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-13.122363377404328`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
            Thickness[0.001]}}}}, {True, False}}, 
      AxesOrigin -> {-0.4, -26.244372881021604`}, 
      PlotRange -> {{-0.4, -0.05}, {-26.244372881021604`, \
-11.482571327620285`}}, AspectRatio -> GoldenRatio^(-1), Axes -> True, 
      AxesOrigin -> {-0.4, -26.5}, 
      CoordinatesToolOptions -> {"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )}, Frame -> {True, False, False, True}, 
      FrameLabel -> {{Null, "Rate of rescue"}, {
        "Wildtype growth rate", Null}}, 
      FrameTicks -> {True, False, False, True}, LabelStyle -> 
      Directive[12, FontFamily -> "Helvetica"], Method -> {}, 
      PlotRange -> {{-0.4, -0.05}, {-26.244372881021604`, \
-11.482571327620285`}}, PlotRangeClipping -> True, PlotRangePadding -> {
        Scaled[0.02], 
        Scaled[0.02]}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          Thickness[Large]], 
         Directive[
          RGBColor[0.6, 0.24, 0.4428931686004542], 
          Thickness[Large]]}, {
         Style[
         "small \!\(\*\nStyleBox[\"\[Psi]\",\nFontSlant->\"Italic\"]\)", 12, 
          FontFamily -> "Helvetica"], 
         Style[
         "large \!\(\*\nStyleBox[SubscriptBox[\"\[Rho]\", \"max\"],\n\
FontSlant->\"Italic\"]\)", 12, FontFamily -> "Helvetica"]}, LegendLayout -> 
        "Column"]], 
      Scaled[{
        Rational[3, 4], 
        Rational[1, 4]}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{{3.769344743620479*^9, 3.7693447576644773`*^9}, 
   3.769344801224498*^9, 3.769352025490095*^9, 3.769352360121275*^9, 
   3.769352416410491*^9, 3.769352783862507*^9, 3.7693528837388277`*^9, 
   3.7693573777900333`*^9, 3.769357845429633*^9, {3.769359166257769*^9, 
   3.7693592112357397`*^9}, {3.76935931321566*^9, 3.7693594016532803`*^9}, 
   3.769429111927463*^9, 3.769429162711669*^9, {3.782253145410344*^9, 
   3.7822531496746397`*^9}, 3.782253199192657*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Closed form approximation - supercriticals (equation 14)\
\>", "Subsubsection",
 CellChangeTimes->{{3.751298225457127*^9, 3.7512982432758417`*^9}, {
   3.7516364473386917`*^9, 3.751636452802126*^9}, {3.760645633002554*^9, 
   3.760645642928447*^9}, {3.769343895272121*^9, 3.7693438984544277`*^9}, {
   3.769346363126889*^9, 3.769346375061676*^9}, {3.769361879826743*^9, 
   3.769361880914719*^9}, {3.769379725863603*^9, 3.769379727577138*^9}, {
   3.769429204108877*^9, 3.769429210749276*^9}, 3.769433213940271*^9, 
   3.771256262489102*^9, 3.771762227613299*^9}],

Cell["\<\
For the supercriticals our approximation for \[CapitalLambda]2 is now the \
integral of \
\>", "Text",
 CellChangeTimes->{{3.769269287704006*^9, 3.769269324512836*^9}, {
  3.769346382485757*^9, 3.769346382661665*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fm", "[", 
   RowBox[{"m", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], "]"}], 
  
  RowBox[{"(", 
   RowBox[{"1", "-", 
    RowBox[{"pest", "[", "m", "]"}]}], ")"}], "AnciauxEqnA12"}]], "Input",
 CellChangeTimes->{{3.769269247899362*^9, 3.769269254921452*^9}, 
   3.769269346276268*^9, {3.769346389026018*^9, 3.769346393465313*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"m", "-", "mmax"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox["\[Psi]wt", "4"]}], ")"}]}]], 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     FractionBox[
      RowBox[{"m", "-", 
       RowBox[{"2", " ", "mmax"}], "+", "mwt"}], "\[Lambda]"]], " ", "U", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"-", "m"}], "+", "mmax"}], "\[Lambda]"], ")"}], 
     RowBox[{"n", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox["\[Psi]wt", "2"]}], ")"}], 
     RowBox[{
      FractionBox["1", "2"], "-", "\[Theta]"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "\[Alpha]"}]], 
       RowBox[{
        SqrtBox["\[Pi]"], " ", 
        SqrtBox["\[Alpha]"]}]], "-", 
      RowBox[{"Erfc", "[", 
       SqrtBox["\[Alpha]"], "]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", "m"}]]}], ")"}], " ", 
       RowBox[{"HeavisideTheta", "[", "m", "]"}]}]}], ")"}], " ", 
    RowBox[{"Hypergeometric0F1Regularized", "[", 
     RowBox[{
      FractionBox["n", "2"], ",", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "m"}], "+", "mmax"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"mmax", "-", "mwt"}], ")"}]}], 
       SuperscriptBox["\[Lambda]", "2"]]}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{{3.7692692501316357`*^9, 3.769269255562914*^9}, 
   3.769269346681357*^9, 3.7693463944128838`*^9, 3.769353834230872*^9, 
   3.769357862865677*^9, 3.782253218531487*^9}]
}, Closed]],

Cell[TextData[{
 "over m from ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["m", "*"], " ", "to", " ", 
    SubscriptBox["m", "max"]}], TraditionalForm]]],
 ", with \[Alpha] dependent on m. "
}], "Text",
 CellChangeTimes->{{3.769269338922679*^9, 3.769269392148407*^9}, {
  3.769372354971304*^9, 3.7693723686106987`*^9}}],

Cell["\<\
As before we can approximately write fm in the \[Psi] scale, leaving us with \
the integral of\
\>", "Text",
 CellChangeTimes->{{3.769269467806487*^9, 3.769269469817292*^9}, {
  3.7692695137057056`*^9, 3.769269560553678*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f\[Psi]", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"pest", "[", "m", "]"}]}], ")"}], " ", "AnciauxEqnA12"}], "/.", 
   
   RowBox[{"\[Alpha]", "\[Rule]", 
    FractionBox[
     RowBox[{"\[Rho]max", " ", 
      SuperscriptBox["\[Psi]", "2"]}], "4"]}]}], "/.", 
  RowBox[{"m", "\[Rule]", " ", 
   RowBox[{"mmax", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"\[Psi]", "/", "4"}]}], ")"}], " ", 
    "\[Psi]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"constant", "=", 
   FractionBox[
    RowBox[{"U", " ", 
     SqrtBox["\[Rho]max"]}], 
    RowBox[{"2", " ", 
     SqrtBox["\[Pi]"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"\[Psi]wt", "/", "4"}]}], ")"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"\[Psi]wt", "/", "2"}]}], ")"}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", "\[Theta]"}]}]]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Psi]term", "=", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "mmax", " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox["\[Psi]", "4"]}], ")"}], " ", "\[Psi]"}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[Rho]max", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}]}]], "  ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"\[Psi]", "/", "2"}]}], ")"}], 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], "+", "\[Theta]"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"\[Rho]max", " ", 
            SuperscriptBox["\[Psi]", "2"]}], "4"]}]]}], 
       RowBox[{
        SqrtBox["\[Pi]"], " ", 
        SqrtBox[
         RowBox[{"\[Rho]max", " ", 
          SuperscriptBox["\[Psi]", "2"]}]]}]], "-", 
      RowBox[{"Erfc", "[", 
       FractionBox[
        SqrtBox[
         RowBox[{"\[Rho]max", " ", 
          SuperscriptBox["\[Psi]", "2"]}]], "2"], "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"f\[Psi]", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"pest", "[", "m", "]"}]}], ")"}], " ", "AnciauxEqnA12"}], "/.", 
       RowBox[{"\[Alpha]", "\[Rule]", 
        FractionBox[
         RowBox[{"\[Rho]max", " ", 
          SuperscriptBox["\[Psi]", "2"]}], "4"]}]}], "/.", 
      RowBox[{"m", "\[Rule]", " ", 
       RowBox[{"mmax", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"\[Psi]", "/", "4"}]}], ")"}], " ", "\[Psi]"}]}]}], ")"}], 
    "\[Equal]", 
    RowBox[{"constant", " ", "\[Psi]term"}]}], " ", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Psi]wt", "<", "0"}], ",", 
     RowBox[{"2", ">", "\[Psi]", ">", "0"}], ",", 
     RowBox[{"mmax", ">", "0"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7692695463482113`*^9, 3.769269546643938*^9}, {
  3.769269589412332*^9, 3.7692696131737823`*^9}, {3.769270161835973*^9, 
  3.7692701637123632`*^9}, {3.769270264363809*^9, 3.76927035274962*^9}, {
  3.769270384838574*^9, 3.769270406987526*^9}, {3.769270441383189*^9, 
  3.769270490654406*^9}, {3.7693439553512897`*^9, 3.7693439797545843`*^9}, {
  3.7693464025296497`*^9, 3.769346436285699*^9}, {3.769346481117077*^9, 
  3.769346481892774*^9}, {3.769346514490905*^9, 3.769346666164495*^9}, {
  3.782253323462467*^9, 3.782253331812166*^9}, {3.7822533988188257`*^9, 
  3.782253418480254*^9}, {3.782253469548038*^9, 3.7822534727253304`*^9}, {
  3.782253594154063*^9, 3.782253594650189*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2", " ", 
    SqrtBox["\[Pi]"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox["\[Psi]wt", "4"]}], ")"}]}]], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}]], " ", "U", " ", 
   SqrtBox["\[Rho]max"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"2", "-", "\[Psi]"}], 
      RowBox[{"2", "-", "\[Psi]wt"}]], ")"}], 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], "+", "\[Theta]"}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox["\[Psi]wt", "2"]}], ")"}], 
    RowBox[{
     FractionBox["1", "2"], "-", "\[Theta]"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"\[Rho]max", " ", 
           SuperscriptBox["\[Psi]", "2"]}], "4"]}]]}], 
      RowBox[{
       SqrtBox["\[Pi]"], " ", 
       SqrtBox[
        RowBox[{"\[Rho]max", " ", 
         SuperscriptBox["\[Psi]", "2"]}]]}]], "-", 
     RowBox[{"Erfc", "[", 
      FractionBox[
       SqrtBox[
        RowBox[{"\[Rho]max", " ", 
         SuperscriptBox["\[Psi]", "2"]}]], "2"], "]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "2"}], " ", "mmax", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            FractionBox["\[Psi]", "4"]}], ")"}], " ", "\[Psi]"}]]}], ")"}], 
      " ", 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{"mmax", " ", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox["\[Psi]", "4"]}], ")"}], " ", "\[Psi]"}], "]"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{{3.769269520085327*^9, 3.769269547982418*^9}, {
   3.7692695914744997`*^9, 3.769269613888485*^9}, 3.769270164140708*^9, 
   3.769270210373291*^9, {3.769270267815881*^9, 3.769270320969038*^9}, {
   3.769270397392211*^9, 3.769270407532835*^9}, {3.7692704611320877`*^9, 
   3.76927049088759*^9}, 3.769343981187142*^9, {3.769346403637165*^9, 
   3.769346437087659*^9}, {3.769346575121416*^9, 3.769346666737363*^9}, 
   3.76935383436263*^9, 3.769357865251276*^9, 3.782253219744041*^9, {
   3.782253324238248*^9, 3.7822533322419863`*^9}, {3.782253402476034*^9, 
   3.78225341906883*^9}, 3.7822534733115788`*^9, 3.782253602988737*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.769269520085327*^9, 3.769269547982418*^9}, {
   3.7692695914744997`*^9, 3.769269613888485*^9}, 3.769270164140708*^9, 
   3.769270210373291*^9, {3.769270267815881*^9, 3.769270320969038*^9}, {
   3.769270397392211*^9, 3.769270407532835*^9}, {3.7692704611320877`*^9, 
   3.76927049088759*^9}, 3.769343981187142*^9, {3.769346403637165*^9, 
   3.769346437087659*^9}, {3.769346575121416*^9, 3.769346666737363*^9}, 
   3.76935383436263*^9, 3.769357865251276*^9, 3.782253219744041*^9, {
   3.782253324238248*^9, 3.7822533322419863`*^9}, {3.782253402476034*^9, 
   3.78225341906883*^9}, 3.7822534733115788`*^9, 3.78225360426019*^9}]
}, Closed]],

Cell["over \[Psi] between \[Psi]* and 2", "Text",
 CellChangeTimes->{{3.769269570697753*^9, 3.769269582578092*^9}, {
  3.769269966216556*^9, 3.7692699672227583`*^9}, {3.769340979728405*^9, 
  3.769341001168212*^9}, {3.769346687337347*^9, 3.769346693279265*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", "m", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["m", "mmax"]}]]}], ")"}]}], "/.", 
    RowBox[{"m", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"mstar", ",", "mmax"}], "}"}]}]}], ",", 
   RowBox[{"mmax", ">", "0"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.769269969568224*^9, 3.7692700128115387`*^9}, {
  3.769346698610929*^9, 3.7693467499096003`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", "-", 
    RowBox[{"2", " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox["mstar", "mmax"]}]]}]}], ",", "2"}], "}"}]], "Output",
 CellChangeTimes->{{3.7692699833537207`*^9, 3.7692700133159657`*^9}, {
   3.769346703671732*^9, 3.769346750323406*^9}, 3.76935383546835*^9, 
   3.769357869520451*^9, 3.782253221664567*^9, 3.782253623236302*^9}]
}, Closed]],

Cell[TextData[{
 "Here we only need one approximation as large m single mutants will \
establish themselves and are unlikely to rescue. So we just look at when \
\[Psi]-\[Psi]wt and \[Psi] \[Rho]max = \[Psi] ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["mmax", "\[Lambda]"], "=", 
    RowBox[{"\[Psi]", 
     FractionBox[
      RowBox[{"mmax", "*", "n"}], 
      RowBox[{"2", "Es"}]]}]}], TraditionalForm]]],
 " are really small, giving"
}], "Text",
 CellChangeTimes->{{3.769276156742867*^9, 3.769276188448271*^9}, 
   3.7692763508205967`*^9, {3.7692770530894833`*^9, 3.769277105013369*^9}, {
   3.769292103911941*^9, 3.769292107786969*^9}, {3.7692936540731773`*^9, 
   3.769293658441058*^9}, {3.771274899576929*^9, 3.771274935152219*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Psi]term", " ", "/.", 
   RowBox[{"\[Psi]", "\[Rule]", 
    RowBox[{"\[Psi]", " ", "\[Epsilon]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Normal", "[", 
     RowBox[{"Series", "[", 
      RowBox[{"%", ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]", ",", "0", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "]"}], "]"}], "/.", 
    RowBox[{"\[Epsilon]", "\[Rule]", "1"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]", ">", "0"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7692772011446047`*^9, 3.769277229634632*^9}, {
   3.769277284984087*^9, 3.769277298183468*^9}, {3.769277330057776*^9, 
   3.769277393567109*^9}, {3.769277431894062*^9, 3.7692774365548286`*^9}, {
   3.769292118743289*^9, 3.7692921204549847`*^9}, {3.769343989015789*^9, 
   3.769343990642921*^9}, 3.769347200920331*^9, {3.769357922684134*^9, 
   3.76935795830999*^9}, 3.769372850700123*^9, {3.769372952248351*^9, 
   3.7693729524384527`*^9}, 3.769373021282102*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[Rho]max", " ", 
       SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]]}], 
  RowBox[{
   SqrtBox["\[Pi]"], " ", 
   SqrtBox["\[Rho]max"], " ", "\[Psi]"}]]], "Output",
 CellChangeTimes->{{3.7692772132348948`*^9, 3.769277230040106*^9}, {
   3.769277286920164*^9, 3.769277298828497*^9}, {3.7692773398242197`*^9, 
   3.769277393776143*^9}, 3.7692774373802347`*^9, 3.769292120866961*^9, 
   3.769343992163577*^9, 3.769346770471714*^9, 3.7693472033874073`*^9, 
   3.769353835539195*^9, 3.769357871502831*^9, {3.769357923333208*^9, 
   3.769357959115971*^9}, 3.769372851329947*^9, 3.769372956412229*^9, 
   3.769373022401125*^9, 3.782253625314106*^9}]
}, Closed]],

Cell["\<\
Right, so for the small \[Psi] approx we need to integrate\
\>", "Text",
 CellChangeTimes->{{3.76934181920712*^9, 3.769341834717923*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"small\[Psi]approx", "=", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Rho]max", " ", 
         SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]]}], 
    RowBox[{
     SqrtBox["\[Pi]"], " ", 
     SqrtBox["\[Rho]max"], " ", "\[Psi]"}]]}], ";"}]], "Input",
 CellChangeTimes->{{3.769341848722046*^9, 3.7693418551624928`*^9}, 
   3.769348707476809*^9}],

Cell["which has a simple expression", "Text",
 CellChangeTimes->{{3.769342301045445*^9, 3.769342302773172*^9}, {
   3.769342430637306*^9, 3.769342448350012*^9}, 3.7693487244255753`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{"small\[Psi]approx", ",", 
   RowBox[{"{", 
    RowBox[{"\[Psi]", ",", "a", ",", "b"}], "}"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", "<", "a", "<", "b", "<", "2"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.76934225708386*^9, 3.769342292894826*^9}, {
  3.769342423096365*^9, 3.769342428770508*^9}, {3.769348717484894*^9, 
  3.7693487201491203`*^9}, {3.769348762775744*^9, 3.769348766910756*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[Rho]max", " ", 
       SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]], " ", 
   RowBox[{"Log", "[", 
    FractionBox["b", "a"], "]"}]}], 
  RowBox[{
   SqrtBox["\[Pi]"], " ", 
   SqrtBox["\[Rho]max"]}]]], "Output",
 CellChangeTimes->{{3.7693422781982203`*^9, 3.7693422938193417`*^9}, {
   3.769342424959627*^9, 3.7693424526717033`*^9}, 3.769348725834333*^9, 
   3.7693538389958553`*^9, 3.78225362933532*^9}]
}, Closed]],

Cell["\<\
OK, so our small \[Rho]max approx for the probability of 2-step supercritical \
rescue is\
\>", "Text",
 CellChangeTimes->{{3.7693440421893387`*^9, 3.769344061340617*^9}, {
  3.769344407464089*^9, 3.7693444108469477`*^9}, {3.769349302005226*^9, 
  3.76934930249333*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"small\[Psi]approxRescueSuper\[Psi]", "=", 
  RowBox[{"constant", " ", 
   RowBox[{"Integrate", "[", 
    RowBox[{"small\[Psi]approx", ",", 
     RowBox[{"{", 
      RowBox[{"\[Psi]", ",", "a", ",", "b"}], "}"}], ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", "<", "a", "<", "b"}], "}"}]}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"small\[Psi]approxRescueSuper", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"%", "/.", 
        RowBox[{"a", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"(", " ", 
           RowBox[{"1", "-", " ", 
            SqrtBox[
             RowBox[{"1", "-", 
              FractionBox["mstar", "mmax"]}]]}], ")"}]}]}]}], "/.", 
       RowBox[{"b", "\[Rule]", 
        FractionBox[
         SqrtBox["2"], 
         SqrtBox["\[Rho]max"]]}]}], "/.", 
      RowBox[{"mstar", "\[Rule]", 
       SqrtBox[
        RowBox[{"\[CapitalLambda]0approx", "/", "2"}]]}]}], "/.", 
     RowBox[{"\[Rho]max", "\[Rule]", 
      RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
    RowBox[{"\[Theta]", "\[Rule]", 
     RowBox[{"n", "/", "2"}]}]}], "/.", 
   RowBox[{"\[Psi]wt", "\[Rule]", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}]}]}], "Input",
 CellChangeTimes->{{3.769344076056356*^9, 3.769344138219789*^9}, {
  3.769344314630602*^9, 3.769344395421007*^9}, {3.769348012899921*^9, 
  3.7693480354592457`*^9}, {3.769353801108457*^9, 3.7693538106511917`*^9}, {
  3.769358212881784*^9, 3.769358242178608*^9}, {3.769358474253397*^9, 
  3.7693584767145977`*^9}, {3.769374284840808*^9, 3.769374287131617*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[Rho]max", " ", 
       SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]], " ", "U", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox["\[Psi]wt", "2"]}], ")"}], 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", "\[Theta]"}]}]], " ", 
   RowBox[{"Log", "[", 
    FractionBox["b", "a"], "]"}]}], 
  RowBox[{"\[Pi]", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     FractionBox["\[Psi]wt", "4"]}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.769344074058526*^9, 3.769344078236953*^9}, {
   3.769344113074533*^9, 3.7693441318488493`*^9}, {3.769344315825962*^9, 
   3.769344397262492*^9}, {3.7693480248811207`*^9, 3.769348036361067*^9}, 
   3.769349321548975*^9, 3.7693538135969887`*^9, 3.7693538451453648`*^9, 
   3.769358248008787*^9, {3.769358458566421*^9, 3.76935847868544*^9}, 
   3.7693742885179567`*^9, 3.769429228715377*^9, 3.782253631722067*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"mmax", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          SqrtBox[
           RowBox[{"1", "-", 
            FractionBox["mwt", "mmax"]}]]}], ")"}], "2"]}], "\[Lambda]"]}]], 
   " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox["mwt", "mmax"]}], ")"}], 
    FractionBox[
     RowBox[{"1", "-", "n"}], "2"]], " ", "U", " ", 
   RowBox[{"Log", "[", 
    FractionBox["1", 
     RowBox[{
      SqrtBox["2"], " ", 
      SqrtBox[
       FractionBox["mmax", "\[Lambda]"]], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SqrtBox[
         RowBox[{"1", "-", 
          FractionBox[
           SqrtBox[
            RowBox[{"U", " ", 
             SqrtBox[
              RowBox[{"mmax", " ", "\[Lambda]"}]]}]], 
           RowBox[{"mmax", " ", 
            SuperscriptBox["\[Pi]", 
             RowBox[{"1", "/", "4"}]]}]]}]]}], ")"}]}]], "]"}]}], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SqrtBox[
         RowBox[{"1", "-", 
          FractionBox["mwt", "mmax"]}]]}], ")"}]}]}], ")"}], " ", 
   "\[Pi]"}]]], "Output",
 CellChangeTimes->{{3.769344074058526*^9, 3.769344078236953*^9}, {
   3.769344113074533*^9, 3.7693441318488493`*^9}, {3.769344315825962*^9, 
   3.769344397262492*^9}, {3.7693480248811207`*^9, 3.769348036361067*^9}, 
   3.769349321548975*^9, 3.7693538135969887`*^9, 3.7693538451453648`*^9, 
   3.769358248008787*^9, {3.769358458566421*^9, 3.76935847868544*^9}, 
   3.7693742885179567`*^9, 3.769429228715377*^9, 3.782253631725113*^9}]
}, Closed]],

Cell[TextData[{
 "where we\[CloseCurlyQuote]ve used our rough cut-off  of ",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    RowBox[{"2", "/", "\[Rho]max"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", after which the rate of rescue declines very very quickly and therefore \
is negligible."
}], "Text",
 CellChangeTimes->{{3.769374717717238*^9, 3.769374750254445*^9}}],

Cell["Check formula in text", "Text",
 CellChangeTimes->{{3.769358485531458*^9, 3.769358491506077*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{" ", 
       RowBox[{"U", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox["\[Psi]wt", "2"]}], ")"}], 
         RowBox[{"1", "-", 
          RowBox[{"2", " ", "\[Theta]"}]}]], " "}]}], 
      RowBox[{" ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox["\[Psi]wt", "4"]}], ")"}]}]], 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "\[Alpha]"}]], 
     RowBox[{
      RowBox[{"Log", "[", 
       FractionBox["b", "a"], "]"}], "/", "\[Pi]"}]}], "==", 
    "small\[Psi]approxRescueSuper\[Psi]"}], "/.", 
   RowBox[{"\[Alpha]", "\[Rule]", 
    FractionBox[
     RowBox[{"\[Rho]max", " ", 
      SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.769358308143629*^9, {3.769358467452443*^9, 3.7693585415618553`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.769358301623743*^9, 3.769358308510178*^9}, {
   3.76935846778971*^9, 3.769358541985684*^9}, 3.769376168517394*^9, 
   3.782253633793899*^9}]
}, Closed]],

Cell["\<\
Compare to better approximation\
\>", "Text",
 CellChangeTimes->{{3.769344560330846*^9, 3.7693445649473047`*^9}, {
  3.769344675526155*^9, 3.7693446777862988`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"n0", "=", 
   SuperscriptBox["10", "4"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "4"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mwt", ",", 
        RowBox[{"U", " ", 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"fm", "[", 
             RowBox[{
             "m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
             "]"}], 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
            FractionBox[
             RowBox[{" ", 
              RowBox[{"\[CapitalLambda]1", "[", 
               RowBox[{
               "m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
               "]"}]}], 
             RowBox[{"Abs", "[", "m1", "]"}]]}], "\[IndentingNewLine]", ",", 
           RowBox[{"{", 
            RowBox[{"m1", ",", "pr0", ",", "mmax"}], "}"}]}], "]"}]}]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"mwt", ",", 
        RowBox[{
         RowBox[{"-", "0.8"}], "mmax"}], ",", 
        RowBox[{
         RowBox[{"-", "0.1"}], "mmax"}], ",", 
        RowBox[{"0.1", "mmax"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
    "}"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LogPlot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"U", " ", "small\[Psi]approxRescueSuper"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"mwt", ",", 
        RowBox[{
         RowBox[{"-", "0.8"}], "mmax"}], ",", 
        RowBox[{
         RowBox[{"-", "0.1"}], "mmax"}]}], "}"}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Frame", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Wildtype growth rate\>\"", ",", ",", ",", 
         "\"\<Rate of rescue\>\""}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"FrameTicks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", "\"\<approx\>\"", "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "/", "4"}], ",", 
            RowBox[{"1", "/", "4"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotMarkers", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Automatic", ",", "Medium"}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Black"}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "n0"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.751063189929034*^9, 3.751063195260857*^9}, {
   3.751063251777727*^9, 3.751063315775334*^9}, {3.751063345833967*^9, 
   3.7510634151982183`*^9}, {3.75106350691444*^9, 3.7510635766974697`*^9}, {
   3.7510636416522617`*^9, 3.7510636671136007`*^9}, {3.751063706981538*^9, 
   3.751063818145526*^9}, {3.751063878393749*^9, 3.751063918090982*^9}, {
   3.7510754524207277`*^9, 3.751075515053173*^9}, {3.7510758146376743`*^9, 
   3.751075849277143*^9}, {3.769267809372196*^9, 3.769267839627472*^9}, {
   3.769344609666925*^9, 3.7693447688709307`*^9}, {3.769352055143111*^9, 
   3.769352067327169*^9}, {3.769352107343092*^9, 3.7693521435992327`*^9}, {
   3.769352213092353*^9, 3.7693522195278254`*^9}, {3.769352258848256*^9, 
   3.7693523712321653`*^9}, {3.769352555917631*^9, 3.769352561187896*^9}, {
   3.7693527428624687`*^9, 3.76935274334965*^9}, {3.769352839938251*^9, 
   3.769352851831604*^9}, {3.769353762585099*^9, 3.7693537846329823`*^9}, {
   3.7693539040021276`*^9, 3.769353980760912*^9}, {3.7693540282803917`*^9, 
   3.7693540289677687`*^9}, 3.76935408110839*^9, {3.769358288383486*^9, 
   3.769358311739477*^9}, 3.769358361725099*^9, {3.769360474612193*^9, 
   3.769360478995838*^9}, {3.769360510231655*^9, 3.76936051129226*^9}, 
   3.769360542262415*^9, {3.7693605924013863`*^9, 3.769360592898966*^9}, 
   3.7693746960173817`*^9, 3.769374763821862*^9, 3.7699670304128304`*^9, {
   3.7822531985101633`*^9, 3.7822531990526543`*^9}}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwVzGs0lAkcx3G0RUpEhKQbOeqZGzMuo9TalnTc1rRCRKXSkpJGp8TKJZVb
WmFq2k6UzDBuMbK2/v+KCdsMYfCoSHJyKSzaZpFZ++J3vufz5rfh0EnvI2oq
KiruC/u/NbSxLB6PhCT7s1uKHrHRI3e5T1cuCb6BX6esa9j4YX6LsX4OCXFh
K6VQzUZd2bH8a9dJIE0MSrsq2RgR3l+ZkkpCbDl3q4aIjWaCjnZuLAk7yolV
4XfZmLWxTt/7IAkladz8HVfZGKZ/madpufBHvdCjH8BGt301vYvKusFw5E1k
l8IeSRMLF73t3RBqFNHqcNseh3x/f31A2gUBJ7TOnNhlj2Z/C0VWe7vALYpX
6DBoh1painyTgU7Yk3PW9Fy6HW5K7pFnhHbCEYth/0yaHdZF1TO3T8hhzj6b
c6PDFpWDY2LVeDmwWQGK9nhbPFVVGu2xRA7OnG2f2Ra2mLGkzK8iuwP4ZWEP
ocMGqS3iUC/zDihscEyaT7LB2SlO9dmSdnCKUwkW02zwDJ9hXu3QDhTZ8RlO
PwuN795rO/+0De4xPueK0lnoZLKu5IJrG4RemfcY2sbC1Wt6irLJV6CaPsqS
TjLRKHrLADP4FYguBU1LCpj4Ym/dztGxVtid/2OV+34m5mf2v7Y80wq5QjUJ
YwUTv100dXb92gKJp6jVk8+tUfvTjHGYQQtI/nmyXzXeGmNWqIXd3igDl3C9
JqmtNe60u6o65yiF0ozvNJu+WOFSzw0TbUEvYdbS68hhsRUSpgN+f5z4CwpW
OCrWRllh0bS5piy1GUa1ZzUkLCuMS/yNNZnTBJt8kszeTTPQV6ldm1HYCG/H
62eaxQxMTdBK3Cd5ATknIwsD4xho+ITVSG+XQB53vLXFiYHzKn0cm4kGaFie
oda4nIFD9FzbqpUNsDtWc587SUfC6HyO0/p6SBm77LGxgI5NGr0O3xyfg9ZA
4mbWaTpieXhA455nULWuUjntSEed4AvP4ehT+Jd2p1umQ8eQuZsJtBSE43lf
nhxspqFZfuO5IEuAvrIpXvRJGjL8A2MehTwGRkKDtrkpDacSXKKsztfB4u+H
l042UfHPZM81t/Nq4bqB1NA7hoq2uX5ewV01YK0rCytkUfGoUW3MrolqqKuf
jaSNUdBFaMy8aFkFymvB9wPLKEjXv8kvDauEtGadpnguBaUTEbNzKeWgyB42
VbApaCtOlblcEYEr5/ruUA0KquwXGVw5J4LhWsGlTHUKNitlB5qPi0A7y29V
zRIKHnDVHXfbI4Ki+3xT9cUUvPQmT9t7mQg8tx4bF6pSsFOt0CsgvQQyKyQp
qrMEcj2x7VRWMXA2P3g68plAx+l+48qLxSC/9atyzYI1eIsOT0UWA7f3Wbr7
JwL5752nuN7F4M+5d6tihMB6rlQvRq8YeofSYmM/EriK37M3+YYQwqkvgsz6
CezdOceXJAvhHeeXB/7vCCwaXDuoHi2EL6/e78jqI3Ab7SD3qo8QLG5FHFa+
JTDk2ccbmauFQBst4fb1EEg9trS3VV0IpK94l+GCFcu2btZVCOD04+aQn0gC
036OEGd3C8DRjZZX30Wgz0zmvLxRAJbDacXznQSuv1PhvLpWANxDOjr2Cx75
oT3DVyAAeRQ2RMkJfDg03cnjCeADWfCytIPA/wBM3JQ1
        "]]}}, {
      GraphicsComplexBox[{{-0.4, -27.335976661610466`}, \
{-0.35000000000000003`, -24.751931568413564`}, {-0.30000000000000004`, \
-22.381170397021293`}, {-0.25, -20.24215868272168}, {-0.2, \
-18.355637969283784`}, {-0.15000000000000002`, -16.744599140442226`}, \
{-0.09999999999999998, -15.433658375468902`}, {-0.04999999999999999, \
-14.446850484095657`}, {-0.4, -27.335976661610466`}, {-0.35000000000000003`, \
-24.751931568413564`}, {-0.30000000000000004`, -22.381170397021293`}, {-0.25, \
-20.24215868272168}, {-0.2, -18.355637969283784`}, {-0.15000000000000002`, \
-16.744599140442226`}, {-0.09999999999999998, -15.433658375468902`}, \
{-0.04999999999999999, -14.446850484095657`}}, {
        {GrayLevel[0], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 9], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 10], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 11], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 12], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 13], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 14], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 15], InsetBox[
          StyleBox["\<\"\[FilledCircle]\"\>",
           StripOnInput->False,
           FontSize->Medium], 16]}, {}}], {}}}, InsetBox[
     TemplateBox[{
      StyleBox["\"approx\"", StripOnInput -> False, FontFamily -> "Helvetica",
         FontSize -> 12]},
      "LineLegend",
      DisplayFunction->(StyleBox[
        StyleBox[
         PaneBox[
          TagBox[
           GridBox[{{
              TagBox[
               GridBox[{{
                  GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                   ImageSize -> {20, 10}, PlotRangePadding -> None, 
                   ImagePadding -> 1, 
                   BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                GridBoxAlignment -> {
                 "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                AutoDelete -> False, 
                GridBoxDividers -> {
                 "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
                GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}],
                "Grid"]}}, 
            GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
            AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
           "Grid"], Alignment -> Left, AppearanceElements -> None, 
          ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"],
          LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
        Background -> Automatic, StripOnInput -> False]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"Directive", "[", 
               RowBox[{
                 RowBox[{"RGBColor", "[", 
                   
                   RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                   "]"}], ",", 
                 RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], 
           ",", 
           RowBox[{"{", #, "}"}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
     NCache[Scaled[{Rational[3, 4], Rational[1, 4]}], Scaled[{0.75, 0.25}]], 
     ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesOrigin->{-0.4, -26.721316007716737`},
   CoordinatesToolOptions:>{"DisplayFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& ), "CopiedValueFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& )},
   Frame->{True, False, False, True},
   FrameLabel->{{"", 
      FormBox["\"Rate of rescue\"", TraditionalForm]}, {
      FormBox["\"Wildtype growth rate\"", TraditionalForm], ""}},
   FrameTicks->{{None, {{-27.631021115928547`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "12"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
          TraditionalForm]}, {-25.328436022934504`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
          TraditionalForm]}, {-23.025850929940457`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
          TraditionalForm]}, {-20.72326583694641, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-18.420680743952367`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-16.11809565095832, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-13.815510557964274`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-26.937873935368604`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-26.53240882726044, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-26.244726754808656`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-26.021583203494448`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-25.839261646700493`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-25.685110966873236`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-25.551579574248713`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-25.43379653859233, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-24.635288842374557`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-24.229823734266393`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.942141661814613`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.7189981105004, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.536676553706446`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.38252587387919, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.248994481254666`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-23.131211445598282`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-22.33270374938051, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.927238641272346`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.639556568820566`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.416413017506358`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.234091460712403`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-21.079940780885142`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.94640938826062, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.82862635260424, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-20.030118656386467`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.624653548278303`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.33697147582652, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-19.11382792451231, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.931506367718356`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.7773556878911, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.643824295266576`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-18.526041259610192`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.72753356339242, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.322068455284256`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-17.034386382832476`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.811242831518264`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.62892127472431, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.474770594897052`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.34123920227253, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-16.223456166616145`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-15.424948470398375`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-15.01948336229021, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.73180128983843, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.508657738524219`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.326336181730264`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.172185501903007`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-14.038654109278484`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-13.9208710736221, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {True, False}},
   GridLines->{None, None},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.4, -0.05}, {-26.721316007716737`, -14.415396113396987`}},
   PlotRangeClipping->True,
   PlotRangePadding->{
     Scaled[0.02], 
     Scaled[0.02]},
   Ticks->{Automatic, {{-27.631021115928547`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "12"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-25.328436022934504`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-23.025850929940457`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-20.72326583694641, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-18.420680743952367`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-26.937873935368604`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-26.53240882726044, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-26.244726754808656`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-26.021583203494448`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-25.839261646700493`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-25.685110966873236`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-25.551579574248713`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-25.43379653859233, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-24.635288842374557`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-24.229823734266393`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.942141661814613`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.7189981105004, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.536676553706446`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.38252587387919, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.248994481254666`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-23.131211445598282`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-22.33270374938051, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-21.927238641272346`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-21.639556568820566`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-21.416413017506358`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-21.234091460712403`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-21.079940780885142`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-20.94640938826062, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-20.82862635260424, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-20.030118656386467`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-19.624653548278303`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-19.33697147582652, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-19.11382792451231, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-18.931506367718356`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-18.7773556878911, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-18.643824295266576`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-18.526041259610192`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.72753356339242, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.322068455284256`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-17.034386382832476`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.811242831518264`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.62892127472431, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.474770594897052`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.34123920227253, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-16.223456166616145`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.424948470398375`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-15.01948336229021, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.73180128983843, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.508657738524219`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.326336181730264`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.172185501903007`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-14.038654109278484`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-13.9208710736221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Thickness[Large], 
         Line[CompressedData["
1:eJwVzGs0lAkcx3G0RUpEhKQbOeqZGzMuo9TalnTc1rRCRKXSkpJGp8TKJZVb
WmFq2k6UzDBuMbK2/v+KCdsMYfCoSHJyKSzaZpFZ++J3vufz5rfh0EnvI2oq
KiruC/u/NbSxLB6PhCT7s1uKHrHRI3e5T1cuCb6BX6esa9j4YX6LsX4OCXFh
K6VQzUZd2bH8a9dJIE0MSrsq2RgR3l+ZkkpCbDl3q4aIjWaCjnZuLAk7yolV
4XfZmLWxTt/7IAkladz8HVfZGKZ/madpufBHvdCjH8BGt301vYvKusFw5E1k
l8IeSRMLF73t3RBqFNHqcNseh3x/f31A2gUBJ7TOnNhlj2Z/C0VWe7vALYpX
6DBoh1painyTgU7Yk3PW9Fy6HW5K7pFnhHbCEYth/0yaHdZF1TO3T8hhzj6b
c6PDFpWDY2LVeDmwWQGK9nhbPFVVGu2xRA7OnG2f2Ra2mLGkzK8iuwP4ZWEP
ocMGqS3iUC/zDihscEyaT7LB2SlO9dmSdnCKUwkW02zwDJ9hXu3QDhTZ8RlO
PwuN795rO/+0De4xPueK0lnoZLKu5IJrG4RemfcY2sbC1Wt6irLJV6CaPsqS
TjLRKHrLADP4FYguBU1LCpj4Ym/dztGxVtid/2OV+34m5mf2v7Y80wq5QjUJ
YwUTv100dXb92gKJp6jVk8+tUfvTjHGYQQtI/nmyXzXeGmNWqIXd3igDl3C9
JqmtNe60u6o65yiF0ozvNJu+WOFSzw0TbUEvYdbS68hhsRUSpgN+f5z4CwpW
OCrWRllh0bS5piy1GUa1ZzUkLCuMS/yNNZnTBJt8kszeTTPQV6ldm1HYCG/H
62eaxQxMTdBK3Cd5ATknIwsD4xho+ITVSG+XQB53vLXFiYHzKn0cm4kGaFie
oda4nIFD9FzbqpUNsDtWc587SUfC6HyO0/p6SBm77LGxgI5NGr0O3xyfg9ZA
4mbWaTpieXhA455nULWuUjntSEed4AvP4ehT+Jd2p1umQ8eQuZsJtBSE43lf
nhxspqFZfuO5IEuAvrIpXvRJGjL8A2MehTwGRkKDtrkpDacSXKKsztfB4u+H
l042UfHPZM81t/Nq4bqB1NA7hoq2uX5ewV01YK0rCytkUfGoUW3MrolqqKuf
jaSNUdBFaMy8aFkFymvB9wPLKEjXv8kvDauEtGadpnguBaUTEbNzKeWgyB42
VbApaCtOlblcEYEr5/ruUA0KquwXGVw5J4LhWsGlTHUKNitlB5qPi0A7y29V
zRIKHnDVHXfbI4Ki+3xT9cUUvPQmT9t7mQg8tx4bF6pSsFOt0CsgvQQyKyQp
qrMEcj2x7VRWMXA2P3g68plAx+l+48qLxSC/9atyzYI1eIsOT0UWA7f3Wbr7
JwL5752nuN7F4M+5d6tihMB6rlQvRq8YeofSYmM/EriK37M3+YYQwqkvgsz6
CezdOceXJAvhHeeXB/7vCCwaXDuoHi2EL6/e78jqI3Ab7SD3qo8QLG5FHFa+
JTDk2ccbmauFQBst4fb1EEg9trS3VV0IpK94l+GCFcu2btZVCOD04+aQn0gC
036OEGd3C8DRjZZX30Wgz0zmvLxRAJbDacXznQSuv1PhvLpWANxDOjr2Cx75
oT3DVyAAeRQ2RMkJfDg03cnjCeADWfCytIPA/wBM3JQ1
          "]]}}}, {
       GraphicsComplex[{{-0.4, -27.335976661610466`}, {-0.35000000000000003`, \
-24.751931568413564`}, {-0.30000000000000004`, -22.381170397021293`}, {-0.25, \
-20.24215868272168}, {-0.2, -18.355637969283784`}, {-0.15000000000000002`, \
-16.744599140442226`}, {-0.09999999999999998, -15.433658375468902`}, \
{-0.04999999999999999, -14.446850484095657`}, {-0.4, -27.335976661610466`}, \
{-0.35000000000000003`, -24.751931568413564`}, {-0.30000000000000004`, \
-22.381170397021293`}, {-0.25, -20.24215868272168}, {-0.2, \
-18.355637969283784`}, {-0.15000000000000002`, -16.744599140442226`}, \
{-0.09999999999999998, -15.433658375468902`}, {-0.04999999999999999, \
-14.446850484095657`}}, {{{
           Hue[0.67, 0.6, 0.6], 
           GrayLevel[0], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 9], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 10], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 11], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 12], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 13], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 14], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 15], 
           Inset[
            Style["\[FilledCircle]", FontSize -> Medium], 16]}, {}}}], {}}}, {
     Ticks -> {Automatic, {{-27.631021115928547`, 
          Superscript[10, -12]}, {-25.328436022934504`, 
          Superscript[10, -11]}, {-23.025850929940457`, 
          Superscript[10, -10]}, {-20.72326583694641, 
          Superscript[10, -9]}, {-18.420680743952367`, 
          Superscript[10, -8]}, {-16.11809565095832, 
          Superscript[10, -7]}, {-13.815510557964274`, 
          Superscript[10, -6]}, {-26.937873935368604`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-26.53240882726044, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-26.244726754808656`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-26.021583203494448`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-25.839261646700493`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-25.685110966873236`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-25.551579574248713`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-25.43379653859233, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-24.635288842374557`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-24.229823734266393`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.942141661814613`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.7189981105004, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.536676553706446`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.38252587387919, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.248994481254666`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-23.131211445598282`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-22.33270374938051, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-21.927238641272346`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-21.639556568820566`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-21.416413017506358`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-21.234091460712403`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-21.079940780885142`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-20.94640938826062, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-20.82862635260424, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-20.030118656386467`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-19.624653548278303`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-19.33697147582652, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-19.11382792451231, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-18.931506367718356`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-18.7773556878911, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-18.643824295266576`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-18.526041259610192`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-17.72753356339242, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-17.322068455284256`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-17.034386382832476`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.811242831518264`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.62892127472431, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.474770594897052`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.34123920227253, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-16.223456166616145`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-15.424948470398375`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-15.01948336229021, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-14.73180128983843, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-14.508657738524219`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-14.326336181730264`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-14.172185501903007`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-14.038654109278484`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-13.9208710736221, "", {0.00375, 0.}, {
           Thickness[0.001]}}}}, GridLines -> {None, None}, 
      FrameTicks -> {{None, {{-27.631021115928547`, 
           Superscript[10, -12]}, {-25.328436022934504`, 
           Superscript[10, -11]}, {-23.025850929940457`, 
           Superscript[10, -10]}, {-20.72326583694641, 
           Superscript[10, -9]}, {-18.420680743952367`, 
           Superscript[10, -8]}, {-16.11809565095832, 
           Superscript[10, -7]}, {-13.815510557964274`, 
           Superscript[10, -6]}, {-26.937873935368604`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-26.53240882726044, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-26.244726754808656`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-26.021583203494448`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-25.839261646700493`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-25.685110966873236`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-25.551579574248713`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-25.43379653859233, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-24.635288842374557`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-24.229823734266393`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.942141661814613`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.7189981105004, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.536676553706446`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.38252587387919, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.248994481254666`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-23.131211445598282`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-22.33270374938051, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-21.927238641272346`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-21.639556568820566`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-21.416413017506358`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-21.234091460712403`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-21.079940780885142`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-20.94640938826062, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-20.82862635260424, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-20.030118656386467`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-19.624653548278303`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-19.33697147582652, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-19.11382792451231, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-18.931506367718356`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-18.7773556878911, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-18.643824295266576`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-18.526041259610192`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-17.72753356339242, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-17.322068455284256`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-17.034386382832476`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.811242831518264`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.62892127472431, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.474770594897052`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.34123920227253, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-16.223456166616145`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-15.424948470398375`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-15.01948336229021, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-14.73180128983843, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-14.508657738524219`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-14.326336181730264`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-14.172185501903007`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-14.038654109278484`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-13.9208710736221, "", {0.00375, 0.}, {
            Thickness[0.001]}}}}, {True, False}}, 
      AxesOrigin -> {-0.4, -26.721316007716737`}, 
      PlotRange -> {{-0.4, -0.05}, {-26.721316007716737`, \
-14.415396113396987`}}, AspectRatio -> GoldenRatio^(-1), Axes -> True, 
      AxesOrigin -> {-0.4, -26.5}, 
      CoordinatesToolOptions -> {"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )}, Frame -> {True, False, False, True}, 
      FrameLabel -> {{Null, "Rate of rescue"}, {
        "Wildtype growth rate", Null}}, 
      FrameTicks -> {True, False, False, True}, LabelStyle -> 
      Directive[12, FontFamily -> "Helvetica"], Method -> {}, 
      PlotRange -> {{-0.4, -0.05}, {-26.721316007716737`, \
-14.415396113396987`}}, PlotRangeClipping -> True, PlotRangePadding -> {
        Scaled[0.02], 
        Scaled[0.02]}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          Thickness[Large]]}, {
         Style["approx", 12, FontFamily -> "Helvetica"]}, LegendLayout -> 
        "Column"]], 
      Scaled[{
        Rational[3, 4], 
        Rational[1, 4]}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{{3.769353950014419*^9, 3.7693539546908207`*^9}, 
   3.7693539854011517`*^9, 3.769354022718892*^9, 3.7693540656726227`*^9, {
   3.7693582892175827`*^9, 3.769358312099654*^9}, 3.769360505286256*^9, 
   3.769360536801445*^9, 3.769360585700039*^9, 3.769360633034041*^9, 
   3.769374343208044*^9, 3.769374738939313*^9, 3.782253680105917*^9}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot approximations (figure 5)", "Subsection",
 CellChangeTimes->{{3.784901500561212*^9, 3.784901510983849*^9}, {
  3.784901886254138*^9, 3.784901894914263*^9}}],

Cell[CellGroupData[{

Cell["Panel A data", "Subsubsection",
 CellChangeTimes->{{3.784901561554943*^9, 3.784901571281739*^9}, {
  3.784902054799513*^9, 3.784902055965486*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"n0", "=", 
    SuperscriptBox["10", "4"]}], ";", "\[IndentingNewLine]", 
   RowBox[{"U", "=", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], ";", "\[IndentingNewLine]", 
   RowBox[{"mmax", "=", "0.5"}], ";", "\[IndentingNewLine]", 
   RowBox[{"\[Lambda]", "=", 
    RowBox[{"2", 
     RowBox[{"Es", "/", "n"}]}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"Es", "=", "0.01"}], ";", "\[IndentingNewLine]", 
   RowBox[{"n", "=", "4"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"mneg", "=", 
      RowBox[{"FindRoot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"2", 
          SuperscriptBox["m1", "2"]}], "-", 
         RowBox[{"\[CapitalLambda]1", "[", 
          RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"m1", ",", 
          RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"mpos", "=", 
      RowBox[{"FindRoot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"2", 
          SuperscriptBox["m1", "2"]}], "-", 
         RowBox[{"\[CapitalLambda]1", "[", 
          RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
          "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"m1", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"xs", "=", 
    RowBox[{"Table", "[", 
     RowBox[{"mwt", ",", 
      RowBox[{"{", 
       RowBox[{"mwt", ",", 
        RowBox[{
         RowBox[{"-", "0.8"}], "mmax"}], ",", 
        RowBox[{
         RowBox[{"-", "0.1"}], "mmax"}], ",", 
        RowBox[{"0.1", "mmax"}]}], "}"}]}], "]"}]}], ";", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"temptab", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Table", "[", " ", 
       RowBox[{
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"fm", "[", 
            RowBox[{
            "m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
            "]"}], 
           FractionBox[
            RowBox[{" ", 
             RowBox[{"\[CapitalLambda]1", "[", 
              RowBox[{
              "m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
              "]"}]}], 
            RowBox[{"Abs", "[", "m1", "]"}]]}], "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"m1", ",", "mwt", ",", 
            RowBox[{"-", "pr0"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"mwt", ",", 
          RowBox[{
           RowBox[{"-", "0.8"}], "mmax"}], ",", 
          RowBox[{
           RowBox[{"-", "0.1"}], "mmax"}], ",", 
          RowBox[{"0.1", "mmax"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"NIntegrate", "[", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"fm", "[", 
            RowBox[{
            "m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
            "]"}], 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
           SqrtBox[
            RowBox[{"2", 
             RowBox[{"\[CapitalLambda]1", "[", 
              RowBox[{
              "m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
              "]"}]}]]}], ",", 
          RowBox[{"{", 
           RowBox[{"m1", ",", 
            RowBox[{"m1", "/.", "mneg"}], ",", 
            RowBox[{"m1", "/.", "mpos"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"mwt", ",", 
          RowBox[{
           RowBox[{"-", "0.8"}], "mmax"}], ",", 
          RowBox[{
           RowBox[{"-", "0.1"}], "mmax"}], ",", 
          RowBox[{"0.1", "mmax"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"fm", "[", 
            RowBox[{
            "m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
            "]"}], 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
           FractionBox[
            RowBox[{" ", 
             RowBox[{"\[CapitalLambda]1", "[", 
              RowBox[{
              "m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
              "]"}]}], 
            RowBox[{"Abs", "[", "m1", "]"}]]}], "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"m1", ",", "pr0", ",", "mmax"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"mwt", ",", 
          RowBox[{
           RowBox[{"-", "0.8"}], "mmax"}], ",", 
          RowBox[{
           RowBox[{"-", "0.1"}], "mmax"}], ",", 
          RowBox[{"0.1", "mmax"}]}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
     "}"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"Transpose", "[", "temptab", "]"}], ";", "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "/", 
      RowBox[{"Total", "[", 
       RowBox[{"%", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "%", "]"}]}], "}"}]}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"test", "=", 
    RowBox[{"Transpose", "[", "%", "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"data", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "xs", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"%", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "}"}], ",", "1"}], "]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "%", "]"}]}], "}"}]}], "]"}]}], ";", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", 
    RowBox[{
    "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "n0"}], 
    "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.784901603196601*^9, 3.78490160382696*^9}, {
   3.784901647808614*^9, 3.784901648600154*^9}, 3.784901799275362*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "0.9456638573208591`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", "0.8818894810731134`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", "0.7882778363153661`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.6791421962065166`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.5706393639682957`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", "0.4705197731917115`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09999999999999998`"}], ",", "0.3776908923323233`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", "0.2793108104800298`"}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "0.03623085604695413`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", "0.07601020185743679`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", "0.13070865247937516`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.1885039970593472`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.23742270239875216`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", "0.2712516380984508`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09999999999999998`"}], ",", "0.2883094661397107`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", "0.2901562484218649`"}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "0.018105286632186777`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "0.042100317069449986`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", "0.08101351120525872`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.13235380673413624`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.1919379336329521`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", "0.2582285887098376`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09999999999999998`"}], ",", "0.3339996415279661`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", "0.4305329410981054`"}], 
        "}"}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.784901788634666*^9, 3.784901792099799*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Panel A", "Subsubsection",
 CellChangeTimes->{{3.7849016584595203`*^9, 3.7849016603718157`*^9}, {
  3.784902059005643*^9, 3.784902059805956*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"n0", "=", 
   SuperscriptBox["10", "4"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "4"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"small\[Psi]approxRescue", ",", 
    RowBox[{"2", " ", "\[CapitalLambda]0approx", " ", 
     RowBox[{"fm", "[", 
      RowBox[{"0", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}]}], " ", ",", "small\[Psi]approxRescueSuper"}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   FractionBox["%", 
    RowBox[{"Total", "[", "%", "]"}]], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"verylarge\[Rho]approxRescue", ",", 
    RowBox[{"2", " ", "\[CapitalLambda]0approx", " ", 
     RowBox[{"fm", "[", 
      RowBox[{"0", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}]}], " ", ",", "small\[Psi]approxRescueSuper"}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   FractionBox["%", 
    RowBox[{"Total", "[", "%", "]"}]], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fig5a", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Plot", "[", "\[IndentingNewLine]", 
      RowBox[{"%", ",", 
       RowBox[{"{", 
        RowBox[{"mwt", ",", 
         RowBox[{"-", "0.4"}], ",", 
         RowBox[{"-", "0.2"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
       
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Wildtype growth rate\>\"", ",", ",", ",", 
          "\"\<Percent of 2-step rescues\>\""}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "False", ",", "False", ",", "All"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"LineLegend", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{
             "\"\<subcritical\>\"", ",", "\"\<critical\>\"", ",", 
              "\"\<supercritical\>\""}], "}"}]}], "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"3", "/", "4"}], ",", 
             RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<A\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.95", ",", "0.95"}], "}"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", "\[IndentingNewLine]", 
      RowBox[{"%%%", ",", 
       RowBox[{"{", 
        RowBox[{"mwt", ",", 
         RowBox[{"-", "0.2"}], ",", 
         RowBox[{"-", "0.01"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}]}], "\[IndentingNewLine]", 
      "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ListPlot", "[", 
      RowBox[{"data", ",", 
       RowBox[{"PlotMarkers", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"defaultcolors", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"Disk", "[", "]"}]}], "}"}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"defaultcolors", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", 
              RowBox[{"Disk", "[", "]"}]}], "}"}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"defaultcolors", "[", 
               RowBox[{"[", "3", "]"}], "]"}], ",", 
              RowBox[{"Disk", "[", "]"}]}], "}"}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.4"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "n0"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.769361975014821*^9, 3.7693620103723793`*^9}, {
   3.769362055403811*^9, 3.76936217516903*^9}, {3.769362300449959*^9, 
   3.769362390146037*^9}, {3.769368135479473*^9, 3.7693682213229628`*^9}, 
   3.7693682631857653`*^9, {3.769368306678321*^9, 3.769368310698353*^9}, 
   3.769368564301279*^9, 3.769368626560327*^9, {3.7693698079180193`*^9, 
   3.769369829262083*^9}, {3.769369878839031*^9, 3.769370020522847*^9}, {
   3.769370057668705*^9, 3.769370111566934*^9}, {3.769370161664791*^9, 
   3.769370192641665*^9}, {3.769370232989592*^9, 3.769370321502605*^9}, {
   3.769370373261149*^9, 3.769370418948492*^9}, {3.769370846488199*^9, 
   3.769370997333514*^9}, 3.7693710527511177`*^9, {3.769371103517735*^9, 
   3.769371174060443*^9}, {3.769371210449788*^9, 3.769371313732812*^9}, {
   3.769371378897552*^9, 3.7693713813143663`*^9}, {3.769371504714951*^9, 
   3.7693715053101063`*^9}, {3.769371612272114*^9, 3.769371613534341*^9}, {
   3.769371865627068*^9, 3.76937205231537*^9}, {3.7693721684190807`*^9, 
   3.769372227742949*^9}, {3.769374794476512*^9, 3.769374795879532*^9}, {
   3.769376802584484*^9, 3.769376842774276*^9}, {3.769376872864873*^9, 
   3.7693769198362837`*^9}, {3.769429285652513*^9, 3.7694293040391207`*^9}, {
   3.769429390566464*^9, 3.769429424345962*^9}, {3.769967053692177*^9, 
   3.769967055786622*^9}, 3.782240619176725*^9, {3.782240705113155*^9, 
   3.782240734995162*^9}, {3.784901318890506*^9, 3.784901325297822*^9}, {
   3.784901675297751*^9, 3.784901679683895*^9}, 3.784903043071323*^9}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwV0Hs8lAkXB3AV0Y2iRVq9Q3grVFRTsTqlEnazm7LbRDEubdhoc1m5LV6U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        "]]}, 
      {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
       LineBox[CompressedData["
1:eJwV1nk4VdsbB3DKdItowEkpJUU6CuUa0iJD6F4UMiTzlLpUIhGlWYWOuToa
ZKrL5ZpK0Stuaq99Dsc2i4rQ4Gb4SSRXv3X+2M9+Pn+std+9v++7nr3GJ3Sv
/zwRERE+uYR347xf027c6IJ0vtaUTH8pssn8wzYzswtWd0SuyBkqRS5X7ktm
ZHSBl9mrccPhUnQsRDYqNa0LvtTvKA/+Wory9D54JHG6YFbsRyIjUYYWvUxX
vxDfBTVxPxLrNcvQmw+TT4+c7IKt+YzdxogydFqjvH+Xaxd0f1tvLylTjpI3
NmklLO0CU5O/2g4dqECStaeCjzKdkDt1d0tJdiVy7a+9yU3uhM+Rb/Wzhx+h
6LP3KY/fO8HWq6iQvb8KiTxifQTpTjBwMTQqfPoE7Tu4SfxxQwew4dxBc7Nq
dLmgXWEqrgM+7DW4kM6rQcqnlrLaTDsgy6ejO3UnoLP8EUWb2XaI0eoVjQit
RTZl7pIeT9uh+2s+N1/nORpR8x5+HN0O0y+K/ZZ/fY58FcQaH+q1w61xk4v4
ZR0yvGVw1+hbG/TW7sqPSaxH/VkyR31L2kB+sYdKYsA/KJAdqcccaoPlSuN3
nhm+QLZ7woffarbBwr9clTeINCCJCbk754da4Wpr95hqWwNS0UA7X+W2wguu
6n/7br5EC3sXDmR7toKBXZVZ0R+vEKMcGvWPUitUfjRS2WpIodn/+Ylc6G4B
7XdVTV2TFJqy+H6+J7UFRLq5rXtrMHJkq3xnHFrgWNpvZ93DaJR4r9dbblkL
bL//l0TkGh7KTDGgBhoZcOKqa/7SxUPiSuoqLokMjL7ndk7F8tHOVRXhPlYM
xEvwVBM2NSL34k4om8/A8iL+z52CRtTZmvj9fn0zCL5JZjz0aUJqke+1NWOb
4djWAGmLmSbUVoxd9xg3g4bfw7BAEwHyPm4V8ew/AcyNtjtNxwrQs0o/Tt1j
AbgWLBaffiZAMQlLuf6RAkhmrZ0d/SZAMv1euXd0BHBlZd9A6OZm9DMtbvt4
fxPUxg2M63g1o6y4EEVt3yY4b5hFaV9rRj1BmaO3OxthTUbZ67RHzehd5Ic8
G+dGGK4br5t83YwunA/bv47mw1S0jG7LXDN6/2DT96umfHC/rvo/35UMWqmq
knQF8aG26/NRitiRu1Qt3pgPcxJJJVrKDGpInLG/aMCHnpM+wdPEBWGvCs5o
8+Hww4Gmy6sZdNjYzyV8DR+47nzPrLUM+iq49chDlA9vnAZj09QZJDG9IEL7
OQ8aw44oPtdlENt/ol4MeHA/409v5a3keczrxZ3VPGAFRXicJM4uLCyKfcwD
tnxh6JZtDNrhbTtIF/NA9YnW2E09Bp3AHMeA2zyIS7MK8DZg0EcuS/dWNA/W
mB+VLt/BINkFonEhJ3lQ+drlngRikN6JT42mJ3ggFe780YX4/J4nwR+P8SDm
6JVrs8RrJNyztwXz4PqgO9vElEFuoXcWC1x4YKnrzn9sxiDadP2YmB4PegoH
D4VaMSjd7Oq2/3R5ICE3GFRG7GUxFjWpzYM7rpw1U8RfrZ6ID7F5UD31/kWM
Nfm+9rYrXqrxoCKZ1X3JhkEhHhGW8fI8cBr/xk76jUFy0Q1cmUkaVqmt+yPY
nkHdpzT7xSdoUFuQ3JVLnBN7fcPcGA1Tuy1F+4j1z7qVjvxLg/LH42f37WGQ
d/zIy6YBGowOJO3esZdBpRkKE5xWGlIaeidFHBnkVB5grVBOQ7x3T8peZwZd
DD7SwCqlwbq/1Pc88WOVKLMVJTTIhyqOVxArJSQYqxTS8Eku1pzlwqA3/uXa
G3NoaJ0M4ncRByjOU9qRSgP7yYifvRuDIqKyPvsfJ/XbuqUuPMCg/C35gUHH
aFh+ukF2G3HnUMlA8BEaBgzdrDyIDR3+eRN6mAa5XcNjxcRzmsPMST8aXPVd
Vtt7MOhSr/7TBEcadt2OHTnnyaBMk9arFVtpcJ5t3VHlTer9zNRe06FBXDJB
rZe4I7V50ncLDekprBoRHwYpfGr0XLKJhkvDmXOWxKkcSjdUlaz3e4GbiDn9
z16rL6Hh85Kf5xhfBpVcq5ETkaPhrvJQ+DixQK/aokOGBskvbiw5P5LP1ari
C7/QYK7fE/IbcaJu+bl+ERqmq557Pye+cv6BJncUw9ft2/Zz/Rn0UKvAK+wL
hrTAAYdKYqozL81mGIPniu7ZJmIpds7P6SEMNcqXPOcFkDzabrc4vcFQJn0w
0Jc473SWFLsHw1rFxr4o4hcaXGOxbgwTkU7SycRisTfyS9swvJWqOgrE59an
RsvyMXwJd4hRCCTzI0guGcIY9nnujtQkroviDNa8wvBmvqmqCfG8pkS7w/9g
OCS/ND6I+MyJeFXqKYa/RZtTKohPvYqlzz7EMNhw/55JEJk/yZmp2AIM2Mj7
qh2xqGX4uug8DBuLdDd7EF+sPxQTlk3215XKjSLmPHPZ7HcTw+N9YtYlxI7/
tez3ysQwbTg3r4ZYYbvdZfd0DL+5jERQxNwqiz7HZAwf6u9d6yPOK9dJsbiC
wbjqY8iigwwKmigC08sYcqgN0yxiTR2Nf40vYmicMTZSJS4pXm2hdxZDnOK7
ET3isJGbR3XOYEje5OdpQqzHVritFYtBqqI43pr46UPpqfVRGBR8EhbuJ479
dElVNRJDZq6iry+xifp8+9URGFozXI8fIm7I/V6geAyDTdXX+ihiwd0hN6lg
DJKdLMV04uS33pfEgjC8TBg34hI7reotEwnAsF3DRymbuPtWi/R3bwy7F/2Y
X0Sc1W1rMOmJQcRxhWwpsddy7D9+AMPtE/UtlcSD6bXPPrliKEa34oG4oM1o
eNAZQ3RbXVQ9cfCyR4r9ThjCNHzUXhKzHXTM3zhgCNEOj8fEY5yiI917MIy9
ncrjE5cK1LPa7TCEbhiKERCHy+ZQzO8YmqaMFrUQ69uu/ta4G4O8yaRzG/HM
tZtraWsMK7/I7O8grqHl7V7uwlA5HKfYRXxmASe63gJDtdrvCd3EO62lC8AM
w6bzh6pfE4tfvtT61BSD10hnTg/xq4Z5oo8Rhus2HMte4ivisexyYwx9p67f
E/p38++uJUYY2oKYCqHlzh2/WGiAIWV07zmhmeejpQW/YtAZk1kgdJrIobc5
2zDwbX5aC/d3QUML7+liGO1eayZ8vlKst36WNunnU8cnhfX2Vvf43diMIemX
Ma9O4rs/nDlpbAwn3DgX2ol9DFtqOJqkvy0cfVuJ1U7afk7QwLDu3taZZuH7
VWgtt92AgeWfNNlI7DG+yGqRGoafO65k0sTR7NGIxrUY6vevfi/MI/NgU26i
Cgb9Ias2YV7lucWttqvI/EqKhgrzbO5Lmi+7EoPikGnJE+IFbvbeSYqkHn9L
jRLiDelbrtvJk37fNef1kNickQPZpRhkAjeY5BDH2DSvvL6IzFN9xVdh/928
+Pdue2kMq7RkcRJxZR0nSm4BhpbNdZaXhf1guLfzujiGH3rKepHEMid0JPfM
J+udqgpCiTeWLdFbLIqhwzijLoDYV7MlhTNLQUKcyL8OwrwDy+r2zFCwr//0
D+H8cO+njC+epiBfQaMUEbevcLRLnqBg2fC7ZRuJJ5y3xu4dp+Bu9PvaVcI8
U5cVLRmlwLJ+aulSYmvptgUpnymoNDIuniHzXj3r1JDSR8HfFZyqF8Rd+nqT
Dm8p8Pr3RNYj4m/HFdYt66XgxTqk/oB485f2uNROClplXXSuEmf3OhunNVFg
EirJ2k0My/UPO/EpYAda6xgS9zixbsnTFHhKGk2oE8s3dk6nNRD7LDsoTnz5
mWt5eg0F78jv6BNy/uXOGLzf95QCnzOiYXnC81NPaYliFQVWvKSgZOIff3WH
ZpRTwFKX3nWQOOTOfs3MPymYP84IlhBffW3k5vKAgrqPqx1myflcoLgynpVP
QXLPo+hB4r6knqHMbAqwVjFUEs/R1fKudykwqxN9fZtYSSrLfPltCpqfXOBe
JP7VPCas6xYFRoVbxUKIHc8cyL5xg4KZDVJLnIj/DwKp0zM=
        "]]}, 
      {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
       LineBox[CompressedData["
1:eJwVzH0w1Akcx/EdeSj0XMjVUcdVpKbGbEndN50Kte6qFUvrMVQ3cT1oKAqT
6UFWeVyx5ThityEsycN+PRR+u+z+rF12Y1PbxsUROfJ0ur0/PvOZ1z/vjYHh
J4J1KBQKTbv/f3/h7vSsLCUemnI1in/HBTf2BXc2W4nODpPqhEEueN3LN8jM
VCJrhWL63igXLoUtv5aWrsRFsXv62fNcKKQO+iY/VGL9F8OMZjMeLGvN2JJw
V4k3LXqK6Md58HZwsvb3KCXOcOTOwc08uLmVrz7CUGKhxfxy4D2DFBvJ9qTV
ShRczNk4XF4CBg3R5y9KFajD86iKOPUcGOqGRzkpCjw2bRi4yqsMrsfnE740
BZ69G2q1EFUOlBdmf6GxAql+Y8brUyrg1LltetUtPTh6TfipVMSHO0XdJl/j
erDcKdzffkkVbIhebSZ36sG+Ps3H2w4vIL5j1NRtvhv1Gxtb5YnV4FZx2sC3
thtrnn5Heyt+CaPWAcPV17vxQbLMj7+yFoJMdMVcajdO3yjWtblaB3uzHXId
p+T4fsHngKq1HtScpReDnsuxhFmcnb8XIdQukir9TY6c2t4OZ48GcD8eMdxv
K8cQIy7VRqcR9CdWPLk1IMOyn1JpVYJGsNwKB9sKZHgkydEEwpvASGWkyfOT
Ya7rzA+87c0g3RB+7ZW5DN2Zj/wPDzXD/JczlIQ3XfiKdeFSBvsVfD00c6sv
rQs1tNTXvvTXQLeznJGe7MK/dU/E2Oi0AOsPVcCKNV3oaXsnvpHbAuxUB0Ij
lmIxZ0eJk18r6JlvsfRiSbGfcvuwuV4bHPy+MiLQRYo0O036n5VtcLpUgRWL
pHhf5CL19iNAIWPN5Dd34iFJXajFLAHWkR922t7oRNWxkqh2jhDkpULG8f2d
+KU/lxG6SwQBV1yuCv4lcWKOfn4IRSCoOvOwqZrEZ3ohMYn0dohJWp0THEli
tvfCSeabdliq9i94sovEQCfXaE1wB3xLj9s3rpbgSnujJU3qDuDEhZnuDJIg
m1lr/9FTDH1n2Z8fK8R4z4DHlJFieBc5WOjmKcbBzy9TGhwlkHDrso+VqAN9
elmC4SIJfCjeNpPo1IH6AZmi+/ok6E8bXt3Z2I52W75VGO8iQeT045gutR1L
LqsYGUwSPPghriZ8ESK9+Xx1PAnsA7LESnsR6l4XWdTkkxDddkMUzxXi0djZ
uZxmEqyj3IeStgoxavzTvgcqEg5Wbl/nvlmIY0WStDmtfceXuSyzFmKeZiE3
5K22d05SwLIUYu8vS7sd+0kw9P41INlUiJzFZWXqdySM7T2heKAnxE2lTtab
NCTUzXu0pL4n8GjhzyWhQyQo91AnT/YTyFgbG0VoPXXFxGqNisBs0aOvNsMk
7BjpjktTEFgh2Gc8onWeynN/uoTACHIk/cIICXcEDH5GPYHPIjst/cdIKJh1
+HCqlsCkupg19Vo3Uc1Xmb4kMCyMVrNunIS5kjfhmXwCgwc2r5dqHfbEx5bN
I1B/NGY3TJCQ2Ovo7VVM4EDMbE2W1kWm6++aPSUwscJxbELr98l9A+w8AstC
+sKf/kPCgqhuLSOXwFk9qxrKJAnmiznO6x5re8mUKobWu51jLiuzCQxdEhJU
rjU9lpmXlUWgMtKlyXCKhP8AbLynOA==
        "]]}}, {{}, {}, 
      {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwVx3k4FIoagHHlKFk7iSsUhqxZTiVLnb5OtFKWKKmsky1LIiZb6aAJ2SJG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        "]]}, 
      {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
       LineBox[CompressedData["
1:eJwd13k4lN8XAHBLhKKFJFSyJSE7US5ZksgSLbLlOyRboiR7Qki2LNmzhKLs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        "]]}, 
      {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
       LineBox[CompressedData["
1:eJwVjXk4FIgfh6eRe+i3q7FdG7kSqVkRqe2rorQo7UZLBzO5EmnTLpIcjWt2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        "]]}}, {{}, GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQPWsmCNzcb1fZdvOB0zv79DQQuLY/efkfzwKLN/Ym
xiBweb999JOCSZYv7RnA4ML+hT6OWR27n9pD9J/c/3nXweq1To+g6g/v59xS
9/2fzD37GWD5nfufyi3JFtO5AeWv3G82VbrY6sFFe5j9YueXn77Zswhuv8ct
5cnppZvh9q9luLWUf/cBuP0rG1yUnymcgNv/eJvA77vJ5+D26y9afkU/5iLc
fv0FPD0riy/B7X//Jqf59cRLcPslrR6aG3ZNgtsfdvWtpU7fUrj9q1U0dX33
boHbf9Vnm/GPDwfg9gfGvhDNmXgCbv/xlTeNL7ZdgNv/1sGfwyHhKtz+u7Xl
nLd6b9uPhv/Ahj8AQBCA5w==
       "], {
        {RGBColor[0.24720000000000014`, 0.24, 0.6], InsetBox[
          GraphicsBox[
           {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
           ImageSize->10], 25], InsetBox[
          GraphicsBox[
           {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
           ImageSize->10], 26], InsetBox[
          GraphicsBox[
           {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
           ImageSize->10], 27], InsetBox[
          GraphicsBox[
           {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
           ImageSize->10], 28], InsetBox[
          GraphicsBox[
           {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
           ImageSize->10], 29], InsetBox[
          GraphicsBox[
           {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
           ImageSize->10], 30], InsetBox[
          GraphicsBox[
           {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
           ImageSize->10], 31], InsetBox[
          GraphicsBox[
           {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
           ImageSize->10], 32]}, 
        {RGBColor[0.6, 0.24, 0.4428931686004542], InsetBox[
          GraphicsBox[
           {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
           ImageSize->10], 33], InsetBox[
          GraphicsBox[
           {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
           ImageSize->10], 34], InsetBox[
          GraphicsBox[
           {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
           ImageSize->10], 35], InsetBox[
          GraphicsBox[
           {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
           ImageSize->10], 36], InsetBox[
          GraphicsBox[
           {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
           ImageSize->10], 37], InsetBox[
          GraphicsBox[
           {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
           ImageSize->10], 38], InsetBox[
          GraphicsBox[
           {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
           ImageSize->10], 39], InsetBox[
          GraphicsBox[
           {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
           ImageSize->10], 40]}, 
        {RGBColor[0.6, 0.5470136627990908, 0.24], InsetBox[
          GraphicsBox[
           {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
           ImageSize->10], 41], InsetBox[
          GraphicsBox[
           {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
           ImageSize->10], 42], InsetBox[
          GraphicsBox[
           {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
           ImageSize->10], 43], InsetBox[
          GraphicsBox[
           {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
           ImageSize->10], 44], InsetBox[
          GraphicsBox[
           {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
           ImageSize->10], 45], InsetBox[
          GraphicsBox[
           {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
           ImageSize->10], 46], InsetBox[
          GraphicsBox[
           {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
           ImageSize->10], 47], InsetBox[
          GraphicsBox[
           {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
           ImageSize->10], 48]}, {}}], {}}}, InsetBox[
     TemplateBox[{
      StyleBox["\"subcritical\"", StripOnInput -> False, FontFamily -> 
        "Helvetica", FontSize -> 12],StyleBox[
       "\"critical\"", StripOnInput -> False, FontFamily -> "Helvetica", 
        FontSize -> 12],StyleBox[
       "\"supercritical\"", StripOnInput -> False, FontFamily -> "Helvetica", 
        FontSize -> 12]},
      "LineLegend",
      DisplayFunction->(StyleBox[
        StyleBox[
         PaneBox[
          TagBox[
           GridBox[{{
              TagBox[
               GridBox[{{
                  GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                   ImageSize -> {20, 10}, PlotRangePadding -> None, 
                   ImagePadding -> 1, 
                   BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                  GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                   ImageSize -> {20, 10}, PlotRangePadding -> None, 
                   ImagePadding -> 1, 
                   BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                  GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                   ImageSize -> {20, 10}, PlotRangePadding -> None, 
                   ImagePadding -> 1, 
                   BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                GridBoxAlignment -> {
                 "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                AutoDelete -> False, 
                GridBoxDividers -> {
                 "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
                GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}],
                "Grid"]}}, 
            GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
            AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
           "Grid"], Alignment -> Left, AppearanceElements -> None, 
          ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"],
          LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
        Background -> Automatic, StripOnInput -> False]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Hue", "[", 
                    RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Hue", "[", 
                    RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}],
                     "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Hue", "[", 
                    RowBox[{"0.1421359549995791`", ",", "0.6`", ",", "0.6`"}],
                     "]"}], ",", 
                   RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], "}"}],
            ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
     NCache[Scaled[{Rational[3, 4], Rational[3, 4]}], Scaled[{0.75, 0.75}]], 
     ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesOrigin->{-0.4, 0},
   Epilog->InsetBox[
     FormBox[
      StyleBox[
      "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
      TraditionalForm], 
     Scaled[{0.95, 0.95}]],
   Frame->{True, False, False, True},
   FrameLabel->{{"", 
      FormBox["\"Percent of 2-step rescues\"", TraditionalForm]}, {
      FormBox["\"Wildtype growth rate\"", TraditionalForm], ""}},
   FrameTicks->{True, False, False, All},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.4, 0}, {0, 1}},
   PlotRangeClipping->True,
   PlotRangePadding->{
     Scaled[0.02], Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Thickness[Large], 
         Line[CompressedData["
1:eJwV0Hs8lAkXB3AV0Y2iRVq9Q3grVFRTsTqlEnazm7LbRDEubdhoc1m5LV6U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          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Thickness[Large], 
         Line[CompressedData["
1:eJwV1nk4VdsbB3DKdItowEkpJUU6CuUa0iJD6F4UMiTzlLpUIhGlWYWOuToa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          "]]}, {
         Hue[0.1421359549995791, 0.6, 0.6], 
         Thickness[Large], 
         Line[CompressedData["
1:eJwVzH0w1Akcx/EdeSj0XMjVUcdVpKbGbEndN50Kte6qFUvrMVQ3cT1oKAqT
6UFWeVyx5ThityEsycN+PRR+u+z+rF12Y1PbxsUROfJ0ur0/PvOZ1z/vjYHh
J4J1KBQKTbv/f3/h7vSsLCUemnI1in/HBTf2BXc2W4nODpPqhEEueN3LN8jM
VCJrhWL63igXLoUtv5aWrsRFsXv62fNcKKQO+iY/VGL9F8OMZjMeLGvN2JJw
V4k3LXqK6Md58HZwsvb3KCXOcOTOwc08uLmVrz7CUGKhxfxy4D2DFBvJ9qTV
ShRczNk4XF4CBg3R5y9KFajD86iKOPUcGOqGRzkpCjw2bRi4yqsMrsfnE740
BZ69G2q1EFUOlBdmf6GxAql+Y8brUyrg1LltetUtPTh6TfipVMSHO0XdJl/j
erDcKdzffkkVbIhebSZ36sG+Ps3H2w4vIL5j1NRtvhv1Gxtb5YnV4FZx2sC3
thtrnn5Heyt+CaPWAcPV17vxQbLMj7+yFoJMdMVcajdO3yjWtblaB3uzHXId
p+T4fsHngKq1HtScpReDnsuxhFmcnb8XIdQukir9TY6c2t4OZ48GcD8eMdxv
K8cQIy7VRqcR9CdWPLk1IMOyn1JpVYJGsNwKB9sKZHgkydEEwpvASGWkyfOT
Ya7rzA+87c0g3RB+7ZW5DN2Zj/wPDzXD/JczlIQ3XfiKdeFSBvsVfD00c6sv
rQs1tNTXvvTXQLeznJGe7MK/dU/E2Oi0AOsPVcCKNV3oaXsnvpHbAuxUB0Ij
lmIxZ0eJk18r6JlvsfRiSbGfcvuwuV4bHPy+MiLQRYo0O036n5VtcLpUgRWL
pHhf5CL19iNAIWPN5Dd34iFJXajFLAHWkR922t7oRNWxkqh2jhDkpULG8f2d
+KU/lxG6SwQBV1yuCv4lcWKOfn4IRSCoOvOwqZrEZ3ohMYn0dohJWp0THEli
tvfCSeabdliq9i94sovEQCfXaE1wB3xLj9s3rpbgSnujJU3qDuDEhZnuDJIg
m1lr/9FTDH1n2Z8fK8R4z4DHlJFieBc5WOjmKcbBzy9TGhwlkHDrso+VqAN9
elmC4SIJfCjeNpPo1IH6AZmi+/ok6E8bXt3Z2I52W75VGO8iQeT045gutR1L
LqsYGUwSPPghriZ8ESK9+Xx1PAnsA7LESnsR6l4XWdTkkxDddkMUzxXi0djZ
uZxmEqyj3IeStgoxavzTvgcqEg5Wbl/nvlmIY0WStDmtfceXuSyzFmKeZiE3
5K22d05SwLIUYu8vS7sd+0kw9P41INlUiJzFZWXqdySM7T2heKAnxE2lTtab
NCTUzXu0pL4n8GjhzyWhQyQo91AnT/YTyFgbG0VoPXXFxGqNisBs0aOvNsMk
7BjpjktTEFgh2Gc8onWeynN/uoTACHIk/cIICXcEDH5GPYHPIjst/cdIKJh1
+HCqlsCkupg19Vo3Uc1Xmb4kMCyMVrNunIS5kjfhmXwCgwc2r5dqHfbEx5bN
I1B/NGY3TJCQ2Ovo7VVM4EDMbE2W1kWm6++aPSUwscJxbELr98l9A+w8AstC
+sKf/kPCgqhuLSOXwFk9qxrKJAnmiznO6x5re8mUKobWu51jLiuzCQxdEhJU
rjU9lpmXlUWgMtKlyXCKhP8AbLynOA==
          "]]}}}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Thickness[Large], 
         Line[CompressedData["
1:eJwVx3k4FIoagHHlKFk7iSsUhqxZTiVLnb5OtFKWKKmsky1LIiZb6aAJ2SJG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          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Thickness[Large], 
         Line[CompressedData["
1:eJwd13k4lN8XAHBLhKKFJFSyJSE7US5ZksgSLbLlOyRboiR7Qki2LNmzhKLs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          "]]}, {
         Hue[0.1421359549995791, 0.6, 0.6], 
         Thickness[Large], 
         Line[CompressedData["
1:eJwVjXk4FIgfh6eRe+i3q7FdG7kSqVkRqe2rorQo7UZLBzO5EmnTLpIcjWt2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          "]]}}}, {{}, 
       GraphicsComplex[CompressedData["
1:eJxTTMoPSmViYGAwAGIQPWsmCNzcb1fZdvOB0zv79DQQuLY/efkfzwKLN/Ym
xiBweb999JOCSZYv7RnA4ML+hT6OWR27n9pD9J/c/3nXweq1To+g6g/v59xS
9/2fzD37GWD5nfufyi3JFtO5AeWv3G82VbrY6sFFe5j9YueXn77Zswhuv8ct
5cnppZvh9q9luLWUf/cBuP0rG1yUnymcgNv/eJvA77vJ5+D26y9afkU/5iLc
fv0FPD0riy/B7X//Jqf59cRLcPslrR6aG3ZNgtsfdvWtpU7fUrj9q1U0dX33
boHbf9Vnm/GPDwfg9gfGvhDNmXgCbv/xlTeNL7ZdgNv/1sGfwyHhKtz+u7Xl
nLd6b9uPhv/Ahj8AQBCA5w==
        "], {{{
           Hue[0.67, 0.6, 0.6], 
           Directive[
            RGBColor[0.24720000000000014`, 0.24, 0.6]], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              Directive[
               RGBColor[0.24720000000000014`, 0.24, 0.6]], 
              RGBColor[0.24720000000000014`, 0.24, 0.6], 
              Disk[{0, 0}]}, ImageSize -> 10], 25], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              Directive[
               RGBColor[0.24720000000000014`, 0.24, 0.6]], 
              RGBColor[0.24720000000000014`, 0.24, 0.6], 
              Disk[{0, 0}]}, ImageSize -> 10], 26], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              Directive[
               RGBColor[0.24720000000000014`, 0.24, 0.6]], 
              RGBColor[0.24720000000000014`, 0.24, 0.6], 
              Disk[{0, 0}]}, ImageSize -> 10], 27], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              Directive[
               RGBColor[0.24720000000000014`, 0.24, 0.6]], 
              RGBColor[0.24720000000000014`, 0.24, 0.6], 
              Disk[{0, 0}]}, ImageSize -> 10], 28], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              Directive[
               RGBColor[0.24720000000000014`, 0.24, 0.6]], 
              RGBColor[0.24720000000000014`, 0.24, 0.6], 
              Disk[{0, 0}]}, ImageSize -> 10], 29], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              Directive[
               RGBColor[0.24720000000000014`, 0.24, 0.6]], 
              RGBColor[0.24720000000000014`, 0.24, 0.6], 
              Disk[{0, 0}]}, ImageSize -> 10], 30], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              Directive[
               RGBColor[0.24720000000000014`, 0.24, 0.6]], 
              RGBColor[0.24720000000000014`, 0.24, 0.6], 
              Disk[{0, 0}]}, ImageSize -> 10], 31], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              Directive[
               RGBColor[0.24720000000000014`, 0.24, 0.6]], 
              RGBColor[0.24720000000000014`, 0.24, 0.6], 
              Disk[{0, 0}]}, ImageSize -> 10], 32]}, {
           Hue[0.9060679774997897, 0.6, 0.6], 
           Directive[
            RGBColor[0.6, 0.24, 0.4428931686004542]], 
           Inset[
            Graphics[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.24, 0.4428931686004542]], 
              RGBColor[0.6, 0.24, 0.4428931686004542], 
              Disk[{0, 0}]}, ImageSize -> 10], 33], 
           Inset[
            Graphics[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.24, 0.4428931686004542]], 
              RGBColor[0.6, 0.24, 0.4428931686004542], 
              Disk[{0, 0}]}, ImageSize -> 10], 34], 
           Inset[
            Graphics[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.24, 0.4428931686004542]], 
              RGBColor[0.6, 0.24, 0.4428931686004542], 
              Disk[{0, 0}]}, ImageSize -> 10], 35], 
           Inset[
            Graphics[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.24, 0.4428931686004542]], 
              RGBColor[0.6, 0.24, 0.4428931686004542], 
              Disk[{0, 0}]}, ImageSize -> 10], 36], 
           Inset[
            Graphics[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.24, 0.4428931686004542]], 
              RGBColor[0.6, 0.24, 0.4428931686004542], 
              Disk[{0, 0}]}, ImageSize -> 10], 37], 
           Inset[
            Graphics[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.24, 0.4428931686004542]], 
              RGBColor[0.6, 0.24, 0.4428931686004542], 
              Disk[{0, 0}]}, ImageSize -> 10], 38], 
           Inset[
            Graphics[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.24, 0.4428931686004542]], 
              RGBColor[0.6, 0.24, 0.4428931686004542], 
              Disk[{0, 0}]}, ImageSize -> 10], 39], 
           Inset[
            Graphics[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.24, 0.4428931686004542]], 
              RGBColor[0.6, 0.24, 0.4428931686004542], 
              Disk[{0, 0}]}, ImageSize -> 10], 40]}, {
           Hue[0.1421359549995791, 0.6, 0.6], 
           Directive[
            RGBColor[0.6, 0.5470136627990908, 0.24]], 
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.5470136627990908, 0.24]], 
              RGBColor[0.6, 0.5470136627990908, 0.24], 
              Disk[{0, 0}]}, ImageSize -> 10], 41], 
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.5470136627990908, 0.24]], 
              RGBColor[0.6, 0.5470136627990908, 0.24], 
              Disk[{0, 0}]}, ImageSize -> 10], 42], 
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.5470136627990908, 0.24]], 
              RGBColor[0.6, 0.5470136627990908, 0.24], 
              Disk[{0, 0}]}, ImageSize -> 10], 43], 
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.5470136627990908, 0.24]], 
              RGBColor[0.6, 0.5470136627990908, 0.24], 
              Disk[{0, 0}]}, ImageSize -> 10], 44], 
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.5470136627990908, 0.24]], 
              RGBColor[0.6, 0.5470136627990908, 0.24], 
              Disk[{0, 0}]}, ImageSize -> 10], 45], 
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.5470136627990908, 0.24]], 
              RGBColor[0.6, 0.5470136627990908, 0.24], 
              Disk[{0, 0}]}, ImageSize -> 10], 46], 
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.5470136627990908, 0.24]], 
              RGBColor[0.6, 0.5470136627990908, 0.24], 
              Disk[{0, 0}]}, ImageSize -> 10], 47], 
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.5470136627990908, 0.24]], 
              RGBColor[0.6, 0.5470136627990908, 0.24], 
              Disk[{0, 0}]}, ImageSize -> 10], 48]}, {}}}], {}}}, {
     PlotRange -> {{-0.4, 0}, {0, 1}}, AspectRatio -> GoldenRatio^(-1), Axes -> 
      True, AxesOrigin -> {-0.4, 0}, Epilog -> Text[
        Style["A", 14, Bold, FontFamily -> "Helvetica"], 
        Scaled[{0.95, 0.95}]], Frame -> {True, False, False, True}, 
      FrameLabel -> {{Null, "Percent of 2-step rescues"}, {
        "Wildtype growth rate", Null}}, 
      FrameTicks -> {True, False, False, All}, LabelStyle -> 
      Directive[12, FontFamily -> "Helvetica"], Method -> {}, 
      PlotRange -> {{-0.4, -0.2}, {0, 1}}, PlotRangeClipping -> True, 
      PlotRangePadding -> {
        Scaled[0.02], Automatic}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          Hue[0.67, 0.6, 0.6], 
          Thickness[Large]], 
         Directive[
          Hue[0.9060679774997897, 0.6, 0.6], 
          Thickness[Large]], 
         Directive[
          Hue[0.1421359549995791, 0.6, 0.6], 
          Thickness[Large]]}, {
         Style["subcritical", 12, FontFamily -> "Helvetica"], 
         Style["critical", 12, FontFamily -> "Helvetica"], 
         Style["supercritical", 12, FontFamily -> "Helvetica"]}, LegendLayout -> 
        "Column"]], 
      Scaled[{
        Rational[3, 4], 
        Rational[3, 4]}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{{3.7693623498045883`*^9, 3.7693623910173407`*^9}, {
   3.769368139076333*^9, 3.769368221917509*^9}, 3.7693682642636127`*^9, 
   3.7693683113505297`*^9, 3.7693685687646923`*^9, 3.769368644074222*^9, {
   3.769370085287794*^9, 3.7693701022019453`*^9}, {3.7693701531574373`*^9, 
   3.7693701675128508`*^9}, {3.769370246466703*^9, 3.7693702726365423`*^9}, 
   3.7693703095645447`*^9, {3.769370368270299*^9, 3.769370419391522*^9}, {
   3.76937085636733*^9, 3.7693709977603683`*^9}, 3.7693710536849403`*^9, {
   3.769371104298933*^9, 3.769371174849309*^9}, 3.769371216569933*^9, {
   3.769371275550788*^9, 3.769371314154649*^9}, 3.76937138174454*^9, 
   3.7693715060222197`*^9, 3.7693716175822277`*^9, 3.7693719046597013`*^9, {
   3.769371935875883*^9, 3.769371974277416*^9}, 3.769372057045204*^9, 
   3.76937214118316*^9, {3.769372178482349*^9, 3.7693722300211153`*^9}, {
   3.7693747875521803`*^9, 3.769374800133121*^9}, {3.7693768194271507`*^9, 
   3.769376840514534*^9}, 3.7693769088319063`*^9, {3.7694293806638117`*^9, 
   3.769429413448456*^9}, {3.7822406946741247`*^9, 3.782240729903997*^9}, 
   3.782253799369376*^9, 3.7849014190364437`*^9, 3.784901807218642*^9, 
   3.784903044590374*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Panel B data", "Subsubsection",
 CellChangeTimes->{{3.7849018212895107`*^9, 3.784901823321034*^9}, {
  3.784902063373114*^9, 3.7849020643101597`*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"n0", "=", 
    SuperscriptBox["10", "4"]}], ";", "\[IndentingNewLine]", 
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.1"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"mmax", "=", "0.5"}], ";", "\[IndentingNewLine]", 
   RowBox[{"\[Lambda]", "=", 
    RowBox[{"2", 
     RowBox[{"Es", "/", "n"}]}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"Es", "=", "0.01"}], ";", "\[IndentingNewLine]", 
   RowBox[{"n", "=", "4"}], ";", "\[IndentingNewLine]", 
   RowBox[{"U", "=", 
    SuperscriptBox["10", "x"]}], ";", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"xs", "=", 
    RowBox[{"Table", "[", 
     RowBox[{"U", ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "6"}], ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], ";", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"temptab2", "=", 
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"mneg", "=", 
        RowBox[{"FindRoot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"2", 
            SuperscriptBox["m1", "2"]}], "-", 
           RowBox[{"\[CapitalLambda]1", "[", 
            RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}],
             "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"m1", ",", 
            RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"mpos", "=", 
        RowBox[{"FindRoot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"2", 
            SuperscriptBox["m1", "2"]}], "-", 
           RowBox[{"\[CapitalLambda]1", "[", 
            RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}],
             "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"m1", ",", "0.1"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"pr0", "=", 
        SqrtBox[
         RowBox[{
          RowBox[{"\[CapitalLambda]1", "[", 
           RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
           "]"}], "/", "2"}]]}], ";", "\[IndentingNewLine]", 
       RowBox[{"{", " ", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"fm", "[", 
             RowBox[{
             "m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
             "]"}], 
            FractionBox[
             RowBox[{" ", 
              RowBox[{"\[CapitalLambda]1", "[", 
               RowBox[{
               "m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
               "]"}]}], 
             RowBox[{"Abs", "[", "m1", "]"}]]}], ",", 
           RowBox[{"{", 
            RowBox[{"m1", ",", "mwt", ",", 
             RowBox[{"-", "pr0"}]}], "}"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"NIntegrate", "[", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"fm", "[", 
             RowBox[{
             "m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
             "]"}], 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
            SqrtBox[
             RowBox[{"2", 
              RowBox[{"\[CapitalLambda]1", "[", 
               RowBox[{
               "m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
               "]"}]}]]}], ",", 
           RowBox[{"{", 
            RowBox[{"m1", ",", 
             RowBox[{"m1", "/.", "mneg"}], ",", 
             RowBox[{"m1", "/.", "mpos"}]}], "}"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"fm", "[", 
             RowBox[{
             "m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
             "]"}], 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
            FractionBox[
             RowBox[{" ", 
              RowBox[{"\[CapitalLambda]1", "[", 
               RowBox[{
               "m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
               "]"}]}], 
             RowBox[{"Abs", "[", "m1", "]"}]]}], ",", 
           RowBox[{"{", 
            RowBox[{"m1", ",", "pr0", ",", "mmax"}], "}"}]}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}], "\[IndentingNewLine]", ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "6"}], ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}], ";", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "temptab2", ";", 
   "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "/", 
      RowBox[{"Total", "[", 
       RowBox[{"%", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", 
       RowBox[{"Length", "[", "%", "]"}]}], "}"}]}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"test", "=", 
    RowBox[{"Transpose", "[", "%", "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"data", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "xs", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"%", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "}"}], ",", "1"}], "]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "%", "]"}]}], "}"}]}], "]"}]}], ";", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", 
    RowBox[{
    "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "mwt", ",", "n0", ",",
      "U"}], "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.769361975014821*^9, 3.7693620103723793`*^9}, {
   3.769362055403811*^9, 3.76936217516903*^9}, {3.769362300449959*^9, 
   3.769362390146037*^9}, {3.769368135479473*^9, 3.7693682213229628`*^9}, 
   3.7693682631857653`*^9, {3.769368306678321*^9, 3.769368310698353*^9}, 
   3.769368564301279*^9, 3.769368626560327*^9, {3.7693698079180193`*^9, 
   3.769369829262083*^9}, {3.769369878839031*^9, 3.769370020522847*^9}, {
   3.769370057668705*^9, 3.769370111566934*^9}, {3.769370161664791*^9, 
   3.769370192641665*^9}, {3.769370232989592*^9, 3.769370321502605*^9}, {
   3.769370373261149*^9, 3.769370418948492*^9}, {3.769370846488199*^9, 
   3.769370997333514*^9}, 3.7693710527511177`*^9, {3.769371103517735*^9, 
   3.769371174060443*^9}, {3.769371210449788*^9, 3.769371313732812*^9}, {
   3.769371378897552*^9, 3.7693713813143663`*^9}, {3.769371504714951*^9, 
   3.7693715053101063`*^9}, {3.769371612272114*^9, 3.769371613534341*^9}, {
   3.769371865627068*^9, 3.76937205231537*^9}, {3.7693721684190807`*^9, 
   3.769372227742949*^9}, {3.769374794476512*^9, 3.769374795879532*^9}, {
   3.769374988362481*^9, 3.7693752015416327`*^9}, {3.769375237833192*^9, 
   3.769375256422389*^9}, {3.769375298989477*^9, 3.769375409315852*^9}, {
   3.7693754563168*^9, 3.7693754588266973`*^9}, {3.769375490723859*^9, 
   3.769375571517234*^9}, {3.769375609955389*^9, 3.769375610671563*^9}, {
   3.769376974624186*^9, 3.769377114815401*^9}, {3.7693771450487623`*^9, 
   3.76937715448282*^9}, {3.769377347783226*^9, 3.769377378573168*^9}, {
   3.769377605499398*^9, 3.7693776443270187`*^9}, {3.7693776803664827`*^9, 
   3.769377681287714*^9}, {3.7693777210513897`*^9, 3.769377820250592*^9}, {
   3.769377931933558*^9, 3.769377946170843*^9}, {3.769429328820836*^9, 
   3.7694293433949003`*^9}, {3.7694295502426443`*^9, 
   3.7694295731041527`*^9}, {3.7699670763512363`*^9, 3.769967078171194*^9}, {
   3.782240522927578*^9, 3.782240594337283*^9}, 3.7822406353601913`*^9, {
   3.782240748133762*^9, 3.782240752011724*^9}, 3.782253654514523*^9, {
   3.784901346943548*^9, 3.784901353252801*^9}, {3.784901839037671*^9, 
   3.784901848815127*^9}, 3.7849019297468433`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "1000000"], ",", "0.4394221756678203`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "100000"], ",", "0.4272522411954631`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "10000"], ",", "0.40885542554335036`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "1000"], ",", "0.3776908923323242`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "100"], ",", "0.3146639788436848`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "10"], ",", "0.16762056652824764`"}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "1000000"], ",", "0.14473575990819615`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "100000"], ",", "0.17364469110334504`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "10000"], ",", "0.2168952147581818`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "1000"], ",", "0.2883094661397102`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "100"], ",", "0.4246353608625372`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "10"], ",", "0.7093264193395161`"}], "}"}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "1000000"], ",", "0.4158420644239835`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "100000"], ",", "0.39910306770119186`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "10000"], ",", "0.37424935969846795`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "1000"], ",", "0.3339996415279655`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "100"], ",", "0.26070066029377786`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "10"], ",", "0.1230530141322361`"}], "}"}]}], 
      "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.784901917595539*^9, 3.784901922664456*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Panel B", "Subsubsection",
 CellChangeTimes->{{3.7849018212895107`*^9, 3.784901852825482*^9}, {
  3.784902067054448*^9, 3.784902067870372*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"n0", "=", 
   SuperscriptBox["10", "4"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", 
   RowBox[{"-", "0.1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "4"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"small\[Psi]approxRescue", 
    RowBox[{"(*", "verylarge\[Rho]approxRescue", "*)"}], ",", 
    RowBox[{"2", " ", "\[CapitalLambda]0approx", " ", 
     RowBox[{"fm", "[", 
      RowBox[{"0", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}]}], " ", ",", "small\[Psi]approxRescueSuper"}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   FractionBox["%", 
    RowBox[{"Total", "[", "%", "]"}]], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fig5b", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"LogLinearPlot", "[", "\[IndentingNewLine]", 
      RowBox[{"%", ",", 
       RowBox[{"{", 
        RowBox[{"U", ",", 
         SuperscriptBox["10", 
          RowBox[{"-", "6"}]], ",", 
         SuperscriptBox["10", 
          RowBox[{"-", "1"}]]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
       
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Mutation rate\>\"", ",", "\"\<Percent of 2-step rescues\>\"", 
          ",", ","}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<B\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{"data", ",", 
       RowBox[{"PlotMarkers", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"defaultcolors", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"Disk", "[", "]"}]}], "}"}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"defaultcolors", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", 
              RowBox[{"Disk", "[", "]"}]}], "}"}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"defaultcolors", "[", 
               RowBox[{"[", "3", "]"}], "]"}], ",", 
              RowBox[{"Disk", "[", "]"}]}], "}"}], ",", 
            RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}]}], "}"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "mwt", ",", "n0", ",", 
   "U"}], "]"}]}], "Input",
 CellChangeTimes->{{3.769361975014821*^9, 3.7693620103723793`*^9}, {
   3.769362055403811*^9, 3.76936217516903*^9}, {3.769362300449959*^9, 
   3.769362390146037*^9}, {3.769368135479473*^9, 3.7693682213229628`*^9}, 
   3.7693682631857653`*^9, {3.769368306678321*^9, 3.769368310698353*^9}, 
   3.769368564301279*^9, 3.769368626560327*^9, {3.7693698079180193`*^9, 
   3.769369829262083*^9}, {3.769369878839031*^9, 3.769370020522847*^9}, {
   3.769370057668705*^9, 3.769370111566934*^9}, {3.769370161664791*^9, 
   3.769370192641665*^9}, {3.769370232989592*^9, 3.769370321502605*^9}, {
   3.769370373261149*^9, 3.769370418948492*^9}, {3.769370846488199*^9, 
   3.769370997333514*^9}, 3.7693710527511177`*^9, {3.769371103517735*^9, 
   3.769371174060443*^9}, {3.769371210449788*^9, 3.769371313732812*^9}, {
   3.769371378897552*^9, 3.7693713813143663`*^9}, {3.769371504714951*^9, 
   3.7693715053101063`*^9}, {3.769371612272114*^9, 3.769371613534341*^9}, {
   3.769371865627068*^9, 3.76937205231537*^9}, {3.7693721684190807`*^9, 
   3.769372227742949*^9}, {3.769374794476512*^9, 3.769374795879532*^9}, {
   3.769374988362481*^9, 3.7693752015416327`*^9}, {3.769375237833192*^9, 
   3.769375256422389*^9}, {3.769375298989477*^9, 3.769375409315852*^9}, {
   3.7693754563168*^9, 3.7693754588266973`*^9}, {3.769375490723859*^9, 
   3.769375571517234*^9}, {3.769375609955389*^9, 3.769375610671563*^9}, {
   3.769376974624186*^9, 3.769377114815401*^9}, {3.7693771450487623`*^9, 
   3.76937715448282*^9}, {3.769377347783226*^9, 3.769377378573168*^9}, {
   3.769377605499398*^9, 3.7693776443270187`*^9}, {3.7693776803664827`*^9, 
   3.769377681287714*^9}, {3.7693777210513897`*^9, 3.769377820250592*^9}, {
   3.769377931933558*^9, 3.769377946170843*^9}, {3.769429328820836*^9, 
   3.7694293433949003`*^9}, {3.7694295502426443`*^9, 
   3.7694295731041527`*^9}, {3.7699670763512363`*^9, 3.769967078171194*^9}, {
   3.782240522927578*^9, 3.782240594337283*^9}, 3.7822406353601913`*^9, {
   3.782240748133762*^9, 3.782240752011724*^9}, 3.782253654514523*^9, {
   3.784901346943548*^9, 3.784901353252801*^9}, {3.7849019437356987`*^9, 
   3.784901951872899*^9}, 3.784903054002616*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwVx3s0lAkYgHF9404xmkYbaZBLMy5llTUtL5EUoim5rFNtrZKUlGqdNtcI
OVKYoyLKpVYNM+0monqLTt/YcZ8xl0+InD2JsrIRqbV/POc5P/P9sbxIQk1N
LWCh/+/1SHA5+yYHgwfdtgecoqB+7+lnjaUcTLGgu2ku2E4D/hkr4eDN/S6W
T+MpYAZ1BgVe46BR3mnZ2gWPjkwaMPI5OGue37X0JAVX6D/klpznYFTQoLXi
OAVDUc+zhYc46Nd5iRseQ0GKsTyt156D1ErWXa8DFDRHn5g7KGQjq9F+Gz2Q
gs4ai6NbNrLxTfNgfv5GCpq4EVrx5BpMKukIUNhQcK9Jy2bEbw0qhHq7H9Ap
OORIelTJbXFV5NyhnV9UYFM0O3A3zBYdml3jeG9U8MK37vb8Kxv8N/X6if6/
VOAwmnG4NNoGu33Yeq5/qqA4RSxMH7fGHkYw58ZVFch0zCcbf7XG32OrPnUn
qWBMuSjCXdMaA6v3vedHqkC7bJefRrYVfr3D8FXzVcGH3U3OpkwrvNXust+H
owKKxi8/U7QaedPMLLmuCipnZrirVq7GB1l2outvlcDtPy5hVlti1nzD5Fax
EqQN4cM8e0ucuFmYL6pQgmtG2FR/vQVqfdoc8DVZCeW+rdm1XAv8JWUmLTVU
Ce94LVslT8yRTIj72OGghK8BPYSrnzleaIka1dVUAhN2eY62sTC8Zk6zSq6A
z6zRhHehLLzzfKLBrFoB8YVGdXGSVUgahPZ7nFXAN6lzWmGPGX7OJLQfblYA
61Oyd9i7lfi+Q7heg64AP5rIsOqDKbKlk2sEUjk4lX20vzhjgtGJntmDhXKo
NdsHhkYmGB9x7pQ8RA4bsoQ/mS1fgYKH3KNxhnLYKWPHSBy+wwSRV/glcS/Y
iR62GW1bjntqm040JPWCQYItd2iHMYqE/o892L2QadF8bUc0EwVuY7wZqQx0
6z01t8Uuw0y/I5bdcTKwcByNHDrPQMFuh02wRAbT6yuZS0uXYp6ySBlUKQWZ
rXe3pNII9Rof8YLZUtg6r59q/ZiO3k7VmYOCHnj5uOFHnWeGmD79aoOuSQ8Q
ppN52vkGqHD6g2VwrhtuJbXkub9YjJbTyivpVBcEN+6pyujUwzQ9Bjd1RRc4
P/KvWDKvg8ymqKpeXifkKPZ6v3TSxmP+14VnPrbDdDt39rKnJho/kT4YGJZA
bubhouI4dWwL14jeXt8KzL748fOH1TExkahSq2mFG47Jm47+rI78KUMrQXkr
1PTyx9x2qOPm0E7FVG4rtK9u8RhYu2CyLMc9shUWPzN7az5Bw9dWXVhn2Ao5
n3tcbx+jIbzmzS07IAZGwEDupYM0HA96WqsZKobistHhM3to6FPt+23CXwz3
tizK9d1Ow7TFOmH3N4hBUugw9NaehvojFiF/64hB3ykr226cwMu+M5HLakko
SC8YYIwQ6OWnzywpJ8FUWeo830fglvvHaGZFJNgl1/W3SQjsqKg5p5dCgn/7
sFPsPQKPBx/0KuCRIDX/cCGkgkB+YMy6ER8SIk7N9kExgZFfTDiOG0mIMaVf
MMwhkK3LsK2xJGEq1rRvJo3ALD7fbNiYhN+abda9PkvgEYaLFl2fBHXj7zPE
Jwm0wkTKRY2Ei9HulOgIgfYd7wtCpl7Cf8RcXNg=
      "]]}, 
    {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
     LineBox[CompressedData["
1:eJwVxXk01AkcAPD6zaSxkiE7qGmYyZVxlCZFu31T8xZpErXkCOmpWEV0KOkS
ciRCT3K1laiU2fdWjnjfqZ9jzGA0NETOxrwGtSmS1ra7f3zehx0S6RVKLFiw
QPCf/99WW5GVepuLZEeWFZUkoTropKiumIsn0q+7uTWSYL0IPk4UcrHMxy8z
o4kExi7ZLo98Lva7BOQaiUlQK6d09LO5yI2biV/bTsJ13Y0ZhZe5GL/+Y8fh
HhJGDj9PrTzExUyi+cH0BAkXDRQJr2y4qC1ZN5TCaIQX4dHfDlZaYbOE5E1F
N4LsMeeIyyYrzKtKHGZLG+GZU8Di4y2r8Xr6XZ8j5k3w6NliC6X7arzWsGZh
fVoTHLJr2VKqsET6meX6BZNNYJE3N/jQ1xKnyu3tzvk3Q6Nr1f35NxYonknW
jpE0g606Kaw43AK3GtP21m5ogYKL4srESXM88FiRli1sgW5N9lRdrDm2lhsc
rrMQw0TvwoDNGuY4pZHu8r5YDLSSPe6LUs2QOHCGkmzRCh+8n/GYDDOMbI8v
4j1shT7KjTun8kyxT60rV4ME7s3OOhmvNEXdsj2Rvj0ScBqIkjIerMJCQx+j
OxFS6KrxG/WyWYW7A8M23NJvA8ck388D1Ry02uttnFLdBndcW1OfOHFw3beQ
nITodhj3It2kDWz0jnF15Np3wD8COeHozsYSqV9w+WQHMGCPs7rNBIdv2Zhl
75fBVxP16fG9Jvj+/qgwtFUGx3P1qo5JjfGpVpRbsEMnfO/iJeTKWbiMb6wp
F3aCycwFvu/4SvTb0SU7yn0J7hQhvfQDE8URFayuqpdgX/LJJm12BSqpeZ3a
rnJ4wgoGut4KLHpSyKlQyMEhpdKfZbgcWfyDQ7bxXbC72ypCamuE19Iqrlaz
u8Fa+LRNb7sh9tEE2f5t3aBz2tJpxNMAS1mx9H05r+AK50W+ZzgD6euDbrr4
K+CHameN7ZE/otelsuV/b+0Bjp06dOSyPpqJEy2trXvhy/p7jGXFy7BpV3nN
Mc5r6Lbkv5Te08M/Tsa+FW/rA7f5JZfM63XRQzH9KTisH5rra37SFNFRsOmt
bSP5BgjmVCYtWwfPefDD6jYNwu/nyczNjdooHD/bwAscgl/rAkuTZFoYL6hs
eM0fBl7tjrtL5zVxVa7l+xDeCKT3BPGb7Wm4zej0lwHHUfjS7jSX5ayB3zME
/PnYt5BxJSyv4BgVzQLWKvNblcDoPz55OYyKMp6saFimhCK7C1uP7Kfi+eDq
r1yFEh6/ujHxsycVo7ToJZJRJbSbklsG11Ax2jCAtmFeCdoi1jv2XxTsZUqM
RWvGIP2r3PH+UQpGKT/P1eSPgb5gMOPaQQrO7Mtyi7s9BgUl6tFTgRT8JHEr
3VI2Bo9cFma47qTgEAfzFH+OgTTXduSdDQVzQ/PEDp1jsMQ+JdV6kkBfwc2y
epoKchJzBvWVBO7caHVLpKMCZm8xb76fwEHPyh4xQwXWF6oG2qQECmtP8VWm
KtjRPmof+YjApfk0D29nFXSxPyT73CWwOshBM95VBQEn5vqhgMDp81m2ZR4q
iGDqJtPTCfTLd5doBargcySzfzaBwBs+09v5oSo4+8Ji7XAcgYWLQn65GKEC
qsG6JHEMga40UvQ8RgVp4Zv7hL8RuFFjt4gWp4J/AYZGYYk=
      "]]}, 
    {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
     LineBox[CompressedData["
1:eJwVx3081AccwPHzu0sU4thRXR4u53Ae6qi4Hr6RpjpUypYxZD2Rup2RSVvM
QzmyLMpLGivpcaI8XB31lcfsCOeepGOo1nWStDw0be2Pz+vzettE8gP3EiQS
yf9T/3/Dvd9zhb+xsX1VYlGFfR+Iwo80iIvZ6HOOaRn0yU5zYFx7gY1ZgvN5
06w+oG3r2ra1kI06fk/CvT9Z8+ztArMzbIwtEfClzD74xcQj50IaG5VmLMEE
ow+GDjwUVuxnY0y5wRvHJX2QYq5IlTuzsfif5j0JJn3QGB37YV+FI35U88/H
T6qgq5xxyHe1I/ZEhCaFqFVQxw2dG9fmgJ70MN3xJhXcrJvLesZzwMGxEIeY
qyrY79q2vkxhj6qvJ0+ps1XAKpgZuBFsj4oXTgmvD6mgeVPNldmnLLyaUqJ7
IEAFLpqMqOJoFmZd62576aqCopRHFemjdvjR9IFRgaEKZPo2b8Xf22Gs2D9o
q1YJWpVO6DpdO/QIVI0K2pWgV7KTN0fIxFSmy8o1pUoY+6LOnU5jImtLZoDV
cSU8IZ+9lFBgi2AaYegWpITLU1NcqyW26M1wOLfKUQlc9bcS2vWlaH+kMHkP
SQm9d78aDnReis/Lq7tI3QrwzAh+pxYxcPip0dL6iwq4tKldeIvLQJKOvHL1
YQW8CmzaLLlvg0I/DX+RhwI++ksJT54NOsii9lqTFUCDnV6aDmtsrZZLW1rk
MG2tSXy1yxpj8tl5SVlyiMun1ggkVpgyskoZFiCHf3vdU/OlljjBUb+O15OD
9ftkn+BXS1A0fHQ6q1EGPHKlcdkYHec/CK/9MU4GnJIJ56ypxVhxzK7UhCGD
W5YRYExdjG8mRvYndfXCysyKEEuLRbiSEn47PLYXdsgcYyQuC3HyoZGFyKwX
nCprO6hbLLDV9/205rYUFiTac4e2m+ONZas5kV5SOMloLNweTUOvU1Wm+LgH
5om8dLfwP0MmR9uwnNcDDFfN3qE0M3QZ5OXnNXfD5IrLNNNiU7wmq49Z69EN
MnufHsllKvp0StoGc7tg86zBT3b1JtivfaD7Q/djaK2/u0a/wRiDC5Pcd6/v
BIL+9rTemQUY9MFYG50jgYvHm06vazbEqchdgzZd7RAkDivL6JqP5Du03NO1
beB+z6/UaFYfN7hlz7ScbIFsZbhPK0cP0wOSBQbMJpjs5M7keumiZs7fHmyP
Bsg5GVVQJKDg51HRRDa3Dmj9caNpURRMD02sH6fXwa+uyd6HdlNwhLr4r43/
iqFcfla7djsFxyfU/ncbxdBp27R+YBkFn994eqmdJwbDBsuXNm/IKOigJGfu
ugfZ01LPK4fJSFDvLKfsEYGZ/0DOz/vIeOTw+x0WPiIoKtEMJ4SRcYhn/djC
VgQ3fXVyNgWQcbJDe0I9XAuSfJehl85k3KA/SUmKrAUDTqbQaZRAK8rGsRch
NZCXnjdg9oxAoyv5MyJuDdBVxe6z/QQeNyhxi19YA07JNeoOCYHKwZHBcnk1
+HUOc/g3CSxPe01ibquGXpuxE1+WEkj9Jm6Hv0s1hMbP9EMRgdlz16yIMKiG
GLrJCeNsAuUWSUEb26rgHZ/eP5VKoDfN/qB5WRUca2Qt/zOJQN/rKfelqVVA
MXfLePQdgfFrh7hHd1dBVvS6J5UHCRx3Ff4xD6rgP7dDXHE=
      "]]}}, {
    GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQveB//8yuhdoHEiMzDOrk79hHr1qkNY9N/YDKxyMn
JCNu24uFbt29MVvpwE/ehE/rtW7ZQ9RLH/gmtyRbTOcGVF7ogJLl9KQS5StQ
PtOBPVIbLKeXHLWHme/Hvr53c9shuPm9N7fY/bU8Bjf/12nW9xaHT8PNV1vA
07Oy+BLc/Ne+L05Z6t6Gm58lsCLw7KZncPN/KB3g0Jh7C26+2KIH05933YSb
z8MjO23z5+tw8x87+HM4JFyFm/+xouFS4PoLcPP13OP/pzXstx8NH/zhAwCm
0SFj
     "], {
      {Hue[0.67, 0.6, 0.6], InsetBox[
        GraphicsBox[
         {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
         ImageSize->10], 19], InsetBox[
        GraphicsBox[
         {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
         ImageSize->10], 20], InsetBox[
        GraphicsBox[
         {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
         ImageSize->10], 21], InsetBox[
        GraphicsBox[
         {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
         ImageSize->10], 22], InsetBox[
        GraphicsBox[
         {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
         ImageSize->10], 23], InsetBox[
        GraphicsBox[
         {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
         ImageSize->10], 24]}, 
      {Hue[0.9060679774997897, 0.6, 0.6], InsetBox[
        GraphicsBox[
         {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
         ImageSize->10], 25], InsetBox[
        GraphicsBox[
         {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
         ImageSize->10], 26], InsetBox[
        GraphicsBox[
         {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
         ImageSize->10], 27], InsetBox[
        GraphicsBox[
         {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
         ImageSize->10], 28], InsetBox[
        GraphicsBox[
         {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
         ImageSize->10], 29], InsetBox[
        GraphicsBox[
         {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
         ImageSize->10], 30]}, 
      {Hue[0.1421359549995791, 0.6, 0.6], InsetBox[
        GraphicsBox[
         {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
         ImageSize->10], 31], InsetBox[
        GraphicsBox[
         {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
         ImageSize->10], 32], InsetBox[
        GraphicsBox[
         {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
         ImageSize->10], 33], InsetBox[
        GraphicsBox[
         {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
         ImageSize->10], 34], InsetBox[
        GraphicsBox[
         {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
         ImageSize->10], 35], InsetBox[
        GraphicsBox[
         {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
         ImageSize->10], 36]}, {}}], {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->NCache[{-Log[1000000], 0}, {-13.815510557964274`, 0}],
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Part[#, 2]}& )},
  Epilog->InsetBox[
    FormBox[
     StyleBox[
     "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
     TraditionalForm], 
    Scaled[{0.05, 0.95}]],
  Frame->{True, True, False, False},
  FrameLabel->{{
     FormBox["\"Percent of 2-step rescues\"", TraditionalForm], ""}, {
     FormBox["\"Mutation rate\"", TraditionalForm], ""}},
  FrameTicks->{{True, False}, {{{-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {-13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.716898269296165`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.429216196844383`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.02375108873622, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.86960040890896, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.736069016284437`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.618285980628055`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, None}},
  GridLines->{None, None},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->
   NCache[{{-Log[1000000], -Log[10]}, {0, 
     1}}, {{-13.815510557964274`, -2.302585092994046}, {0, 1}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {None, None}},
  Ticks->{{{-13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {-13.122363377404328`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.716898269296165`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.429216196844383`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.206072645530174`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.02375108873622, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.86960040890896, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.736069016284437`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.618285980628055`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.414313176302118`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.126631103850338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.721165995742174, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.567015315914915, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.433483923290392, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.315700887634009, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{
  3.769375219996579*^9, 3.769375260370287*^9, 3.76937541462871*^9, 
   3.7693754615227957`*^9, {3.769375502207761*^9, 3.769375572424717*^9}, 
   3.769375611382972*^9, {3.769376975657188*^9, 3.769377082280467*^9}, 
   3.769377126636804*^9, 3.769377314535925*^9, {3.7693773576368437`*^9, 
   3.769377379515867*^9}, {3.769377608357874*^9, 3.7693776450689*^9}, 
   3.7693776820351763`*^9, {3.769377725452115*^9, 3.7693778207474203`*^9}, 
   3.769377984774302*^9, 3.769429513714439*^9, 3.769429556251409*^9, {
   3.782240548842368*^9, 3.782240559692521*^9}, 3.782240594933064*^9, 
   3.782240745171117*^9, 3.782253810793522*^9, 3.7822583255275803`*^9, 
   3.7849014827781553`*^9, 3.784901955819421*^9, 3.78490305779459*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure 5", "Subsubsection",
 CellChangeTimes->{{3.784901858241148*^9, 3.784901859937767*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GraphicsColumn", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"fig5a", ",", "fig5b"}], "}"}], ",", 
   RowBox[{"Spacings", "\[Rule]", 
    RowBox[{"-", "30"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{"figdir", "<>", "\"\<Figure5.eps\>\""}], ",", "%"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.784901977346148*^9, 3.784901998768465*^9}, {
  3.784902375853077*^9, 3.784902376211467*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     FormBox[
      TagBox[
       FormBox[
        GraphicsBox[{{{{}, {}, 
            {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwV0Hs8lAkXB3AV0Y2iRVq9Q3grVFRTsTqlEnazm7LbRDEubdhoc1m5LV6U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              "]]}, 
            {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
             LineBox[CompressedData["
1:eJwV1nk4VdsbB3DKdItowEkpJUU6CuUa0iJD6F4UMiTzlLpUIhGlWYWOuToa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              "]]}, 
            {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
             LineBox[CompressedData["
1:eJwVzH0w1Akcx/EdeSj0XMjVUcdVpKbGbEndN50Kte6qFUvrMVQ3cT1oKAqT
6UFWeVyx5ThityEsycN+PRR+u+z+rF12Y1PbxsUROfJ0ur0/PvOZ1z/vjYHh
J4J1KBQKTbv/f3/h7vSsLCUemnI1in/HBTf2BXc2W4nODpPqhEEueN3LN8jM
VCJrhWL63igXLoUtv5aWrsRFsXv62fNcKKQO+iY/VGL9F8OMZjMeLGvN2JJw
V4k3LXqK6Md58HZwsvb3KCXOcOTOwc08uLmVrz7CUGKhxfxy4D2DFBvJ9qTV
ShRczNk4XF4CBg3R5y9KFajD86iKOPUcGOqGRzkpCjw2bRi4yqsMrsfnE740
BZ69G2q1EFUOlBdmf6GxAql+Y8brUyrg1LltetUtPTh6TfipVMSHO0XdJl/j
erDcKdzffkkVbIhebSZ36sG+Ps3H2w4vIL5j1NRtvhv1Gxtb5YnV4FZx2sC3
thtrnn5Heyt+CaPWAcPV17vxQbLMj7+yFoJMdMVcajdO3yjWtblaB3uzHXId
p+T4fsHngKq1HtScpReDnsuxhFmcnb8XIdQukir9TY6c2t4OZ48GcD8eMdxv
K8cQIy7VRqcR9CdWPLk1IMOyn1JpVYJGsNwKB9sKZHgkydEEwpvASGWkyfOT
Ya7rzA+87c0g3RB+7ZW5DN2Zj/wPDzXD/JczlIQ3XfiKdeFSBvsVfD00c6sv
rQs1tNTXvvTXQLeznJGe7MK/dU/E2Oi0AOsPVcCKNV3oaXsnvpHbAuxUB0Ij
lmIxZ0eJk18r6JlvsfRiSbGfcvuwuV4bHPy+MiLQRYo0O036n5VtcLpUgRWL
pHhf5CL19iNAIWPN5Dd34iFJXajFLAHWkR922t7oRNWxkqh2jhDkpULG8f2d
+KU/lxG6SwQBV1yuCv4lcWKOfn4IRSCoOvOwqZrEZ3ohMYn0dohJWp0THEli
tvfCSeabdliq9i94sovEQCfXaE1wB3xLj9s3rpbgSnujJU3qDuDEhZnuDJIg
m1lr/9FTDH1n2Z8fK8R4z4DHlJFieBc5WOjmKcbBzy9TGhwlkHDrso+VqAN9
elmC4SIJfCjeNpPo1IH6AZmi+/ok6E8bXt3Z2I52W75VGO8iQeT045gutR1L
LqsYGUwSPPghriZ8ESK9+Xx1PAnsA7LESnsR6l4XWdTkkxDddkMUzxXi0djZ
uZxmEqyj3IeStgoxavzTvgcqEg5Wbl/nvlmIY0WStDmtfceXuSyzFmKeZiE3
5K22d05SwLIUYu8vS7sd+0kw9P41INlUiJzFZWXqdySM7T2heKAnxE2lTtab
NCTUzXu0pL4n8GjhzyWhQyQo91AnT/YTyFgbG0VoPXXFxGqNisBs0aOvNsMk
7BjpjktTEFgh2Gc8onWeynN/uoTACHIk/cIICXcEDH5GPYHPIjst/cdIKJh1
+HCqlsCkupg19Vo3Uc1Xmb4kMCyMVrNunIS5kjfhmXwCgwc2r5dqHfbEx5bN
I1B/NGY3TJCQ2Ovo7VVM4EDMbE2W1kWm6++aPSUwscJxbELr98l9A+w8AstC
+sKf/kPCgqhuLSOXwFk9qxrKJAnmiznO6x5re8mUKobWu51jLiuzCQxdEhJU
rjU9lpmXlUWgMtKlyXCKhP8AbLynOA==
              "]]}}, {{}, {}, 
            {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwVx3k4FIoagHHlKFk7iSsUhqxZTiVLnb5OtFKWKKmsky1LIiZb6aAJ2SJG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              "]]}, 
            {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
             LineBox[CompressedData["
1:eJwd13k4lN8XAHBLhKKFJFSyJSE7US5ZksgSLbLlOyRboiR7Qki2LNmzhKLs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              "]]}, 
            {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
             LineBox[CompressedData["
1:eJwVjXk4FIgfh6eRe+i3q7FdG7kSqVkRqe2rorQo7UZLBzO5EmnTLpIcjWt2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              "]]}}, {{}, 
            GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGAwAGIQPWsmCNzcb1fZdvOB0zv79DQQuLY/efkfzwKLN/Ym
xiBweb999JOCSZYv7RnA4ML+hT6OWR27n9pD9J/c/3nXweq1To+g6g/v59xS
9/2fzD37GWD5nfufyi3JFtO5AeWv3G82VbrY6sFFe5j9YueXn77Zswhuv8ct
5cnppZvh9q9luLWUf/cBuP0rG1yUnymcgNv/eJvA77vJ5+D26y9afkU/5iLc
fv0FPD0riy/B7X//Jqf59cRLcPslrR6aG3ZNgtsfdvWtpU7fUrj9q1U0dX33
boHbf9Vnm/GPDwfg9gfGvhDNmXgCbv/xlTeNL7ZdgNv/1sGfwyHhKtz+u7Xl
nLd6b9uPhv/Ahj8AQBCA5w==
             "], {
              {RGBColor[0.24720000000000014`, 0.24, 0.6], InsetBox[
                GraphicsBox[
                 {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
                 
                 ImageSize->10], 25], InsetBox[
                GraphicsBox[
                 {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
                 
                 ImageSize->10], 26], InsetBox[
                GraphicsBox[
                 {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
                 
                 ImageSize->10], 27], InsetBox[
                GraphicsBox[
                 {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
                 
                 ImageSize->10], 28], InsetBox[
                GraphicsBox[
                 {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
                 
                 ImageSize->10], 29], InsetBox[
                GraphicsBox[
                 {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
                 
                 ImageSize->10], 30], InsetBox[
                GraphicsBox[
                 {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
                 
                 ImageSize->10], 31], InsetBox[
                GraphicsBox[
                 {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
                 
                 ImageSize->10], 32]}, 
              {RGBColor[0.6, 0.24, 0.4428931686004542], InsetBox[
                GraphicsBox[
                 {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
                 ImageSize->10], 33], InsetBox[
                GraphicsBox[
                 {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
                 ImageSize->10], 34], InsetBox[
                GraphicsBox[
                 {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
                 ImageSize->10], 35], InsetBox[
                GraphicsBox[
                 {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
                 ImageSize->10], 36], InsetBox[
                GraphicsBox[
                 {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
                 ImageSize->10], 37], InsetBox[
                GraphicsBox[
                 {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
                 ImageSize->10], 38], InsetBox[
                GraphicsBox[
                 {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
                 ImageSize->10], 39], InsetBox[
                GraphicsBox[
                 {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
                 ImageSize->10], 40]}, 
              {RGBColor[0.6, 0.5470136627990908, 0.24], InsetBox[
                GraphicsBox[
                 {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
                 ImageSize->10], 41], InsetBox[
                GraphicsBox[
                 {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
                 ImageSize->10], 42], InsetBox[
                GraphicsBox[
                 {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
                 ImageSize->10], 43], InsetBox[
                GraphicsBox[
                 {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
                 ImageSize->10], 44], InsetBox[
                GraphicsBox[
                 {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
                 ImageSize->10], 45], InsetBox[
                GraphicsBox[
                 {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
                 ImageSize->10], 46], InsetBox[
                GraphicsBox[
                 {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
                 ImageSize->10], 47], InsetBox[
                GraphicsBox[
                 {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
                 ImageSize->10], 48]}, {}}], {}}}, InsetBox[
           
           TemplateBox[{
            StyleBox[
             "\"subcritical\"", StripOnInput -> False, FontFamily -> 
              "Helvetica", FontSize -> 12],StyleBox[
             "\"critical\"", StripOnInput -> False, FontFamily -> "Helvetica",
               FontSize -> 12],StyleBox[
             "\"supercritical\"", StripOnInput -> False, FontFamily -> 
              "Helvetica", FontSize -> 12]},
            "LineLegend",
            DisplayFunction->(StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.1421359549995791, 0.6, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
              False]& ),
            Editable->True,
            InterpretationFunction:>(RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Hue", "[", 
                    RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Hue", "[", 
                    RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}],
                     "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Hue", "[", 
                    RowBox[{"0.1421359549995791`", ",", "0.6`", ",", "0.6`"}],
                     "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
                   "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& )], NCache[
           Scaled[{Rational[3, 4], Rational[3, 4]}], Scaled[{0.75, 0.75}]], 
           ImageScaled[{0.5, 0.5}],
           BaseStyle->{FontSize -> Larger},
           FormatType->StandardForm]},
         AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
         Axes->True,
         AxesOrigin->{-0.4, 0},
         Epilog->InsetBox[
           FormBox[
            StyleBox[
            "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
             False], TraditionalForm], 
           Scaled[{0.95, 0.95}]],
         Frame->{True, False, False, True},
         FrameLabel->{{"", 
            FormBox["\"Percent of 2-step rescues\"", TraditionalForm]}, {
            FormBox["\"Wildtype growth rate\"", TraditionalForm], ""}},
         FrameTicks->{True, False, False, All},
         LabelStyle->Directive[12, FontFamily -> "Helvetica"],
         Method->{},
         PlotRange->{{-0.4, 0}, {0, 1}},
         PlotRangeClipping->True,
         PlotRangePadding->{
           Scaled[0.02], Automatic}],
        TraditionalForm],
       InterpretTemplate[Legended[
         Graphics[{{{{}, {}, {
              Hue[0.67, 0.6, 0.6], 
              Thickness[Large], 
              Line[CompressedData["
1:eJwV0Hs8lAkXB3AV0Y2iRVq9Q3grVFRTsTqlEnazm7LbRDEubdhoc1m5LV6U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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Thickness[Large], 
              Line[CompressedData["
1:eJwV1nk4VdsbB3DKdItowEkpJUU6CuUa0iJD6F4UMiTzlLpUIhGlWYWOuToa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               "]]}, {
              Hue[0.1421359549995791, 0.6, 0.6], 
              Thickness[Large], 
              Line[CompressedData["
1:eJwVzH0w1Akcx/EdeSj0XMjVUcdVpKbGbEndN50Kte6qFUvrMVQ3cT1oKAqT
6UFWeVyx5ThityEsycN+PRR+u+z+rF12Y1PbxsUROfJ0ur0/PvOZ1z/vjYHh
J4J1KBQKTbv/f3/h7vSsLCUemnI1in/HBTf2BXc2W4nODpPqhEEueN3LN8jM
VCJrhWL63igXLoUtv5aWrsRFsXv62fNcKKQO+iY/VGL9F8OMZjMeLGvN2JJw
V4k3LXqK6Md58HZwsvb3KCXOcOTOwc08uLmVrz7CUGKhxfxy4D2DFBvJ9qTV
ShRczNk4XF4CBg3R5y9KFajD86iKOPUcGOqGRzkpCjw2bRi4yqsMrsfnE740
BZ69G2q1EFUOlBdmf6GxAql+Y8brUyrg1LltetUtPTh6TfipVMSHO0XdJl/j
erDcKdzffkkVbIhebSZ36sG+Ps3H2w4vIL5j1NRtvhv1Gxtb5YnV4FZx2sC3
thtrnn5Heyt+CaPWAcPV17vxQbLMj7+yFoJMdMVcajdO3yjWtblaB3uzHXId
p+T4fsHngKq1HtScpReDnsuxhFmcnb8XIdQukir9TY6c2t4OZ48GcD8eMdxv
K8cQIy7VRqcR9CdWPLk1IMOyn1JpVYJGsNwKB9sKZHgkydEEwpvASGWkyfOT
Ya7rzA+87c0g3RB+7ZW5DN2Zj/wPDzXD/JczlIQ3XfiKdeFSBvsVfD00c6sv
rQs1tNTXvvTXQLeznJGe7MK/dU/E2Oi0AOsPVcCKNV3oaXsnvpHbAuxUB0Ij
lmIxZ0eJk18r6JlvsfRiSbGfcvuwuV4bHPy+MiLQRYo0O036n5VtcLpUgRWL
pHhf5CL19iNAIWPN5Dd34iFJXajFLAHWkR922t7oRNWxkqh2jhDkpULG8f2d
+KU/lxG6SwQBV1yuCv4lcWKOfn4IRSCoOvOwqZrEZ3ohMYn0dohJWp0THEli
tvfCSeabdliq9i94sovEQCfXaE1wB3xLj9s3rpbgSnujJU3qDuDEhZnuDJIg
m1lr/9FTDH1n2Z8fK8R4z4DHlJFieBc5WOjmKcbBzy9TGhwlkHDrso+VqAN9
elmC4SIJfCjeNpPo1IH6AZmi+/ok6E8bXt3Z2I52W75VGO8iQeT045gutR1L
LqsYGUwSPPghriZ8ESK9+Xx1PAnsA7LESnsR6l4XWdTkkxDddkMUzxXi0djZ
uZxmEqyj3IeStgoxavzTvgcqEg5Wbl/nvlmIY0WStDmtfceXuSyzFmKeZiE3
5K22d05SwLIUYu8vS7sd+0kw9P41INlUiJzFZWXqdySM7T2heKAnxE2lTtab
NCTUzXu0pL4n8GjhzyWhQyQo91AnT/YTyFgbG0VoPXXFxGqNisBs0aOvNsMk
7BjpjktTEFgh2Gc8onWeynN/uoTACHIk/cIICXcEDH5GPYHPIjst/cdIKJh1
+HCqlsCkupg19Vo3Uc1Xmb4kMCyMVrNunIS5kjfhmXwCgwc2r5dqHfbEx5bN
I1B/NGY3TJCQ2Ovo7VVM4EDMbE2W1kWm6++aPSUwscJxbELr98l9A+w8AstC
+sKf/kPCgqhuLSOXwFk9qxrKJAnmiznO6x5re8mUKobWu51jLiuzCQxdEhJU
rjU9lpmXlUWgMtKlyXCKhP8AbLynOA==
               "]]}}}, {{{}, {}, {
              Hue[0.67, 0.6, 0.6], 
              Thickness[Large], 
              Line[CompressedData["
1:eJwVx3k4FIoagHHlKFk7iSsUhqxZTiVLnb5OtFKWKKmsky1LIiZb6aAJ2SJG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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Thickness[Large], 
              Line[CompressedData["
1:eJwd13k4lN8XAHBLhKKFJFSyJSE7US5ZksgSLbLlOyRboiR7Qki2LNmzhKLs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               "]]}, {
              Hue[0.1421359549995791, 0.6, 0.6], 
              Thickness[Large], 
              Line[CompressedData["
1:eJwVjXk4FIgfh6eRe+i3q7FdG7kSqVkRqe2rorQo7UZLBzO5EmnTLpIcjWt2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               "]]}}}, {{}, 
            GraphicsComplex[CompressedData["
1:eJxTTMoPSmViYGAwAGIQPWsmCNzcb1fZdvOB0zv79DQQuLY/efkfzwKLN/Ym
xiBweb999JOCSZYv7RnA4ML+hT6OWR27n9pD9J/c/3nXweq1To+g6g/v59xS
9/2fzD37GWD5nfufyi3JFtO5AeWv3G82VbrY6sFFe5j9YueXn77Zswhuv8ct
5cnppZvh9q9luLWUf/cBuP0rG1yUnymcgNv/eJvA77vJ5+D26y9afkU/5iLc
fv0FPD0riy/B7X//Jqf59cRLcPslrR6aG3ZNgtsfdvWtpU7fUrj9q1U0dX33
boHbf9Vnm/GPDwfg9gfGvhDNmXgCbv/xlTeNL7ZdgNv/1sGfwyHhKtz+u7Xl
nLd6b9uPhv/Ahj8AQBCA5w==
             "], {{{
                Hue[0.67, 0.6, 0.6], 
                Directive[
                 RGBColor[0.24720000000000014`, 0.24, 0.6]], 
                Inset[
                 Graphics[{
                   Hue[0.67, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], 
                   RGBColor[0.24720000000000014`, 0.24, 0.6], 
                   Disk[{0, 0}]}, ImageSize -> 10], 25], 
                Inset[
                 Graphics[{
                   Hue[0.67, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], 
                   RGBColor[0.24720000000000014`, 0.24, 0.6], 
                   Disk[{0, 0}]}, ImageSize -> 10], 26], 
                Inset[
                 Graphics[{
                   Hue[0.67, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], 
                   RGBColor[0.24720000000000014`, 0.24, 0.6], 
                   Disk[{0, 0}]}, ImageSize -> 10], 27], 
                Inset[
                 Graphics[{
                   Hue[0.67, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], 
                   RGBColor[0.24720000000000014`, 0.24, 0.6], 
                   Disk[{0, 0}]}, ImageSize -> 10], 28], 
                Inset[
                 Graphics[{
                   Hue[0.67, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], 
                   RGBColor[0.24720000000000014`, 0.24, 0.6], 
                   Disk[{0, 0}]}, ImageSize -> 10], 29], 
                Inset[
                 Graphics[{
                   Hue[0.67, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], 
                   RGBColor[0.24720000000000014`, 0.24, 0.6], 
                   Disk[{0, 0}]}, ImageSize -> 10], 30], 
                Inset[
                 Graphics[{
                   Hue[0.67, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], 
                   RGBColor[0.24720000000000014`, 0.24, 0.6], 
                   Disk[{0, 0}]}, ImageSize -> 10], 31], 
                Inset[
                 Graphics[{
                   Hue[0.67, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.24720000000000014`, 0.24, 0.6]], 
                   RGBColor[0.24720000000000014`, 0.24, 0.6], 
                   Disk[{0, 0}]}, ImageSize -> 10], 32]}, {
                Hue[0.9060679774997897, 0.6, 0.6], 
                Directive[
                 RGBColor[0.6, 0.24, 0.4428931686004542]], 
                Inset[
                 Graphics[{
                   Hue[0.9060679774997897, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.24, 0.4428931686004542]], 
                   RGBColor[0.6, 0.24, 0.4428931686004542], 
                   Disk[{0, 0}]}, ImageSize -> 10], 33], 
                Inset[
                 Graphics[{
                   Hue[0.9060679774997897, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.24, 0.4428931686004542]], 
                   RGBColor[0.6, 0.24, 0.4428931686004542], 
                   Disk[{0, 0}]}, ImageSize -> 10], 34], 
                Inset[
                 Graphics[{
                   Hue[0.9060679774997897, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.24, 0.4428931686004542]], 
                   RGBColor[0.6, 0.24, 0.4428931686004542], 
                   Disk[{0, 0}]}, ImageSize -> 10], 35], 
                Inset[
                 Graphics[{
                   Hue[0.9060679774997897, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.24, 0.4428931686004542]], 
                   RGBColor[0.6, 0.24, 0.4428931686004542], 
                   Disk[{0, 0}]}, ImageSize -> 10], 36], 
                Inset[
                 Graphics[{
                   Hue[0.9060679774997897, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.24, 0.4428931686004542]], 
                   RGBColor[0.6, 0.24, 0.4428931686004542], 
                   Disk[{0, 0}]}, ImageSize -> 10], 37], 
                Inset[
                 Graphics[{
                   Hue[0.9060679774997897, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.24, 0.4428931686004542]], 
                   RGBColor[0.6, 0.24, 0.4428931686004542], 
                   Disk[{0, 0}]}, ImageSize -> 10], 38], 
                Inset[
                 Graphics[{
                   Hue[0.9060679774997897, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.24, 0.4428931686004542]], 
                   RGBColor[0.6, 0.24, 0.4428931686004542], 
                   Disk[{0, 0}]}, ImageSize -> 10], 39], 
                Inset[
                 Graphics[{
                   Hue[0.9060679774997897, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.24, 0.4428931686004542]], 
                   RGBColor[0.6, 0.24, 0.4428931686004542], 
                   Disk[{0, 0}]}, ImageSize -> 10], 40]}, {
                Hue[0.1421359549995791, 0.6, 0.6], 
                Directive[
                 RGBColor[0.6, 0.5470136627990908, 0.24]], 
                Inset[
                 Graphics[{
                   Hue[0.1421359549995791, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.5470136627990908, 0.24]], 
                   RGBColor[0.6, 0.5470136627990908, 0.24], 
                   Disk[{0, 0}]}, ImageSize -> 10], 41], 
                Inset[
                 Graphics[{
                   Hue[0.1421359549995791, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.5470136627990908, 0.24]], 
                   RGBColor[0.6, 0.5470136627990908, 0.24], 
                   Disk[{0, 0}]}, ImageSize -> 10], 42], 
                Inset[
                 Graphics[{
                   Hue[0.1421359549995791, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.5470136627990908, 0.24]], 
                   RGBColor[0.6, 0.5470136627990908, 0.24], 
                   Disk[{0, 0}]}, ImageSize -> 10], 43], 
                Inset[
                 Graphics[{
                   Hue[0.1421359549995791, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.5470136627990908, 0.24]], 
                   RGBColor[0.6, 0.5470136627990908, 0.24], 
                   Disk[{0, 0}]}, ImageSize -> 10], 44], 
                Inset[
                 Graphics[{
                   Hue[0.1421359549995791, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.5470136627990908, 0.24]], 
                   RGBColor[0.6, 0.5470136627990908, 0.24], 
                   Disk[{0, 0}]}, ImageSize -> 10], 45], 
                Inset[
                 Graphics[{
                   Hue[0.1421359549995791, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.5470136627990908, 0.24]], 
                   RGBColor[0.6, 0.5470136627990908, 0.24], 
                   Disk[{0, 0}]}, ImageSize -> 10], 46], 
                Inset[
                 Graphics[{
                   Hue[0.1421359549995791, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.5470136627990908, 0.24]], 
                   RGBColor[0.6, 0.5470136627990908, 0.24], 
                   Disk[{0, 0}]}, ImageSize -> 10], 47], 
                Inset[
                 Graphics[{
                   Hue[0.1421359549995791, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.5470136627990908, 0.24]], 
                   RGBColor[0.6, 0.5470136627990908, 0.24], 
                   Disk[{0, 0}]}, ImageSize -> 10], 48]}, {}}}], {}}}, {
          PlotRange -> {{-0.4, 0}, {0, 1}}, AspectRatio -> GoldenRatio^(-1), 
           Axes -> True, AxesOrigin -> {-0.4, 0}, Epilog -> Text[
             Style["A", 14, Bold, FontFamily -> "Helvetica"], 
             Scaled[{0.95, 0.95}]], Frame -> {True, False, False, True}, 
           FrameLabel -> {{Null, "Percent of 2-step rescues"}, {
             "Wildtype growth rate", Null}}, 
           FrameTicks -> {True, False, False, All}, LabelStyle -> 
           Directive[12, FontFamily -> "Helvetica"], Method -> {}, 
           PlotRange -> {{-0.4, -0.2}, {0, 1}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {
             Scaled[0.02], Automatic}}], {
          Placed[
           Unevaluated[
            LineLegend[{
              Directive[
               Hue[0.67, 0.6, 0.6], 
               Thickness[Large]], 
              Directive[
               Hue[0.9060679774997897, 0.6, 0.6], 
               Thickness[Large]], 
              Directive[
               Hue[0.1421359549995791, 0.6, 0.6], 
               Thickness[Large]]}, {
              Style["subcritical", 12, FontFamily -> "Helvetica"], 
              Style["critical", 12, FontFamily -> "Helvetica"], 
              Style["supercritical", 12, FontFamily -> "Helvetica"]}, 
             LegendLayout -> "Column"]], 
           Scaled[{
             Rational[3, 4], 
             Rational[3, 4]}], Identity]}]& ],
       AutoDelete->True,
       Editable->True,
       SelectWithContents->False,
       Selectable->True],
      TraditionalForm], {189., -130.62305898749054`}, {
     Center, Center}, {360., 291.2461179749811}], InsetBox[
     GraphicsBox[{{{}, {}, 
        {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwVx3s0lAkYgHF9404xmkYbaZBLMy5llTUtL5EUoim5rFNtrZKUlGqdNtcI
OVKYoyLKpVYNM+0monqLTt/YcZ8xl0+InD2JsrIRqbV/POc5P/P9sbxIQk1N
LWCh/+/1SHA5+yYHgwfdtgecoqB+7+lnjaUcTLGgu2ku2E4D/hkr4eDN/S6W
T+MpYAZ1BgVe46BR3mnZ2gWPjkwaMPI5OGue37X0JAVX6D/klpznYFTQoLXi
OAVDUc+zhYc46Nd5iRseQ0GKsTyt156D1ErWXa8DFDRHn5g7KGQjq9F+Gz2Q
gs4ai6NbNrLxTfNgfv5GCpq4EVrx5BpMKukIUNhQcK9Jy2bEbw0qhHq7H9Ap
OORIelTJbXFV5NyhnV9UYFM0O3A3zBYdml3jeG9U8MK37vb8Kxv8N/X6if6/
VOAwmnG4NNoGu33Yeq5/qqA4RSxMH7fGHkYw58ZVFch0zCcbf7XG32OrPnUn
qWBMuSjCXdMaA6v3vedHqkC7bJefRrYVfr3D8FXzVcGH3U3OpkwrvNXust+H
owKKxi8/U7QaedPMLLmuCipnZrirVq7GB1l2outvlcDtPy5hVlti1nzD5Fax
EqQN4cM8e0ucuFmYL6pQgmtG2FR/vQVqfdoc8DVZCeW+rdm1XAv8JWUmLTVU
Ce94LVslT8yRTIj72OGghK8BPYSrnzleaIka1dVUAhN2eY62sTC8Zk6zSq6A
z6zRhHehLLzzfKLBrFoB8YVGdXGSVUgahPZ7nFXAN6lzWmGPGX7OJLQfblYA
61Oyd9i7lfi+Q7heg64AP5rIsOqDKbKlk2sEUjk4lX20vzhjgtGJntmDhXKo
NdsHhkYmGB9x7pQ8RA4bsoQ/mS1fgYKH3KNxhnLYKWPHSBy+wwSRV/glcS/Y
iR62GW1bjntqm040JPWCQYItd2iHMYqE/o892L2QadF8bUc0EwVuY7wZqQx0
6z01t8Uuw0y/I5bdcTKwcByNHDrPQMFuh02wRAbT6yuZS0uXYp6ySBlUKQWZ
rXe3pNII9Rof8YLZUtg6r59q/ZiO3k7VmYOCHnj5uOFHnWeGmD79aoOuSQ8Q
ppN52vkGqHD6g2VwrhtuJbXkub9YjJbTyivpVBcEN+6pyujUwzQ9Bjd1RRc4
P/KvWDKvg8ymqKpeXifkKPZ6v3TSxmP+14VnPrbDdDt39rKnJho/kT4YGJZA
bubhouI4dWwL14jeXt8KzL748fOH1TExkahSq2mFG47Jm47+rI78KUMrQXkr
1PTyx9x2qOPm0E7FVG4rtK9u8RhYu2CyLMc9shUWPzN7az5Bw9dWXVhn2Ao5
n3tcbx+jIbzmzS07IAZGwEDupYM0HA96WqsZKobistHhM3to6FPt+23CXwz3
tizK9d1Ow7TFOmH3N4hBUugw9NaehvojFiF/64hB3ykr226cwMu+M5HLakko
SC8YYIwQ6OWnzywpJ8FUWeo830fglvvHaGZFJNgl1/W3SQjsqKg5p5dCgn/7
sFPsPQKPBx/0KuCRIDX/cCGkgkB+YMy6ER8SIk7N9kExgZFfTDiOG0mIMaVf
MMwhkK3LsK2xJGEq1rRvJo3ALD7fbNiYhN+abda9PkvgEYaLFl2fBHXj7zPE
Jwm0wkTKRY2Ei9HulOgIgfYd7wtCpl7Cf8RcXNg=
          "]]}, 
        {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
         LineBox[CompressedData["
1:eJwVxXk01AkcAPD6zaSxkiE7qGmYyZVxlCZFu31T8xZpErXkCOmpWEV0KOkS
ciRCT3K1laiU2fdWjnjfqZ9jzGA0NETOxrwGtSmS1ra7f3zehx0S6RVKLFiw
QPCf/99WW5GVepuLZEeWFZUkoTropKiumIsn0q+7uTWSYL0IPk4UcrHMxy8z
o4kExi7ZLo98Lva7BOQaiUlQK6d09LO5yI2biV/bTsJ13Y0ZhZe5GL/+Y8fh
HhJGDj9PrTzExUyi+cH0BAkXDRQJr2y4qC1ZN5TCaIQX4dHfDlZaYbOE5E1F
N4LsMeeIyyYrzKtKHGZLG+GZU8Di4y2r8Xr6XZ8j5k3w6NliC6X7arzWsGZh
fVoTHLJr2VKqsET6meX6BZNNYJE3N/jQ1xKnyu3tzvk3Q6Nr1f35NxYonknW
jpE0g606Kaw43AK3GtP21m5ogYKL4srESXM88FiRli1sgW5N9lRdrDm2lhsc
rrMQw0TvwoDNGuY4pZHu8r5YDLSSPe6LUs2QOHCGkmzRCh+8n/GYDDOMbI8v
4j1shT7KjTun8kyxT60rV4ME7s3OOhmvNEXdsj2Rvj0ScBqIkjIerMJCQx+j
OxFS6KrxG/WyWYW7A8M23NJvA8ck388D1Ry02uttnFLdBndcW1OfOHFw3beQ
nITodhj3It2kDWz0jnF15Np3wD8COeHozsYSqV9w+WQHMGCPs7rNBIdv2Zhl
75fBVxP16fG9Jvj+/qgwtFUGx3P1qo5JjfGpVpRbsEMnfO/iJeTKWbiMb6wp
F3aCycwFvu/4SvTb0SU7yn0J7hQhvfQDE8URFayuqpdgX/LJJm12BSqpeZ3a
rnJ4wgoGut4KLHpSyKlQyMEhpdKfZbgcWfyDQ7bxXbC72ypCamuE19Iqrlaz
u8Fa+LRNb7sh9tEE2f5t3aBz2tJpxNMAS1mx9H05r+AK50W+ZzgD6euDbrr4
K+CHameN7ZE/otelsuV/b+0Bjp06dOSyPpqJEy2trXvhy/p7jGXFy7BpV3nN
Mc5r6Lbkv5Te08M/Tsa+FW/rA7f5JZfM63XRQzH9KTisH5rra37SFNFRsOmt
bSP5BgjmVCYtWwfPefDD6jYNwu/nyczNjdooHD/bwAscgl/rAkuTZFoYL6hs
eM0fBl7tjrtL5zVxVa7l+xDeCKT3BPGb7Wm4zej0lwHHUfjS7jSX5ayB3zME
/PnYt5BxJSyv4BgVzQLWKvNblcDoPz55OYyKMp6saFimhCK7C1uP7Kfi+eDq
r1yFEh6/ujHxsycVo7ToJZJRJbSbklsG11Ax2jCAtmFeCdoi1jv2XxTsZUqM
RWvGIP2r3PH+UQpGKT/P1eSPgb5gMOPaQQrO7Mtyi7s9BgUl6tFTgRT8JHEr
3VI2Bo9cFma47qTgEAfzFH+OgTTXduSdDQVzQ/PEDp1jsMQ+JdV6kkBfwc2y
epoKchJzBvWVBO7caHVLpKMCZm8xb76fwEHPyh4xQwXWF6oG2qQECmtP8VWm
KtjRPmof+YjApfk0D29nFXSxPyT73CWwOshBM95VBQEn5vqhgMDp81m2ZR4q
iGDqJtPTCfTLd5doBargcySzfzaBwBs+09v5oSo4+8Ji7XAcgYWLQn65GKEC
qsG6JHEMga40UvQ8RgVp4Zv7hL8RuFFjt4gWp4J/AYZGYYk=
          "]]}, 
        {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
         LineBox[CompressedData["
1:eJwVx3081AccwPHzu0sU4thRXR4u53Ae6qi4Hr6RpjpUypYxZD2Rup2RSVvM
QzmyLMpLGivpcaI8XB31lcfsCOeepGOo1nWStDw0be2Pz+vzettE8gP3EiQS
yf9T/3/Dvd9zhb+xsX1VYlGFfR+Iwo80iIvZ6HOOaRn0yU5zYFx7gY1ZgvN5
06w+oG3r2ra1kI06fk/CvT9Z8+ztArMzbIwtEfClzD74xcQj50IaG5VmLMEE
ow+GDjwUVuxnY0y5wRvHJX2QYq5IlTuzsfif5j0JJn3QGB37YV+FI35U88/H
T6qgq5xxyHe1I/ZEhCaFqFVQxw2dG9fmgJ70MN3xJhXcrJvLesZzwMGxEIeY
qyrY79q2vkxhj6qvJ0+ps1XAKpgZuBFsj4oXTgmvD6mgeVPNldmnLLyaUqJ7
IEAFLpqMqOJoFmZd62576aqCopRHFemjdvjR9IFRgaEKZPo2b8Xf22Gs2D9o
q1YJWpVO6DpdO/QIVI0K2pWgV7KTN0fIxFSmy8o1pUoY+6LOnU5jImtLZoDV
cSU8IZ+9lFBgi2AaYegWpITLU1NcqyW26M1wOLfKUQlc9bcS2vWlaH+kMHkP
SQm9d78aDnReis/Lq7tI3QrwzAh+pxYxcPip0dL6iwq4tKldeIvLQJKOvHL1
YQW8CmzaLLlvg0I/DX+RhwI++ksJT54NOsii9lqTFUCDnV6aDmtsrZZLW1rk
MG2tSXy1yxpj8tl5SVlyiMun1ggkVpgyskoZFiCHf3vdU/OlljjBUb+O15OD
9ftkn+BXS1A0fHQ6q1EGPHKlcdkYHec/CK/9MU4GnJIJ56ypxVhxzK7UhCGD
W5YRYExdjG8mRvYndfXCysyKEEuLRbiSEn47PLYXdsgcYyQuC3HyoZGFyKwX
nCprO6hbLLDV9/205rYUFiTac4e2m+ONZas5kV5SOMloLNweTUOvU1Wm+LgH
5om8dLfwP0MmR9uwnNcDDFfN3qE0M3QZ5OXnNXfD5IrLNNNiU7wmq49Z69EN
MnufHsllKvp0StoGc7tg86zBT3b1JtivfaD7Q/djaK2/u0a/wRiDC5Pcd6/v
BIL+9rTemQUY9MFYG50jgYvHm06vazbEqchdgzZd7RAkDivL6JqP5Du03NO1
beB+z6/UaFYfN7hlz7ScbIFsZbhPK0cP0wOSBQbMJpjs5M7keumiZs7fHmyP
Bsg5GVVQJKDg51HRRDa3Dmj9caNpURRMD02sH6fXwa+uyd6HdlNwhLr4r43/
iqFcfla7djsFxyfU/ncbxdBp27R+YBkFn994eqmdJwbDBsuXNm/IKOigJGfu
ugfZ01LPK4fJSFDvLKfsEYGZ/0DOz/vIeOTw+x0WPiIoKtEMJ4SRcYhn/djC
VgQ3fXVyNgWQcbJDe0I9XAuSfJehl85k3KA/SUmKrAUDTqbQaZRAK8rGsRch
NZCXnjdg9oxAoyv5MyJuDdBVxe6z/QQeNyhxi19YA07JNeoOCYHKwZHBcnk1
+HUOc/g3CSxPe01ibquGXpuxE1+WEkj9Jm6Hv0s1hMbP9EMRgdlz16yIMKiG
GLrJCeNsAuUWSUEb26rgHZ/eP5VKoDfN/qB5WRUca2Qt/zOJQN/rKfelqVVA
MXfLePQdgfFrh7hHd1dBVvS6J5UHCRx3Ff4xD6rgP7dDXHE=
          "]]}}, {
        GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQveB//8yuhdoHEiMzDOrk79hHr1qkNY9N/YDKxyMn
JCNu24uFbt29MVvpwE/ehE/rtW7ZQ9RLH/gmtyRbTOcGVF7ogJLl9KQS5StQ
PtOBPVIbLKeXHLWHme/Hvr53c9shuPm9N7fY/bU8Bjf/12nW9xaHT8PNV1vA
07Oy+BLc/Ne+L05Z6t6Gm58lsCLw7KZncPN/KB3g0Jh7C26+2KIH05933YSb
z8MjO23z5+tw8x87+HM4JFyFm/+xouFS4PoLcPP13OP/pzXstx8NH/zhAwCm
0SFj
         "], {
          {Hue[0.67, 0.6, 0.6], InsetBox[
            GraphicsBox[
             {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
             ImageSize->10], 19], InsetBox[
            GraphicsBox[
             {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
             ImageSize->10], 20], InsetBox[
            GraphicsBox[
             {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
             ImageSize->10], 21], InsetBox[
            GraphicsBox[
             {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
             ImageSize->10], 22], InsetBox[
            GraphicsBox[
             {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
             ImageSize->10], 23], InsetBox[
            GraphicsBox[
             {RGBColor[0.24720000000000014`, 0.24, 0.6], DiskBox[{0, 0}]},
             ImageSize->10], 24]}, 
          {Hue[0.9060679774997897, 0.6, 0.6], InsetBox[
            GraphicsBox[
             {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
             ImageSize->10], 25], InsetBox[
            GraphicsBox[
             {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
             ImageSize->10], 26], InsetBox[
            GraphicsBox[
             {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
             ImageSize->10], 27], InsetBox[
            GraphicsBox[
             {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
             ImageSize->10], 28], InsetBox[
            GraphicsBox[
             {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
             ImageSize->10], 29], InsetBox[
            GraphicsBox[
             {RGBColor[0.6, 0.24, 0.4428931686004542], DiskBox[{0, 0}]},
             ImageSize->10], 30]}, 
          {Hue[0.1421359549995791, 0.6, 0.6], InsetBox[
            GraphicsBox[
             {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
             ImageSize->10], 31], InsetBox[
            GraphicsBox[
             {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
             ImageSize->10], 32], InsetBox[
            GraphicsBox[
             {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
             ImageSize->10], 33], InsetBox[
            GraphicsBox[
             {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
             ImageSize->10], 34], InsetBox[
            GraphicsBox[
             {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
             ImageSize->10], 35], InsetBox[
            GraphicsBox[
             {RGBColor[0.6, 0.5470136627990908, 0.24], DiskBox[{0, 0}]},
             ImageSize->10], 36]}, {}}], {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->NCache[{-Log[1000000], 0}, {-13.815510557964274`, 0}],
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Exp[
           Part[#, 1]], 
          Part[#, 2]}& ), "CopiedValueFunction" -> ({
          Exp[
           Part[#, 1]], 
          Part[#, 2]}& )},
      Epilog->InsetBox[
        FormBox[
         StyleBox[
         "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False],
          TraditionalForm], 
        Scaled[{0.05, 0.95}]],
      Frame->{True, True, False, False},
      FrameLabel->{{
         FormBox["\"Percent of 2-step rescues\"", TraditionalForm], ""}, {
         FormBox["\"Mutation rate\"", TraditionalForm], ""}},
      FrameTicks->{{True, False}, {{{-13.815510557964274`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {-13.122363377404328`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.716898269296165`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.429216196844383`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.206072645530174`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.02375108873622, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.86960040890896, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.736069016284437`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.618285980628055`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.819778284410283`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.407945608651872, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, None}},
      GridLines->{None, None},
      LabelStyle->Directive[12, FontFamily -> "Helvetica"],
      Method->{},
      PlotRange->
       NCache[{{-Log[1000000], -Log[10]}, {0, 
         1}}, {{-13.815510557964274`, -2.302585092994046}, {0, 1}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], {None, None}},
      Ticks->{{{-13.815510557964274`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-11.512925464970229`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {-13.122363377404328`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.716898269296165`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.429216196844383`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.206072645530174`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.02375108873622, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.86960040890896, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.736069016284437`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.618285980628055`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.819778284410283`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.414313176302118`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.126631103850338`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.903487552536127, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.721165995742174, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.567015315914915, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.433483923290392, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.315700887634009, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.517193191416238, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.111728083308073, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.824046010856292, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.600902459542082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.418580902748127, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.264430222920869, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.1308988302963465`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.013115794639964, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-6.214608098422191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.407945608651872, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], {189., -391.8691769624716}, 
     ImageScaled[{0.5, 0.5}], {360., 291.2461179749811}]}, {}},
  ContentSelectable->True,
  ImageSize->350,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.784901992654303*^9, 3.7849019992786827`*^9}, 
   3.784902376983913*^9, 3.784903060534437*^9}]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Distribution of growth rates given rescue\
\>", "Section",
 CellChangeTimes->{{3.769432454188607*^9, 3.7694324713318567`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Distribution of growth rates among 1-step rescue mutants (equations 15 and 16)\
\>", "Subsection",
 CellChangeTimes->{{3.743875620097973*^9, 3.743875640058288*^9}, {
  3.769190963792317*^9, 3.769190966391176*^9}, {3.769432491397703*^9, 
  3.769432492124374*^9}, {3.769438830570963*^9, 3.76943883272924*^9}, {
  3.771762242036426*^9, 3.771762243701178*^9}}],

Cell["\<\
The distribution of growth rates among the rescue mutants in 1-step rescue is \
simply\
\>", "Text",
 CellChangeTimes->{{3.7694336772061987`*^9, 3.7694336986401663`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"g1m", "=", 
   FractionBox[
    RowBox[{"U", " ", 
     RowBox[{"fm", "[", 
      RowBox[{"m", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     RowBox[{"pest", "[", "m", "]"}]}], 
    RowBox[{"\[CapitalLambda]1", "[", 
     RowBox[{"mwt", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
     "]"}]]}], ";"}]], "Input",
 CellChangeTimes->{{3.769433701503986*^9, 3.769433812088999*^9}}],

Cell["\<\
We can approximate this using our Laplacian approach. In this case we have\
\>", "Text",
 CellChangeTimes->{{3.7694338599525023`*^9, 3.769433887619721*^9}, {
  3.769433939241918*^9, 3.769433940625366*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"h", "[", "\[Psi]_", "]"}], ":=", "  ", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"1", "-", 
        RowBox[{"\[Psi]", "/", "2"}]}], 
       RowBox[{"1", "-", 
        RowBox[{"\[Psi]wt", "/", "2"}]}]], ")"}], 
     RowBox[{"\[Theta]", "-", 
      FractionBox["1", "2"]}]], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "mmax", " ", "y"}]]}], ")"}]}], "/.", 
   RowBox[{"y", "\[Rule]", 
    RowBox[{"\[Psi]", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"\[Psi]", "/", "4"}]}], ")"}]}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"q", "[", "\[Psi]_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", "4"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], 
    "2"]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"h0", "=", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"h", "[", "\[Psi]", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Psi]", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"g1mapprox", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{
       FractionBox["U", 
        RowBox[{"-", "mwt"}]], 
       FractionBox[
        RowBox[{" ", 
         SqrtBox["\[Rho]max"], " "}], 
        RowBox[{"2", " ", 
         SqrtBox["\[Pi]"]}]], "h0", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "\[Rho]max"}], " ", 
         RowBox[{"q", "[", "\[Psi]", "]"}]}], "]"}]}], "AnciauxEqnA12"], "/.", 
     RowBox[{"mwt", "\[Rule]", 
      RowBox[{"mmax", 
       RowBox[{"(", 
        RowBox[{"4", "-", "\[Psi]wt"}], ")"}], 
       RowBox[{"\[Psi]wt", "/", "4"}]}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Psi]wt", "<", "0"}], ",", 
      RowBox[{"\[Alpha]", ">", "0"}], ",", 
      RowBox[{"\[Rho]max", ">", "0"}]}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7694339651802197`*^9, 3.769433987328753*^9}, 
   3.769434065704546*^9, {3.7694341033624763`*^9, 3.7694341237122793`*^9}, {
   3.7694341555890102`*^9, 3.769434157708951*^9}, {3.769434928711341*^9, 
   3.769435046187687*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"\[Alpha]", "-", 
     RowBox[{
      FractionBox["1", "4"], " ", "\[Rho]max", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}]}]], " ", 
   SqrtBox[
    RowBox[{"\[Alpha]", " ", "\[Rho]max"}]], " ", "\[Psi]"}], 
  RowBox[{"\[Psi]wt", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", "\[Alpha]"], " ", 
      SqrtBox["\[Pi]"], " ", 
      SqrtBox["\[Alpha]"], " ", 
      RowBox[{"Erfc", "[", 
       SqrtBox["\[Alpha]"], "]"}]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{
  3.769433981919272*^9, {3.769434060679175*^9, 3.76943406640823*^9}, {
   3.769434111557509*^9, 3.769434124287526*^9}, 3.769434158238821*^9, {
   3.769434930891176*^9, 3.769434936200713*^9}, {3.769435030937812*^9, 
   3.769435046528747*^9}, 3.7822586351141376`*^9}]
}, Closed]],

Cell["\<\
And if we want to plot on an m scale (and still want a pdf) we need to scale \
by\
\>", "Text",
 CellChangeTimes->{{3.769434793575427*^9, 3.769434827433496*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"scaleg1approx", "=", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["m", "mmax"]}]]}], ")"}]}], ",", "m"}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.769434831900239*^9, 3.769434835340361*^9}}],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{
   SqrtBox[
    RowBox[{"1", "-", 
     FractionBox["m", "mmax"]}]], " ", "mmax"}]]], "Output",
 CellChangeTimes->{{3.769434819879476*^9, 3.769434835894264*^9}, 
   3.782258635194201*^9}]
}, Closed]],

Cell["giving", "Text",
 CellChangeTimes->{{3.771610083227487*^9, 3.771610086055661*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"g1mApp", "=", 
   RowBox[{"scaleg1approx", " ", "g1mapprox"}]}], ";"}]], "Input"],

Cell["Numerically compare", "Text",
 CellChangeTimes->{{3.76943490624275*^9, 3.769434910050397*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", 
   RowBox[{"-", "0.1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{"g1m", ",", "\[IndentingNewLine]", "g1mApp"}], 
         "\[IndentingNewLine]", "}"}], "/.", 
        RowBox[{"\[Alpha]", "\[Rule]", 
         RowBox[{
          SuperscriptBox["\[Psi]wt", "2"], 
          RowBox[{"\[Rho]max", "/", "4"}]}]}]}], "/.", 
       RowBox[{"\[Rho]max", "\[Rule]", 
        RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
      RowBox[{"\[Theta]", "\[Rule]", 
       RowBox[{"n", "/", "2"}]}]}], "/.", 
     RowBox[{"\[Psi]wt", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SqrtBox[
          RowBox[{"1", "-", 
           FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}], "/.", 
    RowBox[{"\[Psi]", "\[Rule]", 
     RowBox[{"2", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SqrtBox[
         RowBox[{"1", "-", 
          FractionBox["m", "mmax"]}]]}], ")"}]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", 
      RowBox[{"-", "0.2"}], ",", "0.2"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "All"}], "}"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Growth rate\>\"", ",", "\"\<Density\>\""}], "}"}]}], ",", 
    RowBox[{"PlotLegends", "\[Rule]", 
     RowBox[{"Placed", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<true\>\"", ",", "\"\<closed form\>\""}], "}"}], ",", 
       "Top"}], "]"}]}], ",", 
    RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{"mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.745605827856853*^9, 3.745605967789041*^9}, {
   3.7456061870109653`*^9, 3.7456062493713837`*^9}, {3.74560631565994*^9, 
   3.7456063233756523`*^9}, {3.745606373416418*^9, 3.745606415678789*^9}, {
   3.745606889208753*^9, 3.745606932448284*^9}, {3.7510460248393803`*^9, 
   3.751046125108657*^9}, {3.751046159359934*^9, 3.751046173118959*^9}, {
   3.751569069079301*^9, 3.7515690945833*^9}, {3.7515691257166567`*^9, 
   3.7515691499251947`*^9}, {3.751569201870821*^9, 3.75156923272721*^9}, 
   3.7515693203349752`*^9, {3.751569837906849*^9, 3.751569972007575*^9}, {
   3.751570002626707*^9, 3.7515700641586742`*^9}, {3.751570094265408*^9, 
   3.751570126168432*^9}, {3.751570163169345*^9, 3.751570171668024*^9}, {
   3.751570222692821*^9, 3.751570289475067*^9}, {3.75157047933195*^9, 
   3.751570482902234*^9}, {3.751570518552079*^9, 3.751570523841608*^9}, {
   3.751571282697386*^9, 3.751571308490201*^9}, {3.751571348556931*^9, 
   3.7515713600277452`*^9}, 3.751648563678364*^9, {3.751648606913094*^9, 
   3.751648618381736*^9}, {3.751648662830717*^9, 3.751648666948554*^9}, {
   3.751650747564664*^9, 3.751650758085843*^9}, {3.769434168131123*^9, 
   3.7694342110774593`*^9}, {3.7694342574782124`*^9, 
   3.7694343130880327`*^9}, {3.76943468554528*^9, 3.7694346860207787`*^9}, {
   3.769434718281143*^9, 3.769434774188259*^9}, {3.7694348396517763`*^9, 
   3.7694348957480497`*^9}, {3.7694356553880043`*^9, 
   3.7694357016936693`*^9}, {3.7694359633035927`*^9, 3.7694359670946903`*^9}, 
   3.771610124463101*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJx12Xk0VdH7P3Ahc5IiQhnCHTKlpJRnmxKSlCkhZEqDoYQMRTIkScbM1xTJ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     "], {{{}, {
        Hue[0.67, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[CompressedData["
1:eJwl1GdU1mUYB2C04Wln0yAU0limAWqBZTIUBI2KAHGAiaAmysZjjsAYLShL
Kcv2KS1HHyptp82T7aFlnrKllZ7Gh8rVvJ7jh4vf777f9xx4/+/zEFtRW1jT
OyIiohcT/ShiBT2k2t0uR9LBb+ZkuYgn9R+I1xuYrz/CTqLMM8nX1/IdA801
VOi38RZ9zIWk6M08zBdE2lWRpz/Bt5xnnsd0vZs3OdZ8Fcl6Ew+xg3PsKhmn
P843xJrnco3exRscY76SC/VGHuRz+tnNIFefxq28ztF2VzBUb+ABPuPs8LnI
0cu5hdc4yq6AIXo997Ods8LnYKxexs28Sm+7y7lAr+M+tnFm+LsZo0/lJraE
78xuAoP1WlbxKWfYTSNbn8KNbI448iWPJ0mt4V4+4XS7crL0yXTyCv+Rb58o
53EPH3OaXRmZ+iQ6eJl/ybNPkHNZyUf0tZtKhl5KOy/xD+Ps42U1d/Mhp9pN
YXQ4k7TxIn+Tax8nL6OEG3iBv8jx2vlyFMUs5XkOM9Zrg8I5DGcpnAcupYhW
nuMQY7wvRs7hLj7gFLvJXKJfTQvPcpBs+wFyA3uIM9dzrd7D+5xsnhTukb6G
r4kxV4fzr/9Eot7E9XqKXMwm/QBZen+ZLtv5NZyxcG5ZyHpzlxxBK7vDGQnP
gjpmm7vlRSxlXzhz4dyEexvuezjjclj4/bwXzow8iVLSzWmyjZ/1IXIBq/Xh
soVd+gA5J9xJ/UcS9EaW6BvZT6Y5Wv7CUP061unfM0ivZZa+lyS9meX6u5zY
68j/qDT9Mb6if3jW4R7ri3mGP8mwO1fO5E7e4QS7Ei7WH+VLosPzCfdaX8TT
/MFouyhZxR1s5Xi74vAc9QIW8hS/h/NoHykrWUZq+Ny8rXfK4/gfy4Waxw==

          "]]]}, {}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Opacity[0.2], 
        EdgeForm[None], 
        GraphicsGroupBox[
         PolygonBox[CompressedData["
1:eJwV03lgznUcB/ANhUqKVMqZpKJSlHQ4Og1FI1dU1uEojS6dbtEpVgpho+Yo
NmojKWPR7qGQITp0idIlurw+f7z2+bw/z/N7nt/z+37WOCU1+YFKCQkJiST5
s0tIU5eyUz+Nz+jOsxRzGp0YSz7feu/x6lU8wgrWmtVWr+Np1sTnmB3mfP1d
vMUSeS/H6a/kYXLJM6ulXstTfMSnZn9xnj6FN3lH/obq+it4iJz4PrOT1Wt4
kg/ZbHaIc/UDmc/b8tdU07flQd6L7zPbxJ80k+9kHovlr6iqv5wRvBufb7aR
PzhHvoMMFslfcqy+DcNZzmqzcn6nqXw76SyU93CM/jJSWcYHZmX8xtnyAOay
QN5NFf2lxGFms8qslF9pIvdnDpnyF1TWt2YYWbxvVsJBzpJvY3acUewElfSt
uJ+lrDQr5hcay/14I84k9oZE/SXcF2ccO2FWxM80kvsyK85AzqWQAzQ068PM
eN5yBunMZQ6zyaGA/TTwvt7MiO+Xd8Qi6y9maOxHnKfZSWpHnohnzydmP1Ff
34vX437kU9UbGcM6Ksy6qhPjGv6XW6pDYnfi7OWXY7e4mUkUUpMXKKMDW3k8
zpENrqlQX2IjndnGeNazz+vb1ecooR5buJXX4tnE71Snxv8E3ficyRRRhxcp
5wZGs5btrpuibqILE+Je+M/8ebWUixgcex57an6T+gwFnEh7Hov9inv1epI6
jo/5UT5T7cn0OBP5FPV6RpEX92n2LxfqB7Eo9luuobZjZOxifJ7ZD5yh78Gr
cUbyNv7hAvleFpItn6BezaOxm+SbfU9dfTKvxLOTt/I3LeR7WECWvI7vOF2+
hbT4DfIWjtBcvptMjgIv7Lhm
          "]]]}, {}, {}, {}, {}, {}, {}}, {{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        LineBox[{1, 315, 240, 175, 119, 75, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 
         11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 316, 241, 
         176, 120, 76, 52, 339, 264, 199, 143, 99, 25, 317, 242, 177, 121, 77,
          359, 284, 219, 163, 375, 300, 235, 386, 311, 398, 53}], 
        LineBox[CompressedData["
1:eJwt03l8z3UcB/CtlEelg3TYcsw2u+yipClKB1J2WEh0jM1ULBkPJUeHzcxy
lIpy5IFy5A+UKEeHHlS6KT2i0t1D9UfRfTzfj0d/PPd+vd+/3x77ft+fz1Iq
asrGJiYkJFznRzknUcdusylqF+bKI0mip/5ndQN3M4Bu///+yeyR51FJMr3M
flE3Mpliqs3a8om8ggsZpD+F1+X5VHEel5odVTdxDyWMNmvHQXkl3Rmsb8Eb
8kNMkLP5Th5FjZzGF/Ja7pLz+EFuy2XyMfXZeG/G6zP5Ri7lVrk9h+Rp6vms
kiepuRyR71e7c5E8RD2Vet7UT1W70sjD+olqDg18r79X7UYT1fo71HRm8qV+
unoBs1kXu1fzmcWP+gfi78Ze5N7qr+pzsTO5kKlyrZrFt3IZt8kd+FR+iiKu
15/GXnlB7Jpx+k58JT9Dey7X/6Zujn0wkB4MNT+dt+RHYm904Aqz39Xn410o
52JS6EgqaVzpe3+oW2Inca+4hHSu8tmf6lbuizsT95FO9PHZX+oLcQ5xH+Lu
cYP5GbwtPxrvTAZ9zf5WX4zdxXnFXWOYeUvekR/jdjLpZ/aPuo0Zsae4Mww3
b8W78kLGkMXVZv+q26mLvcS5cKP5mbwnL2Is2fSPf0J2KPXx3LFjbjJrzfvy
43GPyeEas0R2yjPjuWPH3Gx2Fh/IT8Q9ojPXmh3HS3JDPHfsmlvMzmafvDjO
mlwGmB3Py/KseO7YPxVm57BfXsKd5FFs1oxX5MZ47jgTRpidy4fyUsaTT4nZ
Cbwqz47njl3rU/hMfjrOiJH6NnwkL6OWAkrNTmSX3BTvEbvXd+RzeXWcGZX6
JA7ITzKBQsrMmvOa/GC8V5yFPpXD8po4Q6r0yXwsL2divLM+g6/l9UyWC/gp
7oZaxBy66P8D9k2ZmA==
         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        LineBox[CompressedData["
1:eJwV1HeA1nMcB/DnIqRCSqLEKS1pSlmhqKu0DiGkPWibWaFERtp1dyGjK9J1
dw0aujsN7WvcyGgYZe/KLq/PH6/n83l/fs/ze57f7/v9Pcl9R6QOT0okEile
9pZJJDLpz8X8bVbMTKbJ3anG1/KHLGa+PICG/COXMIvpcirn8I28lvf1D3I1
Fcg2W6AO5BL+lUuZzQz5Js7lW3kdK/QP0ZqK5Ji9rQ6iEf/Je8jXP8ENVCEt
rkG9mep8F+dTn6YD6+WV6sNcw2lsZAKdyXX8HXUwjdnGCxwz36COpxM7eZmP
zQvUsbSjkJc4i808xx66spspfEp63Dv1FoqpwVaej3PyvePr1XGU0pEdTOIT
Nji+Sh1DCdeynRc5nU08Sxd2MZklPrNQHUITjssfqc9wY5w31lp9kvZUJSPW
SO3BefwQn2G1/hGu4wyWmr2r3kNTEnGdZnNI099KTX6UN7KMV3iV15jL67xB
uvfdxvn8JG9iOW+SYXY7F/CzvJn3WCTfSzOS+Mzsrfh+fU+S+UXeEnuTLHko
zSnDXrN58Zv0d3Ahv8pbYy/G/peHcSknsM8sM36//k5q8Zu8LfYX2fJwWnAi
++P5iWvV30Vtfpe3xzqSI4/gMspyIJ6XuC/6XlzEYbkw7j258khachKfx/MR
91B/N3U4Iu/gA5bIo2jFyXwR+zzut743dTkq72QNS+XRXM4pfBl7J9ZA34d6
/CHvivPrH6UNlciL9VXv4wrK8VXsj1gTfV/q86e8O75P/xhtOZP8WG/1fq7k
VA7GGsca6fvRgL/kIvL0j3M9lSmIPaE+wFWU51D8L6lPkcLZbGEi3Shiauwb
srz3f+9Et88=
         "]]}, {
        Hue[0.67, 0.6, 0.6], 
        Opacity[0.2], 
        LineBox[{401, 400}]}}, {{}, {}, {}, {}}}], AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesOrigin -> {0, 0}, Frame -> {True, True, False, False}, FrameLabel -> {{
       FormBox["\"Density\"", TraditionalForm], None}, {
       FormBox["\"Growth rate\"", TraditionalForm], None}}, LabelStyle -> 
    Directive[12, FontFamily -> "Helvetica"], 
    Method -> {"AxesInFront" -> True}, PlotRange -> {{-0.2, 0.2}, {0, All}}, 
    PlotRangeClipping -> True, PlotRangePadding -> {
      Scaled[0.02], Automatic}],
   TemplateBox[{"\"true\"", "\"closed form\""}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #, 
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.8, 0.5}}}], "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxDividers -> {"Columns" -> {{None}}, "Rows" -> {{None}}}, 
          GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
          GridBoxSpacings -> {"Columns" -> {{0}}, "Rows" -> {{1}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Row\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}, {
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {2, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "Top"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.7456058322539787`*^9, 3.745605908567705*^9}, {
   3.745605942058544*^9, 3.745605968054598*^9}, {3.745606208371788*^9, 
   3.7456062195118303`*^9}, 3.7456062513295593`*^9, {3.7456063168460903`*^9, 
   3.7456063238340816`*^9}, {3.745606374002508*^9, 3.745606416297852*^9}, {
   3.745606890029995*^9, 3.745606932976078*^9}, 3.751045900742908*^9, {
   3.751046066980158*^9, 3.751046125760919*^9}, {3.751046159917791*^9, 
   3.7510461737020893`*^9}, 3.7515690181240063`*^9, {3.751569073266165*^9, 
   3.751569095042678*^9}, {3.7515692160675297`*^9, 3.751569233136425*^9}, 
   3.7515693209569693`*^9, {3.7515699150073557`*^9, 3.7515699265467787`*^9}, 
   3.751569973038656*^9, {3.751570035416127*^9, 3.751570065748238*^9}, {
   3.75157010259474*^9, 3.751570127046865*^9}, 3.751570172745405*^9, 
   3.751570290363813*^9, 3.751570486779619*^9, 3.751570524866406*^9, 
   3.7515707579143887`*^9, 3.7515713127384853`*^9, 3.751571361472867*^9, {
   3.751648608033161*^9, 3.751648619121511*^9}, {3.7516507498925*^9, 
   3.7516507604113197`*^9}, {3.769434181828429*^9, 3.769434211980193*^9}, {
   3.769434258720147*^9, 3.769434313811761*^9}, 3.7694346871753807`*^9, {
   3.769434719224903*^9, 3.7694347296240377`*^9}, {3.769434764541567*^9, 
   3.769434774821121*^9}, {3.769434840741889*^9, 3.769434896599667*^9}, {
   3.769435038027804*^9, 3.769435049147591*^9}, {3.769435662093069*^9, 
   3.769435696972994*^9}, {3.769435955980545*^9, 3.769435967576002*^9}, 
   3.782258635485488*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Distribution of growth rates among 2-step rescue genotypes (equation 17)\
\>", "Subsection",
 CellChangeTimes->{{3.743875717895998*^9, 3.743875728748897*^9}, {
   3.75107650717444*^9, 3.751076524823639*^9}, {3.751596759091982*^9, 
   3.751596760787457*^9}, 3.7515981694076033`*^9, {3.769432553879045*^9, 
   3.7694325628883266`*^9}, {3.769433270084774*^9, 3.7694332725639563`*^9}, 
   3.769438838265975*^9, 3.771762248357271*^9}],

Cell["\<\
The rate of 2-step rescue through double mutants with growth rate m2 is\
\>", "Text",
 CellChangeTimes->{{3.76944007898392*^9, 3.7694401299761553`*^9}, {
  3.769440249803377*^9, 3.769440250555582*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"g2numerator", "[", 
    RowBox[{"m0_", ",", 
     RowBox[{"m2_", "?", "NumericQ"}]}], "]"}], ":=", 
   RowBox[{"U", " ", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"fm", "[", 
        RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
        "]"}], 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
       RowBox[{"prescuem", "[", 
        RowBox[{"m", ",", 
         RowBox[{"U", " ", 
          RowBox[{"fm", "[", 
           RowBox[{"m2", ",", "m", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
           "]"}], 
          RowBox[{"pest", "[", "m2", "]"}]}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "\[Infinity]"}], ",", "mmax"}], "}"}]}], "]"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.76944016476042*^9, 3.769440223663084*^9}, {
  3.7694406285294867`*^9, 3.7694406782594852`*^9}, {3.769440769060835*^9, 
  3.769440770789144*^9}}],

Cell["\<\
Integrating this over m2 then provides the correct normalization, \
\>", "Text",
 CellChangeTimes->{{3.769440289013824*^9, 3.769440322277135*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"g2denominator", "[", 
    RowBox[{"m0_", "?", "NumericQ"}], "]"}], ":=", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{"U", " ", 
      RowBox[{"fm", "[", 
       RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
      RowBox[{"prescuem", "[", 
       RowBox[{"m", ",", 
        RowBox[{"U", " ", 
         RowBox[{"fm", "[", 
          RowBox[{"m2", ",", "m", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
          "]"}], 
         RowBox[{"pest", "[", "m2", "]"}]}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"-", "\[Infinity]"}], ",", "mmax"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m2", ",", "0", ",", "mmax"}], "}"}]}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.769440720466605*^9, 3.7694407571970253`*^9}, {
  3.7694411218731337`*^9, 3.769441124352386*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plot growth rates of rescue genotypes (figure 6)\
\>", "Subsection",
 CellChangeTimes->{{3.743875717895998*^9, 3.743875728748897*^9}, {
   3.75107650717444*^9, 3.751076524823639*^9}, {3.751596759091982*^9, 
   3.751596760787457*^9}, 3.7515981694076033`*^9, {3.769432553879045*^9, 
   3.7694325628883266`*^9}, {3.769433270084774*^9, 3.7694332725639563`*^9}, 
   3.769438838265975*^9, {3.769438950950025*^9, 3.7694389670448503`*^9}, {
   3.771524323583331*^9, 3.771524324805073*^9}}],

Cell[CellGroupData[{

Cell["Panels", "Subsubsection",
 CellChangeTimes->{{3.7849022223479357`*^9, 3.784902222978959*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"-", "0.3"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"xmax", "=", "0.25"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ymax", "=", "28"}], ";"}]}], "Input",
 CellChangeTimes->{{3.77152432562892*^9, 3.771524330042083*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.1"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", "random", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        RowBox[{"fm", "[", 
         RowBox[{"m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "xmin", ",", "xmax", ",", "0.01"}], "}"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"(*", "established", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"fm", "[", 
           RowBox[{
           "m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], "]"}], 
          RowBox[{"pest", "[", 
           RowBox[{"m2", "-", "mwt"}], "]"}]}], 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"fm", "[", 
             RowBox[{
             "m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
             "]"}], 
            RowBox[{"pest", "[", 
             RowBox[{"m2", "-", "mwt"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"m2", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "mwt", ",", "xmax", ",", "0.01"}], "}"}]}], "]"}]}],
    "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Gray", ",", "Dashed"}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Gray"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{"\"\<random\>\"", ",", "\"\<established\>\""}], "}"}]}], 
          "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1.5", "/", "8"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"1", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        RowBox[{"g1m", "/.", 
         RowBox[{"m", "\[Rule]", "m2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "0", ",", "xmax", ",", "0.005"}], "}"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"2", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"total", "=", 
      RowBox[{"Re", "[", 
       RowBox[{"g2denominator", "[", "mwt", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"m2", ",", 
         RowBox[{
          FractionBox["1", "total"], 
          RowBox[{"g2numerator", "[", 
           RowBox[{"mwt", ",", "m2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "xmax", ",", "0.005"}], "}"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{"\"\<1-step\>\"", ",", "\"\<2-step\>\""}], "}"}]}], "]"}],
          ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1.5", "/", "8"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"g1mApp", "/.", 
       RowBox[{"\[Alpha]", "\[Rule]", 
        RowBox[{
         SuperscriptBox["\[Psi]wt", "2"], 
         RowBox[{"\[Rho]max", "/", "4"}]}]}]}], "/.", 
      RowBox[{"\[Rho]max", "\[Rule]", 
       RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
     RowBox[{"\[Theta]", "\[Rule]", 
      RowBox[{"n", "/", "2"}]}]}], "/.", 
    RowBox[{"\[Psi]wt", "\[Rule]", 
     RowBox[{"2", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SqrtBox[
         RowBox[{"1", "-", 
          FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}], "/.", 
   RowBox[{"\[Psi]", "\[Rule]", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["m", "mmax"]}]]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"onestepapp", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "0", ",", "xmax"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Dashed"}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", "\"\<1-step approx.\>\"", "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1.5", "/", "8"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "datadir", "<>", 
     "\"\<dfe_poisson_N10000_n4_U0.00200_Es0.01_mmax0.50_mwt-0.10_mutmax10_\
nreps10000.csv\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"onestep", "=", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"dat", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], "&"}]}], "]"}], 
    "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"twostep", "=", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"dat", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
    "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Histogram", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"onestep", ",", "twostep"}], "}"}], ",", "50", ",", 
      "\"\<PDF\>\"", ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fig6a", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
    "oldtheory", ",", "data", ",", "theory", ",", "onestepapp", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontColor", "\[Rule]", "White"}], ",", "Automatic", ",", 
        "Automatic", ",", "Automatic"}], "}"}]}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<\!\(\*SubscriptBox[\(m\), \(0\)]\)=\>\"", "<>", 
             RowBox[{"ToString", "[", "mwt", "]"}]}], ",", "12", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"7", "/", "8"}], ",", 
             RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<A\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{"Gray", ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"mwt", ",", "10"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.035"}], ",", "10"}], "}"}]}], "}"}], "]"}]}], 
         "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{"Gray", ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"mwt", ",", "9.5"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"mwt", ",", "10.5"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{"Gray", ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.035"}], ",", "9.5"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.035"}], ",", "10.5"}], "}"}]}], "}"}], "]"}]}],
          "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{
            RowBox[{"defaultcolors", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"mwt", ",", "15"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.03", ",", "15"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{
            RowBox[{"defaultcolors", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"mwt", ",", "14.5"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"mwt", ",", "15.5"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{
            RowBox[{"defaultcolors", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0.03", ",", "14.5"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.03", ",", "15.5"}], "}"}]}], "}"}], "]"}]}], "}"}]}],
        "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.751575679958344*^9, 3.751575707856783*^9}, {
   3.751575756450697*^9, 3.7515757716167583`*^9}, {3.751575806118587*^9, 
   3.751575998358532*^9}, {3.7515761122033863`*^9, 3.751576131258815*^9}, {
   3.751576172283361*^9, 3.751576174879533*^9}, {3.7515762580970592`*^9, 
   3.751576326479478*^9}, {3.7515763695777597`*^9, 3.751576370332637*^9}, {
   3.7515764174224873`*^9, 3.751576419272636*^9}, {3.751577234452231*^9, 
   3.751577234571393*^9}, {3.751598119440303*^9, 3.7515981249463587`*^9}, 
   3.751650792683756*^9, {3.751650847039688*^9, 3.751650935724555*^9}, {
   3.751651020576578*^9, 3.751651024456732*^9}, {3.7516511744217253`*^9, 
   3.751651271292901*^9}, {3.7516514431359167`*^9, 3.751651596903675*^9}, {
   3.75165167006041*^9, 3.7516517016743317`*^9}, {3.751651837998188*^9, 
   3.751651848660565*^9}, {3.751651901804051*^9, 3.751651938743773*^9}, {
   3.75165209054011*^9, 3.751652092941709*^9}, {3.751654667780588*^9, 
   3.751654726734174*^9}, {3.751654761368635*^9, 3.751654832140562*^9}, {
   3.751654888268785*^9, 3.7516548919393587`*^9}, 3.751656018745837*^9, {
   3.751656381036447*^9, 3.7516563882551813`*^9}, {3.7565000581145897`*^9, 
   3.7565001021945477`*^9}, {3.756500617190415*^9, 3.75650065699045*^9}, 
   3.75650069938904*^9, {3.756500741026494*^9, 3.756500755155011*^9}, {
   3.756501221346011*^9, 3.75650122389799*^9}, 3.756502363067445*^9, 
   3.756502628112669*^9, 3.7565026817972727`*^9, {3.756503286102932*^9, 
   3.756503290049591*^9}, 3.756503323237875*^9, {3.756503496903769*^9, 
   3.75650353646167*^9}, {3.7565038167736483`*^9, 3.756503833330291*^9}, {
   3.7565038702319183`*^9, 3.7565038987244377`*^9}, {3.7565039623685904`*^9, 
   3.7565039995283422`*^9}, 3.756511754548572*^9, 3.756511866105935*^9, {
   3.756511901000861*^9, 3.756511903883478*^9}, {3.7565119526094627`*^9, 
   3.756511957815688*^9}, {3.756512664854374*^9, 3.756512670495578*^9}, {
   3.7565186714828672`*^9, 3.756518674830636*^9}, {3.756518724785604*^9, 
   3.7565187318397303`*^9}, {3.756518775324299*^9, 3.75651877705446*^9}, {
   3.756518831207197*^9, 3.756518836010257*^9}, {3.7565191876130047`*^9, 
   3.7565192273750753`*^9}, 3.756557317943141*^9, 3.756565191609994*^9, {
   3.756565226853438*^9, 3.756565227347921*^9}, {3.756565372407086*^9, 
   3.756565372554656*^9}, {3.7642581275023746`*^9, 3.764258130547591*^9}, {
   3.764258191591094*^9, 3.7642582094474382`*^9}, 3.769438935312201*^9, {
   3.769440382123701*^9, 3.769440472454721*^9}, 3.769440550032837*^9, {
   3.769440597811926*^9, 3.76944060297188*^9}, {3.769440831103504*^9, 
   3.769440912756571*^9}, {3.769440959415164*^9, 3.769440994826437*^9}, {
   3.769441059064315*^9, 3.769441091058297*^9}, {3.769441130350876*^9, 
   3.76944116439666*^9}, {3.7694411991785088`*^9, 3.7694412021516743`*^9}, 
   3.76996874883585*^9, 3.769968810893046*^9, {3.771262388292754*^9, 
   3.771262479562519*^9}, {3.771262525425778*^9, 3.771262540854212*^9}, {
   3.771262571282227*^9, 3.771262676392552*^9}, 3.771262708817911*^9, {
   3.771262787550537*^9, 3.77126278925319*^9}, {3.771262848265294*^9, 
   3.7712628699284153`*^9}, {3.771263092625225*^9, 3.771263094812828*^9}, 
   3.771263271500595*^9, {3.771523030703679*^9, 3.7715230467362022`*^9}, {
   3.771523079011808*^9, 3.771523152186151*^9}, {3.77152320543019*^9, 
   3.771523315803763*^9}, {3.7715233464449253`*^9, 3.771523576781527*^9}, {
   3.771523631873809*^9, 3.7715236430826683`*^9}, {3.7715241526920757`*^9, 
   3.771524155896125*^9}, {3.7715242229465923`*^9, 3.771524257316955*^9}, {
   3.771524320220757*^9, 3.771524423589848*^9}, {3.771524462952353*^9, 
   3.771524468371491*^9}, 3.771524519796175*^9, {3.771524560722151*^9, 
   3.77152458745588*^9}, {3.7715456914503183`*^9, 3.771545693694459*^9}, 
   3.7715458002283154`*^9, {3.771545911589119*^9, 3.771545926111433*^9}, {
   3.77160975420442*^9, 3.7716097651557693`*^9}, {3.7716099182331963`*^9, 
   3.77160992062647*^9}, {3.771609967213895*^9, 3.771610003678589*^9}, {
   3.771610042996176*^9, 3.771610061906077*^9}, {3.771610106603993*^9, 
   3.771610114408716*^9}, {3.771610201107335*^9, 3.771610202727501*^9}, 
   3.771610248378283*^9, 3.7822587135494137`*^9, {3.78490212808366*^9, 
   3.784902133335487*^9}, 3.784903418455496*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "izero"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Integral and error estimates are 0 on all integration \
subregions. Try increasing the value of the MinRecursion option. If value of \
integral may be 0, specify a finite value for the AccuracyGoal option. \\!\\(\
\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/NIntegrate\\\", ButtonNote -> \
\\\"NIntegrate::izero\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.771545649489097*^9, 3.7715456687648563`*^9}, 
   3.7715457102473392`*^9, 3.771545775469632*^9, 3.771545813254785*^9, 
   3.771545934235961*^9, 3.7716096787386017`*^9, 3.771609730201099*^9, 
   3.77160977627625*^9, 3.771610014629425*^9, 3.771610077361767*^9, 
   3.771610125234447*^9, 3.7716102157341127`*^9, 3.782258662739026*^9, 
   3.782258693507845*^9, 3.7822587427251*^9, {3.7849021370243607`*^9, 
   3.784902159272544*^9}, 3.784903432829946*^9}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {{}, {}, 
       {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
        LineBox[CompressedData["
1:eJwtU3tI01EUntN8v/aAUlIyrUaalbYSxJ0bRCqZNQVJ85GS+Uema0E5k7Qw
UyIt0TLfopUW2srhi+lVp2ibE1/zEY2cY+YrTNJMi0x/93fgcjmce7/vO+d+
1yUuOSSeyWAwfLbXzu5NxSjWVuiGqkzGIK97jReZN4LTytr3r69MwaKwxfnh
4jDucwpNn6mchgBdKrfBfxgzHS+uB3EMUCPys5yoHsKBjsyD3xMWgEHFEJY3
nfUWh/+AndvClkFcaeI2yDdaBeq4SI0znrs7O3n+hm2ybcYB/FljiL6u/QsU
vE6J/Qpch7uZRuglFZ/wfPAN1U2lMQqhAPuxyONN2/sWU7SD5mfZh7eytE5m
cgtEye/uxQINDprpsEYUXGoPDpbk7D5ea4dIvwoc9Gc/w9eThUh/XXjy8r6A
4hg2qqYEduI1JXspLIKDiP4OfFU2NmFgcRHRK8fXpkxDzdO4qIjS14pnWWtf
6p9xaT3NODFQ0vf6Apfml+HMSJkJq5mDFii+D9jdlvs0Sc2m8RtwWaxGGlXK
ovHqsJVawPx1zB6lUPdr8PwhlxQp3wZJqfPleMCofsl+3AKJqHoB5tt2/YuL
N0UZVJ6J74wIwGBsjBh0LDBrj0SVbAFdB8Wy996Ajxt0XgDuhblSXuIqdBJ8
OH8yJ9asaZmu14DKs2+Rbz4HlUQfPBLu+Zqt0NHv2wDRvq1htS+mYIn0B+IV
7yn/n8OQRvqH2cHpb1X3+sGazAeWmeOqdr9OKCXzg81wtrV4TgYeZL5wNCv3
br7DWxq/A8yyVVfO5FbQfuuEV+/u71Lcyqf5uqCZ06t9MJkJJ8j7gjKbN+vV
fJvm74FsjXxofDwBeog/IFnSZaW3uQS0f0Btnet46pw/0P4CN1V6fUwJH4qJ
/8CnvDfKn+cKM8SfsPGkMWPUyx4OE/9CUWGS5LTdpkBM/A1tvWmqA3q9oI34
H/RakVDSNCAwIv8DNA51EezHjYL/hVay3A==
         "]]}, 
       {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQPWsmCOzczwAF3NcXF9hybd8vWXAltPwgg0O1yDr3
h1Vb9k91DQ6KkxJweBO4Q6719cb9NVoSe2TPiznsBPICd6zbzzTDVT7CRMYB
Yt7K/RP/FH734lFwqAHrX7L/RJFpa7WxosMOsPp5+x+GTI28NFkRKj9l/zcT
ppoldooODWB+y/7dk+u1f/krOMDcZfLK0NvwmqxDBUTeXshnR6lNrhSUP8X+
0ak35mkbxWDm2x/dkcfX/lwIZr/9wjtznydP4HOYAXGf/RxJv58/f7JD1a+z
31WuseagPRPMf/YrLRO8+z/+sq+C+N/eh2OZnrPHZ3suSPjY2y3y9ZLc+8oe
Gn72/QleC3Z+emivEdN/6KvGHnvTpHjLeX7X7SHm77PPbLFKa7c/a78EqPv6
4gP2D/c/XK+//aD9a7B9B+1fzVu2U3vjFntjMDhsb3GQ58Zt1+X2kPA/Ys//
yOhvuvZM+8NfQTYctZ/l/fith1KXPSS+jtv/dE+I+MJYZQ82LvCEvelkO82t
hzLswc6bedJ+2tSmypWNYfYPwR46Zb9kq7+KYq2zvSbYvWfsGfolZ6zlNLAv
BDmv4Ky98Xp1yUcskvaQ+D1nH75D5Xl3IZM9JDYu2B9Je/ZDbN5LOwAJBgl/

         "]]}}, {}}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[Opacity[0.35]], {{}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], Opacity[0.5], EdgeForm[
        Opacity[0.35]], 
        RectangleBox[{0., 0.}, 
         NCache[{0.005, Rational[800, 169]}, {0.005, 4.733727810650888}],
         RoundingRadius->0], 
        RectangleBox[{0.005, 0.}, 
         NCache[{0.01, Rational[3320, 507]}, {0.01, 6.548323471400394}],
         RoundingRadius->0], 
        RectangleBox[{0.01, 0.}, 
         NCache[{0.015, Rational[3920, 507]}, {0.015, 7.731755424063117}],
         RoundingRadius->0], 
        RectangleBox[{0.015, 0.}, 
         NCache[{0.02, Rational[4960, 507]}, {0.02, 9.783037475345168}],
         RoundingRadius->0], 
        RectangleBox[{0.02, 0.}, 
         NCache[{0.025, Rational[5440, 507]}, {0.025, 10.729783037475345`}],
         RoundingRadius->0], 
        RectangleBox[{0.025, 0.}, 
         NCache[{0.03, Rational[1840, 169]}, {0.03, 10.887573964497042`}],
         RoundingRadius->0], 
        RectangleBox[{0.03, 0.}, 
         NCache[{0.035, Rational[2000, 169]}, {0.035, 11.834319526627219`}],
         RoundingRadius->0], 
        RectangleBox[{0.035, 0.}, 
         NCache[{0.04, Rational[2100, 169]}, {0.04, 12.42603550295858}],
         RoundingRadius->0], 
        RectangleBox[{0.04, 0.}, 
         NCache[{0.045, Rational[2160, 169]}, {0.045, 12.781065088757396`}],
         RoundingRadius->0], 
        RectangleBox[{0.045, 0.}, 
         NCache[{0.05, Rational[2160, 169]}, {0.05, 12.781065088757396`}],
         RoundingRadius->0], 
        RectangleBox[{0.05, 0.}, 
         NCache[{0.055, Rational[5780, 507]}, {0.055, 11.400394477317555`}],
         RoundingRadius->0], 
        RectangleBox[{0.055, 0.}, 
         NCache[{0.06, Rational[140, 13]}, {0.06, 10.76923076923077}],
         RoundingRadius->0], 
        RectangleBox[{0.06, 0.}, 
         NCache[{0.065, Rational[400, 39]}, {0.065, 10.256410256410257`}],
         RoundingRadius->0], 
        RectangleBox[{0.065, 0.}, 
         NCache[{0.07, Rational[4840, 507]}, {0.07, 9.546351084812624}],
         RoundingRadius->0], 
        RectangleBox[{0.07, 0.}, 
         NCache[{0.075, Rational[120, 13]}, {0.075, 9.23076923076923}],
         RoundingRadius->0], 
        RectangleBox[{0.075, 0.}, 
         NCache[{0.08, Rational[4240, 507]}, {0.08, 8.362919132149901}],
         RoundingRadius->0], 
        RectangleBox[{0.08, 0.}, 
         NCache[{0.085, Rational[1140, 169]}, {0.085, 6.745562130177515}],
         RoundingRadius->0], 
        RectangleBox[{0.085, 0.}, 
         NCache[{0.09, Rational[2920, 507]}, {0.09, 5.759368836291913}],
         RoundingRadius->0], 
        RectangleBox[{0.09, 0.}, 
         NCache[{0.095, Rational[200, 39]}, {0.095, 5.128205128205129}],
         RoundingRadius->0], 
        RectangleBox[{0.095, 0.}, 
         NCache[{0.1, Rational[2320, 507]}, {0.1, 4.575936883629192}],
         RoundingRadius->0], 
        RectangleBox[{0.1, 0.}, 
         NCache[{0.105, Rational[1600, 507]}, {0.105, 3.155818540433925}],
         RoundingRadius->0], 
        RectangleBox[{0.105, 0.}, 
         NCache[{0.11, Rational[40, 13]}, {0.11, 3.076923076923077}],
         RoundingRadius->0], 
        RectangleBox[{0.11, 0.}, 
         NCache[{0.115, Rational[1280, 507]}, {0.115, 2.52465483234714}],
         RoundingRadius->0], 
        RectangleBox[{0.115, 0.}, 
         NCache[{0.12, Rational[1000, 507]}, {0.12, 1.9723865877712032`}],
         RoundingRadius->0], 
        RectangleBox[{0.12, 0.}, 
         NCache[{0.125, Rational[860, 507]}, {0.125, 1.6962524654832347`}],
         RoundingRadius->0], 
        RectangleBox[{0.125, 0.}, 
         NCache[{0.13, Rational[860, 507]}, {0.13, 1.6962524654832347`}],
         RoundingRadius->0], 
        RectangleBox[{0.13, 0.}, 
         NCache[{0.135, Rational[400, 507]}, {0.135, 0.7889546351084813}],
         RoundingRadius->0], 
        RectangleBox[{0.135, 0.}, 
         NCache[{0.14, Rational[120, 169]}, {0.14, 0.7100591715976331}],
         RoundingRadius->0], 
        RectangleBox[{0.14, 0.}, 
         NCache[{0.145, Rational[340, 507]}, {0.145, 0.6706114398422091}],
         RoundingRadius->0], 
        RectangleBox[{0.145, 0.}, 
         NCache[{0.15, Rational[140, 507]}, {0.15, 0.27613412228796846`}],
         RoundingRadius->0], 
        RectangleBox[{0.15, 0.}, 
         NCache[{0.155, Rational[20, 39]}, {0.155, 0.5128205128205128}],
         RoundingRadius->0], 
        RectangleBox[{0.155, 0.}, 
         NCache[{0.16, Rational[100, 507]}, {0.16, 0.19723865877712032`}],
         RoundingRadius->0], 
        RectangleBox[{0.16, 0.}, 
         NCache[{0.165, Rational[80, 507]}, {0.165, 0.15779092702169625`}],
         RoundingRadius->0], 
        RectangleBox[{0.165, 0.}, 
         NCache[{0.17, Rational[20, 169]}, {0.17, 0.11834319526627218`}],
         RoundingRadius->0], 
        RectangleBox[{0.17, 0.}, 
         NCache[{0.175, Rational[20, 169]}, {0.175, 0.11834319526627218`}],
         RoundingRadius->0], 
        RectangleBox[{0.175, 0.}, 
         NCache[{0.18, Rational[20, 507]}, {0.18, 0.03944773175542406}],
         RoundingRadius->0], 
        RectangleBox[{0.18, 0.}, 
         NCache[{0.185, Rational[40, 507]}, {0.185, 0.07889546351084813}],
         RoundingRadius->0], RectangleBox[{0.185, 0.}, {0.19, 0},
         RoundingRadius->0], 
        RectangleBox[{0.19, 0.}, 
         NCache[{0.195, Rational[20, 169]}, {0.195, 0.11834319526627218`}],
         RoundingRadius->0], RectangleBox[{0.195, 0.}, {0.2, 0},
         RoundingRadius->0], 
        RectangleBox[{0.2, 0.}, 
         NCache[{0.205, Rational[20, 507]}, {0.205, 0.03944773175542406}],
         RoundingRadius->0], RectangleBox[{0.205, 0.}, {0.21, 0},
         RoundingRadius->0], RectangleBox[{0.21, 0.}, {0.215, 0},
         RoundingRadius->0], RectangleBox[{0.215, 0.}, {0.22, 0},
         RoundingRadius->0], RectangleBox[{0.22, 0.}, {0.225, 0},
         RoundingRadius->0], RectangleBox[{0.225, 0.}, {0.23, 0},
         RoundingRadius->0], RectangleBox[{0.23, 0.}, {0.235, 0},
         RoundingRadius->0], 
        RectangleBox[{0.235, 0.}, 
         NCache[{0.24, Rational[20, 507]}, {0.24, 0.03944773175542406}],
         RoundingRadius->0], RectangleBox[{0.24, 0.}, {0.245, 0},
         RoundingRadius->0], RectangleBox[{0.245, 0.}, {0.25, 0},
         RoundingRadius->0]}, {}, {}}, {{}, 
       {RGBColor[0.6, 0.24, 0.4428931686004542], Opacity[0.5], EdgeForm[
        Opacity[0.35]], 
        RectangleBox[{0., 0.}, 
         NCache[{0.005, Rational[200, 241]}, {0.005, 0.8298755186721992}],
         RoundingRadius->0], 
        RectangleBox[{0.005, 0.}, 
         NCache[{0.01, Rational[450, 241]}, {0.01, 1.8672199170124482`}],
         RoundingRadius->0], 
        RectangleBox[{0.01, 0.}, 
         NCache[{0.015, Rational[750, 241]}, {0.015, 3.112033195020747}],
         RoundingRadius->0], 
        RectangleBox[{0.015, 0.}, 
         NCache[{0.02, Rational[1200, 241]}, {0.02, 4.979253112033195}],
         RoundingRadius->0], 
        RectangleBox[{0.02, 0.}, 
         NCache[{0.025, Rational[1050, 241]}, {0.025, 4.356846473029045}],
         RoundingRadius->0], 
        RectangleBox[{0.025, 0.}, 
         NCache[{0.03, Rational[1400, 241]}, {0.03, 5.809128630705394}],
         RoundingRadius->0], 
        RectangleBox[{0.03, 0.}, 
         NCache[{0.035, Rational[1900, 241]}, {0.035, 7.8838174273858925`}],
         RoundingRadius->0], 
        RectangleBox[{0.035, 0.}, 
         NCache[{0.04, Rational[1350, 241]}, {0.04, 5.601659751037344}],
         RoundingRadius->0], 
        RectangleBox[{0.04, 0.}, 
         NCache[{0.045, Rational[1500, 241]}, {0.045, 6.224066390041494}],
         RoundingRadius->0], 
        RectangleBox[{0.045, 0.}, 
         NCache[{0.05, Rational[1650, 241]}, {0.05, 6.846473029045643}],
         RoundingRadius->0], 
        RectangleBox[{0.05, 0.}, 
         NCache[{0.055, Rational[1950, 241]}, {0.055, 8.091286307053942}],
         RoundingRadius->0], 
        RectangleBox[{0.055, 0.}, 
         NCache[{0.06, Rational[1950, 241]}, {0.06, 8.091286307053942}],
         RoundingRadius->0], 
        RectangleBox[{0.06, 0.}, 
         NCache[{0.065, Rational[2250, 241]}, {0.065, 9.336099585062241}],
         RoundingRadius->0], 
        RectangleBox[{0.065, 0.}, 
         NCache[{0.07, Rational[1700, 241]}, {0.07, 7.053941908713693}],
         RoundingRadius->0], 
        RectangleBox[{0.07, 0.}, 
         NCache[{0.075, Rational[1750, 241]}, {0.075, 7.261410788381743}],
         RoundingRadius->0], 
        RectangleBox[{0.075, 0.}, 
         NCache[{0.08, Rational[1900, 241]}, {0.08, 7.8838174273858925`}],
         RoundingRadius->0], 
        RectangleBox[{0.08, 0.}, 
         NCache[{0.085, Rational[1700, 241]}, {0.085, 7.053941908713693}],
         RoundingRadius->0], 
        RectangleBox[{0.085, 0.}, 
         NCache[{0.09, Rational[1800, 241]}, {0.09, 7.468879668049793}],
         RoundingRadius->0], 
        RectangleBox[{0.09, 0.}, 
         NCache[{0.095, Rational[1850, 241]}, {0.095, 7.676348547717843}],
         RoundingRadius->0], 
        RectangleBox[{0.095, 0.}, 
         NCache[{0.1, Rational[1800, 241]}, {0.1, 7.468879668049793}],
         RoundingRadius->0], 
        RectangleBox[{0.1, 0.}, 
         NCache[{0.105, Rational[2350, 241]}, {0.105, 9.751037344398341}],
         RoundingRadius->0], 
        RectangleBox[{0.105, 0.}, 
         NCache[{0.11, Rational[1800, 241]}, {0.11, 7.468879668049793}],
         RoundingRadius->0], 
        RectangleBox[{0.11, 0.}, 
         NCache[{0.115, Rational[1300, 241]}, {0.115, 5.394190871369295}],
         RoundingRadius->0], 
        RectangleBox[{0.115, 0.}, 
         NCache[{0.12, Rational[1500, 241]}, {0.12, 6.224066390041494}],
         RoundingRadius->0], 
        RectangleBox[{0.12, 0.}, 
         NCache[{0.125, Rational[1600, 241]}, {0.125, 6.639004149377594}],
         RoundingRadius->0], 
        RectangleBox[{0.125, 0.}, 
         NCache[{0.13, Rational[1450, 241]}, {0.13, 6.016597510373444}],
         RoundingRadius->0], 
        RectangleBox[{0.13, 0.}, 
         NCache[{0.135, Rational[1200, 241]}, {0.135, 4.979253112033195}],
         RoundingRadius->0], 
        RectangleBox[{0.135, 0.}, 
         NCache[{0.14, Rational[950, 241]}, {0.14, 3.9419087136929463`}],
         RoundingRadius->0], 
        RectangleBox[{0.14, 0.}, 
         NCache[{0.145, Rational[750, 241]}, {0.145, 3.112033195020747}],
         RoundingRadius->0], 
        RectangleBox[{0.145, 0.}, 
         NCache[{0.15, Rational[550, 241]}, {0.15, 2.2821576763485476`}],
         RoundingRadius->0], 
        RectangleBox[{0.15, 0.}, 
         NCache[{0.155, Rational[600, 241]}, {0.155, 2.4896265560165975`}],
         RoundingRadius->0], 
        RectangleBox[{0.155, 0.}, 
         NCache[{0.16, Rational[650, 241]}, {0.16, 2.6970954356846475`}],
         RoundingRadius->0], 
        RectangleBox[{0.16, 0.}, 
         NCache[{0.165, Rational[650, 241]}, {0.165, 2.6970954356846475`}],
         RoundingRadius->0], 
        RectangleBox[{0.165, 0.}, 
         NCache[{0.17, Rational[550, 241]}, {0.17, 2.2821576763485476`}],
         RoundingRadius->0], 
        RectangleBox[{0.17, 0.}, 
         NCache[{0.175, Rational[500, 241]}, {0.175, 2.074688796680498}],
         RoundingRadius->0], 
        RectangleBox[{0.175, 0.}, 
         NCache[{0.18, Rational[300, 241]}, {0.18, 1.2448132780082988`}],
         RoundingRadius->0], 
        RectangleBox[{0.18, 0.}, 
         NCache[{0.185, Rational[150, 241]}, {0.185, 0.6224066390041494}],
         RoundingRadius->0], 
        RectangleBox[{0.185, 0.}, 
         NCache[{0.19, Rational[300, 241]}, {0.19, 1.2448132780082988`}],
         RoundingRadius->0], 
        RectangleBox[{0.19, 0.}, 
         NCache[{0.195, Rational[200, 241]}, {0.195, 0.8298755186721992}],
         RoundingRadius->0], 
        RectangleBox[{0.195, 0.}, 
         NCache[{0.2, Rational[100, 241]}, {0.2, 0.4149377593360996}],
         RoundingRadius->0], 
        RectangleBox[{0.2, 0.}, 
         NCache[{0.205, Rational[100, 241]}, {0.205, 0.4149377593360996}],
         RoundingRadius->0], RectangleBox[{0.205, 0.}, {0.21, 0},
         RoundingRadius->0], 
        RectangleBox[{0.21, 0.}, 
         NCache[{0.215, Rational[250, 241]}, {0.215, 1.037344398340249}],
         RoundingRadius->0], 
        RectangleBox[{0.215, 0.}, 
         NCache[{0.22, Rational[150, 241]}, {0.22, 0.6224066390041494}],
         RoundingRadius->0], 
        RectangleBox[{0.22, 0.}, 
         NCache[{0.225, Rational[50, 241]}, {0.225, 0.2074688796680498}],
         RoundingRadius->0], RectangleBox[{0.225, 0.}, {0.23, 0},
         RoundingRadius->0], RectangleBox[{0.23, 0.}, {0.235, 0},
         RoundingRadius->0], 
        RectangleBox[{0.235, 0.}, 
         NCache[{0.24, Rational[50, 241]}, {0.24, 0.2074688796680498}],
         RoundingRadius->0], RectangleBox[{0.24, 0.}, {0.245, 0},
         RoundingRadius->0], 
        RectangleBox[{0.245, 0.}, 
         NCache[{0.25, Rational[50, 241]}, {0.25, 0.2074688796680498}],
         RoundingRadius->0]}, {}, {}}}, {{}, {{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJxdUXss1HEAP7dFY0KdNPFrku6kMFfTGJ+v7XrILueR1UYbpaZV3OYfZ2pt
rqxVHrOMJHLWNM4jdG4YLp3Oo2tXERZiJcxj16kR636Pv/ps3333fX1eX6+U
9NhUPo/HE1sHPf+PbIH61LQiE5t/7wQGtzgTdp0LQ0LbbO2MJ9FQyoUYzSNo
v1Y5xK96c+fFsFW0SbYrhaSslAFCKh1vXxrz5e5X4EZV2GM15UcWY+idKuiT
Ygq3cvy49yroPN1cZPv9iP1IdUaY/QsUC8aLBoMOcXy1mJTPi0NNIuKbmN9r
EdXBI+2BsdxbyPGrkbIy3LIKH6Kyvh6pbsTPPJXah3hzek0wX/geRB33ImIG
r9AcsrliSKc4/RY02AVMfSlxJzqLyKrQio1wY2Xv+m7Oz2vsdRpwca3ZRWJZ
QTgU1+RdrnDm/LVj55EVTeBHBzKtoAm1uMvPlac723F+O9BKCmzjF/lETtvL
6MRE5Iflss4tsHRdyOIbZCc0f8D+QjdCf1imNurNYPN0w50v1R3etozTjEAP
nNJMmyrxHNh8PcheH5X2NX4DrWaVREC9hNIVTYDNq8PkL5+ziqefwMQZ0cGG
1xQd7G8Em/8NukyjXeO/9dhH26H6MJvVntyZ3wO2jz5EybVzJzPbcfUKjbfQ
KSm9f3gz2H706L5489nnsVrQbAK1HpU25W4PPZ6D7asfjjPaHBdBKdZoOks/
dpQP3V8SFoLt7x2uJ0ki7APvIZwhNKCjQzZXZL4Ftk8DTHvGz8tSM8HYUw7g
SdNagzDvGth+ByFtnY+LsEvG0CADRPKXeI3558D2PQRZwsG4yYUzcGUMDkMa
cSBKUki4/oeResxdaXI7CoYu8T3MO5d6DTwR9x9GvCwpqIsO9cA/nj54kQ==

         "]]}, 
       {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
        LineBox[CompressedData["
1:eJxdUXlI01EAHh5UdlDqvJpzo5qaVogssqbfM1uGaKIpiamhafOI1CGCK0jz
QCpmhBQqGDFLwpSVk6ZZznQ6542Zlilq+UeeKM0Ro2i/468+eDze9V1PmJYb
m2HD4XACrYOa/8ct55bwBUUBVImlrfq7HMKsy5CYLz48em4P0fLLV2K0SnzJ
dK+L+u7InlcjjPfg8UOjC6mtoYFxryA7i8WdvV+Pmpth58eUPLIaQ+08g9gx
JLewms++b8D2draseq+AOEyp8oIdGtF8KXP56RMBy/cS9WnJ4vU1AfFNqvpo
8nkFuYrIVFwhy98Cxd/0uEdOQtJgfT2lUmNe3msXuSpg9V7DvTHqqk+DgATS
aEVySldrBASsvgaS4sqS8FIv0mPysSq0wbuZJ/+RzGf9vEWB6NRsGdeTxDKC
SIg+dmRGfZD11w77xc0XASc9yIKCIuzAdJDSOavJjfXbCe+VDT8z15XkU/by
3uPQYsD6koLL+v+ACT+JbGLOiTC/oMOBykL7Lakjm0eHccnlgl2a/eQCLdCN
RufW3o2EfWy+bkg6JN6y9N2EUrNKosgiD66p2snm7cH82vK12Tl7QseZ6gEn
UndfH2/L5u8FL7QzRWjmEC/KDl+PtpzcVJt7f8D0YV0XReyQl/yG7DqFPlw5
USE1TJrA9NOPrTvZ/p8qtkCxObf04/mI5w1X0QaYvgyInqu7GLrxE9sUnckA
IvVfP526BKa/AQxobEUu8gWE0IRGKM+0W277fwPTpxEzfbVHDSWfQdsrH4Q6
c/LdnGEcTL9DiDSPqb8ODmJ4iAZ04WeLtQo9mL6H0SD29fDP0oFLGxzB8bZf
GU1GLZj+R2DuzuGLSt+ApksahSZ+ZjonrgnMf4xBKu7Su22q8A+I6HQZ
         
         "]]}}, {}}, {{}, {}, 
      {Hue[0.67, 0.6, 0.6], Thickness[Large], Dashing[{Small, Small}], 
       LineBox[CompressedData["
1:eJwVlnc8Vf8fx1WKJCIqVEjGtSMqldeJhowyC0VWkTKySsPeIyrJzN4Z2Xtf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        "]]}}}, InsetBox[
     TagBox[GridBox[{
        {
         TemplateBox[{
          StyleBox[
           "\"1-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
            FontSize -> 12],StyleBox[
           "\"2-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
            FontSize -> 12]},
          "LineLegend",
          DisplayFunction->(StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
            False]& ),
          Editable->True,
          InterpretationFunction:>(RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]},
        {
         TemplateBox[{
          StyleBox[
           "\"random\"", StripOnInput -> False, FontFamily -> "Helvetica", 
            FontSize -> 12],StyleBox[
           "\"established\"", StripOnInput -> False, FontFamily -> 
            "Helvetica", FontSize -> 12]},
          "LineLegend",
          DisplayFunction->(StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
            False]& ),
          Editable->True,
          InterpretationFunction:>(RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                   ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}]}], "]"}]}], "}"}],
                ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]},
        {
         TemplateBox[{
          StyleBox[
           "\"1-step approx.\"", StripOnInput -> False, FontFamily -> 
            "Helvetica", FontSize -> 12]},
          "LineLegend",
          DisplayFunction->(StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6], 
                    Thickness[Large], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6], 
                    Thickness[Large], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
            False]& ),
          Editable->True,
          InterpretationFunction:>(RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"Directive", "[", 
                   RowBox[{
                    RowBox[{"Hue", "[", 
                    RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                 "}"}], ",", 
               RowBox[{"{", #, "}"}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
             "]"}]& )]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {{0}}}],
      "Grid"], NCache[
     Scaled[{0.1875, Rational[1, 2]}], Scaled[{0.1875, 0.5}]], ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesLabel->{None, None},
   AxesOrigin->{0., 0.},
   Epilog->{
     InsetBox[
      FormBox[
       StyleBox[
       "\"\\!\\(\\*SubscriptBox[\\(m\\), \\(0\\)]\\)=-0.1\"", 12, FontFamily -> 
        "Helvetica", StripOnInput -> False], TraditionalForm], 
      NCache[
       Scaled[{
         Rational[7, 8], 
         Rational[3, 4]}], 
       Scaled[{0.875, 0.75}]]], 
     InsetBox[
      FormBox[
       StyleBox[
       "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
       TraditionalForm], 
      Scaled[{0.05, 0.95}]], {
      Directive[
       GrayLevel[0.5], 
       Thickness[Large]], 
      LineBox[{{-0.1, 10}, {-0.035, 10}}]}, {
      Directive[
       GrayLevel[0.5], 
       Thickness[Large]], 
      LineBox[{{-0.1, 9.5}, {-0.1, 10.5}}]}, {
      Directive[
       GrayLevel[0.5], 
       Thickness[Large]], 
      LineBox[{{-0.035, 9.5}, {-0.035, 10.5}}]}, {
      Directive[
       RGBColor[0.24720000000000014`, 0.24, 0.6], 
       Thickness[Large]], 
      LineBox[{{-0.1, 15}, {0.03, 15}}]}, {
      Directive[
       RGBColor[0.24720000000000014`, 0.24, 0.6], 
       Thickness[Large]], 
      LineBox[{{-0.1, 14.5}, {-0.1, 15.5}}]}, {
      Directive[
       RGBColor[0.24720000000000014`, 0.24, 0.6], 
       Thickness[Large]], 
      LineBox[{{0.03, 14.5}, {0.03, 15.5}}]}},
   Frame->{True, False, False, False},
   FrameTicksStyle->{
    FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.3, 0.25}, {0, 28}},
   PlotRangeClipping->True,
   PlotRangePadding->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           GrayLevel[0.5], 
           Dashing[{Small, Small}]], 
          Line[CompressedData["
1:eJwtU3tI01EUntN8v/aAUlIyrUaalbYSxJ0bRCqZNQVJ85GS+Uema0E5k7Qw
UyIt0TLfopUW2srhi+lVp2ibE1/zEY2cY+YrTNJMi0x/93fgcjmce7/vO+d+
1yUuOSSeyWAwfLbXzu5NxSjWVuiGqkzGIK97jReZN4LTytr3r69MwaKwxfnh
4jDucwpNn6mchgBdKrfBfxgzHS+uB3EMUCPys5yoHsKBjsyD3xMWgEHFEJY3
nfUWh/+AndvClkFcaeI2yDdaBeq4SI0znrs7O3n+hm2ybcYB/FljiL6u/QsU
vE6J/Qpch7uZRuglFZ/wfPAN1U2lMQqhAPuxyONN2/sWU7SD5mfZh7eytE5m
cgtEye/uxQINDprpsEYUXGoPDpbk7D5ea4dIvwoc9Gc/w9eThUh/XXjy8r6A
4hg2qqYEduI1JXspLIKDiP4OfFU2NmFgcRHRK8fXpkxDzdO4qIjS14pnWWtf
6p9xaT3NODFQ0vf6Apfml+HMSJkJq5mDFii+D9jdlvs0Sc2m8RtwWaxGGlXK
ovHqsJVawPx1zB6lUPdr8PwhlxQp3wZJqfPleMCofsl+3AKJqHoB5tt2/YuL
N0UZVJ6J74wIwGBsjBh0LDBrj0SVbAFdB8Wy996Ajxt0XgDuhblSXuIqdBJ8
OH8yJ9asaZmu14DKs2+Rbz4HlUQfPBLu+Zqt0NHv2wDRvq1htS+mYIn0B+IV
7yn/n8OQRvqH2cHpb1X3+sGazAeWmeOqdr9OKCXzg81wtrV4TgYeZL5wNCv3
br7DWxq/A8yyVVfO5FbQfuuEV+/u71Lcyqf5uqCZ06t9MJkJJ8j7gjKbN+vV
fJvm74FsjXxofDwBeog/IFnSZaW3uQS0f0Btnet46pw/0P4CN1V6fUwJH4qJ
/8CnvDfKn+cKM8SfsPGkMWPUyx4OE/9CUWGS5LTdpkBM/A1tvWmqA3q9oI34
H/RakVDSNCAwIv8DNA51EezHjYL/hVay3A==
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           GrayLevel[0.5]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGBQAWIQPWsmCOzczwAF3NcXF9hybd8vWXAltPwgg0O1yDr3
h1Vb9k91DQ6KkxJweBO4Q6719cb9NVoSe2TPiznsBPICd6zbzzTDVT7CRMYB
Yt7K/RP/FH734lFwqAHrX7L/RJFpa7WxosMOsPp5+x+GTI28NFkRKj9l/zcT
ppoldooODWB+y/7dk+u1f/krOMDcZfLK0NvwmqxDBUTeXshnR6lNrhSUP8X+
0ak35mkbxWDm2x/dkcfX/lwIZr/9wjtznydP4HOYAXGf/RxJv58/f7JD1a+z
31WuseagPRPMf/YrLRO8+z/+sq+C+N/eh2OZnrPHZ3suSPjY2y3y9ZLc+8oe
Gn72/QleC3Z+emivEdN/6KvGHnvTpHjLeX7X7SHm77PPbLFKa7c/a78EqPv6
4gP2D/c/XK+//aD9a7B9B+1fzVu2U3vjFntjMDhsb3GQ58Zt1+X2kPA/Ys//
yOhvuvZM+8NfQTYctZ/l/fith1KXPSS+jtv/dE+I+MJYZQ82LvCEvelkO82t
hzLswc6bedJ+2tSmypWNYfYPwR46Zb9kq7+KYq2zvSbYvWfsGfolZ6zlNLAv
BDmv4Ky98Xp1yUcskvaQ+D1nH75D5Xl3IZM9JDYu2B9Je/ZDbN5LOwAJBgl/

           "]]}}}, {}}, {
       Directive[
        EdgeForm[
         Opacity[0.35]], 
        RGBColor[
        0.798413061722744, 0.824719615472648, 0.968322270542458]], {{{{}, {
           Directive[
            Opacity[0.5], 
            Directive[
             EdgeForm[
              Opacity[0.35]], 
             RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458]], 
            Directive[
             RGBColor[0.24720000000000014`, 0.24, 0.6]]], {{{
              Rectangle[{0., 0.}, {0.005, 
                Rational[800, 169]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.005, 0.}, {0.01, 
                Rational[3320, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.01, 0.}, {0.015, 
                Rational[3920, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.015, 0.}, {0.02, 
                Rational[4960, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.02, 0.}, {0.025, 
                Rational[5440, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.025, 0.}, {0.03, 
                Rational[1840, 169]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.03, 0.}, {0.035, 
                Rational[2000, 169]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.035, 0.}, {0.04, 
                Rational[2100, 169]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.04, 0.}, {0.045, 
                Rational[2160, 169]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.045, 0.}, {0.05, 
                Rational[2160, 169]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.05, 0.}, {0.055, 
                Rational[5780, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.055, 0.}, {0.06, 
                Rational[140, 13]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.06, 0.}, {0.065, 
                Rational[400, 39]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.065, 0.}, {0.07, 
                Rational[4840, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.07, 0.}, {0.075, 
                Rational[120, 13]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.075, 0.}, {0.08, 
                Rational[4240, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.08, 0.}, {0.085, 
                Rational[1140, 169]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.085, 0.}, {0.09, 
                Rational[2920, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.09, 0.}, {0.095, 
                Rational[200, 39]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.095, 0.}, {0.1, 
                Rational[2320, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.1, 0.}, {0.105, 
                Rational[1600, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.105, 0.}, {0.11, 
                Rational[40, 13]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.11, 0.}, {0.115, 
                Rational[1280, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.115, 0.}, {0.12, 
                Rational[1000, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.12, 0.}, {0.125, 
                Rational[860, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.125, 0.}, {0.13, 
                Rational[860, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.13, 0.}, {0.135, 
                Rational[400, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.135, 0.}, {0.14, 
                Rational[120, 169]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.14, 0.}, {0.145, 
                Rational[340, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.145, 0.}, {0.15, 
                Rational[140, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.15, 0.}, {0.155, 
                Rational[20, 39]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.155, 0.}, {0.16, 
                Rational[100, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.16, 0.}, {0.165, 
                Rational[80, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.165, 0.}, {0.17, 
                Rational[20, 169]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.17, 0.}, {0.175, 
                Rational[20, 169]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.175, 0.}, {0.18, 
                Rational[20, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.18, 0.}, {0.185, 
                Rational[40, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.185, 0.}, {0.19, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.19, 0.}, {0.195, 
                Rational[20, 169]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.195, 0.}, {0.2, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.2, 0.}, {0.205, 
                Rational[20, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.205, 0.}, {0.21, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.21, 0.}, {0.215, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.215, 0.}, {0.22, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.22, 0.}, {0.225, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.225, 0.}, {0.23, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.23, 0.}, {0.235, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.235, 0.}, {0.24, 
                Rational[20, 507]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.24, 0.}, {0.245, 0}, "RoundingRadius" -> 0]}}, {{
              
              Rectangle[{0.245, 0.}, {0.25, 0}, "RoundingRadius" -> 
               0]}}}}, {}, {}}}, {{{}, {
           Directive[
            Opacity[0.5], 
            Directive[
             EdgeForm[
              Opacity[0.35]], 
             RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458]], 
            Directive[
             RGBColor[0.6, 0.24, 0.4428931686004542]]], {{{
              Rectangle[{0., 0.}, {0.005, 
                Rational[200, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.005, 0.}, {0.01, 
                Rational[450, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.01, 0.}, {0.015, 
                Rational[750, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.015, 0.}, {0.02, 
                Rational[1200, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.02, 0.}, {0.025, 
                Rational[1050, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.025, 0.}, {0.03, 
                Rational[1400, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.03, 0.}, {0.035, 
                Rational[1900, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.035, 0.}, {0.04, 
                Rational[1350, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.04, 0.}, {0.045, 
                Rational[1500, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.045, 0.}, {0.05, 
                Rational[1650, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.05, 0.}, {0.055, 
                Rational[1950, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.055, 0.}, {0.06, 
                Rational[1950, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.06, 0.}, {0.065, 
                Rational[2250, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.065, 0.}, {0.07, 
                Rational[1700, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.07, 0.}, {0.075, 
                Rational[1750, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.075, 0.}, {0.08, 
                Rational[1900, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.08, 0.}, {0.085, 
                Rational[1700, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.085, 0.}, {0.09, 
                Rational[1800, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.09, 0.}, {0.095, 
                Rational[1850, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.095, 0.}, {0.1, 
                Rational[1800, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.1, 0.}, {0.105, 
                Rational[2350, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.105, 0.}, {0.11, 
                Rational[1800, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.11, 0.}, {0.115, 
                Rational[1300, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.115, 0.}, {0.12, 
                Rational[1500, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.12, 0.}, {0.125, 
                Rational[1600, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.125, 0.}, {0.13, 
                Rational[1450, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.13, 0.}, {0.135, 
                Rational[1200, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.135, 0.}, {0.14, 
                Rational[950, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.14, 0.}, {0.145, 
                Rational[750, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.145, 0.}, {0.15, 
                Rational[550, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.15, 0.}, {0.155, 
                Rational[600, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.155, 0.}, {0.16, 
                Rational[650, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.16, 0.}, {0.165, 
                Rational[650, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.165, 0.}, {0.17, 
                Rational[550, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.17, 0.}, {0.175, 
                Rational[500, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.175, 0.}, {0.18, 
                Rational[300, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.18, 0.}, {0.185, 
                Rational[150, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.185, 0.}, {0.19, 
                Rational[300, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.19, 0.}, {0.195, 
                Rational[200, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.195, 0.}, {0.2, 
                Rational[100, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.2, 0.}, {0.205, 
                Rational[100, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.205, 0.}, {0.21, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.21, 0.}, {0.215, 
                Rational[250, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.215, 0.}, {0.22, 
                Rational[150, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.22, 0.}, {0.225, 
                Rational[50, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.225, 0.}, {0.23, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.23, 0.}, {0.235, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.235, 0.}, {0.24, 
                Rational[50, 241]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.24, 0.}, {0.245, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.245, 0.}, {0.25, 
                Rational[50, 241]}, "RoundingRadius" -> 
               0]}}}}, {}, {}}}}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           Thickness[Large]], 
          Line[CompressedData["
1:eJxdUXss1HEAP7dFY0KdNPFrku6kMFfTGJ+v7XrILueR1UYbpaZV3OYfZ2pt
rqxVHrOMJHLWNM4jdG4YLp3Oo2tXERZiJcxj16kR636Pv/ps3333fX1eX6+U
9NhUPo/HE1sHPf+PbIH61LQiE5t/7wQGtzgTdp0LQ0LbbO2MJ9FQyoUYzSNo
v1Y5xK96c+fFsFW0SbYrhaSslAFCKh1vXxrz5e5X4EZV2GM15UcWY+idKuiT
Ygq3cvy49yroPN1cZPv9iP1IdUaY/QsUC8aLBoMOcXy1mJTPi0NNIuKbmN9r
EdXBI+2BsdxbyPGrkbIy3LIKH6Kyvh6pbsTPPJXah3hzek0wX/geRB33ImIG
r9AcsrliSKc4/RY02AVMfSlxJzqLyKrQio1wY2Xv+m7Oz2vsdRpwca3ZRWJZ
QTgU1+RdrnDm/LVj55EVTeBHBzKtoAm1uMvPlac723F+O9BKCmzjF/lETtvL
6MRE5Iflss4tsHRdyOIbZCc0f8D+QjdCf1imNurNYPN0w50v1R3etozTjEAP
nNJMmyrxHNh8PcheH5X2NX4DrWaVREC9hNIVTYDNq8PkL5+ziqefwMQZ0cGG
1xQd7G8Em/8NukyjXeO/9dhH26H6MJvVntyZ3wO2jz5EybVzJzPbcfUKjbfQ
KSm9f3gz2H706L5489nnsVrQbAK1HpU25W4PPZ6D7asfjjPaHBdBKdZoOks/
dpQP3V8SFoLt7x2uJ0ki7APvIZwhNKCjQzZXZL4Ftk8DTHvGz8tSM8HYUw7g
SdNagzDvGth+ByFtnY+LsEvG0CADRPKXeI3558D2PQRZwsG4yYUzcGUMDkMa
cSBKUki4/oeResxdaXI7CoYu8T3MO5d6DTwR9x9GvCwpqIsO9cA/nj54kQ==

           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Directive[
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           Thickness[Large]], 
          Line[CompressedData["
1:eJxdUXlI01EAHh5UdlDqvJpzo5qaVogssqbfM1uGaKIpiamhafOI1CGCK0jz
QCpmhBQqGDFLwpSVk6ZZznQ6542Zlilq+UeeKM0Ro2i/468+eDze9V1PmJYb
m2HD4XACrYOa/8ct55bwBUUBVImlrfq7HMKsy5CYLz48em4P0fLLV2K0SnzJ
dK+L+u7InlcjjPfg8UOjC6mtoYFxryA7i8WdvV+Pmpth58eUPLIaQ+08g9gx
JLewms++b8D2draseq+AOEyp8oIdGtF8KXP56RMBy/cS9WnJ4vU1AfFNqvpo
8nkFuYrIVFwhy98Cxd/0uEdOQtJgfT2lUmNe3msXuSpg9V7DvTHqqk+DgATS
aEVySldrBASsvgaS4sqS8FIv0mPysSq0wbuZJ/+RzGf9vEWB6NRsGdeTxDKC
SIg+dmRGfZD11w77xc0XASc9yIKCIuzAdJDSOavJjfXbCe+VDT8z15XkU/by
3uPQYsD6koLL+v+ACT+JbGLOiTC/oMOBykL7Lakjm0eHccnlgl2a/eQCLdCN
RufW3o2EfWy+bkg6JN6y9N2EUrNKosgiD66p2snm7cH82vK12Tl7QseZ6gEn
UndfH2/L5u8FL7QzRWjmEC/KDl+PtpzcVJt7f8D0YV0XReyQl/yG7DqFPlw5
USE1TJrA9NOPrTvZ/p8qtkCxObf04/mI5w1X0QaYvgyInqu7GLrxE9sUnckA
IvVfP526BKa/AQxobEUu8gWE0IRGKM+0W277fwPTpxEzfbVHDSWfQdsrH4Q6
c/LdnGEcTL9DiDSPqb8ODmJ4iAZ04WeLtQo9mL6H0SD29fDP0oFLGxzB8bZf
GU1GLZj+R2DuzuGLSt+ApksahSZ+ZjonrgnMf4xBKu7Su22q8A+I6HQZ
           
           "]]}}}, {}}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Thickness[Large], 
         Dashing[{Small, Small}], 
         Line[CompressedData["
1:eJwVlnc8Vf8fx1WKJCIqVEjGtSMqldeJhowyC0VWkTKySsPeIyrJzN4Z2Xtf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          "]]}}}}, {
     PlotRange -> {{-0.3, 0.25}, {0, 28}}, 
      Frame -> {True, False, False, False}, LabelStyle -> 
      Directive[12, FontFamily -> "Helvetica"], 
      FrameTicksStyle -> {
       FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, Epilog -> {
        Text[
         Style[
         "\!\(\*SubscriptBox[\(m\), \(0\)]\)=-0.1", 12, FontFamily -> 
          "Helvetica"], 
         Scaled[{
           Rational[7, 8], 
           Rational[3, 4]}]], 
        Text[
         Style["A", 14, Bold, FontFamily -> "Helvetica"], 
         Scaled[{0.05, 0.95}]], {
         Directive[
          GrayLevel[0.5], 
          Thickness[Large]], 
         Line[{{-0.1, 10}, {-0.035, 10}}]}, {
         Directive[
          GrayLevel[0.5], 
          Thickness[Large]], 
         Line[{{-0.1, 9.5}, {-0.1, 10.5}}]}, {
         Directive[
          GrayLevel[0.5], 
          Thickness[Large]], 
         Line[{{-0.035, 9.5}, {-0.035, 10.5}}]}, {
         Directive[
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          Thickness[Large]], 
         Line[{{-0.1, 15}, {0.03, 15}}]}, {
         Directive[
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          Thickness[Large]], 
         Line[{{-0.1, 14.5}, {-0.1, 15.5}}]}, {
         Directive[
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          Thickness[Large]], 
         Line[{{0.03, 14.5}, {0.03, 15.5}}]}}, AxesLabel -> {None, None}, 
      AspectRatio -> GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0., 0.}, 
      Method -> {}, PlotRange -> {All, All}, PlotRangeClipping -> True, 
      PlotRangePadding -> {Automatic, Automatic}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          Hue[0.67, 0.6, 0.6], 
          Thickness[Large], 
          Dashing[{Small, Small}]]}, {
         Style["1-step approx.", 12, FontFamily -> "Helvetica"]}, 
        LegendLayout -> "Column"]], 
      Scaled[{0.1875, 
        Rational[1, 2]}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.77126290269053*^9, 3.7712631403483553`*^9, {3.771523188832201*^9, 
   3.771523316538505*^9}, {3.7715233586600723`*^9, 3.771523429185876*^9}, {
   3.771523496960186*^9, 3.7715235085268383`*^9}, 3.771523577163733*^9, 
   3.771523635374526*^9, 3.771524212882955*^9, {3.771524343265089*^9, 
   3.7715243538024197`*^9}, 3.771524455026264*^9, 3.771524499563287*^9, {
   3.771524550935479*^9, 3.771524565294944*^9}, {3.7715456474245777`*^9, 
   3.771545652894565*^9}, 3.7715456872691793`*^9, 3.7715457296385317`*^9, 
   3.771545793052265*^9, 3.7715458322363873`*^9, 3.771545952552939*^9, 
   3.771609692807869*^9, 3.771609744274592*^9, 3.771609790776779*^9, 
   3.771610029248679*^9, 3.7716100920075207`*^9, 3.771610139764802*^9, 
   3.7716102306194897`*^9, 3.782258673633251*^9, 3.782258710233138*^9, 
   3.782258760379017*^9, 3.7849021433778667`*^9, 3.784902174226256*^9, 
   3.7849034477043657`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", "random", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        RowBox[{"fm", "[", 
         RowBox[{"m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "xmin", ",", "xmax", ",", "0.01"}], "}"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"(*", "established", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"fm", "[", 
           RowBox[{
           "m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], "]"}], 
          RowBox[{"pest", "[", 
           RowBox[{"m2", "-", "mwt"}], "]"}]}], 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"fm", "[", 
             RowBox[{
             "m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
             "]"}], 
            RowBox[{"pest", "[", 
             RowBox[{"m2", "-", "mwt"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"m2", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "mwt", ",", "xmax", ",", "0.01"}], "}"}]}], "]"}]}],
    "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Gray", ",", "Dashed"}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Gray"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"1", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        RowBox[{"g1m", "/.", 
         RowBox[{"m", "\[Rule]", "m2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "0", ",", "xmax", ",", "0.005"}], "}"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"2", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"total", "=", 
      RowBox[{"Re", "[", 
       RowBox[{"g2denominator", "[", "mwt", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"m2", ",", 
         RowBox[{
          FractionBox["1", "total"], 
          RowBox[{"g2numerator", "[", 
           RowBox[{"mwt", ",", "m2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "xmax", ",", "0.005"}], "}"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"g1mApp", "/.", 
       RowBox[{"\[Alpha]", "\[Rule]", 
        RowBox[{
         SuperscriptBox["\[Psi]wt", "2"], 
         RowBox[{"\[Rho]max", "/", "4"}]}]}]}], "/.", 
      RowBox[{"\[Rho]max", "\[Rule]", 
       RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
     RowBox[{"\[Theta]", "\[Rule]", 
      RowBox[{"n", "/", "2"}]}]}], "/.", 
    RowBox[{"\[Psi]wt", "\[Rule]", 
     RowBox[{"2", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SqrtBox[
         RowBox[{"1", "-", 
          FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}], "/.", 
   RowBox[{"\[Psi]", "\[Rule]", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["m", "mmax"]}]]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"onestepapp", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "0", ",", "xmax"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Dashed"}], "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "datadir", "<>", 
     "\"\<dfe_poisson_N10000_n4_U0.00200_Es0.01_mmax0.50_mwt-0.20_mutmax10_\
nreps100000.csv\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"onestep", "=", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"dat", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], "&"}]}], "]"}], 
    "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"twostep", "=", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"dat", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
    "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Histogram", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"onestep", ",", "twostep"}], "}"}], ",", "50", ",", 
      "\"\<PDF\>\"", ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fig6b", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
    "oldtheory", ",", "data", ",", "theory", ",", "onestepapp", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontColor", "\[Rule]", "White"}], ",", "Automatic", ",", 
        "Automatic", ",", "Automatic"}], "}"}]}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<\!\(\*SubscriptBox[\(m\), \(0\)]\)=\>\"", "<>", 
             RowBox[{"ToString", "[", "mwt", "]"}]}], ",", "12", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"7", "/", "8"}], ",", 
             RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<B\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{"Gray", ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"mwt", ",", "10"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.125"}], ",", "10"}], "}"}]}], "}"}], "]"}]}], 
         "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{"Gray", ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"mwt", ",", "9.5"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"mwt", ",", "10.5"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{"Gray", ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.125"}], ",", "9.5"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.125"}], ",", "10.5"}], "}"}]}], "}"}], "]"}]}],
          "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{
            RowBox[{"defaultcolors", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"mwt", ",", "20"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.023", ",", "20"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{
            RowBox[{"defaultcolors", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"mwt", ",", 
               RowBox[{"20", "-", "0.5"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"mwt", ",", 
               RowBox[{"20", "+", "0.5"}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{
            RowBox[{"defaultcolors", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0.023", ",", 
               RowBox[{"20", "-", "0.5"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.023", ",", 
               RowBox[{"20", "+", "0.5"}]}], "}"}]}], "}"}], "]"}]}], "}"}]}],
        "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.751575679958344*^9, 3.751575707856783*^9}, {
   3.751575756450697*^9, 3.7515757716167583`*^9}, {3.751575806118587*^9, 
   3.751575998358532*^9}, {3.7515761122033863`*^9, 3.751576131258815*^9}, {
   3.751576172283361*^9, 3.751576174879533*^9}, {3.7515762580970592`*^9, 
   3.751576326479478*^9}, {3.7515763695777597`*^9, 3.751576370332637*^9}, {
   3.7515764174224873`*^9, 3.751576419272636*^9}, {3.751577234452231*^9, 
   3.751577234571393*^9}, {3.751598119440303*^9, 3.7515981249463587`*^9}, 
   3.751650792683756*^9, {3.751650847039688*^9, 3.751650935724555*^9}, {
   3.751651020576578*^9, 3.751651024456732*^9}, {3.7516511744217253`*^9, 
   3.751651271292901*^9}, {3.7516514431359167`*^9, 3.751651596903675*^9}, {
   3.75165167006041*^9, 3.7516517016743317`*^9}, {3.751651837998188*^9, 
   3.751651848660565*^9}, {3.751651901804051*^9, 3.751651938743773*^9}, {
   3.75165209054011*^9, 3.751652092941709*^9}, {3.751654667780588*^9, 
   3.751654726734174*^9}, {3.751654761368635*^9, 3.751654832140562*^9}, {
   3.751654888268785*^9, 3.7516548919393587`*^9}, 3.751656018745837*^9, {
   3.751656381036447*^9, 3.7516563882551813`*^9}, {3.7565000581145897`*^9, 
   3.7565001021945477`*^9}, {3.756500617190415*^9, 3.75650065699045*^9}, 
   3.75650069938904*^9, {3.756500741026494*^9, 3.756500755155011*^9}, {
   3.756501221346011*^9, 3.75650122389799*^9}, 3.756502363067445*^9, 
   3.756502628112669*^9, 3.7565026817972727`*^9, {3.756503286102932*^9, 
   3.756503290049591*^9}, 3.756503323237875*^9, {3.756503496903769*^9, 
   3.75650353646167*^9}, {3.7565038167736483`*^9, 3.756503833330291*^9}, {
   3.7565038702319183`*^9, 3.7565038987244377`*^9}, {3.7565039623685904`*^9, 
   3.7565039995283422`*^9}, 3.756511754548572*^9, 3.756511866105935*^9, {
   3.756511901000861*^9, 3.756511903883478*^9}, {3.7565119526094627`*^9, 
   3.756511957815688*^9}, {3.756512664854374*^9, 3.756512670495578*^9}, {
   3.7565186714828672`*^9, 3.756518674830636*^9}, {3.756518724785604*^9, 
   3.7565187318397303`*^9}, {3.756518775324299*^9, 3.75651877705446*^9}, {
   3.756518831207197*^9, 3.756518836010257*^9}, {3.7565191876130047`*^9, 
   3.7565192273750753`*^9}, 3.756557317943141*^9, 3.756565191609994*^9, {
   3.756565226853438*^9, 3.756565227347921*^9}, {3.756565372407086*^9, 
   3.756565372554656*^9}, {3.7642581275023746`*^9, 3.764258130547591*^9}, {
   3.764258191591094*^9, 3.7642582094474382`*^9}, 3.769438935312201*^9, {
   3.769440382123701*^9, 3.769440472454721*^9}, 3.769440550032837*^9, {
   3.769440597811926*^9, 3.76944060297188*^9}, {3.769440831103504*^9, 
   3.769440912756571*^9}, {3.769440959415164*^9, 3.769440994826437*^9}, {
   3.769441059064315*^9, 3.769441091058297*^9}, {3.769441130350876*^9, 
   3.76944116439666*^9}, {3.7694411991785088`*^9, 3.7694412021516743`*^9}, 
   3.76996874883585*^9, 3.769968810893046*^9, {3.771262388292754*^9, 
   3.771262479562519*^9}, {3.771262525425778*^9, 3.771262540854212*^9}, {
   3.771262571282227*^9, 3.771262676392552*^9}, 3.771262708817911*^9, {
   3.771262787550537*^9, 3.77126278925319*^9}, {3.771262829817032*^9, 
   3.771262838787562*^9}, {3.771262886757546*^9, 3.7712629040416183`*^9}, 
   3.771263001498148*^9, {3.7712630472762423`*^9, 3.7712630824252787`*^9}, 
   3.7712632766794453`*^9, {3.771523654909391*^9, 3.771523717281061*^9}, {
   3.771523767763907*^9, 3.771523863711122*^9}, {3.771524143434939*^9, 
   3.771524146712611*^9}, 3.771524181712408*^9, {3.771524610006549*^9, 
   3.771524614342845*^9}, 3.771524684688016*^9, {3.771524787074443*^9, 
   3.771524787442294*^9}, 3.771524831257451*^9, 3.7715250445794687`*^9, 
   3.7715459403767967`*^9, {3.771610187981874*^9, 3.771610217885456*^9}, 
   3.771610262237557*^9, 3.782258748129232*^9, {3.784902188392308*^9, 
   3.784902193229968*^9}, 3.784903427590049*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "izero"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Integral and error estimates are 0 on all integration \
subregions. Try increasing the value of the MinRecursion option. If value of \
integral may be 0, specify a finite value for the AccuracyGoal option. \\!\\(\
\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/NIntegrate\\\", ButtonNote -> \
\\\"NIntegrate::izero\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.771524161040945*^9, 3.771524627858238*^9, {3.771524817718388*^9, 
   3.7715248458514633`*^9}, 3.7716102420767117`*^9, 3.782258773285884*^9, 
   3.7849022049233723`*^9, 3.784903458133173*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
      LineBox[CompressedData["
1:eJw1U21Ik1EUfqdiqUPnFBTNsqwMlRRWIoHvuYjlEHJ+gQbLytJ+zEoTSoZo
ZoqaaYmKlZTk8hOnUyOz2N10pebXloZmBClaMHOk2/xupO99PXC5HM69z/Oc
c597OPlWbIoVRVEhO2t3FzAxgW1d3QarT9ug8j7zCXH5FzyiLTVYhmzRYkzP
wYJFHRbkxiznX7NDwlmpqzxCh515dusZRgckSw+1n6rX4iZnQav7VUdEMaHF
hVaXzkaJeGj3dkzPGLa+H+eVI3RGzPH0Ufy9ukvj5cJHO2Q7jCPYPUptETXw
EQM/+xmP1d3gGjf56CkTQ7j16KaNH9cFxTKAg3hJrU0bmOKjXbRQ+wFcGTQS
9SiJjxj5fR9xCL8s+YzMGTFwUg0OTlAlXG7nIdJvP+a4xWfY8Z3Y/tQYPyx/
czyLi+oZgSpsaIypEjfbsfqV2L9f2vVVacvq/YDzTTdHPXTWqIbR9w5fUFyU
t6xSrJ63uMwUxntVsA2EvxvPm08WvS5eAz3Dp8CPF5s81x2NQPDlOHHCVB0e
bgCC14wLkxqdkst+QxZzX4ajRNIchXkWOpjzL7BTWmP43PgMpDP1Snw941hL
QNUE3GPyB1jvSJW0rQ8Dxca2rlAiKejfq4NStt+j5Hkvm1eC5sB4rkqhABXB
h5cp3T/jVxrYugx4831F8/9qoY7og/AZfadx4smefjCvrkQuxBbAH9IfSD5N
hq4OZEE26R96fM+LNowS4JL5gIPWR5JWkQS1ZH6wL5CKNAVFQwCZL4iP8Np+
VSMWXwmpjWF/OyRBQPymgpq7Y8Up4kMsnxo4KI8j+saFU+R9wbPeohcWbtCE
XwNmLDwX2L5Aa4g/oDZwstOlSUez/oEteTR1J+89zfoLyuLMgopMGf2M+A+c
/FNFgrVSeo74E65M/1g2ZmfSfsS/4G0R1ixNJ9K3ib/B4DMwHGEIpXuJ/0FV
u9Xiu+lNc8j/gOBti5LjYkX/B/QNtns=
       "]]}, 
     {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8HntgvvNJtOveCP/bc1xcX
2HId3192c0Ke+kJuh8NfNWL6Dx3dfyXoXW36FmGHapF17g+rjuyfqxPTsHKW
hIOJMQgc3r//wVGFJ1EyDm8CQQYe3G9xyZGj8r6cwxKgadcXH9i/Kjvnp4mw
gsNOkHU79u3Pddm60khBwUELaPpXjT37l4YH37L1k3eAuG/n/uz/E5WUamUd
IO7Zvl+/T3EFN5O0Qw3Y/i37+bPDPr0RkYDat3H/IvUZq1XeiDiAvbNj3f64
/wsql+8QdJgDNm/l/oYY5muJbrxQ/Uv2z1KvWug6lR2qft7+6h7BCsV2JocG
sPyU/fMSrx9yTf5jD+G37JcomNEdZfzVHhZuTvM7Sr7efmdfAJG3/5QV5rPg
wVP7Coh++yzDSe49xvfsoebbd8jejbzncQUqv8Re/19bR0j9KfsZEPfZd7T8
a4u8eACqfp39Ou3NK4/s2mIP9Z/9H33GeRanVthD/W+vctFNq27PHHsOSPjY
O/wt+/BLYQLUvJ32eQGsB9Y0N9prQMLXfocH59uZCUVQ8/fZ1/Rf2SI2J8ke
Gj/2fy+lH7qoGQS176D91c0ny77zO9pD49eeU/bA59xzevZVkPi3X3Zhr/3h
dVL2hyDpw9765rtZuUps9lyQ9GOfdmivbmLvRzto+rJnVWr7YNJ3yw6a/ux7
X01jeCB32O4R2MBT9jWbWO79UFllB3HvGXulr+tt3N9OsAM7r+Cs/T/2VZFB
m0rsIO4/Z++XnjPlwcVwO0hsXLDfvrRkB+d2SzsAfQxhnA==
       "]]}}, {}}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.371]], {{}, 
     {RGBColor[0.24720000000000014`, 0.24, 0.6], Opacity[0.5], EdgeForm[
      Opacity[0.371]], 
      RectangleBox[{0., 0.}, 
       NCache[{0.005, Rational[2520, 241]}, {0.005, 10.45643153526971}],
       RoundingRadius->0], 
      RectangleBox[{0.005, 0.}, 
       NCache[{0.01, Rational[3800, 241]}, {0.01, 15.767634854771785`}],
       RoundingRadius->0], 
      RectangleBox[{0.01, 0.}, 
       NCache[{0.015, Rational[4040, 241]}, {0.015, 16.763485477178424`}],
       RoundingRadius->0], 
      RectangleBox[{0.015, 0.}, 
       NCache[{0.02, Rational[4200, 241]}, {0.02, 17.42738589211618}],
       RoundingRadius->0], 
      RectangleBox[{0.02, 0.}, 
       NCache[{0.025, Rational[3920, 241]}, {0.025, 16.265560165975103`}],
       RoundingRadius->0], 
      RectangleBox[{0.025, 0.}, 
       NCache[{0.03, Rational[4480, 241]}, {0.03, 18.589211618257263`}],
       RoundingRadius->0], 
      RectangleBox[{0.03, 0.}, 
       NCache[{0.035, Rational[4160, 241]}, {0.035, 17.261410788381742`}],
       RoundingRadius->0], 
      RectangleBox[{0.035, 0.}, 
       NCache[{0.04, Rational[3520, 241]}, {0.04, 14.605809128630705`}],
       RoundingRadius->0], 
      RectangleBox[{0.04, 0.}, 
       NCache[{0.045, Rational[2800, 241]}, {0.045, 11.618257261410788`}],
       RoundingRadius->0], 
      RectangleBox[{0.045, 0.}, 
       NCache[{0.05, Rational[3240, 241]}, {0.05, 13.443983402489627`}],
       RoundingRadius->0], 
      RectangleBox[{0.05, 0.}, 
       NCache[{0.055, Rational[2160, 241]}, {0.055, 8.962655601659751}],
       RoundingRadius->0], 
      RectangleBox[{0.055, 0.}, 
       NCache[{0.06, Rational[1080, 241]}, {0.06, 4.481327800829876}],
       RoundingRadius->0], 
      RectangleBox[{0.06, 0.}, 
       NCache[{0.065, Rational[1880, 241]}, {0.065, 7.800829875518672}],
       RoundingRadius->0], 
      RectangleBox[{0.065, 0.}, 
       NCache[{0.07, Rational[1360, 241]}, {0.07, 5.643153526970955}],
       RoundingRadius->0], 
      RectangleBox[{0.07, 0.}, 
       NCache[{0.075, Rational[1240, 241]}, {0.075, 5.145228215767635}],
       RoundingRadius->0], 
      RectangleBox[{0.075, 0.}, 
       NCache[{0.08, Rational[760, 241]}, {0.08, 3.1535269709543567`}],
       RoundingRadius->0], 
      RectangleBox[{0.08, 0.}, 
       NCache[{0.085, Rational[640, 241]}, {0.085, 2.6556016597510372`}],
       RoundingRadius->0], 
      RectangleBox[{0.085, 0.}, 
       NCache[{0.09, Rational[600, 241]}, {0.09, 2.4896265560165975`}],
       RoundingRadius->0], 
      RectangleBox[{0.09, 0.}, 
       NCache[{0.095, Rational[720, 241]}, {0.095, 2.987551867219917}],
       RoundingRadius->0], 
      RectangleBox[{0.095, 0.}, 
       NCache[{0.1, Rational[400, 241]}, {0.1, 1.6597510373443984`}],
       RoundingRadius->0], 
      RectangleBox[{0.1, 0.}, 
       NCache[{0.105, Rational[200, 241]}, {0.105, 0.8298755186721992}],
       RoundingRadius->0], 
      RectangleBox[{0.105, 0.}, 
       NCache[{0.11, Rational[80, 241]}, {0.11, 0.33195020746887965`}],
       RoundingRadius->0], 
      RectangleBox[{0.11, 0.}, 
       NCache[{0.115, Rational[120, 241]}, {0.115, 0.4979253112033195}],
       RoundingRadius->0], 
      RectangleBox[{0.115, 0.}, 
       NCache[{0.12, Rational[120, 241]}, {0.12, 0.4979253112033195}],
       RoundingRadius->0], RectangleBox[{0.12, 0.}, {0.125, 0},
       RoundingRadius->0], RectangleBox[{0.125, 0.}, {0.13, 0},
       RoundingRadius->0], 
      RectangleBox[{0.13, 0.}, 
       NCache[{0.135, Rational[80, 241]}, {0.135, 0.33195020746887965`}],
       RoundingRadius->0], RectangleBox[{0.135, 0.}, {0.14, 0},
       RoundingRadius->0], RectangleBox[{0.14, 0.}, {0.145, 0},
       RoundingRadius->0], RectangleBox[{0.145, 0.}, {0.15, 0},
       RoundingRadius->0], RectangleBox[{0.15, 0.}, {0.155, 0},
       RoundingRadius->0], RectangleBox[{0.155, 0.}, {0.16, 0},
       RoundingRadius->0], RectangleBox[{0.16, 0.}, {0.165, 0},
       RoundingRadius->0], 
      RectangleBox[{0.165, 0.}, 
       NCache[{0.17, Rational[40, 241]}, {0.17, 0.16597510373443983`}],
       RoundingRadius->0], RectangleBox[{0.17, 0.}, {0.175, 0},
       RoundingRadius->0], RectangleBox[{0.175, 0.}, {0.18, 0},
       RoundingRadius->0], 
      RectangleBox[{0.18, 0.}, 
       NCache[{0.185, Rational[40, 241]}, {0.185, 0.16597510373443983`}],
       RoundingRadius->0], RectangleBox[{0.185, 0.}, {0.19, 0},
       RoundingRadius->0], RectangleBox[{0.19, 0.}, {0.195, 0},
       RoundingRadius->0], RectangleBox[{0.195, 0.}, {0.2, 0},
       RoundingRadius->0], RectangleBox[{0.2, 0.}, {0.205, 0},
       RoundingRadius->0], RectangleBox[{0.205, 0.}, {0.21, 0},
       RoundingRadius->0], RectangleBox[{0.21, 0.}, {0.215, 0},
       RoundingRadius->0], RectangleBox[{0.215, 0.}, {0.22, 0},
       RoundingRadius->0], RectangleBox[{0.22, 0.}, {0.225, 0},
       RoundingRadius->0], RectangleBox[{0.225, 0.}, {0.23, 0},
       RoundingRadius->0], RectangleBox[{0.23, 0.}, {0.235, 0},
       RoundingRadius->0]}, {}, {}}, {{}, 
     {RGBColor[0.6, 0.24, 0.4428931686004542], Opacity[0.5], EdgeForm[Opacity[
      0.371]], RectangleBox[{0., 0.}, 
       NCache[{0.005, Rational[100, 59]}, {0.005, 1.694915254237288}],
       RoundingRadius->0], 
      RectangleBox[{0.005, 0.}, 
       NCache[{0.01, Rational[50, 59]}, {0.01, 0.847457627118644}],
       RoundingRadius->0], 
      RectangleBox[{0.01, 0.}, 
       NCache[{0.015, Rational[550, 177]}, {0.015, 3.1073446327683616`}],
       RoundingRadius->0], 
      RectangleBox[{0.015, 0.}, 
       NCache[{0.02, Rational[1000, 177]}, {0.02, 5.649717514124294}],
       RoundingRadius->0], 
      RectangleBox[{0.02, 0.}, 
       NCache[{0.025, Rational[350, 59]}, {0.025, 5.932203389830509}],
       RoundingRadius->0], 
      RectangleBox[{0.025, 0.}, 
       NCache[{0.03, Rational[450, 59]}, {0.03, 7.627118644067797}],
       RoundingRadius->0], 
      RectangleBox[{0.03, 0.}, 
       NCache[{0.035, Rational[1450, 177]}, {0.035, 8.192090395480227}],
       RoundingRadius->0], 
      RectangleBox[{0.035, 0.}, 
       NCache[{0.04, Rational[1150, 177]}, {0.04, 6.497175141242938}],
       RoundingRadius->0], 
      RectangleBox[{0.04, 0.}, 
       NCache[{0.045, Rational[1400, 177]}, {0.045, 7.909604519774011}],
       RoundingRadius->0], 
      RectangleBox[{0.045, 0.}, 
       NCache[{0.05, Rational[1450, 177]}, {0.05, 8.192090395480227}],
       RoundingRadius->0], 
      RectangleBox[{0.05, 0.}, 
       NCache[{0.055, Rational[1900, 177]}, {0.055, 10.734463276836157`}],
       RoundingRadius->0], 
      RectangleBox[{0.055, 0.}, 
       NCache[{0.06, Rational[1550, 177]}, {0.06, 8.757062146892656}],
       RoundingRadius->0], 
      RectangleBox[{0.06, 0.}, 
       NCache[{0.065, Rational[1900, 177]}, {0.065, 10.734463276836157`}],
       RoundingRadius->0], 
      RectangleBox[{0.065, 0.}, 
       NCache[{0.07, Rational[1600, 177]}, {0.07, 9.03954802259887}],
       RoundingRadius->0], 
      RectangleBox[{0.07, 0.}, 
       NCache[{0.075, Rational[450, 59]}, {0.075, 7.627118644067797}],
       RoundingRadius->0], 
      RectangleBox[{0.075, 0.}, 
       NCache[{0.08, Rational[1550, 177]}, {0.08, 8.757062146892656}],
       RoundingRadius->0], 
      RectangleBox[{0.08, 0.}, 
       NCache[{0.085, Rational[700, 59]}, {0.085, 11.864406779661017`}],
       RoundingRadius->0], 
      RectangleBox[{0.085, 0.}, 
       NCache[{0.09, Rational[1300, 177]}, {0.09, 7.344632768361582}],
       RoundingRadius->0], 
      RectangleBox[{0.09, 0.}, 
       NCache[{0.095, Rational[1250, 177]}, {0.095, 7.062146892655368}],
       RoundingRadius->0], 
      RectangleBox[{0.095, 0.}, 
       NCache[{0.1, Rational[1450, 177]}, {0.1, 8.192090395480227}],
       RoundingRadius->0], 
      RectangleBox[{0.1, 0.}, 
       NCache[{0.105, Rational[350, 59]}, {0.105, 5.932203389830509}],
       RoundingRadius->0], 
      RectangleBox[{0.105, 0.}, 
       NCache[{0.11, Rational[1400, 177]}, {0.11, 7.909604519774011}],
       RoundingRadius->0], 
      RectangleBox[{0.11, 0.}, 
       NCache[{0.115, Rational[350, 59]}, {0.115, 5.932203389830509}],
       RoundingRadius->0], 
      RectangleBox[{0.115, 0.}, 
       NCache[{0.12, Rational[1000, 177]}, {0.12, 5.649717514124294}],
       RoundingRadius->0], 
      RectangleBox[{0.12, 0.}, 
       NCache[{0.125, Rational[250, 59]}, {0.125, 4.237288135593221}],
       RoundingRadius->0], 
      RectangleBox[{0.125, 0.}, 
       NCache[{0.13, Rational[650, 177]}, {0.13, 3.672316384180791}],
       RoundingRadius->0], 
      RectangleBox[{0.13, 0.}, 
       NCache[{0.135, Rational[250, 59]}, {0.135, 4.237288135593221}],
       RoundingRadius->0], 
      RectangleBox[{0.135, 0.}, 
       NCache[{0.14, Rational[150, 59]}, {0.14, 2.542372881355932}],
       RoundingRadius->0], 
      RectangleBox[{0.14, 0.}, 
       NCache[{0.145, Rational[550, 177]}, {0.145, 3.1073446327683616`}],
       RoundingRadius->0], 
      RectangleBox[{0.145, 0.}, 
       NCache[{0.15, Rational[200, 177]}, {0.15, 1.1299435028248588`}],
       RoundingRadius->0], 
      RectangleBox[{0.15, 0.}, 
       NCache[{0.155, Rational[100, 59]}, {0.155, 1.694915254237288}],
       RoundingRadius->0], 
      RectangleBox[{0.155, 0.}, 
       NCache[{0.16, Rational[150, 59]}, {0.16, 2.542372881355932}],
       RoundingRadius->0], 
      RectangleBox[{0.16, 0.}, 
       NCache[{0.165, Rational[250, 177]}, {0.165, 1.4124293785310735`}],
       RoundingRadius->0], RectangleBox[{0.165, 0.}, {0.17, 0},
       RoundingRadius->0], 
      RectangleBox[{0.17, 0.}, 
       NCache[{0.175, Rational[100, 177]}, {0.175, 0.5649717514124294}],
       RoundingRadius->0], 
      RectangleBox[{0.175, 0.}, 
       NCache[{0.18, Rational[200, 177]}, {0.18, 1.1299435028248588`}],
       RoundingRadius->0], 
      RectangleBox[{0.18, 0.}, 
       NCache[{0.185, Rational[100, 177]}, {0.185, 0.5649717514124294}],
       RoundingRadius->0], 
      RectangleBox[{0.185, 0.}, 
       NCache[{0.19, Rational[100, 177]}, {0.19, 0.5649717514124294}],
       RoundingRadius->0], 
      RectangleBox[{0.19, 0.}, 
       NCache[{0.195, Rational[50, 177]}, {0.195, 0.2824858757062147}],
       RoundingRadius->0], RectangleBox[{0.195, 0.}, {0.2, 0},
       RoundingRadius->0], RectangleBox[{0.2, 0.}, {0.205, 0},
       RoundingRadius->0], RectangleBox[{0.205, 0.}, {0.21, 0},
       RoundingRadius->0], 
      RectangleBox[{0.21, 0.}, 
       NCache[{0.215, Rational[50, 177]}, {0.215, 0.2824858757062147}],
       RoundingRadius->0], 
      RectangleBox[{0.215, 0.}, 
       NCache[{0.22, Rational[50, 177]}, {0.22, 0.2824858757062147}],
       RoundingRadius->0], 
      RectangleBox[{0.22, 0.}, 
       NCache[{0.225, Rational[50, 177]}, {0.225, 0.2824858757062147}],
       RoundingRadius->0], RectangleBox[{0.225, 0.}, {0.23, 0},
       RoundingRadius->0], 
      RectangleBox[{0.23, 0.}, 
       NCache[{0.235, Rational[50, 177]}, {0.235, 0.2824858757062147}],
       RoundingRadius->0]}, {}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
      LineBox[CompressedData["
1:eJxdUVtIk1EAnpJSloK0YVM2FcFcZuYVKfq/H31QQwMNowfFMtwoQy0mkXvQ
ahYZJpRrKC4QRY3KNPOyoenuNnVTcW5WmJM0pwmh2IUU23956oPD4dy+2wkv
Ksst9uZwOAmeQc3/Q8btSndVSrEnEXOmY8JJZi2HXe1fmhRxnBwU1qznDD6G
XHR17kJMHHvegJUAYablfjzZ1EgD/auiuLuqePb+czzolT4pc8SR33OonRYk
Z9VHF8pPsu/bQPgEFTfqYkg/R2v5Gb8OzMrGu3eTj7F8LxDMX9YMt0eSovx6
3XbUK9wZU676EhEsfxc2hJ+D5o6EkW2e147WbugywwSKumBWrwcFsvMydTOP
TKDRi/lvda0+hYGs/jsYo7NMpPIgqd+O8ij0oU2ZtiLr9GH9DKDqmUGZbeOQ
uYwgZgT2tQzrHzD+1LAVqQSTyi24KilCDWyKJF5L6QYYv0NQrG5NWRaWcYOy
Vz6Mm5H7zTzuIhi699CoRxSGKw4wvzCKXXFaint2CkyeURxVzeal/jIjgxbQ
4uKnkIKlxVEw+bTYc740npAPgFLzSIJf/SjQK7EbTF49DlvXOxa47aDjOPSQ
ud8OSbUqMPkNMO3r74ydeYpQyo7QiFqisz07uBZMH0ZElw/eVu1UQyKmYEJs
2ZuJFmcFmH7MUE2LUpq1JaDYuF1mrI8H/pZcuwymrzH8CLrH6WnIw0+KbnsM
pS5NqFR8lu3vA5Yepic6vwAETWiBNyFITt2JZ/u0wLkbeujvuUjQ9mrGsenl
8gqf57P9TsB9QLU6UuOPyQka8Otv0vuqOGzfk8iXVFUElGwSPNqgFby+Wzpu
yFeC6d8KvWHNdLrJTtB0+TacMqv5H+0mgvmPKVx/fcltHxog/gFkeX7y
       "]]}, 
     {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
      LineBox[CompressedData["
1:eJxdUXss1HEAR6Mlz0MRzuNSZCvrVsuUz3cmjzXVUaGd1dWwYvPeRI3FmVpI
649okWO5Lt3cEuftnLfjStoVTXNNVtRoo2TU/R7902f77rvv6/P6elxKiYw3
MTIy4hsGNf+PXHt56GxOJrKEosvTmaaEWRei5MNVaYuCQ5Rc8YJAWYpb3kmu
vcuO7Pl99FncEedqXEllBQ2oRn3LdO3u7P0qCJJEh6asPMmigNqpgbwozI4s
e7Lv6zDOSzk4lc4j5rra1GPm9ciPXLTR1vBYvqeI3dNm/fE2j/gIy3pXvBsw
Gay9UOLPY/nlmJK4+AUoPUmd4bWuthFbfYcnAmz+6SmQRThRc+EehE/jBfqc
iqOrk91Z/SbMmXo90m9wiXrF26DwEpmbN9+7W7qyflqQX38+YdrGmUQyghjg
/PIttnVi/bXiYnxxasSOnWQ2hyJsw+KJNAHXy4H124ECjtBEF2RH0ih7qZ2Q
m+wti8mwZf13ISRcpgzNsCbML/SA+1YaOn/Ags3TA+F6okjmto2E0QIqbDef
PJ4XbMbmU8H57m7HqOothFIzSGLm9NINfz9jNq8aJudidO7fNkDH0alx5jd3
Hfo1MPn7IJKlP08+ugo3yg63H62yfcj7+QNMH/244vi4u8lqCYkJFAZwUvs6
WrL2FUw/g2h3+h6Rnf0ZFJu9fBAVRwrN+KV6MH0NIe5wiP31uBmsUnQrQ1BM
KPolD9+B6W8Yw+vlKn7XGwTShCMItfsjEMdqwfQ5gkCXhW591RBoe+JRnNqV
1yzmqsH0q8E1rajoWWwnxjQ00PaE9+BsUDOYvsewWWbZUdDQCAfa4DjmS6pk
QTIpmP7HUb7f58uYsQQ0nVCLeDNNlHS5Asx/vILVp1KbypR7+AuX5nEj
       
       "]]}}, {}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], Thickness[Large], Dashing[{Small, Small}], 
     LineBox[CompressedData["
1:eJwVl3k0ld8XxpEiZI4MhVDIcG9Jke7zCqlQIhkSkhJNSIWSSpR5niVTKhlK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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"\\!\\(\\*SubscriptBox[\\(m\\), \\(0\\)]\\)=-0.2\"", 12, FontFamily -> 
       "Helvetica", StripOnInput -> False], TraditionalForm], 
     NCache[
      Scaled[{
        Rational[7, 8], 
        Rational[3, 4]}], 
      Scaled[{0.875, 0.75}]]], 
    InsetBox[
     FormBox[
      StyleBox[
      "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
      TraditionalForm], 
     Scaled[{0.05, 0.95}]], {
     Directive[
      GrayLevel[0.5], 
      Thickness[Large]], 
     LineBox[{{-0.2, 10}, {-0.125, 10}}]}, {
     Directive[
      GrayLevel[0.5], 
      Thickness[Large]], 
     LineBox[{{-0.2, 9.5}, {-0.2, 10.5}}]}, {
     Directive[
      GrayLevel[0.5], 
      Thickness[Large]], 
     LineBox[{{-0.125, 9.5}, {-0.125, 10.5}}]}, {
     Directive[
      RGBColor[0.24720000000000014`, 0.24, 0.6], 
      Thickness[Large]], 
     LineBox[{{-0.2, 20}, {0.023, 20}}]}, {
     Directive[
      RGBColor[0.24720000000000014`, 0.24, 0.6], 
      Thickness[Large]], 
     LineBox[{{-0.2, 19.5}, {-0.2, 20.5}}]}, {
     Directive[
      RGBColor[0.24720000000000014`, 0.24, 0.6], 
      Thickness[Large]], 
     LineBox[{{0.023, 19.5}, {0.023, 20.5}}]}},
  Frame->{True, False, False, False},
  FrameTicksStyle->{
   FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{-0.3, 0.25}, {0, 28}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.769440943507813*^9, 3.769440996995473*^9}, {
   3.769441060072113*^9, 3.769441094285623*^9}, 3.7694411428106737`*^9, 
   3.769441188775669*^9, 3.7699687716085443`*^9, 3.771262486432934*^9, 
   3.771262527415967*^9, 3.77126257467249*^9, {3.771262657482053*^9, 
   3.771262678404565*^9}, 3.77126271054572*^9, 3.771262776998979*^9, 
   3.771262839801453*^9, 3.771262933566534*^9, 3.7712630296244917`*^9, 
   3.771263111342054*^9, 3.7715237550248127`*^9, {3.771523794607482*^9, 
   3.771523853556178*^9}, 3.771524179576941*^9, 3.7715246466803093`*^9, 
   3.77152481765935*^9, 3.771524863968569*^9, 3.771610256443774*^9, 
   3.782258789357695*^9, 3.784902219872904*^9, 3.78490347253898*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.3"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", "random", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        RowBox[{"fm", "[", 
         RowBox[{"m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "xmin", ",", "xmax", ",", "0.01"}], "}"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"(*", "established", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"fm", "[", 
           RowBox[{
           "m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], "]"}], 
          RowBox[{"pest", "[", 
           RowBox[{"m2", "-", "mwt"}], "]"}]}], 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"fm", "[", 
             RowBox[{
             "m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
             "]"}], 
            RowBox[{"pest", "[", 
             RowBox[{"m2", "-", "mwt"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"m2", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "mwt", ",", "xmax", ",", "0.01"}], "}"}]}], "]"}]}],
    "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Gray", ",", "Dashed"}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Gray"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"1", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        RowBox[{"g1m", "/.", 
         RowBox[{"m", "\[Rule]", "m2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "0", ",", "xmax", ",", "0.005"}], "}"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"2", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"total", "=", 
      RowBox[{"Re", "[", 
       RowBox[{"g2denominator", "[", "mwt", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"m2", ",", 
         RowBox[{
          FractionBox["1", "total"], 
          RowBox[{"g2numerator", "[", 
           RowBox[{"mwt", ",", "m2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "xmax", ",", "0.005"}], "}"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"g1mApp", "/.", 
       RowBox[{"\[Alpha]", "\[Rule]", 
        RowBox[{
         SuperscriptBox["\[Psi]wt", "2"], 
         RowBox[{"\[Rho]max", "/", "4"}]}]}]}], "/.", 
      RowBox[{"\[Rho]max", "\[Rule]", 
       RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
     RowBox[{"\[Theta]", "\[Rule]", 
      RowBox[{"n", "/", "2"}]}]}], "/.", 
    RowBox[{"\[Psi]wt", "\[Rule]", 
     RowBox[{"2", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SqrtBox[
         RowBox[{"1", "-", 
          FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}], "/.", 
   RowBox[{"\[Psi]", "\[Rule]", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["m", "mmax"]}]]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"onestepapp", "=", 
    RowBox[{"Plot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "0", ",", "xmax"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Dashed"}], "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "datadir", "<>", 
     "\"\<dfe_poisson_N10000_n4_U0.00200_Es0.01_mmax0.50_mwt-0.30_mutmax10_\
nreps1000000.csv\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"onestep", "=", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"dat", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], "&"}]}], "]"}], 
    "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"twostep", "=", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"dat", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
    "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Histogram", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"onestep", ",", "twostep"}], "}"}], ",", "50", ",", 
      "\"\<PDF\>\"", ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fig6c", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
    "oldtheory", ",", "data", ",", "theory", ",", "onestepapp", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", "\"\<Growth rate\>\"", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<\!\(\*SubscriptBox[\(m\), \(0\)]\)=\>\"", "<>", 
             RowBox[{"ToString", "[", "mwt", "]"}]}], ",", "12", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"7", "/", "8"}], ",", 
             RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<C\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{"Gray", ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"mwt", ",", "10"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.22"}], ",", "10"}], "}"}]}], "}"}], "]"}]}], 
         "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{"Gray", ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"mwt", "+", "0.001"}], ",", "9.5"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"mwt", "+", "0.001"}], ",", "10.5"}], "}"}]}], "}"}], 
           "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{"Gray", ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.22"}], ",", "9.5"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "0.22"}], ",", "10.5"}], "}"}]}], "}"}], "]"}]}], 
         "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{
            RowBox[{"defaultcolors", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"mwt", ",", "25"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.015", ",", "25"}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{
            RowBox[{"defaultcolors", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"mwt", "+", "0.001"}], ",", 
               RowBox[{"25", "-", "0.5"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"mwt", "+", "0.001"}], ",", 
               RowBox[{"25", "+", "0.5"}]}], "}"}]}], "}"}], "]"}]}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{
            RowBox[{"defaultcolors", "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", "Thick"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0.015", ",", 
               RowBox[{"25", "-", "0.5"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.015", ",", 
               RowBox[{"25", "+", "0.5"}]}], "}"}]}], "}"}], "]"}]}], "}"}]}],
        "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.751575679958344*^9, 3.751575707856783*^9}, {
   3.751575756450697*^9, 3.7515757716167583`*^9}, {3.751575806118587*^9, 
   3.751575998358532*^9}, {3.7515761122033863`*^9, 3.751576131258815*^9}, {
   3.751576172283361*^9, 3.751576174879533*^9}, {3.7515762580970592`*^9, 
   3.751576326479478*^9}, {3.7515763695777597`*^9, 3.751576370332637*^9}, {
   3.7515764174224873`*^9, 3.751576419272636*^9}, {3.751577234452231*^9, 
   3.751577234571393*^9}, {3.751598119440303*^9, 3.7515981249463587`*^9}, 
   3.751650792683756*^9, {3.751650847039688*^9, 3.751650935724555*^9}, {
   3.751651020576578*^9, 3.751651024456732*^9}, {3.7516511744217253`*^9, 
   3.751651271292901*^9}, {3.7516514431359167`*^9, 3.751651596903675*^9}, {
   3.75165167006041*^9, 3.7516517016743317`*^9}, {3.751651837998188*^9, 
   3.751651848660565*^9}, {3.751651901804051*^9, 3.751651938743773*^9}, {
   3.75165209054011*^9, 3.751652092941709*^9}, {3.751654667780588*^9, 
   3.751654726734174*^9}, {3.751654761368635*^9, 3.751654832140562*^9}, {
   3.751654888268785*^9, 3.7516548919393587`*^9}, 3.751656018745837*^9, {
   3.751656381036447*^9, 3.7516563882551813`*^9}, {3.7565000581145897`*^9, 
   3.7565001021945477`*^9}, {3.756500617190415*^9, 3.75650065699045*^9}, 
   3.75650069938904*^9, {3.756500741026494*^9, 3.756500755155011*^9}, {
   3.756501221346011*^9, 3.75650122389799*^9}, 3.756502363067445*^9, 
   3.756502628112669*^9, 3.7565026817972727`*^9, {3.756503286102932*^9, 
   3.756503290049591*^9}, 3.756503323237875*^9, {3.756503496903769*^9, 
   3.75650353646167*^9}, {3.7565038167736483`*^9, 3.756503833330291*^9}, {
   3.7565038702319183`*^9, 3.7565038987244377`*^9}, {3.7565039623685904`*^9, 
   3.7565039995283422`*^9}, 3.756511754548572*^9, 3.756511866105935*^9, {
   3.756511901000861*^9, 3.756511903883478*^9}, {3.7565119526094627`*^9, 
   3.756511957815688*^9}, {3.756512664854374*^9, 3.756512670495578*^9}, {
   3.7565186714828672`*^9, 3.756518674830636*^9}, {3.756518724785604*^9, 
   3.7565187318397303`*^9}, {3.756518775324299*^9, 3.75651877705446*^9}, {
   3.756518831207197*^9, 3.756518836010257*^9}, {3.7565191876130047`*^9, 
   3.7565192273750753`*^9}, 3.756557317943141*^9, 3.756565191609994*^9, {
   3.756565226853438*^9, 3.756565227347921*^9}, {3.756565372407086*^9, 
   3.756565372554656*^9}, {3.7642581275023746`*^9, 3.764258130547591*^9}, {
   3.764258191591094*^9, 3.7642582094474382`*^9}, 3.769438935312201*^9, {
   3.769440382123701*^9, 3.769440472454721*^9}, 3.769440550032837*^9, {
   3.769440597811926*^9, 3.76944060297188*^9}, {3.769440831103504*^9, 
   3.769440912756571*^9}, {3.769440959415164*^9, 3.769440994826437*^9}, {
   3.769441059064315*^9, 3.769441091058297*^9}, {3.769441130350876*^9, 
   3.76944116439666*^9}, {3.7694411991785088`*^9, 3.7694412021516743`*^9}, 
   3.76996874883585*^9, 3.769968810893046*^9, {3.771262388292754*^9, 
   3.771262479562519*^9}, {3.771262525425778*^9, 3.771262540854212*^9}, {
   3.771262571282227*^9, 3.771262676392552*^9}, 3.771262708817911*^9, {
   3.771262787550537*^9, 3.77126278925319*^9}, {3.771262829817032*^9, 
   3.771262838787562*^9}, {3.771262886757546*^9, 3.7712629040416183`*^9}, {
   3.771262993953033*^9, 3.771263040572254*^9}, {3.771263132235148*^9, 
   3.771263132728526*^9}, 3.77126325155289*^9, 3.771263283102374*^9, {
   3.771523894904652*^9, 3.7715239610032177`*^9}, {3.771524017890419*^9, 
   3.771524041541985*^9}, {3.77152408040277*^9, 3.771524131872752*^9}, {
   3.771524701872202*^9, 3.771524827210793*^9}, {3.7715250108383627`*^9, 
   3.7715250393253717`*^9}, 3.771545946432982*^9, {3.7716102268827133`*^9, 
   3.771610236693431*^9}, 3.771610296515996*^9, 3.782258755370878*^9, {
   3.7849021974516497`*^9, 3.784902203105094*^9}, 3.784903432213937*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "izero"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Integral and error estimates are 0 on all integration \
subregions. Try increasing the value of the MinRecursion option. If value of \
integral may be 0, specify a finite value for the AccuracyGoal option. \\!\\(\
\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/NIntegrate\\\", ButtonNote -> \
\\\"NIntegrate::izero\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.771610279327977*^9, 3.782258801679686*^9, 
  3.784902230644465*^9, 3.784903482965461*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
      LineBox[CompressedData["
1:eJw1U2tIk1EY/jTzrmt4pSI1L6npnxQx7PveTypv4A8XoVSEZhKK4jQmsixN
p6aFmhpmecN5xy0lw7tnc9NUljm1lSnIEiOaJbOMipzpdz5fOBxe3nOe53nf
8xy3G+m8JGOCIIL31v4ewMQCSu89Zk7Mc+ny8W3va+XzaNIRhG7tXFoXM3Ci
UKdGiVddyPnzXDpCK7SXhqtR2J3iUVnXEbqFT1q+F8+h1JB/tlFyDk0wMYd0
cw/B8oMNvX87ZmAW2fErA/s7rWjmOP8NqvL22ImOsKD3yPYYVch5qT3l3aQp
zcBrZxAUzdnEBpvQtUxMo8Yz9ptrUiOaxwBOIa5X2WG+wAD7aKTla6QRPG90
WvgDjPzxCSQJbRWQj7aBgRMq0cJ0nsPOCz3gfhWoaemmyemyDcD9yRGVb2Lc
1/EZxIxAGSrpVgR979IC1j+GaohCQsFZBqx3BMUoT25uxS3CU0bfIFKl8wa3
TGdZPf1oRRKYmzA8wfL3IavJteFfmjH4yvD1ot227g73jFcsvhS9vCwcCA+Q
sHidyGI1wsc9SwzZzP0WtP57Zig5vhZ6mPMNaDnR0azPrwL4TL0acRZz0wlP
EeQxuQiJtpBBdi8bCDZKKwS6S5y0gzrIbCu+ec3Gs3k11Mdq6kI3eSDD+GBU
+fHtuuICW28BeU+GvsozCJqwPmi9e1Tq98PrQD+IXHyKBxycYAP3Bw8ketdI
kSnk4P6h3SOh63jYNmWN5wNlwcr7aZlrVB2eH4Q4qOun/NWUH54v8PXmF2ui
Ril2/pDvaF0Sye2gsN9k4KtK9to0q6IwnxzqbHtG/XU5VCB+X4j9ErtSYJdE
YX4lxBV0xuelRFNK7A9o5sRF+DUEUKx/QNFcqr7105li/QXRsyO8okAD+Qz7
D6RP/FWnrmjJT9if4Jvis2tYHSd9sX/htjbr+lqCmMzE/oazY/2WrsP55BD2
P7Qd0jx2/xtPGuH/Ada6ckmq/Bz5H0jOssk=
       "]]}, 
     {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJw1U38s1GEYP0Y1SaycH/mRTQ2rLT9H6/t9vv1RTInTIeKPGHHmXLbSjJOI
oxl3aJTsNqdTIlR+Zd5zjqjIuW5olNMf1Fkp+TlTfN+vZ3v37tnzvp/P53ne
z+sUmxoab8hisXy3187uSYcGsZgoUS67RJeMIaOKvePX/q2BntPhcE+vRuu2
gbVDXvuoAF3G4SZ/NRKroSw6yoKSCQiT8dpRJPpUEcHWWFIYZRTx/WxDfOJs
qJ3bnI4RVFRlJstaOULRxwXD6Pzi1LQk357aJttm/ICqZIRlm60DRcPr3iGy
/UBL6oA9VUXHEGqVunyMldtRoTTgIHJInAjImbWldtAIk7fIvOP15QWpNUXL
V/ajr4bmmaOmbIqGy1Chsvoxy/xLhyjcbx/yqB8rcC8yp3B/vSg+vLGb3b2f
qqUFKhCvsljZp9zD6O9B8z9fhEsDDBm93WhunbsVotiESlpfJ5Lc4IhyHFcA
62lHbReen/orXwTM/wrJbVhhOaJ5+EHztaBVvVZj1aADjN+EwoA7kDszweA9
RRZ1kd/0dmq4Td+Xod+fxRuarQFops/XoOLShBpPtx4Q0PVy5DZgpFUGvYQ7
dJ6HJE4J8yKreth91ycm/r/cgx7v1kEYl5CeFCVm8nLYTBInN7LyQIHxYSYm
/dj75FtMXQaTkpTsyOREkGJ94OuVstSrjtzVD7rqOuesjEBYwP1BzEjqsDb4
NGTi/qFQtGxsHOwKpng+4Bp01uBZoRVU4/kBV+0+x3Y2hhN4vnByuoFfEfKH
ZOYPkzzrZn3pFxL7TQH3l/qys0WDJObrhYJCR4XN91bSC78vcF14d/OXHpGY
XwURwkG5T38uqcL+AMXBVW1oO49k/APCo/oCV28OyfgLRBePn8mz9CYfYv/B
fBe7/FyuNTmL/Qn8pWVV3doG4Yb9C6pKo2m+wRSRhv0ND/yE1zOuviG6sP9B
69G5csWsijDA/wPSBL6cstSbxH9fErHE
       "]]}}, {}}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.371]], {{}, 
     {RGBColor[0.24720000000000014`, 0.24, 0.6], Opacity[0.5], EdgeForm[
      Opacity[0.371]], 
      RectangleBox[{0., 0.}, 
       NCache[{0.005, Rational[1400, 127]}, {0.005, 11.023622047244094`}],
       RoundingRadius->0], 
      RectangleBox[{0.005, 0.}, 
       NCache[{0.01, Rational[2200, 127]}, {0.01, 17.322834645669293`}],
       RoundingRadius->0], 
      RectangleBox[{0.01, 0.}, 
       NCache[{0.015, Rational[1400, 127]}, {0.015, 11.023622047244094`}],
       RoundingRadius->0], 
      RectangleBox[{0.015, 0.}, 
       NCache[{0.02, Rational[3000, 127]}, {0.02, 23.62204724409449}],
       RoundingRadius->0], 
      RectangleBox[{0.02, 0.}, 
       NCache[{0.025, Rational[2400, 127]}, {0.025, 18.89763779527559}],
       RoundingRadius->0], 
      RectangleBox[{0.025, 0.}, 
       NCache[{0.03, Rational[3400, 127]}, {0.03, 26.771653543307085`}],
       RoundingRadius->0], 
      RectangleBox[{0.03, 0.}, 
       NCache[{0.035, Rational[2200, 127]}, {0.035, 17.322834645669293`}],
       RoundingRadius->0], 
      RectangleBox[{0.035, 0.}, 
       NCache[{0.04, Rational[2600, 127]}, {0.04, 20.47244094488189}],
       RoundingRadius->0], 
      RectangleBox[{0.04, 0.}, 
       NCache[{0.045, Rational[1000, 127]}, {0.045, 7.874015748031496}],
       RoundingRadius->0], 
      RectangleBox[{0.045, 0.}, 
       NCache[{0.05, Rational[1400, 127]}, {0.05, 11.023622047244094`}],
       RoundingRadius->0], 
      RectangleBox[{0.05, 0.}, 
       NCache[{0.055, Rational[600, 127]}, {0.055, 4.724409448818897}],
       RoundingRadius->0], 
      RectangleBox[{0.055, 0.}, 
       NCache[{0.06, Rational[800, 127]}, {0.06, 6.299212598425197}],
       RoundingRadius->0], 
      RectangleBox[{0.06, 0.}, 
       NCache[{0.065, Rational[600, 127]}, {0.065, 4.724409448818897}],
       RoundingRadius->0], 
      RectangleBox[{0.065, 0.}, 
       NCache[{0.07, Rational[800, 127]}, {0.07, 6.299212598425197}],
       RoundingRadius->0], 
      RectangleBox[{0.07, 0.}, 
       NCache[{0.075, Rational[400, 127]}, {0.075, 3.1496062992125986`}],
       RoundingRadius->0], 
      RectangleBox[{0.075, 0.}, 
       NCache[{0.08, Rational[400, 127]}, {0.08, 3.1496062992125986`}],
       RoundingRadius->0], RectangleBox[{0.08, 0.}, {0.085, 0},
       RoundingRadius->0], 
      RectangleBox[{0.085, 0.}, 
       NCache[{0.09, Rational[400, 127]}, {0.09, 3.1496062992125986`}],
       RoundingRadius->0], 
      RectangleBox[{0.09, 0.}, 
       NCache[{0.095, Rational[200, 127]}, {0.095, 1.5748031496062993`}],
       RoundingRadius->0], RectangleBox[{0.095, 0.}, {0.1, 0},
       RoundingRadius->0], RectangleBox[{0.1, 0.}, {0.105, 0},
       RoundingRadius->0], 
      RectangleBox[{0.105, 0.}, 
       NCache[{0.11, Rational[200, 127]}, {0.11, 1.5748031496062993`}],
       RoundingRadius->0], RectangleBox[{0.11, 0.}, {0.115, 0},
       RoundingRadius->0], RectangleBox[{0.115, 0.}, {0.12, 0},
       RoundingRadius->0], RectangleBox[{0.12, 0.}, {0.125, 0},
       RoundingRadius->0], RectangleBox[{0.125, 0.}, {0.13, 0},
       RoundingRadius->0], RectangleBox[{0.13, 0.}, {0.135, 0},
       RoundingRadius->0], RectangleBox[{0.135, 0.}, {0.14, 0},
       RoundingRadius->0], RectangleBox[{0.14, 0.}, {0.145, 0},
       RoundingRadius->0], RectangleBox[{0.145, 0.}, {0.15, 0},
       RoundingRadius->0], RectangleBox[{0.15, 0.}, {0.155, 0},
       RoundingRadius->0], RectangleBox[{0.155, 0.}, {0.16, 0},
       RoundingRadius->0], RectangleBox[{0.16, 0.}, {0.165, 0},
       RoundingRadius->0], RectangleBox[{0.165, 0.}, {0.17, 0},
       RoundingRadius->0], RectangleBox[{0.17, 0.}, {0.175, 0},
       RoundingRadius->0], RectangleBox[{0.175, 0.}, {0.18, 0},
       RoundingRadius->0], RectangleBox[{0.18, 0.}, {0.185, 0},
       RoundingRadius->0], RectangleBox[{0.185, 0.}, {0.19, 0},
       RoundingRadius->0], RectangleBox[{0.19, 0.}, {0.195, 0},
       RoundingRadius->0], RectangleBox[{0.195, 0.}, {0.2, 0},
       RoundingRadius->0], RectangleBox[{0.2, 0.}, {0.205, 0},
       RoundingRadius->0], RectangleBox[{0.205, 0.}, {0.21, 0},
       RoundingRadius->0], RectangleBox[{0.21, 0.}, {0.215, 0},
       RoundingRadius->0], RectangleBox[{0.215, 0.}, {0.22, 0},
       RoundingRadius->0], RectangleBox[{0.22, 0.}, {0.225, 0},
       RoundingRadius->0], RectangleBox[{0.225, 0.}, {0.23, 0},
       RoundingRadius->0], RectangleBox[{0.23, 0.}, {0.235, 0},
       RoundingRadius->0]}, {}, {}}, {{}, 
     {RGBColor[0.6, 0.24, 0.4428931686004542], Opacity[0.5], EdgeForm[Opacity[
      0.371]], RectangleBox[{0., 0.}, 
       NCache[{0.005, Rational[800, 211]}, {0.005, 3.7914691943127963`}],
       RoundingRadius->0], 
      RectangleBox[{0.005, 0.}, 
       NCache[{0.01, Rational[1000, 211]}, {0.01, 4.739336492890995}],
       RoundingRadius->0], 
      RectangleBox[{0.01, 0.}, 
       NCache[{0.015, Rational[1000, 211]}, {0.015, 4.739336492890995}],
       RoundingRadius->0], 
      RectangleBox[{0.015, 0.}, 
       NCache[{0.02, Rational[2600, 211]}, {0.02, 12.322274881516588`}],
       RoundingRadius->0], 
      RectangleBox[{0.02, 0.}, 
       NCache[{0.025, Rational[1600, 211]}, {0.025, 7.5829383886255926`}],
       RoundingRadius->0], 
      RectangleBox[{0.025, 0.}, 
       NCache[{0.03, Rational[1000, 211]}, {0.03, 4.739336492890995}],
       RoundingRadius->0], 
      RectangleBox[{0.03, 0.}, 
       NCache[{0.035, Rational[1800, 211]}, {0.035, 8.530805687203792}],
       RoundingRadius->0], 
      RectangleBox[{0.035, 0.}, 
       NCache[{0.04, Rational[2000, 211]}, {0.04, 9.47867298578199}],
       RoundingRadius->0], 
      RectangleBox[{0.04, 0.}, 
       NCache[{0.045, Rational[1600, 211]}, {0.045, 7.5829383886255926`}],
       RoundingRadius->0], 
      RectangleBox[{0.045, 0.}, 
       NCache[{0.05, Rational[3400, 211]}, {0.05, 16.113744075829384`}],
       RoundingRadius->0], 
      RectangleBox[{0.05, 0.}, 
       NCache[{0.055, Rational[4400, 211]}, {0.055, 20.85308056872038}],
       RoundingRadius->0], 
      RectangleBox[{0.055, 0.}, 
       NCache[{0.06, Rational[2200, 211]}, {0.06, 10.42654028436019}],
       RoundingRadius->0], 
      RectangleBox[{0.06, 0.}, 
       NCache[{0.065, Rational[2000, 211]}, {0.065, 9.47867298578199}],
       RoundingRadius->0], 
      RectangleBox[{0.065, 0.}, 
       NCache[{0.07, Rational[1800, 211]}, {0.07, 8.530805687203792}],
       RoundingRadius->0], 
      RectangleBox[{0.07, 0.}, 
       NCache[{0.075, Rational[2800, 211]}, {0.075, 13.270142180094787`}],
       RoundingRadius->0], 
      RectangleBox[{0.075, 0.}, 
       NCache[{0.08, Rational[1400, 211]}, {0.08, 6.6350710900473935`}],
       RoundingRadius->0], 
      RectangleBox[{0.08, 0.}, 
       NCache[{0.085, Rational[1000, 211]}, {0.085, 4.739336492890995}],
       RoundingRadius->0], 
      RectangleBox[{0.085, 0.}, 
       NCache[{0.09, Rational[1200, 211]}, {0.09, 5.687203791469194}],
       RoundingRadius->0], 
      RectangleBox[{0.09, 0.}, 
       NCache[{0.095, Rational[1400, 211]}, {0.095, 6.6350710900473935`}],
       RoundingRadius->0], 
      RectangleBox[{0.095, 0.}, 
       NCache[{0.1, Rational[600, 211]}, {0.1, 2.843601895734597}],
       RoundingRadius->0], 
      RectangleBox[{0.1, 0.}, 
       NCache[{0.105, Rational[800, 211]}, {0.105, 3.7914691943127963`}],
       RoundingRadius->0], 
      RectangleBox[{0.105, 0.}, 
       NCache[{0.11, Rational[1000, 211]}, {0.11, 4.739336492890995}],
       RoundingRadius->0], 
      RectangleBox[{0.11, 0.}, 
       NCache[{0.115, Rational[600, 211]}, {0.115, 2.843601895734597}],
       RoundingRadius->0], 
      RectangleBox[{0.115, 0.}, 
       NCache[{0.12, Rational[600, 211]}, {0.12, 2.843601895734597}],
       RoundingRadius->0], 
      RectangleBox[{0.12, 0.}, 
       NCache[{0.125, Rational[600, 211]}, {0.125, 2.843601895734597}],
       RoundingRadius->0], 
      RectangleBox[{0.125, 0.}, 
       NCache[{0.13, Rational[400, 211]}, {0.13, 1.8957345971563981`}],
       RoundingRadius->0], 
      RectangleBox[{0.13, 0.}, 
       NCache[{0.135, Rational[400, 211]}, {0.135, 1.8957345971563981`}],
       RoundingRadius->0], 
      RectangleBox[{0.135, 0.}, 
       NCache[{0.14, Rational[200, 211]}, {0.14, 0.9478672985781991}],
       RoundingRadius->0], 
      RectangleBox[{0.14, 0.}, 
       NCache[{0.145, Rational[400, 211]}, {0.145, 1.8957345971563981`}],
       RoundingRadius->0], 
      RectangleBox[{0.145, 0.}, 
       NCache[{0.15, Rational[400, 211]}, {0.15, 1.8957345971563981`}],
       RoundingRadius->0], RectangleBox[{0.15, 0.}, {0.155, 0},
       RoundingRadius->0], RectangleBox[{0.155, 0.}, {0.16, 0},
       RoundingRadius->0], RectangleBox[{0.16, 0.}, {0.165, 0},
       RoundingRadius->0], RectangleBox[{0.165, 0.}, {0.17, 0},
       RoundingRadius->0], 
      RectangleBox[{0.17, 0.}, 
       NCache[{0.175, Rational[200, 211]}, {0.175, 0.9478672985781991}],
       RoundingRadius->0], RectangleBox[{0.175, 0.}, {0.18, 0},
       RoundingRadius->0], RectangleBox[{0.18, 0.}, {0.185, 0},
       RoundingRadius->0], 
      RectangleBox[{0.185, 0.}, 
       NCache[{0.19, Rational[200, 211]}, {0.19, 0.9478672985781991}],
       RoundingRadius->0], 
      RectangleBox[{0.19, 0.}, 
       NCache[{0.195, Rational[400, 211]}, {0.195, 1.8957345971563981`}],
       RoundingRadius->0], RectangleBox[{0.195, 0.}, {0.2, 0},
       RoundingRadius->0], 
      RectangleBox[{0.2, 0.}, 
       NCache[{0.205, Rational[200, 211]}, {0.205, 0.9478672985781991}],
       RoundingRadius->0], RectangleBox[{0.205, 0.}, {0.21, 0},
       RoundingRadius->0], RectangleBox[{0.21, 0.}, {0.215, 0},
       RoundingRadius->0], RectangleBox[{0.215, 0.}, {0.22, 0},
       RoundingRadius->0], RectangleBox[{0.22, 0.}, {0.225, 0},
       RoundingRadius->0], RectangleBox[{0.225, 0.}, {0.23, 0},
       RoundingRadius->0], 
      RectangleBox[{0.23, 0.}, 
       NCache[{0.235, Rational[200, 211]}, {0.235, 0.9478672985781991}],
       RoundingRadius->0]}, {}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
      LineBox[CompressedData["
1:eJxdUWlIk2EA1lA080Bx/lC0JjOvAkHyqr7nE8WjQvJISkVRKmU0NFJsHmDm
gUoHpJXKJHM21HJKSst0uKbucFOJzBkdTFwpaik1tR9Z+47+9MDLy3s918vN
K0y5tM/KyirUMqj5f5S798cby4rx8/GtP62bwSSzrsEvj3pvjdsxUuZTu5Ys
u40ml2EnqTScPW9GREmVvX91ONnWSgP+uXXZtiP/7nfggq8q098vlFxPpnY6
0fyw+YwsMYR9L8bNeXzzMgeRDgtdRScdJDALJ4Iz9H4sXw8Kn634TidyycCs
O6/NAU/R3VepTdvyZPn7cVjZ0LvX406KLa8Xugbg6Bq9U3DChdUbRJK3JPBI
oh0ZSuM5cqb18cd9rVn9IQSHWdXFftmF0hxgURiGk+t8sezzFhg/L8D1bJMt
Zq4ihRHEXrZK/FVlBOPvJaoUZ3eETwwwllGEIyitGllSLM+B8TsKk4ET5GWa
wlXKXtEYBK01IT79cjB0cmyWulVmpA6B+YVxcCLepxse9YLJMw6RaL/wDdGJ
BFpAASlfUB3NuQ8mnwJOYwP6rR9NoNQskjCIF2crKm6AyauEo4OZt95RAjrO
ghK2TR3fT/H5YPJPwCOvbfT0Ug4OUnZ8JiFM4IneWaeyfUziQYNAl54bh/zL
FKZQvkF+/GQTxfajQq/9ga7kD0dBsbn3qxBW65jhvHqI7UuNjbv31HKTG7Yp
OrMaaZE8seitDdufBi3cqDaBeJsgaEItDCaJ3C9mhWD61EKj6bbb7VgkaHu1
0/DgcyOvS7QE068OKieFsy7pFaHX0UBAzLVldWMfwfStx15LfZbxXDvBoQ3O
YDZ/MU4lbSSY/megit1q7xMJCZouaxaDjr+vuAQVEMx/zOH8WkIS72I68RdI
6HvQ
       "]]}, 
     {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
      LineBox[CompressedData["
1:eJxdUWlIk2EAntcMBU2aIzXmiW4RiNkBXs+nkkmiof6KlFDwCIqUppG3pZG4
tFhRW1iMTZekU5lXo0TTzc1NneaR9MMrNC+0Y0aW2b7jVw+8vLzXc72+mTdS
smxZLFaodZDz/yjmqM4vFgkxJKkXq++5EPS6CvuRz01tzzyJXl71RnJvHYQJ
dYshQl/m/DEeqV1knekBhFRCAZxGTZ2FCGTuv8BI7wnHhcQgYjOZ3JGhZU3w
2tgaxLxXwO3kTHtGVRDhNCvPi3RSwj8m9kv0TiDD14xud6NtrXMgIUirf2/h
t8AgsFxP3Qxg+FU4ZT8RfLTRn1BYX8/K27FK1LIDzvkxeh3Qpfaotj/6EKEU
1Ljkknn65xSP0e+ETUhmUpzdMWLQwrcqdKG6R/tgMt6D8dODpqlvsaUqLpFC
C2J5qT3nThiH8fcGGXGeDhs7bsRiEUmogUE0JFxRujJ+34J/O6pMr3cm8kl7
ee9wYQk8Xewhxn8fPCrZH3K5DgT9C/2Y/Lpm2oqwZfL042W4QXcx6wDxlMAA
Cl91/5J93gOdbwBPGiYEks1dkGpWSWRPu7tq8r+DzjuI4pbgAmnuDqg4s4MI
i/+jJkQboPMPQerfUXjlYAXepB2eFgrv+Ydi7jLoPrRId0xYLy+bR042CR26
beIUBeY50P0MQ8H2+iGzmwbJxlENg8UuXy3+bQbdlx610X7reRFG7JJ0Fj2u
hTftxTRrQfdngDzt1qj5yACiKMIRdM3g70KrBnSfI7h6ec6LL+8EZa/aiOCu
mk/LkjbQ/ZqwX+ItLt1WYtREAWaV6Kz3lgx036NQaMwNyhop3CmDY6jsr/Sq
yBGD7n8M90O4FeP2IlB0aeO4mdR3Zmn3Luj/MOOpT+LxqcMl+AfoqX6K
       
       "]]}}, {}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], Thickness[Large], Dashing[{Small, Small}], 
     LineBox[CompressedData["
1:eJwVV3c8Vv8XR4qQrOprhUjISjyE7rllz8xkJCSVjKwSIbL3Xtmj7L0yHzzm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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"\\!\\(\\*SubscriptBox[\\(m\\), \\(0\\)]\\)=-0.3\"", 12, FontFamily -> 
       "Helvetica", StripOnInput -> False], TraditionalForm], 
     NCache[
      Scaled[{
        Rational[7, 8], 
        Rational[3, 4]}], 
      Scaled[{0.875, 0.75}]]], 
    InsetBox[
     FormBox[
      StyleBox[
      "\"C\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
      TraditionalForm], 
     Scaled[{0.05, 0.95}]], {
     Directive[
      GrayLevel[0.5], 
      Thickness[Large]], 
     LineBox[{{-0.3, 10}, {-0.22, 10}}]}, {
     Directive[
      GrayLevel[0.5], 
      Thickness[Large]], 
     LineBox[{{-0.299, 9.5}, {-0.299, 10.5}}]}, {
     Directive[
      GrayLevel[0.5], 
      Thickness[Large]], 
     LineBox[{{-0.22, 9.5}, {-0.22, 10.5}}]}, {
     Directive[
      RGBColor[0.24720000000000014`, 0.24, 0.6], 
      Thickness[Large]], 
     LineBox[{{-0.3, 25}, {0.015, 25}}]}, {
     Directive[
      RGBColor[0.24720000000000014`, 0.24, 0.6], 
      Thickness[Large]], 
     LineBox[{{-0.299, 24.5}, {-0.299, 25.5}}]}, {
     Directive[
      RGBColor[0.24720000000000014`, 0.24, 0.6], 
      Thickness[Large]], 
     LineBox[{{0.015, 24.5}, {0.015, 25.5}}]}},
  Frame->{True, False, False, False},
  FrameLabel->{
    FormBox["\"Growth rate\"", TraditionalForm]},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{-0.3, 0.25}, {0, 28}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.771263165415267*^9, 3.771263277667255*^9, 3.771523994309102*^9, 
   3.771524049158046*^9, {3.771524090588943*^9, 3.771524122472548*^9}, 
   3.771524738003189*^9, 3.771524808298708*^9, 3.771524897243631*^9, 
   3.771525024600727*^9, 3.771610292991431*^9, 3.782258818056086*^9, 
   3.784902245574193*^9, 3.7849034972403803`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"ymax", ",", "xmin", ",", "xmax"}], "]"}]], "Input",
 CellChangeTimes->{{3.771524790837747*^9, 3.771524798718314*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure 6", "Subsubsection",
 CellChangeTimes->{{3.7849022333949413`*^9, 3.784902236443346*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GraphicsColumn", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"fig6a", ",", "fig6b", ",", "fig6c"}], "}"}], ",", 
   RowBox[{"Spacings", "\[Rule]", 
    RowBox[{"-", "30"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{"figdir", "<>", "\"\<Figure6.pdf\>\""}], ",", "%"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.784902249832263*^9, 3.784902261025084*^9}, {
  3.784902301417657*^9, 3.7849023344506598`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     FormBox[
      TagBox[
       FormBox[
        GraphicsBox[{{{{}, {{}, {}, 
             {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
              LineBox[CompressedData["
1:eJwtU3tI01EUntN8v/aAUlIyrUaalbYSxJ0bRCqZNQVJ85GS+Uema0E5k7Qw
UyIt0TLfopUW2srhi+lVp2ibE1/zEY2cY+YrTNJMi0x/93fgcjmce7/vO+d+
1yUuOSSeyWAwfLbXzu5NxSjWVuiGqkzGIK97jReZN4LTytr3r69MwaKwxfnh
4jDucwpNn6mchgBdKrfBfxgzHS+uB3EMUCPys5yoHsKBjsyD3xMWgEHFEJY3
nfUWh/+AndvClkFcaeI2yDdaBeq4SI0znrs7O3n+hm2ybcYB/FljiL6u/QsU
vE6J/Qpch7uZRuglFZ/wfPAN1U2lMQqhAPuxyONN2/sWU7SD5mfZh7eytE5m
cgtEye/uxQINDprpsEYUXGoPDpbk7D5ea4dIvwoc9Gc/w9eThUh/XXjy8r6A
4hg2qqYEduI1JXspLIKDiP4OfFU2NmFgcRHRK8fXpkxDzdO4qIjS14pnWWtf
6p9xaT3NODFQ0vf6Apfml+HMSJkJq5mDFii+D9jdlvs0Sc2m8RtwWaxGGlXK
ovHqsJVawPx1zB6lUPdr8PwhlxQp3wZJqfPleMCofsl+3AKJqHoB5tt2/YuL
N0UZVJ6J74wIwGBsjBh0LDBrj0SVbAFdB8Wy996Ajxt0XgDuhblSXuIqdBJ8
OH8yJ9asaZmu14DKs2+Rbz4HlUQfPBLu+Zqt0NHv2wDRvq1htS+mYIn0B+IV
7yn/n8OQRvqH2cHpb1X3+sGazAeWmeOqdr9OKCXzg81wtrV4TgYeZL5wNCv3
br7DWxq/A8yyVVfO5FbQfuuEV+/u71Lcyqf5uqCZ06t9MJkJJ8j7gjKbN+vV
fJvm74FsjXxofDwBeog/IFnSZaW3uQS0f0Btnet46pw/0P4CN1V6fUwJH4qJ
/8CnvDfKn+cKM8SfsPGkMWPUyx4OE/9CUWGS5LTdpkBM/A1tvWmqA3q9oI34
H/RakVDSNCAwIv8DNA51EezHjYL/hVay3A==
               "]]}, 
             {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQPWsmCOzczwAF3NcXF9hybd8vWXAltPwgg0O1yDr3
h1Vb9k91DQ6KkxJweBO4Q6719cb9NVoSe2TPiznsBPICd6zbzzTDVT7CRMYB
Yt7K/RP/FH734lFwqAHrX7L/RJFpa7WxosMOsPp5+x+GTI28NFkRKj9l/zcT
ppoldooODWB+y/7dk+u1f/krOMDcZfLK0NvwmqxDBUTeXshnR6lNrhSUP8X+
0ak35mkbxWDm2x/dkcfX/lwIZr/9wjtznydP4HOYAXGf/RxJv58/f7JD1a+z
31WuseagPRPMf/YrLRO8+z/+sq+C+N/eh2OZnrPHZ3suSPjY2y3y9ZLc+8oe
Gn72/QleC3Z+emivEdN/6KvGHnvTpHjLeX7X7SHm77PPbLFKa7c/a78EqPv6
4gP2D/c/XK+//aD9a7B9B+1fzVu2U3vjFntjMDhsb3GQ58Zt1+X2kPA/Ys//
yOhvuvZM+8NfQTYctZ/l/fith1KXPSS+jtv/dE+I+MJYZQ82LvCEvelkO82t
hzLswc6bedJ+2tSmypWNYfYPwR46Zb9kq7+KYq2zvSbYvWfsGfolZ6zlNLAv
BDmv4Ky98Xp1yUcskvaQ+D1nH75D5Xl3IZM9JDYu2B9Je/ZDbN5LOwAJBgl/

               "]]}}, {}}, 
           {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458],
             EdgeForm[Opacity[0.35]], {{}, 
             {RGBColor[0.24720000000000014`, 0.24, 0.6], Opacity[0.5], 
              EdgeForm[Opacity[0.35]], 
              RectangleBox[{0., 0.}, 
               NCache[{0.005, Rational[800, 169]}, {0.005, 4.733727810650888}],
               RoundingRadius->0], 
              RectangleBox[{0.005, 0.}, 
               NCache[{0.01, Rational[3320, 507]}, {0.01, 6.548323471400394}],
               
               RoundingRadius->0], 
              RectangleBox[{0.01, 0.}, 
               NCache[{0.015, Rational[3920, 507]}, {0.015, 
                7.731755424063117}],
               RoundingRadius->0], 
              RectangleBox[{0.015, 0.}, 
               NCache[{0.02, Rational[4960, 507]}, {0.02, 9.783037475345168}],
               
               RoundingRadius->0], 
              RectangleBox[{0.02, 0.}, 
               NCache[{0.025, Rational[5440, 507]}, {0.025, 
                10.729783037475345`}],
               RoundingRadius->0], 
              RectangleBox[{0.025, 0.}, 
               NCache[{0.03, Rational[1840, 169]}, {0.03, 
                10.887573964497042`}],
               RoundingRadius->0], 
              RectangleBox[{0.03, 0.}, 
               NCache[{0.035, Rational[2000, 169]}, {0.035, 
                11.834319526627219`}],
               RoundingRadius->0], 
              RectangleBox[{0.035, 0.}, 
               NCache[{0.04, Rational[2100, 169]}, {0.04, 12.42603550295858}],
               
               RoundingRadius->0], 
              RectangleBox[{0.04, 0.}, 
               NCache[{0.045, Rational[2160, 169]}, {0.045, 
                12.781065088757396`}],
               RoundingRadius->0], 
              RectangleBox[{0.045, 0.}, 
               NCache[{0.05, Rational[2160, 169]}, {0.05, 
                12.781065088757396`}],
               RoundingRadius->0], 
              RectangleBox[{0.05, 0.}, 
               NCache[{0.055, Rational[5780, 507]}, {0.055, 
                11.400394477317555`}],
               RoundingRadius->0], 
              RectangleBox[{0.055, 0.}, 
               NCache[{0.06, Rational[140, 13]}, {0.06, 10.76923076923077}],
               RoundingRadius->0], 
              RectangleBox[{0.06, 0.}, 
               NCache[{0.065, Rational[400, 39]}, {0.065, 
                10.256410256410257`}],
               RoundingRadius->0], 
              RectangleBox[{0.065, 0.}, 
               NCache[{0.07, Rational[4840, 507]}, {0.07, 9.546351084812624}],
               
               RoundingRadius->0], 
              RectangleBox[{0.07, 0.}, 
               NCache[{0.075, Rational[120, 13]}, {0.075, 9.23076923076923}],
               RoundingRadius->0], 
              RectangleBox[{0.075, 0.}, 
               NCache[{0.08, Rational[4240, 507]}, {0.08, 8.362919132149901}],
               
               RoundingRadius->0], 
              RectangleBox[{0.08, 0.}, 
               NCache[{0.085, Rational[1140, 169]}, {0.085, 
                6.745562130177515}],
               RoundingRadius->0], 
              RectangleBox[{0.085, 0.}, 
               NCache[{0.09, Rational[2920, 507]}, {0.09, 5.759368836291913}],
               
               RoundingRadius->0], 
              RectangleBox[{0.09, 0.}, 
               NCache[{0.095, Rational[200, 39]}, {0.095, 5.128205128205129}],
               
               RoundingRadius->0], 
              RectangleBox[{0.095, 0.}, 
               NCache[{0.1, Rational[2320, 507]}, {0.1, 4.575936883629192}],
               RoundingRadius->0], 
              RectangleBox[{0.1, 0.}, 
               NCache[{0.105, Rational[1600, 507]}, {0.105, 
                3.155818540433925}],
               RoundingRadius->0], 
              RectangleBox[{0.105, 0.}, 
               NCache[{0.11, Rational[40, 13]}, {0.11, 3.076923076923077}],
               RoundingRadius->0], 
              RectangleBox[{0.11, 0.}, 
               NCache[{0.115, Rational[1280, 507]}, {0.115, 2.52465483234714}],
               RoundingRadius->0], 
              RectangleBox[{0.115, 0.}, 
               NCache[{0.12, Rational[1000, 507]}, {0.12, 
                1.9723865877712032`}],
               RoundingRadius->0], 
              RectangleBox[{0.12, 0.}, 
               NCache[{0.125, Rational[860, 507]}, {0.125, 
                1.6962524654832347`}],
               RoundingRadius->0], 
              RectangleBox[{0.125, 0.}, 
               NCache[{0.13, Rational[860, 507]}, {0.13, 1.6962524654832347`}],
               RoundingRadius->0], 
              RectangleBox[{0.13, 0.}, 
               NCache[{0.135, Rational[400, 507]}, {0.135, 
                0.7889546351084813}],
               RoundingRadius->0], 
              RectangleBox[{0.135, 0.}, 
               NCache[{0.14, Rational[120, 169]}, {0.14, 0.7100591715976331}],
               
               RoundingRadius->0], 
              RectangleBox[{0.14, 0.}, 
               NCache[{0.145, Rational[340, 507]}, {0.145, 
                0.6706114398422091}],
               RoundingRadius->0], 
              RectangleBox[{0.145, 0.}, 
               NCache[{0.15, Rational[140, 507]}, {0.15, 
                0.27613412228796846`}],
               RoundingRadius->0], 
              RectangleBox[{0.15, 0.}, 
               NCache[{0.155, Rational[20, 39]}, {0.155, 0.5128205128205128}],
               
               RoundingRadius->0], 
              RectangleBox[{0.155, 0.}, 
               NCache[{0.16, Rational[100, 507]}, {0.16, 
                0.19723865877712032`}],
               RoundingRadius->0], 
              RectangleBox[{0.16, 0.}, 
               NCache[{0.165, Rational[80, 507]}, {0.165, 
                0.15779092702169625`}],
               RoundingRadius->0], 
              RectangleBox[{0.165, 0.}, 
               NCache[{0.17, Rational[20, 169]}, {0.17, 0.11834319526627218`}],
               RoundingRadius->0], 
              RectangleBox[{0.17, 0.}, 
               NCache[{0.175, Rational[20, 169]}, {0.175, 
                0.11834319526627218`}],
               RoundingRadius->0], 
              RectangleBox[{0.175, 0.}, 
               NCache[{0.18, Rational[20, 507]}, {0.18, 0.03944773175542406}],
               
               RoundingRadius->0], 
              RectangleBox[{0.18, 0.}, 
               NCache[{0.185, Rational[40, 507]}, {0.185, 
                0.07889546351084813}],
               RoundingRadius->0], RectangleBox[{0.185, 0.}, {0.19, 0},
               RoundingRadius->0], 
              RectangleBox[{0.19, 0.}, 
               NCache[{0.195, Rational[20, 169]}, {0.195, 
                0.11834319526627218`}],
               RoundingRadius->0], RectangleBox[{0.195, 0.}, {0.2, 0},
               RoundingRadius->0], 
              RectangleBox[{0.2, 0.}, 
               NCache[{0.205, Rational[20, 507]}, {0.205, 
                0.03944773175542406}],
               RoundingRadius->0], RectangleBox[{0.205, 0.}, {0.21, 0},
               RoundingRadius->0], RectangleBox[{0.21, 0.}, {0.215, 0},
               RoundingRadius->0], RectangleBox[{0.215, 0.}, {0.22, 0},
               RoundingRadius->0], RectangleBox[{0.22, 0.}, {0.225, 0},
               RoundingRadius->0], RectangleBox[{0.225, 0.}, {0.23, 0},
               RoundingRadius->0], RectangleBox[{0.23, 0.}, {0.235, 0},
               RoundingRadius->0], 
              RectangleBox[{0.235, 0.}, 
               NCache[{0.24, Rational[20, 507]}, {0.24, 0.03944773175542406}],
               
               RoundingRadius->0], RectangleBox[{0.24, 0.}, {0.245, 0},
               RoundingRadius->0], RectangleBox[{0.245, 0.}, {0.25, 0},
               RoundingRadius->0]}, {}, {}}, {{}, 
             {RGBColor[0.6, 0.24, 0.4428931686004542], Opacity[0.5], EdgeForm[
              Opacity[0.35]], 
              RectangleBox[{0., 0.}, 
               NCache[{0.005, Rational[200, 241]}, {0.005, 
                0.8298755186721992}],
               RoundingRadius->0], 
              RectangleBox[{0.005, 0.}, 
               NCache[{0.01, Rational[450, 241]}, {0.01, 1.8672199170124482`}],
               RoundingRadius->0], 
              RectangleBox[{0.01, 0.}, 
               NCache[{0.015, Rational[750, 241]}, {0.015, 3.112033195020747}],
               RoundingRadius->0], 
              RectangleBox[{0.015, 0.}, 
               NCache[{0.02, Rational[1200, 241]}, {0.02, 4.979253112033195}],
               
               RoundingRadius->0], 
              RectangleBox[{0.02, 0.}, 
               NCache[{0.025, Rational[1050, 241]}, {0.025, 
                4.356846473029045}],
               RoundingRadius->0], 
              RectangleBox[{0.025, 0.}, 
               NCache[{0.03, Rational[1400, 241]}, {0.03, 5.809128630705394}],
               
               RoundingRadius->0], 
              RectangleBox[{0.03, 0.}, 
               NCache[{0.035, Rational[1900, 241]}, {0.035, 
                7.8838174273858925`}],
               RoundingRadius->0], 
              RectangleBox[{0.035, 0.}, 
               NCache[{0.04, Rational[1350, 241]}, {0.04, 5.601659751037344}],
               
               RoundingRadius->0], 
              RectangleBox[{0.04, 0.}, 
               NCache[{0.045, Rational[1500, 241]}, {0.045, 
                6.224066390041494}],
               RoundingRadius->0], 
              RectangleBox[{0.045, 0.}, 
               NCache[{0.05, Rational[1650, 241]}, {0.05, 6.846473029045643}],
               
               RoundingRadius->0], 
              RectangleBox[{0.05, 0.}, 
               NCache[{0.055, Rational[1950, 241]}, {0.055, 
                8.091286307053942}],
               RoundingRadius->0], 
              RectangleBox[{0.055, 0.}, 
               NCache[{0.06, Rational[1950, 241]}, {0.06, 8.091286307053942}],
               
               RoundingRadius->0], 
              RectangleBox[{0.06, 0.}, 
               NCache[{0.065, Rational[2250, 241]}, {0.065, 
                9.336099585062241}],
               RoundingRadius->0], 
              RectangleBox[{0.065, 0.}, 
               NCache[{0.07, Rational[1700, 241]}, {0.07, 7.053941908713693}],
               
               RoundingRadius->0], 
              RectangleBox[{0.07, 0.}, 
               NCache[{0.075, Rational[1750, 241]}, {0.075, 
                7.261410788381743}],
               RoundingRadius->0], 
              RectangleBox[{0.075, 0.}, 
               NCache[{0.08, Rational[1900, 241]}, {0.08, 
                7.8838174273858925`}],
               RoundingRadius->0], 
              RectangleBox[{0.08, 0.}, 
               NCache[{0.085, Rational[1700, 241]}, {0.085, 
                7.053941908713693}],
               RoundingRadius->0], 
              RectangleBox[{0.085, 0.}, 
               NCache[{0.09, Rational[1800, 241]}, {0.09, 7.468879668049793}],
               
               RoundingRadius->0], 
              RectangleBox[{0.09, 0.}, 
               NCache[{0.095, Rational[1850, 241]}, {0.095, 
                7.676348547717843}],
               RoundingRadius->0], 
              RectangleBox[{0.095, 0.}, 
               NCache[{0.1, Rational[1800, 241]}, {0.1, 7.468879668049793}],
               RoundingRadius->0], 
              RectangleBox[{0.1, 0.}, 
               NCache[{0.105, Rational[2350, 241]}, {0.105, 
                9.751037344398341}],
               RoundingRadius->0], 
              RectangleBox[{0.105, 0.}, 
               NCache[{0.11, Rational[1800, 241]}, {0.11, 7.468879668049793}],
               
               RoundingRadius->0], 
              RectangleBox[{0.11, 0.}, 
               NCache[{0.115, Rational[1300, 241]}, {0.115, 
                5.394190871369295}],
               RoundingRadius->0], 
              RectangleBox[{0.115, 0.}, 
               NCache[{0.12, Rational[1500, 241]}, {0.12, 6.224066390041494}],
               
               RoundingRadius->0], 
              RectangleBox[{0.12, 0.}, 
               NCache[{0.125, Rational[1600, 241]}, {0.125, 
                6.639004149377594}],
               RoundingRadius->0], 
              RectangleBox[{0.125, 0.}, 
               NCache[{0.13, Rational[1450, 241]}, {0.13, 6.016597510373444}],
               
               RoundingRadius->0], 
              RectangleBox[{0.13, 0.}, 
               NCache[{0.135, Rational[1200, 241]}, {0.135, 
                4.979253112033195}],
               RoundingRadius->0], 
              RectangleBox[{0.135, 0.}, 
               NCache[{0.14, Rational[950, 241]}, {0.14, 3.9419087136929463`}],
               RoundingRadius->0], 
              RectangleBox[{0.14, 0.}, 
               NCache[{0.145, Rational[750, 241]}, {0.145, 3.112033195020747}],
               RoundingRadius->0], 
              RectangleBox[{0.145, 0.}, 
               NCache[{0.15, Rational[550, 241]}, {0.15, 2.2821576763485476`}],
               RoundingRadius->0], 
              RectangleBox[{0.15, 0.}, 
               NCache[{0.155, Rational[600, 241]}, {0.155, 
                2.4896265560165975`}],
               RoundingRadius->0], 
              RectangleBox[{0.155, 0.}, 
               NCache[{0.16, Rational[650, 241]}, {0.16, 2.6970954356846475`}],
               RoundingRadius->0], 
              RectangleBox[{0.16, 0.}, 
               NCache[{0.165, Rational[650, 241]}, {0.165, 
                2.6970954356846475`}],
               RoundingRadius->0], 
              RectangleBox[{0.165, 0.}, 
               NCache[{0.17, Rational[550, 241]}, {0.17, 2.2821576763485476`}],
               RoundingRadius->0], 
              RectangleBox[{0.17, 0.}, 
               NCache[{0.175, Rational[500, 241]}, {0.175, 2.074688796680498}],
               RoundingRadius->0], 
              RectangleBox[{0.175, 0.}, 
               NCache[{0.18, Rational[300, 241]}, {0.18, 1.2448132780082988`}],
               RoundingRadius->0], 
              RectangleBox[{0.18, 0.}, 
               NCache[{0.185, Rational[150, 241]}, {0.185, 
                0.6224066390041494}],
               RoundingRadius->0], 
              RectangleBox[{0.185, 0.}, 
               NCache[{0.19, Rational[300, 241]}, {0.19, 1.2448132780082988`}],
               RoundingRadius->0], 
              RectangleBox[{0.19, 0.}, 
               NCache[{0.195, Rational[200, 241]}, {0.195, 
                0.8298755186721992}],
               RoundingRadius->0], 
              RectangleBox[{0.195, 0.}, 
               NCache[{0.2, Rational[100, 241]}, {0.2, 0.4149377593360996}],
               RoundingRadius->0], 
              RectangleBox[{0.2, 0.}, 
               NCache[{0.205, Rational[100, 241]}, {0.205, 
                0.4149377593360996}],
               RoundingRadius->0], RectangleBox[{0.205, 0.}, {0.21, 0},
               RoundingRadius->0], 
              RectangleBox[{0.21, 0.}, 
               NCache[{0.215, Rational[250, 241]}, {0.215, 1.037344398340249}],
               RoundingRadius->0], 
              RectangleBox[{0.215, 0.}, 
               NCache[{0.22, Rational[150, 241]}, {0.22, 0.6224066390041494}],
               
               RoundingRadius->0], 
              RectangleBox[{0.22, 0.}, 
               NCache[{0.225, Rational[50, 241]}, {0.225, 0.2074688796680498}],
               RoundingRadius->0], RectangleBox[{0.225, 0.}, {0.23, 0},
               RoundingRadius->0], RectangleBox[{0.23, 0.}, {0.235, 0},
               RoundingRadius->0], 
              RectangleBox[{0.235, 0.}, 
               NCache[{0.24, Rational[50, 241]}, {0.24, 0.2074688796680498}],
               RoundingRadius->0], RectangleBox[{0.24, 0.}, {0.245, 0},
               RoundingRadius->0], 
              RectangleBox[{0.245, 0.}, 
               NCache[{0.25, Rational[50, 241]}, {0.25, 0.2074688796680498}],
               RoundingRadius->0]}, {}, {}}}, {{}, {{}, {}, 
             {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
              LineBox[CompressedData["
1:eJxdUXss1HEAP7dFY0KdNPFrku6kMFfTGJ+v7XrILueR1UYbpaZV3OYfZ2pt
rqxVHrOMJHLWNM4jdG4YLp3Oo2tXERZiJcxj16kR636Pv/ps3333fX1eX6+U
9NhUPo/HE1sHPf+PbIH61LQiE5t/7wQGtzgTdp0LQ0LbbO2MJ9FQyoUYzSNo
v1Y5xK96c+fFsFW0SbYrhaSslAFCKh1vXxrz5e5X4EZV2GM15UcWY+idKuiT
Ygq3cvy49yroPN1cZPv9iP1IdUaY/QsUC8aLBoMOcXy1mJTPi0NNIuKbmN9r
EdXBI+2BsdxbyPGrkbIy3LIKH6Kyvh6pbsTPPJXah3hzek0wX/geRB33ImIG
r9AcsrliSKc4/RY02AVMfSlxJzqLyKrQio1wY2Xv+m7Oz2vsdRpwca3ZRWJZ
QTgU1+RdrnDm/LVj55EVTeBHBzKtoAm1uMvPlac723F+O9BKCmzjF/lETtvL
6MRE5Iflss4tsHRdyOIbZCc0f8D+QjdCf1imNurNYPN0w50v1R3etozTjEAP
nNJMmyrxHNh8PcheH5X2NX4DrWaVREC9hNIVTYDNq8PkL5+ziqefwMQZ0cGG
1xQd7G8Em/8NukyjXeO/9dhH26H6MJvVntyZ3wO2jz5EybVzJzPbcfUKjbfQ
KSm9f3gz2H706L5489nnsVrQbAK1HpU25W4PPZ6D7asfjjPaHBdBKdZoOks/
dpQP3V8SFoLt7x2uJ0ki7APvIZwhNKCjQzZXZL4Ftk8DTHvGz8tSM8HYUw7g
SdNagzDvGth+ByFtnY+LsEvG0CADRPKXeI3558D2PQRZwsG4yYUzcGUMDkMa
cSBKUki4/oeResxdaXI7CoYu8T3MO5d6DTwR9x9GvCwpqIsO9cA/nj54kQ==

               "]]}, 
             {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
              LineBox[CompressedData["
1:eJxdUXlI01EAHh5UdlDqvJpzo5qaVogssqbfM1uGaKIpiamhafOI1CGCK0jz
QCpmhBQqGDFLwpSVk6ZZznQ6542Zlilq+UeeKM0Ro2i/468+eDze9V1PmJYb
m2HD4XACrYOa/8ct55bwBUUBVImlrfq7HMKsy5CYLz48em4P0fLLV2K0SnzJ
dK+L+u7InlcjjPfg8UOjC6mtoYFxryA7i8WdvV+Pmpth58eUPLIaQ+08g9gx
JLewms++b8D2draseq+AOEyp8oIdGtF8KXP56RMBy/cS9WnJ4vU1AfFNqvpo
8nkFuYrIVFwhy98Cxd/0uEdOQtJgfT2lUmNe3msXuSpg9V7DvTHqqk+DgATS
aEVySldrBASsvgaS4sqS8FIv0mPysSq0wbuZJ/+RzGf9vEWB6NRsGdeTxDKC
SIg+dmRGfZD11w77xc0XASc9yIKCIuzAdJDSOavJjfXbCe+VDT8z15XkU/by
3uPQYsD6koLL+v+ACT+JbGLOiTC/oMOBykL7Lakjm0eHccnlgl2a/eQCLdCN
RufW3o2EfWy+bkg6JN6y9N2EUrNKosgiD66p2snm7cH82vK12Tl7QseZ6gEn
UndfH2/L5u8FL7QzRWjmEC/KDl+PtpzcVJt7f8D0YV0XReyQl/yG7DqFPlw5
USE1TJrA9NOPrTvZ/p8qtkCxObf04/mI5w1X0QaYvgyInqu7GLrxE9sUnckA
IvVfP526BKa/AQxobEUu8gWE0IRGKM+0W277fwPTpxEzfbVHDSWfQdsrH4Q6
c/LdnGEcTL9DiDSPqb8ODmJ4iAZ04WeLtQo9mL6H0SD29fDP0oFLGxzB8bZf
GU1GLZj+R2DuzuGLSt+ApksahSZ+ZjonrgnMf4xBKu7Su22q8A+I6HQZ
               
               "]]}}, {}}, {{}, {}, 
            {Hue[0.67, 0.6, 0.6], Thickness[Large], Dashing[{Small, Small}], 
             LineBox[CompressedData["
1:eJwVlnc8Vf8fx1WKJCIqVEjGtSMqldeJhowyC0VWkTKySsPeIyrJzN4Z2Xtf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              "]]}}}, InsetBox[
           TagBox[GridBox[{
              {
               
               TemplateBox[{
                StyleBox[
                 "\"1-step\"", StripOnInput -> False, FontFamily -> 
                  "Helvetica", FontSize -> 12],StyleBox[
                 "\"2-step\"", StripOnInput -> False, FontFamily -> 
                  "Helvetica", FontSize -> 12]},
                "LineLegend",
                DisplayFunction->(StyleBox[
                  StyleBox[
                   PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                  FontFamily -> "Times"}, Background -> Automatic, 
                  StripOnInput -> False]& ),
                Editable->True,
                InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.24720000000000014`", ",", "0.24`", ",", 
                    "0.6`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.6`", ",", "0.24`", ",", 
                    "0.4428931686004542`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
                    "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                    RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], 
                   "]"}]& )]},
              {
               
               TemplateBox[{
                StyleBox[
                 "\"random\"", StripOnInput -> False, FontFamily -> 
                  "Helvetica", FontSize -> 12],StyleBox[
                 "\"established\"", StripOnInput -> False, FontFamily -> 
                  "Helvetica", FontSize -> 12]},
                "LineLegend",
                DisplayFunction->(StyleBox[
                  StyleBox[
                   PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                  FontFamily -> "Times"}, Background -> Automatic, 
                  StripOnInput -> False]& ),
                Editable->True,
                InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}]}], "]"}]}], "}"}],
                     ",", 
                    RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                    RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], 
                   "]"}]& )]},
              {
               
               TemplateBox[{
                StyleBox[
                 "\"1-step approx.\"", StripOnInput -> False, FontFamily -> 
                  "Helvetica", FontSize -> 12]},
                "LineLegend",
                DisplayFunction->(StyleBox[
                  StyleBox[
                   PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6], 
                    Thickness[Large], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6], 
                    Thickness[Large], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                  FontFamily -> "Times"}, Background -> Automatic, 
                  StripOnInput -> False]& ),
                Editable->True,
                InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Hue", "[", 
                    RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                    "}"}], ",", 
                    RowBox[{"{", #, "}"}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                   "]"}]& )]}
             },
             AutoDelete->False,
             GridBoxAlignment->{"Columns" -> {{Left}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
             GridBoxSpacings->{"Columns" -> {{0}}}],
            "Grid"], NCache[
           Scaled[{0.1875, Rational[1, 2]}], Scaled[{0.1875, 0.5}]], 
           ImageScaled[{0.5, 0.5}],
           BaseStyle->{FontSize -> Larger},
           FormatType->StandardForm]},
         AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
         Axes->True,
         AxesLabel->{None, None},
         AxesOrigin->{0., 0.},
         Epilog->{
           InsetBox[
            FormBox[
             StyleBox[
             "\"\\!\\(\\*SubscriptBox[\\(m\\), \\(0\\)]\\)=-0.1\"", 12, 
              FontFamily -> "Helvetica", StripOnInput -> False], 
             TraditionalForm], 
            NCache[
             Scaled[{
               Rational[7, 8], 
               Rational[3, 4]}], 
             Scaled[{0.875, 0.75}]]], 
           InsetBox[
            FormBox[
             StyleBox[
             "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
              False], TraditionalForm], 
            Scaled[{0.05, 0.95}]], {
            Directive[
             GrayLevel[0.5], 
             Thickness[Large]], 
            LineBox[{{-0.1, 10}, {-0.035, 10}}]}, {
            Directive[
             GrayLevel[0.5], 
             Thickness[Large]], 
            LineBox[{{-0.1, 9.5}, {-0.1, 10.5}}]}, {
            Directive[
             GrayLevel[0.5], 
             Thickness[Large]], 
            LineBox[{{-0.035, 9.5}, {-0.035, 10.5}}]}, {
            Directive[
             RGBColor[0.24720000000000014`, 0.24, 0.6], 
             Thickness[Large]], 
            LineBox[{{-0.1, 15}, {0.03, 15}}]}, {
            Directive[
             RGBColor[0.24720000000000014`, 0.24, 0.6], 
             Thickness[Large]], 
            LineBox[{{-0.1, 14.5}, {-0.1, 15.5}}]}, {
            Directive[
             RGBColor[0.24720000000000014`, 0.24, 0.6], 
             Thickness[Large]], 
            LineBox[{{0.03, 14.5}, {0.03, 15.5}}]}},
         Frame->{True, False, False, False},
         FrameTicksStyle->{
          FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
         LabelStyle->Directive[12, FontFamily -> "Helvetica"],
         Method->{},
         PlotRange->{{-0.3, 0.25}, {0, 28}},
         PlotRangeClipping->True,
         PlotRangePadding->{Automatic, Automatic}],
        TraditionalForm],
       InterpretTemplate[Legended[
         Graphics[{{{}, {{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                Thickness[Large], 
                GrayLevel[0.5], 
                Dashing[{Small, Small}]], 
               Line[CompressedData["
1:eJwtU3tI01EUntN8v/aAUlIyrUaalbYSxJ0bRCqZNQVJ85GS+Uema0E5k7Qw
UyIt0TLfopUW2srhi+lVp2ibE1/zEY2cY+YrTNJMi0x/93fgcjmce7/vO+d+
1yUuOSSeyWAwfLbXzu5NxSjWVuiGqkzGIK97jReZN4LTytr3r69MwaKwxfnh
4jDucwpNn6mchgBdKrfBfxgzHS+uB3EMUCPys5yoHsKBjsyD3xMWgEHFEJY3
nfUWh/+AndvClkFcaeI2yDdaBeq4SI0znrs7O3n+hm2ybcYB/FljiL6u/QsU
vE6J/Qpch7uZRuglFZ/wfPAN1U2lMQqhAPuxyONN2/sWU7SD5mfZh7eytE5m
cgtEye/uxQINDprpsEYUXGoPDpbk7D5ea4dIvwoc9Gc/w9eThUh/XXjy8r6A
4hg2qqYEduI1JXspLIKDiP4OfFU2NmFgcRHRK8fXpkxDzdO4qIjS14pnWWtf
6p9xaT3NODFQ0vf6Apfml+HMSJkJq5mDFii+D9jdlvs0Sc2m8RtwWaxGGlXK
ovHqsJVawPx1zB6lUPdr8PwhlxQp3wZJqfPleMCofsl+3AKJqHoB5tt2/YuL
N0UZVJ6J74wIwGBsjBh0LDBrj0SVbAFdB8Wy996Ajxt0XgDuhblSXuIqdBJ8
OH8yJ9asaZmu14DKs2+Rbz4HlUQfPBLu+Zqt0NHv2wDRvq1htS+mYIn0B+IV
7yn/n8OQRvqH2cHpb1X3+sGazAeWmeOqdr9OKCXzg81wtrV4TgYeZL5wNCv3
br7DWxq/A8yyVVfO5FbQfuuEV+/u71Lcyqf5uqCZ06t9MJkJJ8j7gjKbN+vV
fJvm74FsjXxofDwBeog/IFnSZaW3uQS0f0Btnet46pw/0P4CN1V6fUwJH4qJ
/8CnvDfKn+cKM8SfsPGkMWPUyx4OE/9CUWGS5LTdpkBM/A1tvWmqA3q9oI34
H/RakVDSNCAwIv8DNA51EezHjYL/hVay3A==
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                Thickness[Large], 
                GrayLevel[0.5]], 
               Line[CompressedData["
1:eJxTTMoPSmViYGBQAWIQPWsmCOzczwAF3NcXF9hybd8vWXAltPwgg0O1yDr3
h1Vb9k91DQ6KkxJweBO4Q6719cb9NVoSe2TPiznsBPICd6zbzzTDVT7CRMYB
Yt7K/RP/FH734lFwqAHrX7L/RJFpa7WxosMOsPp5+x+GTI28NFkRKj9l/zcT
ppoldooODWB+y/7dk+u1f/krOMDcZfLK0NvwmqxDBUTeXshnR6lNrhSUP8X+
0ak35mkbxWDm2x/dkcfX/lwIZr/9wjtznydP4HOYAXGf/RxJv58/f7JD1a+z
31WuseagPRPMf/YrLRO8+z/+sq+C+N/eh2OZnrPHZ3suSPjY2y3y9ZLc+8oe
Gn72/QleC3Z+emivEdN/6KvGHnvTpHjLeX7X7SHm77PPbLFKa7c/a78EqPv6
4gP2D/c/XK+//aD9a7B9B+1fzVu2U3vjFntjMDhsb3GQ58Zt1+X2kPA/Ys//
yOhvuvZM+8NfQTYctZ/l/fith1KXPSS+jtv/dE+I+MJYZQ82LvCEvelkO82t
hzLswc6bedJ+2tSmypWNYfYPwR46Zb9kq7+KYq2zvSbYvWfsGfolZ6zlNLAv
BDmv4Ky98Xp1yUcskvaQ+D1nH75D5Xl3IZM9JDYu2B9Je/ZDbN5LOwAJBgl/

                "]]}}}, {}}, {
            Directive[
             EdgeForm[
              Opacity[0.35]], 
             RGBColor[
             0.798413061722744, 0.824719615472648, 
              0.968322270542458]], {{{{}, {
                Directive[
                 Opacity[0.5], 
                 Directive[
                  EdgeForm[
                   Opacity[0.35]], 
                  RGBColor[
                  0.798413061722744, 0.824719615472648, 0.968322270542458]], 
                 Directive[
                  RGBColor[0.24720000000000014`, 0.24, 0.6]]], {{{
                   Rectangle[{0., 0.}, {0.005, 
                    Rational[800, 169]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.005, 0.}, {0.01, 
                    Rational[3320, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.01, 0.}, {0.015, 
                    Rational[3920, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.015, 0.}, {0.02, 
                    Rational[4960, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.02, 0.}, {0.025, 
                    Rational[5440, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.025, 0.}, {0.03, 
                    Rational[1840, 169]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.03, 0.}, {0.035, 
                    Rational[2000, 169]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.035, 0.}, {0.04, 
                    Rational[2100, 169]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.04, 0.}, {0.045, 
                    Rational[2160, 169]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.045, 0.}, {0.05, 
                    Rational[2160, 169]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.05, 0.}, {0.055, 
                    Rational[5780, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.055, 0.}, {0.06, 
                    Rational[140, 13]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.06, 0.}, {0.065, 
                    Rational[400, 39]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.065, 0.}, {0.07, 
                    Rational[4840, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.07, 0.}, {0.075, 
                    Rational[120, 13]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.075, 0.}, {0.08, 
                    Rational[4240, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.08, 0.}, {0.085, 
                    Rational[1140, 169]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.085, 0.}, {0.09, 
                    Rational[2920, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.09, 0.}, {0.095, 
                    Rational[200, 39]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.095, 0.}, {0.1, 
                    Rational[2320, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.1, 0.}, {0.105, 
                    Rational[1600, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.105, 0.}, {0.11, 
                    Rational[40, 13]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.11, 0.}, {0.115, 
                    Rational[1280, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.115, 0.}, {0.12, 
                    Rational[1000, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.12, 0.}, {0.125, 
                    Rational[860, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.125, 0.}, {0.13, 
                    Rational[860, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.13, 0.}, {0.135, 
                    Rational[400, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.135, 0.}, {0.14, 
                    Rational[120, 169]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.14, 0.}, {0.145, 
                    Rational[340, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.145, 0.}, {0.15, 
                    Rational[140, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.15, 0.}, {0.155, 
                    Rational[20, 39]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.155, 0.}, {0.16, 
                    Rational[100, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.16, 0.}, {0.165, 
                    Rational[80, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.165, 0.}, {0.17, 
                    Rational[20, 169]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.17, 0.}, {0.175, 
                    Rational[20, 169]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.175, 0.}, {0.18, 
                    Rational[20, 507]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.18, 0.}, {0.185, 
                    Rational[40, 507]}, "RoundingRadius" -> 0]}}, {{
                   
                   Rectangle[{0.185, 0.}, {0.19, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   Rectangle[{0.19, 0.}, {0.195, 
                    Rational[20, 169]}, "RoundingRadius" -> 0]}}, {{
                   
                   Rectangle[{0.195, 0.}, {0.2, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   Rectangle[{0.2, 0.}, {0.205, 
                    Rational[20, 507]}, "RoundingRadius" -> 0]}}, {{
                   
                   Rectangle[{0.205, 0.}, {0.21, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.21, 0.}, {0.215, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.215, 0.}, {0.22, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.22, 0.}, {0.225, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.225, 0.}, {0.23, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.23, 0.}, {0.235, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   Rectangle[{0.235, 0.}, {0.24, 
                    Rational[20, 507]}, "RoundingRadius" -> 0]}}, {{
                   
                   Rectangle[{0.24, 0.}, {0.245, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.245, 0.}, {0.25, 0}, "RoundingRadius" -> 
                    0]}}}}, {}, {}}}, {{{}, {
                Directive[
                 Opacity[0.5], 
                 Directive[
                  EdgeForm[
                   Opacity[0.35]], 
                  RGBColor[
                  0.798413061722744, 0.824719615472648, 0.968322270542458]], 
                 Directive[
                  RGBColor[0.6, 0.24, 0.4428931686004542]]], {{{
                   Rectangle[{0., 0.}, {0.005, 
                    Rational[200, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.005, 0.}, {0.01, 
                    Rational[450, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.01, 0.}, {0.015, 
                    Rational[750, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.015, 0.}, {0.02, 
                    Rational[1200, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.02, 0.}, {0.025, 
                    Rational[1050, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.025, 0.}, {0.03, 
                    Rational[1400, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.03, 0.}, {0.035, 
                    Rational[1900, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.035, 0.}, {0.04, 
                    Rational[1350, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.04, 0.}, {0.045, 
                    Rational[1500, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.045, 0.}, {0.05, 
                    Rational[1650, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.05, 0.}, {0.055, 
                    Rational[1950, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.055, 0.}, {0.06, 
                    Rational[1950, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.06, 0.}, {0.065, 
                    Rational[2250, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.065, 0.}, {0.07, 
                    Rational[1700, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.07, 0.}, {0.075, 
                    Rational[1750, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.075, 0.}, {0.08, 
                    Rational[1900, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.08, 0.}, {0.085, 
                    Rational[1700, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.085, 0.}, {0.09, 
                    Rational[1800, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.09, 0.}, {0.095, 
                    Rational[1850, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.095, 0.}, {0.1, 
                    Rational[1800, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.1, 0.}, {0.105, 
                    Rational[2350, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.105, 0.}, {0.11, 
                    Rational[1800, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.11, 0.}, {0.115, 
                    Rational[1300, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.115, 0.}, {0.12, 
                    Rational[1500, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.12, 0.}, {0.125, 
                    Rational[1600, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.125, 0.}, {0.13, 
                    Rational[1450, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.13, 0.}, {0.135, 
                    Rational[1200, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.135, 0.}, {0.14, 
                    Rational[950, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.14, 0.}, {0.145, 
                    Rational[750, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.145, 0.}, {0.15, 
                    Rational[550, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.15, 0.}, {0.155, 
                    Rational[600, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.155, 0.}, {0.16, 
                    Rational[650, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.16, 0.}, {0.165, 
                    Rational[650, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.165, 0.}, {0.17, 
                    Rational[550, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.17, 0.}, {0.175, 
                    Rational[500, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.175, 0.}, {0.18, 
                    Rational[300, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.18, 0.}, {0.185, 
                    Rational[150, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.185, 0.}, {0.19, 
                    Rational[300, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.19, 0.}, {0.195, 
                    Rational[200, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.195, 0.}, {0.2, 
                    Rational[100, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.2, 0.}, {0.205, 
                    Rational[100, 241]}, "RoundingRadius" -> 0]}}, {{
                   
                   Rectangle[{0.205, 0.}, {0.21, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   Rectangle[{0.21, 0.}, {0.215, 
                    Rational[250, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.215, 0.}, {0.22, 
                    Rational[150, 241]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.22, 0.}, {0.225, 
                    Rational[50, 241]}, "RoundingRadius" -> 0]}}, {{
                   
                   Rectangle[{0.225, 0.}, {0.23, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.23, 0.}, {0.235, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   Rectangle[{0.235, 0.}, {0.24, 
                    Rational[50, 241]}, "RoundingRadius" -> 0]}}, {{
                   
                   Rectangle[{0.24, 0.}, {0.245, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   Rectangle[{0.245, 0.}, {0.25, 
                    Rational[50, 241]}, "RoundingRadius" -> 
                    0]}}}}, {}, {}}}}}, {{}, {{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                RGBColor[0.24720000000000014`, 0.24, 0.6], 
                Thickness[Large]], 
               Line[CompressedData["
1:eJxdUXss1HEAP7dFY0KdNPFrku6kMFfTGJ+v7XrILueR1UYbpaZV3OYfZ2pt
rqxVHrOMJHLWNM4jdG4YLp3Oo2tXERZiJcxj16kR636Pv/ps3333fX1eX6+U
9NhUPo/HE1sHPf+PbIH61LQiE5t/7wQGtzgTdp0LQ0LbbO2MJ9FQyoUYzSNo
v1Y5xK96c+fFsFW0SbYrhaSslAFCKh1vXxrz5e5X4EZV2GM15UcWY+idKuiT
Ygq3cvy49yroPN1cZPv9iP1IdUaY/QsUC8aLBoMOcXy1mJTPi0NNIuKbmN9r
EdXBI+2BsdxbyPGrkbIy3LIKH6Kyvh6pbsTPPJXah3hzek0wX/geRB33ImIG
r9AcsrliSKc4/RY02AVMfSlxJzqLyKrQio1wY2Xv+m7Oz2vsdRpwca3ZRWJZ
QTgU1+RdrnDm/LVj55EVTeBHBzKtoAm1uMvPlac723F+O9BKCmzjF/lETtvL
6MRE5Iflss4tsHRdyOIbZCc0f8D+QjdCf1imNurNYPN0w50v1R3etozTjEAP
nNJMmyrxHNh8PcheH5X2NX4DrWaVREC9hNIVTYDNq8PkL5+ziqefwMQZ0cGG
1xQd7G8Em/8NukyjXeO/9dhH26H6MJvVntyZ3wO2jz5EybVzJzPbcfUKjbfQ
KSm9f3gz2H706L5489nnsVrQbAK1HpU25W4PPZ6D7asfjjPaHBdBKdZoOks/
dpQP3V8SFoLt7x2uJ0ki7APvIZwhNKCjQzZXZL4Ftk8DTHvGz8tSM8HYUw7g
SdNagzDvGth+ByFtnY+LsEvG0CADRPKXeI3558D2PQRZwsG4yYUzcGUMDkMa
cSBKUki4/oeResxdaXI7CoYu8T3MO5d6DTwR9x9GvCwpqIsO9cA/nj54kQ==

                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                RGBColor[0.6, 0.24, 0.4428931686004542], 
                Thickness[Large]], 
               Line[CompressedData["
1:eJxdUXlI01EAHh5UdlDqvJpzo5qaVogssqbfM1uGaKIpiamhafOI1CGCK0jz
QCpmhBQqGDFLwpSVk6ZZznQ6542Zlilq+UeeKM0Ro2i/468+eDze9V1PmJYb
m2HD4XACrYOa/8ct55bwBUUBVImlrfq7HMKsy5CYLz48em4P0fLLV2K0SnzJ
dK+L+u7InlcjjPfg8UOjC6mtoYFxryA7i8WdvV+Pmpth58eUPLIaQ+08g9gx
JLewms++b8D2draseq+AOEyp8oIdGtF8KXP56RMBy/cS9WnJ4vU1AfFNqvpo
8nkFuYrIVFwhy98Cxd/0uEdOQtJgfT2lUmNe3msXuSpg9V7DvTHqqk+DgATS
aEVySldrBASsvgaS4sqS8FIv0mPysSq0wbuZJ/+RzGf9vEWB6NRsGdeTxDKC
SIg+dmRGfZD11w77xc0XASc9yIKCIuzAdJDSOavJjfXbCe+VDT8z15XkU/by
3uPQYsD6koLL+v+ACT+JbGLOiTC/oMOBykL7Lakjm0eHccnlgl2a/eQCLdCN
RufW3o2EfWy+bkg6JN6y9N2EUrNKosgiD66p2snm7cH82vK12Tl7QseZ6gEn
UndfH2/L5u8FL7QzRWjmEC/KDl+PtpzcVJt7f8D0YV0XReyQl/yG7DqFPlw5
USE1TJrA9NOPrTvZ/p8qtkCxObf04/mI5w1X0QaYvgyInqu7GLrxE9sUnckA
IvVfP526BKa/AQxobEUu8gWE0IRGKM+0W277fwPTpxEzfbVHDSWfQdsrH4Q6
c/LdnGEcTL9DiDSPqb8ODmJ4iAZ04WeLtQo9mL6H0SD29fDP0oFLGxzB8bZf
GU1GLZj+R2DuzuGLSt+ApksahSZ+ZjonrgnMf4xBKu7Su22q8A+I6HQZ
                
                "]]}}}, {}}, {{{}, {}, {
              Hue[0.67, 0.6, 0.6], 
              Thickness[Large], 
              Dashing[{Small, Small}], 
              Line[CompressedData["
1:eJwVlnc8Vf8fx1WKJCIqVEjGtSMqldeJhowyC0VWkTKySsPeIyrJzN4Z2Xtf
17ouMiKjRZTCV0pR/e7vr/N4Pt7nM855vd5D0MJB9+p6BgaG5XUMDP9/ql+d
6WucVVDWaX+9maG9V5lRlddxkocLhgfeVLyvL4B8UkxCCc9+BFkFGTOU1kOD
OlycyHMQ30c3Zac978FFq591j3lOonsdx15xlwmMywSqhvPoI97KWT+Q/xuS
uc8HhPBYYSqCT1X+9h94M5eIBvO4QOhsGvmaOCshfuZRULGjC1ruafVJxLIS
/f4Os28oLohsPBj3iGkrsX+DZJ60myvGXp5uwIetRNufdOmBfjc0BBuPiUWz
E6xL0Qr8Ye5wcibZC7pyEDHjd1XL/npgpOi3FH8mF3Fit1H6hIEn1PTkgtOH
uYjPxoc2Mud7wkc/um2VmZvYO+dumS/lhVO+JD6BG9yEw3VFYYYxL+z4mBt1
QmoHwWlVmJ1x2Af+0wIHl7J3EoZGKYULi36wKfoXbO/BS8y/0WdJ5fWHjljt
HsssXiLAlPmqnqo/7hktLcr28hIllg685VH+uBoTFGwoyEew2R/3v3coAAy2
/eWvm/gIss+I8aYHgVg47CeZtbqbkHvBsWk3cwhciciVHl1+okOabEaVDcHo
5U3E+tv8hNnLOzUeRiGIm3VQ2RbPT4SXTzq+yw1BzQmenNr3/MRMY/6bTK1Q
XNnwV1zysADxfPDsywNPwjA5lbtOr1mA2PLP+/KZvRGwj+tV/dUuSMRcv2gq
eToCZk9sbO69FiT2D0iacdhH4MomvatznwQJ5Zxhyzd1EZiTDmKI37SPqMqJ
LquQjgTl8LC1hOo+4qveXK1GTyR0to9d3lu1jzDIftblvPUxXO/b2d+JESIS
THw0rwk+xgenuvh3GULEe047qqHCY3jPrdkolQgRDg9UaMdNHuOnJ3WtmipE
BOt+7WfKfwx3geralXX7ibo1ldF4zSfITtc6dtN6PyGs822mJTQK7xVWIs1E
hAlezzNK1ilREKE+FGmSEya25SeHslRE4d1X05vsECZ+M+tJ67yPwuxpK3HX
i8JEb2OF88Thp6itDL58LVCYuCvr/Xdl6ikWNrkxfvogTPSwc3FJE8+g31gp
khghQrQct7vaZ/AMhAkf0RorQlTeaCt3ufEM1nmGfKNpIkQa5Y5RTfQzCEhy
KvVXiBB3PMefq319hpshqVuWJ0SIffOZJMu4GGyMNElkFRclbvccQcz3WJDq
5yoaS0QJNumyqQ7mOAiY2pWeqREl0sNlw1Z3x2FP70BSY7Mo0acpOmJ6Kg5x
DVxmQX2ihEQXl7NwdBy8t+Wfd/wmSkxS5jOLD8XD8tuFw9nCYoSb6A2tjxrx
MNRZ8NGRFCNYA6eXuM3iMTlRKfNVTow4cnqccA+KR5J8U/cqxIgnrZ2jGInH
pjX5STcjMeJMUwYb9W4Cyr7E13wOFiMmBATL/j5MwMaYsvC6CDHCxSvhkmxa
AtgjPir4PhUjUvAk+0lXAiRKw4Q/JYsRq3VeKsa7E+HjbaXFWSFGFFZfcvtU
lwjjhwZ8a2/FiNO8w7t5+hPh/6iu/N+UGDHmrtuiPp2IY7vCE358FiM2Hzm7
rYDtOVgveVvVfxcjLCsUc12uPAfb1pSX5UwkYmcpx8S6dUn4EXwlWVuCRFwO
W9X/uCMJS9mrt6dlSESq1VRXm2QSiLx/X+wOkghJ7qqqUMMkXOA37tE5TiJU
3MyechclQbSR28v+HIkIOqfOukJOgty1fOXHuiSCKnLQd/RNEsxL3n/IukAi
XnzxraRtSIaYI8GUY0oiFBMuZkbJJONYnnvZBnsSYRTU/c5fKRn/RIteVNwi
EfddTuy5fSoZm43LBkxcSUSTpkSU0aVkCAueGPO6TyI0//z13huYjKePprr3
hZAIc9NMk+yJZDyuzzg/kUoi/NT5YmNnk6FsWpRXlUEiMhUjB0K+J6Pxdk13
YDaJmGO7q2HHkoKggT6ftXwS4dagdUROMQVlR0ab1CpJRGxes4vQiRTkj7ap
1VSTiNpnh4q4NFOQ8CFtQqCORKxzFBT9aZ4CP/vdl8lNJCJMYJmrNjwFeXNm
yS6dJKKA1VY7PyYFWlelU7y6SUTfykTo87QUtMyX/fbsIRE7+trXe1el4OF/
nWOG/STiSN1xZafWFNCuN9+WG6DrkVPsbklLwauZM5H/BklEinfCwqmpFIQ4
tZu6jJCIVjsOyUMLKYiTExXd/YZETBsFWIutpuCCyZtHFWN0veQcJ1g4UhEm
st65Y5JElL9X7aYdS0VUu8ZV4ykSMaTmvRh+JhUbw6puxE2TiB8F9Ts0dVNx
2fAetecTiTh074h5u3UqZg+lk7k+kwjDd24BAU6p2PvUxE7kC4m4c6Y07+SD
VJwKYn8iOUciKrfL/Gh8nIpHJj/v7vhGIl673+TzTEzF/U+3z/2m88pkDnE8
OxVL5wOa++dJxK7Tn66uFqfC/SZ5MmmBRBx+sT+0qi4Vv1iHC8wX6edxWhTd
bk+F08qlw7v+o593J2lQ4VUqPGaX/FroXHWSV6B4JhXHXYaCV5ZIxGjuxVOO
S6kIFrmk5/OdRPze9tRW+m8qqMzW69ctkwje2/0Rc8xpKLKKSnKhs9I4e1nu
9jRIW96XH6ezsarWqM3eNAhsrmhT+kEi7uaE/BMhpeGv/BvzcDrHsbfvn5JP
g3O0x9ZBOle7blRPU04Db5lCP8dP+vlvVBzMz9L5w5NKVTr/PuEVxa+fhgll
iQ5bOvNm11WNm6ahtyCMNZDOR9lWJ+Kvp+HX+JnQGDpfdjnMaOySRu8HX7SS
6Hx/1JW0yzMNdbMbTOLpnECUnBsKToPM0J6mMDrXZi44R0WlgSW+xceZzmOs
0rG6SWnwCfbIPU/nNacb9dty0zCaNkQI0nn3SPaHntI0HIzTPTdDv/9xTDOH
N6RBmXL7TTqdTTOEpDU608At1blwgc4eW8z1Ng+mYe1Wd/Rf+v95fuv5Hcok
ff34v8F4OtcPv0n0/0y/r97Hcmk6TxznaVFdToORwcqJCvr//5t2YWYdQzp+
rVR6KtB5L0vU1kaWdLB+TrmTQ9dL2bFPzoObHreSUthOZ9MhNsNjAumQOzhQ
50TX1+OY5oPf4ulYn7+Vr53uhwZmCsWNSEfrEzZXfbpf3tozfj2okQ7t03U+
oXQ/MQye4FwySIelMDWgku43IqX2ssONdAjq9zz5TvenGdNvbym3dNQ2x+Vv
oLOX3aGsL17pSHjqMclM93PjkeJF6+h0xHgdyF+eoe+fNL9DJCUd3TI0o3F6
PjBskjr2MS8dN28IEjX0fDnRnxVg1pQOxi0Ob4w+kohm20Q+o7l0iL0SOiRE
z7eS2Rs3TH+kw2E/7+LgOIlIt1GqsWTIwFGrCEsven76Xxs2tufKQEj3xvBa
ej6rWXDE+R7LAE+fSmH/K3o9eDc5G3Q6A71Cxp9V6fVB3KzgyEPtDLSZz23P
7yURrKYaIzFWGciXuaZlTSURNCP/XQVhGZA+ksp9v43+Pa/1bEqiMzB1N9wr
v5VEFF3cV1mZnAH1jzHsw80k4rFBw8WW0gxwSbaXcjaQiAs6v6Jfj2Ug9wgx
JFlB95OaHfcGqUwU/Q45/R+9flIpR68yH6Lzh02cOWl0/U+zlG09kYkq1ZEb
hikkIulklv4ug0y8tRr9mJxAIiyId0+kHmSCece19JHHJGLmkAGnITUTsv6K
3AsPSMSyyHH2fLss3NA5c2qC3j+U36tQQu5kIdjAgWqvQSICEtU8bXyzoBpf
HPzzDL1ecunPC8Vm4dWJ7Q2LBL1/rLtBi2vNAmXejiFEjl4f3sREBPFlQz9y
9ps2F93/Ed/ZrTqywa7v5+XYL0ac1PhNOTGQDQGX53t39ogRYZsYvPgns3FM
HgvlHWLEngdbFka/Z0PYQEfrfaMYoWy7r1dHIAdH17W3zxSIEZ4ntSNxOwcC
o9ZhNfR+vv5X3jY+4VysEjVf85XECD6qyhJkcqG73y74nYIYcTBlZNDqSC5e
P15g3XZAjLh6lim+QCsXZUX5H0xExYj2WAthFbdcmChpuddtFyMilHiUrlNy
0ZzFGPToiyix+36AZcX1PEy6zPWWPxMlFP+ZlesVvMCPDBfFox9EiG6/gz1t
4oXY2bfPUtJImOCP/PIr51sRCnZ9Nd/lJ0R8+Tk5MShbjC1l5n/mqgSJ9M81
nWwPSxD7mlK2LpifYNuTNf/xYyn8MyS2ZrbwEWHXy64l7y9HY+ZsTbzVLuIH
kffRxrMCsnfYpe8ucxEucq2lO1oqoUvd2VfNwElMFrSG9glWQ3dP0c9KOTZi
1XYgnnS3Bgb3LD7aCGwmJE4w/b1WU4srRnu2HltmJM6kClq/3FmP8UPtmyWY
1xG391zZ9+5yA9LqfHZ+aF+FhbbshTHzBmxU1j4nU7yKc77rQoavNYDQMf0W
HL8Kkdm0RapjAw4KMV2wtV/FQOlMY7Ufff32pwrDXKuQ1XS6EvWiAZnd7vWX
rX5j5q5/wpm1BlSs3KL+t/UXJOcMtgxrNcJc9JWeUMgPVOprNoRoN4J23GIj
XH9AtU7FWVmvEW7ss3tszX7Q5yyZNxmGjUhVH7H+pvgDwbKb81wsG1FrTY0r
+LiMaZdadU73RogJ++gzqS4j+c++EK30RkyJ+j2cYfmO7ewLzK2/G3Eyxy58
lLyI/rqQwLN/GpFdoDhQX7aIxzeFN9H+NWJwZ/TPgoxFcHYabxhlbILJ37za
Yn86+5P/zLM1QSv2WMKZ04vYthr3H59QE3y4ZB+ldCyA9dOpMWeNJkh3yb4c
fTkPxob4QqGEJvBVu9UpHZjD6LGTapPPmzDMP9tmzDWHwuq5t3EpTZiryyWe
/PwC4/LjnJxZTTBSMVfXqv+Cl/mTLgzFTfA8sML3UfMLTBOElMYpTeh3/DIb
Yf8Zle55rdFLTYjO8cTdlhncOFgzslmjGUVBz/Sdi6bQ2Dv4olKrGcN1FqU5
sVPgtlvwtNZuhq85g9R3nyk0ZAiLkA2asUNiWZ5sMIXtOyOdvMya0U9cFruw
9hE1v6y2/HRtxnWTDnkxrY/Y0sB2/GNyMy5b+00e+PMeeWctkut/NCNBpO7z
tqi3OCgpqIxfzeioVjgv4PsW9Wxv3zSsNoM5dvCmstNb9L4y2dnE0IKHY9tf
ZGq/xXcTo4ctLC3YZssiKsL2FspO2vfb97agaBdtrWjnJHrjlA37T7eAqe3F
QLjQOIwe/FnWPduC+XWJBxQ2juP9ldonrzRacC9sNfrn9Bi+71eiDWi3QOJT
oQw1dww8hQqnh41bQPmqFVolPwaLFsmDY/YtqCbqowPU32D5C++26egWpM3z
fnIMHUFU4idKQmwLcsyvu7Haj0D+fKmnXkIL+v5M85K1R3CrWGu+MaUFxUMn
1MJ3jODrHa+e+BctMKQ8qnRLe42pjdNhOs30OOOWg3HNwxjkf7m57msL2D8P
/gjkHoJL34Mm54UWyMVr0uJWB7HdV91dfKkFb8XPrVDeDUJn+sPMs5UWXHfD
tGPBIKgvdrQ7bWhF9G2bsd9qgyAfuR8gxtMK04K+3DGfAZTpndkQdbIV5fs7
3p/a/ApBGpX+u8+0YkLgbPCfpX5cViUxZ5xtxZKu5ljHRD/Wy2/ZWn6uFW6Z
RaeTS/txjpO247VhKxx+JF5TMe/HTO8F8d12rSh+5lurVd8H3nPXdNKftsL4
vDuVI7AXX08Nv5KMaUWfG41efHrReFztQllcK4R54ti9zXtxTUr8UltSKzYz
Zb9XOtaLEtZvVjM5reBpDHixa4oGzS7XO5L1rXg81xAjR+6Bp5p/Uul0K0ZU
nZY/JXWj39TmsuxsK85Hvsww9ezGflcNnhdfWvH95tv6ZdNudKZwPElbaEWR
t06T395ucK0mBjz+3Yqnbzv3CiV1ITu/3M6RjYyqzHsH1DM70cs5c1RSkYwe
O+GIsK527CN1rWQdJiP20vbe8YJ2uKKgTOgoGUVMWSc0H7eD96aLDB9Bhp5v
vZ6XUTusyAxCLOpkOGX98VaZpWDlNg/LjAl9v3cKeTxsFAiOq79O8ydDQPeX
w42bZIQ0Hy00CCJDxfUfhV2HjP+yJAOYQskwD+381a9ARrMT28EbkWRQ90+6
lv1rhRVzf4RcPBn9jT2pn6JakS1vdKapiIyYLbY5n1pbIB1iXT7xhoyN6RkW
j5SaEe1gGB45QYZ7z3+TI/ua8U//rJXKOzLSfdQrjm9pRi+/BGfmNBnB8Zab
L4414VbZNzu7RTKe9T3Vp3o2ofStq/DapjZUdOk9ftnVCKVDflE8cm34q1u9
Rf1rPYYseBQTD7ahWpKwZqHUw/lhwbDAoTaomI8NfU+ux4up17xix9pwxyFb
/4xBPfZGSaUonm7DyeL13hMNdVi/OJSvZ9wGjpsp+SUJtejKJVHCfdpwXiM1
bd65GjZD9TYc/m10H504lK1bDcb1+ixPA9tQclJcNOBANZSNPLQSwtqQTuYP
ezlfRdfl1avc6DZsyrL3abarQpTV/beU3DaUCQ8fKnCsxOW9tF/rXrXhkaHq
r+rIcrDxOJXVDLahudwxw+FWOZq2c99yfd2GIs9KcQ3dcohsvjQzM96GgSJr
XjeucswvTQ/RZtpg3lTC8iyuDD4df0sS/7bBf43s/y6/FNku0vZHxCng0O2r
9JkvhrFDH2lJkgLHFI+E1oFibLV1mXohQ0F047frYtXFcLpSfVlAgQLjj6xS
Bv7FOKp+WoOJoEDxn4wa9hSjh99UbNCAgqoo3nEFvZdY7gx/7+hNQYr90vdr
+YUY2zJos+ZLwZDrDvYxn0I0a+6eDwygYPtvgUQ/w0JE9uSuPg+loJld4JgD
YyHE+ylc1KcUzJLNUtNNC2A6su4MKZcCeXvfMPPd+Wj75Jr3rp+C8nOl3FU1
uXghVnfAbpCC/MUNWw89y8WT64yVK8MUlP6iMr93yoXZl8et7OMUKMkEadSL
5+L3t8Lx458oYPrLXBGSkAOZH7PscasU6Bk98DgblI0YRlMX3f3t+PRA8Aiv
Zyb+Wu5U6BNpR3FNoOhds0xYtfQunye1g0nk1Kt/9LlU1kf1tpZ0O2K61Bvu
bcxE+z+xu2qH2xFy8KD7gYcZ+Pl7yVNZsx3HmGav38pMx4XF4FBxl3ZURMyp
yS2molZbVTPHrR1TpXOmf4ZSsa9ojVXMvR1hbavGs7Wp+Gbv8FDYgx6v8XMW
Ck6F/5z+I4GgdtxdvnRgt1AqSj/xP9uR0A7Gta1ZDCYp2D5Rlrq+lX5/r8K5
k7QkPGR98KCirR2+6xhVyc+TwHL0pOHNjnYkrdqMBNknYX1M/9ahnnZol22+
/5otCf/pzN/JGWnHRY8vqZG6z9FLFjuvPd+OgQsDk3umExCWH7+ayNuBo9Yz
dkFH48A8ZjGku6cDLlWFy0OccfBjEX/JJNCBtQW/zVc+x+KedeW1W8Id2Cbx
rYQ3Lha2goN9J2U7kCbZpHR4LQZqT9myv5zqQMszvpM9nc+w8YG3/pFbHRi2
mFQPjHiK0sW5Xw3OHdBpvrq/1eEprK4ZJp1260DkI4l6Ce2naD0v81nvXgdO
x3NevcvxFH77xj3t/TvAyC7xjT06Cozth/PSYjtg81eEeSHzCdZvX1jH1tyB
h9fFymWmH6E48FJWVGsHRF7qfrPqegSLtTZNPkoH7qWHjNcXPULzVOIzse4O
5Gr8knx77xF8KjWkVIc64BizI//V9kdYZ5pleOdzB+TD5SouqkeCIce08D1n
JwrsPgvrpYSjbW7YPom7E8anrjh6O4YjTFZH+vKuTjirb/f7hXDsrFTNH9zT
CWvePDfyZBikKWJ57WKduNblXdC0LwyXp/7LLFCmr8+W2vGjLARVgoHP79p2
Yk1vwb+GLQgeVxlMD9l10ucE/VvXpwPpc6D7nu8OnXj9MuuuQX0gemVvJti5
duJckt7DaftAzEAnzsyrE4d6mCw/9Adghylf9OnoTrxcPWj6N8MfTnGF4ZzN
nbhub7XH180XFWtxgc2tnWCfaU2cN/DFmmmAtxOlExYnzxo8VPBFoJCJa393
J47fZdQ1X/ZBwgsWk8fDnVALfffN4LYPyPVXJTm/dmKjerGMsp83dn3g6+LY
1QVVy+6vHl6eMDnFRG7i7YJ0mQ/jB3VPpGb9V39rTxe4yLQz8dyekLzZUdy3
rwsUabhueuGBE8tucY+kusC4q8a5euwBbJn6r3OodqFuUlJUXus+6iSCmDns
u6BI+oYL1u5QHNhJfezYBdkL1Yf1ld1RdD/rEZdzF9IVlc0iuN2RSm3j3XWn
C8n/Nc/XtN5BkMNGKX6fLmzqec01JXwHuiU+OlLRXfCpZx+VXXLDJ6UHcWfr
u6A9v2FLeIULzD6wXulq7ELCZZlLz566YDQ0QUirpQsqX33lB51d0D1W80K7
vQvon7zyWdYFxR6/6y/2d4FHb/2iU74z7jff/nB1ugt80qOXGwudwKHuJOnD
1o3D+4aG7gw7IrmJfYsSRzdcHW76cVc5QvZI/uzi9m58EOJnnopzxDmxmUxz
nm6knHW+xHfFESGbTAVP7O/GqIFqTNUrBzC2nN3BoNQNiduZv99ts8ePo4IM
Hle7YXfgqXwHzRb+JfUTCjbdaK086Rf33BZcEpfrvtp2w+r2QEKDnS3keZ/d
NXHsRpbuXb4NW23huMK6fOxeN4yYl2TMz1/HbOnK7GpkN+4dkmDZ8sEaY1K9
r9xru9F+6sZwi8pVJH3heLChoRt/Is/w1e+5CoscPZHwpm5w+DzQ/75ihdn9
w3eS2+hz0fFvKtuLrPCDb2IPpbcbrGGJdhyCVuBgmbPmmuoGC1emdctWS5ye
Zlor2EqFRtpcdiW7OTann804vI0KFUdyeviiGbrNQ881c9LjPC/ORb0yg944
W8rgTirc3bi9FGLMYDbAfXpNkIqh/LFDDUJmuNcsFHlWkYrD2hYuZoGmKHqO
/R9NqeDz95I+rn4JS3eXmMzNqfi7ZWBJnvcSFC9mfRm3pKJahP+J+2dj1LCz
lwzbULGhQs53PtQYbV4TJ7qcqMgrWznl3m+ENxYPrhQHUPGT7a5akp0hNonW
xHkVUNElsbNccsQAZzc4ePwposI2oDtWqNgAYZP7LO6WUOHA/S3hUqgBOGJC
SC6VVHwaGHcMVzbA7s3GldbNVCjFd7p/zdKH3JeVwXNDVLyW1hNWD9CDSaEi
x56/9PcHDT/O2uug3HiFrZehB6/7L6YkaeqAbVM1q+8GOlcfsIsS10Hj5ePM
s8w9+PFE1v/IJ23sYzn5r3R7D0TdwvZfs9TGtJXOV01SDz4xHdQap56DPe/N
jvv6PVgIPUzilNVAG1mKInOxB4+L4v9V/VIH/6351vdGPfg+HxVAaVFHL8Wp
Ue1KD96+VpveZqQOOVf3Ci7bHtgVX5g9G3QWP2kBGS88e0D9M2PWuHIGXv4p
3mO5PejmSyVp7zmFrbeZ1M3ze/Co5vN9teWTiLOx45wu7MH7T1mLgdSTKNE4
kjZf2gPvd1tujHqcxDRHX+v6hh4wSnR/b/yoCo3nDMykVz3YZul04UCdCnZU
XHnoutqDfN1jR3MSCaRlky/8/tODjz0jFoUPCMjGSfB7MtBwkG+j2rwJgbMP
fhYGbaTBZuEfhZefwH3ViL54dhpmNqTrSaoB72n1XM1CNOxn/W4c63gc+TN7
4tk0aZjeeKbpIZsSghL9zSbO0ZBn8fdiy+ARWOl+FS7QoeGRhNKRm4lHsLu2
tkjrIg3l+Qeu7ZQ+gpCIS21hFjRUdAiH1ugfho1i7CKLOw3fRnXee5Ur4uQX
horRezT8xxB2/6mfIviTbe7netBgPdp3iENPEUObDzOp+9Fgzr+yorSogFPj
Q7uDI2jIkLxwWkVOAfv8uNSYMmkI7X7h6t4mj7+H728dzqbB434Fc2acPEa+
fujPzKNhJFRqWcpBHpEXS0xOv6QhuCWQW4tHHv/EdZ39a2lYunboYtktOYz1
RTzf8IqG6+dK5mPkDqAy4Kflq0EaducSYeKsBxB19Aop7TUNpY3hv1mnZaGR
IV2qMkFDVazCq6Y4WVTfoXZ4z9L376uxGGWSRbSUQoTOHA17U3KnmykyuPU+
QV9wnobY89sYrnvJQEzz5mTjdxoClbgd7ixJg3HdQHrkT7o+2wacJ/Ol8bbs
qK3Zbxq2dv7pGbGRRq1tmozsHxq+GpqbXNsvjWf8W5b//aNBseztH9+3Uvgf
HjMFoQ==
               "]]}}}}, {
          PlotRange -> {{-0.3, 0.25}, {0, 28}}, 
           Frame -> {True, False, False, False}, LabelStyle -> 
           Directive[12, FontFamily -> "Helvetica"], 
           FrameTicksStyle -> {
            FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, 
           Epilog -> {
             Text[
              Style[
              "\!\(\*SubscriptBox[\(m\), \(0\)]\)=-0.1", 12, FontFamily -> 
               "Helvetica"], 
              Scaled[{
                Rational[7, 8], 
                Rational[3, 4]}]], 
             Text[
              Style["A", 14, Bold, FontFamily -> "Helvetica"], 
              Scaled[{0.05, 0.95}]], {
              Directive[
               GrayLevel[0.5], 
               Thickness[Large]], 
              Line[{{-0.1, 10}, {-0.035, 10}}]}, {
              Directive[
               GrayLevel[0.5], 
               Thickness[Large]], 
              Line[{{-0.1, 9.5}, {-0.1, 10.5}}]}, {
              Directive[
               GrayLevel[0.5], 
               Thickness[Large]], 
              Line[{{-0.035, 9.5}, {-0.035, 10.5}}]}, {
              Directive[
               RGBColor[0.24720000000000014`, 0.24, 0.6], 
               Thickness[Large]], 
              Line[{{-0.1, 15}, {0.03, 15}}]}, {
              Directive[
               RGBColor[0.24720000000000014`, 0.24, 0.6], 
               Thickness[Large]], 
              Line[{{-0.1, 14.5}, {-0.1, 15.5}}]}, {
              Directive[
               RGBColor[0.24720000000000014`, 0.24, 0.6], 
               Thickness[Large]], 
              Line[{{0.03, 14.5}, {0.03, 15.5}}]}}, AxesLabel -> {None, None},
            AspectRatio -> GoldenRatio^(-1), Axes -> True, 
           AxesOrigin -> {0., 0.}, Method -> {}, PlotRange -> {All, All}, 
           PlotRangeClipping -> True, 
           PlotRangePadding -> {Automatic, Automatic}}], {
          Placed[
           Unevaluated[
            LineLegend[{
              Directive[
               Hue[0.67, 0.6, 0.6], 
               Thickness[Large], 
               Dashing[{Small, Small}]]}, {
              Style["1-step approx.", 12, FontFamily -> "Helvetica"]}, 
             LegendLayout -> "Column"]], 
           Scaled[{0.1875, 
             Rational[1, 2]}], Identity]}]& ],
       AutoDelete->True,
       Editable->True,
       SelectWithContents->False,
       Selectable->True],
      TraditionalForm], {189., -119.16407864998737`}, {
     Center, Center}, {360., 268.32815729997475`}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
          LineBox[CompressedData["
1:eJw1U21Ik1EUfqdiqUPnFBTNsqwMlRRWIoHvuYjlEHJ+gQbLytJ+zEoTSoZo
ZoqaaYmKlZTk8hOnUyOz2N10pebXloZmBClaMHOk2/xupO99PXC5HM69z/Oc
c597OPlWbIoVRVEhO2t3FzAxgW1d3QarT9ug8j7zCXH5FzyiLTVYhmzRYkzP
wYJFHRbkxiznX7NDwlmpqzxCh515dusZRgckSw+1n6rX4iZnQav7VUdEMaHF
hVaXzkaJeGj3dkzPGLa+H+eVI3RGzPH0Ufy9ukvj5cJHO2Q7jCPYPUptETXw
EQM/+xmP1d3gGjf56CkTQ7j16KaNH9cFxTKAg3hJrU0bmOKjXbRQ+wFcGTQS
9SiJjxj5fR9xCL8s+YzMGTFwUg0OTlAlXG7nIdJvP+a4xWfY8Z3Y/tQYPyx/
czyLi+oZgSpsaIypEjfbsfqV2L9f2vVVacvq/YDzTTdHPXTWqIbR9w5fUFyU
t6xSrJ63uMwUxntVsA2EvxvPm08WvS5eAz3Dp8CPF5s81x2NQPDlOHHCVB0e
bgCC14wLkxqdkst+QxZzX4ajRNIchXkWOpjzL7BTWmP43PgMpDP1Snw941hL
QNUE3GPyB1jvSJW0rQ8Dxca2rlAiKejfq4NStt+j5Hkvm1eC5sB4rkqhABXB
h5cp3T/jVxrYugx4831F8/9qoY7og/AZfadx4smefjCvrkQuxBbAH9IfSD5N
hq4OZEE26R96fM+LNowS4JL5gIPWR5JWkQS1ZH6wL5CKNAVFQwCZL4iP8Np+
VSMWXwmpjWF/OyRBQPymgpq7Y8Up4kMsnxo4KI8j+saFU+R9wbPeohcWbtCE
XwNmLDwX2L5Aa4g/oDZwstOlSUez/oEteTR1J+89zfoLyuLMgopMGf2M+A+c
/FNFgrVSeo74E65M/1g2ZmfSfsS/4G0R1ixNJ9K3ib/B4DMwHGEIpXuJ/0FV
u9Xiu+lNc8j/gOBti5LjYkX/B/QNtns=
           "]]}, 
         {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8HntgvvNJtOveCP/bc1xcX
2HId3192c0Ke+kJuh8NfNWL6Dx3dfyXoXW36FmGHapF17g+rjuyfqxPTsHKW
hIOJMQgc3r//wVGFJ1EyDm8CQQYe3G9xyZGj8r6cwxKgadcXH9i/Kjvnp4mw
gsNOkHU79u3Pddm60khBwUELaPpXjT37l4YH37L1k3eAuG/n/uz/E5WUamUd
IO7Zvl+/T3EFN5O0Qw3Y/i37+bPDPr0RkYDat3H/IvUZq1XeiDiAvbNj3f64
/wsql+8QdJgDNm/l/oYY5muJbrxQ/Uv2z1KvWug6lR2qft7+6h7BCsV2JocG
sPyU/fMSrx9yTf5jD+G37JcomNEdZfzVHhZuTvM7Sr7efmdfAJG3/5QV5rPg
wVP7Coh++yzDSe49xvfsoebbd8jejbzncQUqv8Re/19bR0j9KfsZEPfZd7T8
a4u8eACqfp39Ou3NK4/s2mIP9Z/9H33GeRanVthD/W+vctFNq27PHHsOSPjY
O/wt+/BLYQLUvJ32eQGsB9Y0N9prQMLXfocH59uZCUVQ8/fZ1/Rf2SI2J8ke
Gj/2fy+lH7qoGQS176D91c0ny77zO9pD49eeU/bA59xzevZVkPi3X3Zhr/3h
dVL2hyDpw9765rtZuUps9lyQ9GOfdmivbmLvRzto+rJnVWr7YNJ3yw6a/ux7
X01jeCB32O4R2MBT9jWbWO79UFllB3HvGXulr+tt3N9OsAM7r+Cs/T/2VZFB
m0rsIO4/Z++XnjPlwcVwO0hsXLDfvrRkB+d2SzsAfQxhnA==
           "]]}}, {}}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        EdgeForm[Opacity[0.371]], {{}, 
         {RGBColor[0.24720000000000014`, 0.24, 0.6], Opacity[0.5], EdgeForm[
          Opacity[0.371]], 
          RectangleBox[{0., 0.}, 
           NCache[{0.005, Rational[2520, 241]}, {0.005, 10.45643153526971}],
           RoundingRadius->0], 
          RectangleBox[{0.005, 0.}, 
           NCache[{0.01, Rational[3800, 241]}, {0.01, 15.767634854771785`}],
           RoundingRadius->0], 
          RectangleBox[{0.01, 0.}, 
           NCache[{0.015, Rational[4040, 241]}, {0.015, 16.763485477178424`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.015, 0.}, 
           NCache[{0.02, Rational[4200, 241]}, {0.02, 17.42738589211618}],
           RoundingRadius->0], 
          RectangleBox[{0.02, 0.}, 
           NCache[{0.025, Rational[3920, 241]}, {0.025, 16.265560165975103`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.025, 0.}, 
           NCache[{0.03, Rational[4480, 241]}, {0.03, 18.589211618257263`}],
           RoundingRadius->0], 
          RectangleBox[{0.03, 0.}, 
           NCache[{0.035, Rational[4160, 241]}, {0.035, 17.261410788381742`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.035, 0.}, 
           NCache[{0.04, Rational[3520, 241]}, {0.04, 14.605809128630705`}],
           RoundingRadius->0], 
          RectangleBox[{0.04, 0.}, 
           NCache[{0.045, Rational[2800, 241]}, {0.045, 11.618257261410788`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.045, 0.}, 
           NCache[{0.05, Rational[3240, 241]}, {0.05, 13.443983402489627`}],
           RoundingRadius->0], 
          RectangleBox[{0.05, 0.}, 
           NCache[{0.055, Rational[2160, 241]}, {0.055, 8.962655601659751}],
           RoundingRadius->0], 
          RectangleBox[{0.055, 0.}, 
           NCache[{0.06, Rational[1080, 241]}, {0.06, 4.481327800829876}],
           RoundingRadius->0], 
          RectangleBox[{0.06, 0.}, 
           NCache[{0.065, Rational[1880, 241]}, {0.065, 7.800829875518672}],
           RoundingRadius->0], 
          RectangleBox[{0.065, 0.}, 
           NCache[{0.07, Rational[1360, 241]}, {0.07, 5.643153526970955}],
           RoundingRadius->0], 
          RectangleBox[{0.07, 0.}, 
           NCache[{0.075, Rational[1240, 241]}, {0.075, 5.145228215767635}],
           RoundingRadius->0], 
          RectangleBox[{0.075, 0.}, 
           NCache[{0.08, Rational[760, 241]}, {0.08, 3.1535269709543567`}],
           RoundingRadius->0], 
          RectangleBox[{0.08, 0.}, 
           NCache[{0.085, Rational[640, 241]}, {0.085, 2.6556016597510372`}],
           RoundingRadius->0], 
          RectangleBox[{0.085, 0.}, 
           NCache[{0.09, Rational[600, 241]}, {0.09, 2.4896265560165975`}],
           RoundingRadius->0], 
          RectangleBox[{0.09, 0.}, 
           NCache[{0.095, Rational[720, 241]}, {0.095, 2.987551867219917}],
           RoundingRadius->0], 
          RectangleBox[{0.095, 0.}, 
           NCache[{0.1, Rational[400, 241]}, {0.1, 1.6597510373443984`}],
           RoundingRadius->0], 
          RectangleBox[{0.1, 0.}, 
           NCache[{0.105, Rational[200, 241]}, {0.105, 0.8298755186721992}],
           RoundingRadius->0], 
          RectangleBox[{0.105, 0.}, 
           NCache[{0.11, Rational[80, 241]}, {0.11, 0.33195020746887965`}],
           RoundingRadius->0], 
          RectangleBox[{0.11, 0.}, 
           NCache[{0.115, Rational[120, 241]}, {0.115, 0.4979253112033195}],
           RoundingRadius->0], 
          RectangleBox[{0.115, 0.}, 
           NCache[{0.12, Rational[120, 241]}, {0.12, 0.4979253112033195}],
           RoundingRadius->0], RectangleBox[{0.12, 0.}, {0.125, 0},
           RoundingRadius->0], RectangleBox[{0.125, 0.}, {0.13, 0},
           RoundingRadius->0], 
          RectangleBox[{0.13, 0.}, 
           NCache[{0.135, Rational[80, 241]}, {0.135, 0.33195020746887965`}],
           RoundingRadius->0], RectangleBox[{0.135, 0.}, {0.14, 0},
           RoundingRadius->0], RectangleBox[{0.14, 0.}, {0.145, 0},
           RoundingRadius->0], RectangleBox[{0.145, 0.}, {0.15, 0},
           RoundingRadius->0], RectangleBox[{0.15, 0.}, {0.155, 0},
           RoundingRadius->0], RectangleBox[{0.155, 0.}, {0.16, 0},
           RoundingRadius->0], RectangleBox[{0.16, 0.}, {0.165, 0},
           RoundingRadius->0], 
          RectangleBox[{0.165, 0.}, 
           NCache[{0.17, Rational[40, 241]}, {0.17, 0.16597510373443983`}],
           RoundingRadius->0], RectangleBox[{0.17, 0.}, {0.175, 0},
           RoundingRadius->0], RectangleBox[{0.175, 0.}, {0.18, 0},
           RoundingRadius->0], 
          RectangleBox[{0.18, 0.}, 
           NCache[{0.185, Rational[40, 241]}, {0.185, 0.16597510373443983`}],
           RoundingRadius->0], RectangleBox[{0.185, 0.}, {0.19, 0},
           RoundingRadius->0], RectangleBox[{0.19, 0.}, {0.195, 0},
           RoundingRadius->0], RectangleBox[{0.195, 0.}, {0.2, 0},
           RoundingRadius->0], RectangleBox[{0.2, 0.}, {0.205, 0},
           RoundingRadius->0], RectangleBox[{0.205, 0.}, {0.21, 0},
           RoundingRadius->0], RectangleBox[{0.21, 0.}, {0.215, 0},
           RoundingRadius->0], RectangleBox[{0.215, 0.}, {0.22, 0},
           RoundingRadius->0], RectangleBox[{0.22, 0.}, {0.225, 0},
           RoundingRadius->0], RectangleBox[{0.225, 0.}, {0.23, 0},
           RoundingRadius->0], RectangleBox[{0.23, 0.}, {0.235, 0},
           RoundingRadius->0]}, {}, {}}, {{}, 
         {RGBColor[0.6, 0.24, 0.4428931686004542], Opacity[0.5], EdgeForm[
          Opacity[0.371]], 
          RectangleBox[{0., 0.}, 
           NCache[{0.005, Rational[100, 59]}, {0.005, 1.694915254237288}],
           RoundingRadius->0], 
          RectangleBox[{0.005, 0.}, 
           NCache[{0.01, Rational[50, 59]}, {0.01, 0.847457627118644}],
           RoundingRadius->0], 
          RectangleBox[{0.01, 0.}, 
           NCache[{0.015, Rational[550, 177]}, {0.015, 3.1073446327683616`}],
           RoundingRadius->0], 
          RectangleBox[{0.015, 0.}, 
           NCache[{0.02, Rational[1000, 177]}, {0.02, 5.649717514124294}],
           RoundingRadius->0], 
          RectangleBox[{0.02, 0.}, 
           NCache[{0.025, Rational[350, 59]}, {0.025, 5.932203389830509}],
           RoundingRadius->0], 
          RectangleBox[{0.025, 0.}, 
           NCache[{0.03, Rational[450, 59]}, {0.03, 7.627118644067797}],
           RoundingRadius->0], 
          RectangleBox[{0.03, 0.}, 
           NCache[{0.035, Rational[1450, 177]}, {0.035, 8.192090395480227}],
           RoundingRadius->0], 
          RectangleBox[{0.035, 0.}, 
           NCache[{0.04, Rational[1150, 177]}, {0.04, 6.497175141242938}],
           RoundingRadius->0], 
          RectangleBox[{0.04, 0.}, 
           NCache[{0.045, Rational[1400, 177]}, {0.045, 7.909604519774011}],
           RoundingRadius->0], 
          RectangleBox[{0.045, 0.}, 
           NCache[{0.05, Rational[1450, 177]}, {0.05, 8.192090395480227}],
           RoundingRadius->0], 
          RectangleBox[{0.05, 0.}, 
           NCache[{0.055, Rational[1900, 177]}, {0.055, 10.734463276836157`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.055, 0.}, 
           NCache[{0.06, Rational[1550, 177]}, {0.06, 8.757062146892656}],
           RoundingRadius->0], 
          RectangleBox[{0.06, 0.}, 
           NCache[{0.065, Rational[1900, 177]}, {0.065, 10.734463276836157`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.065, 0.}, 
           NCache[{0.07, Rational[1600, 177]}, {0.07, 9.03954802259887}],
           RoundingRadius->0], 
          RectangleBox[{0.07, 0.}, 
           NCache[{0.075, Rational[450, 59]}, {0.075, 7.627118644067797}],
           RoundingRadius->0], 
          RectangleBox[{0.075, 0.}, 
           NCache[{0.08, Rational[1550, 177]}, {0.08, 8.757062146892656}],
           RoundingRadius->0], 
          RectangleBox[{0.08, 0.}, 
           NCache[{0.085, Rational[700, 59]}, {0.085, 11.864406779661017`}],
           RoundingRadius->0], 
          RectangleBox[{0.085, 0.}, 
           NCache[{0.09, Rational[1300, 177]}, {0.09, 7.344632768361582}],
           RoundingRadius->0], 
          RectangleBox[{0.09, 0.}, 
           NCache[{0.095, Rational[1250, 177]}, {0.095, 7.062146892655368}],
           RoundingRadius->0], 
          RectangleBox[{0.095, 0.}, 
           NCache[{0.1, Rational[1450, 177]}, {0.1, 8.192090395480227}],
           RoundingRadius->0], 
          RectangleBox[{0.1, 0.}, 
           NCache[{0.105, Rational[350, 59]}, {0.105, 5.932203389830509}],
           RoundingRadius->0], 
          RectangleBox[{0.105, 0.}, 
           NCache[{0.11, Rational[1400, 177]}, {0.11, 7.909604519774011}],
           RoundingRadius->0], 
          RectangleBox[{0.11, 0.}, 
           NCache[{0.115, Rational[350, 59]}, {0.115, 5.932203389830509}],
           RoundingRadius->0], 
          RectangleBox[{0.115, 0.}, 
           NCache[{0.12, Rational[1000, 177]}, {0.12, 5.649717514124294}],
           RoundingRadius->0], 
          RectangleBox[{0.12, 0.}, 
           NCache[{0.125, Rational[250, 59]}, {0.125, 4.237288135593221}],
           RoundingRadius->0], 
          RectangleBox[{0.125, 0.}, 
           NCache[{0.13, Rational[650, 177]}, {0.13, 3.672316384180791}],
           RoundingRadius->0], 
          RectangleBox[{0.13, 0.}, 
           NCache[{0.135, Rational[250, 59]}, {0.135, 4.237288135593221}],
           RoundingRadius->0], 
          RectangleBox[{0.135, 0.}, 
           NCache[{0.14, Rational[150, 59]}, {0.14, 2.542372881355932}],
           RoundingRadius->0], 
          RectangleBox[{0.14, 0.}, 
           NCache[{0.145, Rational[550, 177]}, {0.145, 3.1073446327683616`}],
           RoundingRadius->0], 
          RectangleBox[{0.145, 0.}, 
           NCache[{0.15, Rational[200, 177]}, {0.15, 1.1299435028248588`}],
           RoundingRadius->0], 
          RectangleBox[{0.15, 0.}, 
           NCache[{0.155, Rational[100, 59]}, {0.155, 1.694915254237288}],
           RoundingRadius->0], 
          RectangleBox[{0.155, 0.}, 
           NCache[{0.16, Rational[150, 59]}, {0.16, 2.542372881355932}],
           RoundingRadius->0], 
          RectangleBox[{0.16, 0.}, 
           NCache[{0.165, Rational[250, 177]}, {0.165, 1.4124293785310735`}],
           RoundingRadius->0], RectangleBox[{0.165, 0.}, {0.17, 0},
           RoundingRadius->0], 
          RectangleBox[{0.17, 0.}, 
           NCache[{0.175, Rational[100, 177]}, {0.175, 0.5649717514124294}],
           RoundingRadius->0], 
          RectangleBox[{0.175, 0.}, 
           NCache[{0.18, Rational[200, 177]}, {0.18, 1.1299435028248588`}],
           RoundingRadius->0], 
          RectangleBox[{0.18, 0.}, 
           NCache[{0.185, Rational[100, 177]}, {0.185, 0.5649717514124294}],
           RoundingRadius->0], 
          RectangleBox[{0.185, 0.}, 
           NCache[{0.19, Rational[100, 177]}, {0.19, 0.5649717514124294}],
           RoundingRadius->0], 
          RectangleBox[{0.19, 0.}, 
           NCache[{0.195, Rational[50, 177]}, {0.195, 0.2824858757062147}],
           RoundingRadius->0], RectangleBox[{0.195, 0.}, {0.2, 0},
           RoundingRadius->0], RectangleBox[{0.2, 0.}, {0.205, 0},
           RoundingRadius->0], RectangleBox[{0.205, 0.}, {0.21, 0},
           RoundingRadius->0], 
          RectangleBox[{0.21, 0.}, 
           NCache[{0.215, Rational[50, 177]}, {0.215, 0.2824858757062147}],
           RoundingRadius->0], 
          RectangleBox[{0.215, 0.}, 
           NCache[{0.22, Rational[50, 177]}, {0.22, 0.2824858757062147}],
           RoundingRadius->0], 
          RectangleBox[{0.22, 0.}, 
           NCache[{0.225, Rational[50, 177]}, {0.225, 0.2824858757062147}],
           RoundingRadius->0], RectangleBox[{0.225, 0.}, {0.23, 0},
           RoundingRadius->0], 
          RectangleBox[{0.23, 0.}, 
           NCache[{0.235, Rational[50, 177]}, {0.235, 0.2824858757062147}],
           RoundingRadius->0]}, {}, {}}}, {{}, {{}, {}, 
         {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
          LineBox[CompressedData["
1:eJxdUVtIk1EAnpJSloK0YVM2FcFcZuYVKfq/H31QQwMNowfFMtwoQy0mkXvQ
ahYZJpRrKC4QRY3KNPOyoenuNnVTcW5WmJM0pwmh2IUU23956oPD4dy+2wkv
Ksst9uZwOAmeQc3/Q8btSndVSrEnEXOmY8JJZi2HXe1fmhRxnBwU1qznDD6G
XHR17kJMHHvegJUAYablfjzZ1EgD/auiuLuqePb+czzolT4pc8SR33OonRYk
Z9VHF8pPsu/bQPgEFTfqYkg/R2v5Gb8OzMrGu3eTj7F8LxDMX9YMt0eSovx6
3XbUK9wZU676EhEsfxc2hJ+D5o6EkW2e147WbugywwSKumBWrwcFsvMydTOP
TKDRi/lvda0+hYGs/jsYo7NMpPIgqd+O8ij0oU2ZtiLr9GH9DKDqmUGZbeOQ
uYwgZgT2tQzrHzD+1LAVqQSTyi24KilCDWyKJF5L6QYYv0NQrG5NWRaWcYOy
Vz6Mm5H7zTzuIhi699CoRxSGKw4wvzCKXXFaint2CkyeURxVzeal/jIjgxbQ
4uKnkIKlxVEw+bTYc740npAPgFLzSIJf/SjQK7EbTF49DlvXOxa47aDjOPSQ
ud8OSbUqMPkNMO3r74ydeYpQyo7QiFqisz07uBZMH0ZElw/eVu1UQyKmYEJs
2ZuJFmcFmH7MUE2LUpq1JaDYuF1mrI8H/pZcuwymrzH8CLrH6WnIw0+KbnsM
pS5NqFR8lu3vA5Yepic6vwAETWiBNyFITt2JZ/u0wLkbeujvuUjQ9mrGsenl
8gqf57P9TsB9QLU6UuOPyQka8Otv0vuqOGzfk8iXVFUElGwSPNqgFby+Wzpu
yFeC6d8KvWHNdLrJTtB0+TacMqv5H+0mgvmPKVx/fcltHxog/gFkeX7y
           "]]}, 
         {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
          LineBox[CompressedData["
1:eJxdUXss1HEAR6Mlz0MRzuNSZCvrVsuUz3cmjzXVUaGd1dWwYvPeRI3FmVpI
649okWO5Lt3cEuftnLfjStoVTXNNVtRoo2TU/R7902f77rvv6/P6elxKiYw3
MTIy4hsGNf+PXHt56GxOJrKEosvTmaaEWRei5MNVaYuCQ5Rc8YJAWYpb3kmu
vcuO7Pl99FncEedqXEllBQ2oRn3LdO3u7P0qCJJEh6asPMmigNqpgbwozI4s
e7Lv6zDOSzk4lc4j5rra1GPm9ciPXLTR1vBYvqeI3dNm/fE2j/gIy3pXvBsw
Gay9UOLPY/nlmJK4+AUoPUmd4bWuthFbfYcnAmz+6SmQRThRc+EehE/jBfqc
iqOrk91Z/SbMmXo90m9wiXrF26DwEpmbN9+7W7qyflqQX38+YdrGmUQyghjg
/PIttnVi/bXiYnxxasSOnWQ2hyJsw+KJNAHXy4H124ECjtBEF2RH0ih7qZ2Q
m+wti8mwZf13ISRcpgzNsCbML/SA+1YaOn/Ags3TA+F6okjmto2E0QIqbDef
PJ4XbMbmU8H57m7HqOothFIzSGLm9NINfz9jNq8aJudidO7fNkDH0alx5jd3
Hfo1MPn7IJKlP08+ugo3yg63H62yfcj7+QNMH/244vi4u8lqCYkJFAZwUvs6
WrL2FUw/g2h3+h6Rnf0ZFJu9fBAVRwrN+KV6MH0NIe5wiP31uBmsUnQrQ1BM
KPolD9+B6W8Yw+vlKn7XGwTShCMItfsjEMdqwfQ5gkCXhW591RBoe+JRnNqV
1yzmqsH0q8E1rajoWWwnxjQ00PaE9+BsUDOYvsewWWbZUdDQCAfa4DjmS6pk
QTIpmP7HUb7f58uYsQQ0nVCLeDNNlHS5Asx/vILVp1KbypR7+AuX5nEj
           
           "]]}}, {}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Thickness[Large], Dashing[{Small, Small}], 
         LineBox[CompressedData["
1:eJwVl3k0ld8XxpEiZI4MhVDIcG9Jke7zCqlQIhkSkhJNSIWSSpR5niVTKhlK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          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesLabel->{None, None},
      AxesOrigin->{0., 0.},
      Epilog->{
        InsetBox[
         FormBox[
          StyleBox[
          "\"\\!\\(\\*SubscriptBox[\\(m\\), \\(0\\)]\\)=-0.2\"", 12, 
           FontFamily -> "Helvetica", StripOnInput -> False], 
          TraditionalForm], 
         NCache[
          Scaled[{
            Rational[7, 8], 
            Rational[3, 4]}], 
          Scaled[{0.875, 0.75}]]], 
        InsetBox[
         FormBox[
          StyleBox[
          "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
           False], TraditionalForm], 
         Scaled[{0.05, 0.95}]], {
         Directive[
          GrayLevel[0.5], 
          Thickness[Large]], 
         LineBox[{{-0.2, 10}, {-0.125, 10}}]}, {
         Directive[
          GrayLevel[0.5], 
          Thickness[Large]], 
         LineBox[{{-0.2, 9.5}, {-0.2, 10.5}}]}, {
         Directive[
          GrayLevel[0.5], 
          Thickness[Large]], 
         LineBox[{{-0.125, 9.5}, {-0.125, 10.5}}]}, {
         Directive[
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          Thickness[Large]], 
         LineBox[{{-0.2, 20}, {0.023, 20}}]}, {
         Directive[
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          Thickness[Large]], 
         LineBox[{{-0.2, 19.5}, {-0.2, 20.5}}]}, {
         Directive[
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          Thickness[Large]], 
         LineBox[{{0.023, 19.5}, {0.023, 20.5}}]}},
      Frame->{True, False, False, False},
      FrameTicksStyle->{
       FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
      LabelStyle->Directive[12, FontFamily -> "Helvetica"],
      Method->{},
      PlotRange->{{-0.3, 0.25}, {0, 28}},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {189., -357.49223594996215`},
      ImageScaled[{0.5, 0.5}], {360., 268.32815729997475`}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
          LineBox[CompressedData["
1:eJw1U2tIk1EY/jTzrmt4pSI1L6npnxQx7PveTypv4A8XoVSEZhKK4jQmsixN
p6aFmhpmecN5xy0lw7tnc9NUljm1lSnIEiOaJbOMipzpdz5fOBxe3nOe53nf
8xy3G+m8JGOCIIL31v4ewMQCSu89Zk7Mc+ny8W3va+XzaNIRhG7tXFoXM3Ci
UKdGiVddyPnzXDpCK7SXhqtR2J3iUVnXEbqFT1q+F8+h1JB/tlFyDk0wMYd0
cw/B8oMNvX87ZmAW2fErA/s7rWjmOP8NqvL22ImOsKD3yPYYVch5qT3l3aQp
zcBrZxAUzdnEBpvQtUxMo8Yz9ptrUiOaxwBOIa5X2WG+wAD7aKTla6QRPG90
WvgDjPzxCSQJbRWQj7aBgRMq0cJ0nsPOCz3gfhWoaemmyemyDcD9yRGVb2Lc
1/EZxIxAGSrpVgR979IC1j+GaohCQsFZBqx3BMUoT25uxS3CU0bfIFKl8wa3
TGdZPf1oRRKYmzA8wfL3IavJteFfmjH4yvD1ot227g73jFcsvhS9vCwcCA+Q
sHidyGI1wsc9SwzZzP0WtP57Zig5vhZ6mPMNaDnR0azPrwL4TL0acRZz0wlP
EeQxuQiJtpBBdi8bCDZKKwS6S5y0gzrIbCu+ec3Gs3k11Mdq6kI3eSDD+GBU
+fHtuuICW28BeU+GvsozCJqwPmi9e1Tq98PrQD+IXHyKBxycYAP3Bw8ketdI
kSnk4P6h3SOh63jYNmWN5wNlwcr7aZlrVB2eH4Q4qOun/NWUH54v8PXmF2ui
Ril2/pDvaF0Sye2gsN9k4KtK9to0q6IwnxzqbHtG/XU5VCB+X4j9ErtSYJdE
YX4lxBV0xuelRFNK7A9o5sRF+DUEUKx/QNFcqr7105li/QXRsyO8okAD+Qz7
D6RP/FWnrmjJT9if4Jvis2tYHSd9sX/htjbr+lqCmMzE/oazY/2WrsP55BD2
P7Qd0jx2/xtPGuH/Ada6ckmq/Bz5H0jOssk=
           "]]}, 
         {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJw1U38s1GEYP0Y1SaycH/mRTQ2rLT9H6/t9vv1RTInTIeKPGHHmXLbSjJOI
oxl3aJTsNqdTIlR+Zd5zjqjIuW5olNMf1Fkp+TlTfN+vZ3v37tnzvp/P53ne
z+sUmxoab8hisXy3187uSYcGsZgoUS67RJeMIaOKvePX/q2BntPhcE+vRuu2
gbVDXvuoAF3G4SZ/NRKroSw6yoKSCQiT8dpRJPpUEcHWWFIYZRTx/WxDfOJs
qJ3bnI4RVFRlJstaOULRxwXD6Pzi1LQk357aJttm/ICqZIRlm60DRcPr3iGy
/UBL6oA9VUXHEGqVunyMldtRoTTgIHJInAjImbWldtAIk7fIvOP15QWpNUXL
V/ajr4bmmaOmbIqGy1Chsvoxy/xLhyjcbx/yqB8rcC8yp3B/vSg+vLGb3b2f
qqUFKhCvsljZp9zD6O9B8z9fhEsDDBm93WhunbsVotiESlpfJ5Lc4IhyHFcA
62lHbReen/orXwTM/wrJbVhhOaJ5+EHztaBVvVZj1aADjN+EwoA7kDszweA9
RRZ1kd/0dmq4Td+Xod+fxRuarQFops/XoOLShBpPtx4Q0PVy5DZgpFUGvYQ7
dJ6HJE4J8yKreth91ycm/r/cgx7v1kEYl5CeFCVm8nLYTBInN7LyQIHxYSYm
/dj75FtMXQaTkpTsyOREkGJ94OuVstSrjtzVD7rqOuesjEBYwP1BzEjqsDb4
NGTi/qFQtGxsHOwKpng+4Bp01uBZoRVU4/kBV+0+x3Y2hhN4vnByuoFfEfKH
ZOYPkzzrZn3pFxL7TQH3l/qys0WDJObrhYJCR4XN91bSC78vcF14d/OXHpGY
XwURwkG5T38uqcL+AMXBVW1oO49k/APCo/oCV28OyfgLRBePn8mz9CYfYv/B
fBe7/FyuNTmL/Qn8pWVV3doG4Yb9C6pKo2m+wRSRhv0ND/yE1zOuviG6sP9B
69G5csWsijDA/wPSBL6cstSbxH9fErHE
           "]]}}, {}}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        EdgeForm[Opacity[0.371]], {{}, 
         {RGBColor[0.24720000000000014`, 0.24, 0.6], Opacity[0.5], EdgeForm[
          Opacity[0.371]], 
          RectangleBox[{0., 0.}, 
           NCache[{0.005, Rational[1400, 127]}, {0.005, 11.023622047244094`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.005, 0.}, 
           NCache[{0.01, Rational[2200, 127]}, {0.01, 17.322834645669293`}],
           RoundingRadius->0], 
          RectangleBox[{0.01, 0.}, 
           NCache[{0.015, Rational[1400, 127]}, {0.015, 11.023622047244094`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.015, 0.}, 
           NCache[{0.02, Rational[3000, 127]}, {0.02, 23.62204724409449}],
           RoundingRadius->0], 
          RectangleBox[{0.02, 0.}, 
           NCache[{0.025, Rational[2400, 127]}, {0.025, 18.89763779527559}],
           RoundingRadius->0], 
          RectangleBox[{0.025, 0.}, 
           NCache[{0.03, Rational[3400, 127]}, {0.03, 26.771653543307085`}],
           RoundingRadius->0], 
          RectangleBox[{0.03, 0.}, 
           NCache[{0.035, Rational[2200, 127]}, {0.035, 17.322834645669293`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.035, 0.}, 
           NCache[{0.04, Rational[2600, 127]}, {0.04, 20.47244094488189}],
           RoundingRadius->0], 
          RectangleBox[{0.04, 0.}, 
           NCache[{0.045, Rational[1000, 127]}, {0.045, 7.874015748031496}],
           RoundingRadius->0], 
          RectangleBox[{0.045, 0.}, 
           NCache[{0.05, Rational[1400, 127]}, {0.05, 11.023622047244094`}],
           RoundingRadius->0], 
          RectangleBox[{0.05, 0.}, 
           NCache[{0.055, Rational[600, 127]}, {0.055, 4.724409448818897}],
           RoundingRadius->0], 
          RectangleBox[{0.055, 0.}, 
           NCache[{0.06, Rational[800, 127]}, {0.06, 6.299212598425197}],
           RoundingRadius->0], 
          RectangleBox[{0.06, 0.}, 
           NCache[{0.065, Rational[600, 127]}, {0.065, 4.724409448818897}],
           RoundingRadius->0], 
          RectangleBox[{0.065, 0.}, 
           NCache[{0.07, Rational[800, 127]}, {0.07, 6.299212598425197}],
           RoundingRadius->0], 
          RectangleBox[{0.07, 0.}, 
           NCache[{0.075, Rational[400, 127]}, {0.075, 3.1496062992125986`}],
           RoundingRadius->0], 
          RectangleBox[{0.075, 0.}, 
           NCache[{0.08, Rational[400, 127]}, {0.08, 3.1496062992125986`}],
           RoundingRadius->0], RectangleBox[{0.08, 0.}, {0.085, 0},
           RoundingRadius->0], 
          RectangleBox[{0.085, 0.}, 
           NCache[{0.09, Rational[400, 127]}, {0.09, 3.1496062992125986`}],
           RoundingRadius->0], 
          RectangleBox[{0.09, 0.}, 
           NCache[{0.095, Rational[200, 127]}, {0.095, 1.5748031496062993`}],
           RoundingRadius->0], RectangleBox[{0.095, 0.}, {0.1, 0},
           RoundingRadius->0], RectangleBox[{0.1, 0.}, {0.105, 0},
           RoundingRadius->0], 
          RectangleBox[{0.105, 0.}, 
           NCache[{0.11, Rational[200, 127]}, {0.11, 1.5748031496062993`}],
           RoundingRadius->0], RectangleBox[{0.11, 0.}, {0.115, 0},
           RoundingRadius->0], RectangleBox[{0.115, 0.}, {0.12, 0},
           RoundingRadius->0], RectangleBox[{0.12, 0.}, {0.125, 0},
           RoundingRadius->0], RectangleBox[{0.125, 0.}, {0.13, 0},
           RoundingRadius->0], RectangleBox[{0.13, 0.}, {0.135, 0},
           RoundingRadius->0], RectangleBox[{0.135, 0.}, {0.14, 0},
           RoundingRadius->0], RectangleBox[{0.14, 0.}, {0.145, 0},
           RoundingRadius->0], RectangleBox[{0.145, 0.}, {0.15, 0},
           RoundingRadius->0], RectangleBox[{0.15, 0.}, {0.155, 0},
           RoundingRadius->0], RectangleBox[{0.155, 0.}, {0.16, 0},
           RoundingRadius->0], RectangleBox[{0.16, 0.}, {0.165, 0},
           RoundingRadius->0], RectangleBox[{0.165, 0.}, {0.17, 0},
           RoundingRadius->0], RectangleBox[{0.17, 0.}, {0.175, 0},
           RoundingRadius->0], RectangleBox[{0.175, 0.}, {0.18, 0},
           RoundingRadius->0], RectangleBox[{0.18, 0.}, {0.185, 0},
           RoundingRadius->0], RectangleBox[{0.185, 0.}, {0.19, 0},
           RoundingRadius->0], RectangleBox[{0.19, 0.}, {0.195, 0},
           RoundingRadius->0], RectangleBox[{0.195, 0.}, {0.2, 0},
           RoundingRadius->0], RectangleBox[{0.2, 0.}, {0.205, 0},
           RoundingRadius->0], RectangleBox[{0.205, 0.}, {0.21, 0},
           RoundingRadius->0], RectangleBox[{0.21, 0.}, {0.215, 0},
           RoundingRadius->0], RectangleBox[{0.215, 0.}, {0.22, 0},
           RoundingRadius->0], RectangleBox[{0.22, 0.}, {0.225, 0},
           RoundingRadius->0], RectangleBox[{0.225, 0.}, {0.23, 0},
           RoundingRadius->0], RectangleBox[{0.23, 0.}, {0.235, 0},
           RoundingRadius->0]}, {}, {}}, {{}, 
         {RGBColor[0.6, 0.24, 0.4428931686004542], Opacity[0.5], EdgeForm[
          Opacity[0.371]], 
          RectangleBox[{0., 0.}, 
           NCache[{0.005, Rational[800, 211]}, {0.005, 3.7914691943127963`}],
           RoundingRadius->0], 
          RectangleBox[{0.005, 0.}, 
           NCache[{0.01, Rational[1000, 211]}, {0.01, 4.739336492890995}],
           RoundingRadius->0], 
          RectangleBox[{0.01, 0.}, 
           NCache[{0.015, Rational[1000, 211]}, {0.015, 4.739336492890995}],
           RoundingRadius->0], 
          RectangleBox[{0.015, 0.}, 
           NCache[{0.02, Rational[2600, 211]}, {0.02, 12.322274881516588`}],
           RoundingRadius->0], 
          RectangleBox[{0.02, 0.}, 
           NCache[{0.025, Rational[1600, 211]}, {0.025, 7.5829383886255926`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.025, 0.}, 
           NCache[{0.03, Rational[1000, 211]}, {0.03, 4.739336492890995}],
           RoundingRadius->0], 
          RectangleBox[{0.03, 0.}, 
           NCache[{0.035, Rational[1800, 211]}, {0.035, 8.530805687203792}],
           RoundingRadius->0], 
          RectangleBox[{0.035, 0.}, 
           NCache[{0.04, Rational[2000, 211]}, {0.04, 9.47867298578199}],
           RoundingRadius->0], 
          RectangleBox[{0.04, 0.}, 
           NCache[{0.045, Rational[1600, 211]}, {0.045, 7.5829383886255926`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.045, 0.}, 
           NCache[{0.05, Rational[3400, 211]}, {0.05, 16.113744075829384`}],
           RoundingRadius->0], 
          RectangleBox[{0.05, 0.}, 
           NCache[{0.055, Rational[4400, 211]}, {0.055, 20.85308056872038}],
           RoundingRadius->0], 
          RectangleBox[{0.055, 0.}, 
           NCache[{0.06, Rational[2200, 211]}, {0.06, 10.42654028436019}],
           RoundingRadius->0], 
          RectangleBox[{0.06, 0.}, 
           NCache[{0.065, Rational[2000, 211]}, {0.065, 9.47867298578199}],
           RoundingRadius->0], 
          RectangleBox[{0.065, 0.}, 
           NCache[{0.07, Rational[1800, 211]}, {0.07, 8.530805687203792}],
           RoundingRadius->0], 
          RectangleBox[{0.07, 0.}, 
           NCache[{0.075, Rational[2800, 211]}, {0.075, 13.270142180094787`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.075, 0.}, 
           NCache[{0.08, Rational[1400, 211]}, {0.08, 6.6350710900473935`}],
           RoundingRadius->0], 
          RectangleBox[{0.08, 0.}, 
           NCache[{0.085, Rational[1000, 211]}, {0.085, 4.739336492890995}],
           RoundingRadius->0], 
          RectangleBox[{0.085, 0.}, 
           NCache[{0.09, Rational[1200, 211]}, {0.09, 5.687203791469194}],
           RoundingRadius->0], 
          RectangleBox[{0.09, 0.}, 
           NCache[{0.095, Rational[1400, 211]}, {0.095, 6.6350710900473935`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.095, 0.}, 
           NCache[{0.1, Rational[600, 211]}, {0.1, 2.843601895734597}],
           RoundingRadius->0], 
          RectangleBox[{0.1, 0.}, 
           NCache[{0.105, Rational[800, 211]}, {0.105, 3.7914691943127963`}],
           RoundingRadius->0], 
          RectangleBox[{0.105, 0.}, 
           NCache[{0.11, Rational[1000, 211]}, {0.11, 4.739336492890995}],
           RoundingRadius->0], 
          RectangleBox[{0.11, 0.}, 
           NCache[{0.115, Rational[600, 211]}, {0.115, 2.843601895734597}],
           RoundingRadius->0], 
          RectangleBox[{0.115, 0.}, 
           NCache[{0.12, Rational[600, 211]}, {0.12, 2.843601895734597}],
           RoundingRadius->0], 
          RectangleBox[{0.12, 0.}, 
           NCache[{0.125, Rational[600, 211]}, {0.125, 2.843601895734597}],
           RoundingRadius->0], 
          RectangleBox[{0.125, 0.}, 
           NCache[{0.13, Rational[400, 211]}, {0.13, 1.8957345971563981`}],
           RoundingRadius->0], 
          RectangleBox[{0.13, 0.}, 
           NCache[{0.135, Rational[400, 211]}, {0.135, 1.8957345971563981`}],
           RoundingRadius->0], 
          RectangleBox[{0.135, 0.}, 
           NCache[{0.14, Rational[200, 211]}, {0.14, 0.9478672985781991}],
           RoundingRadius->0], 
          RectangleBox[{0.14, 0.}, 
           NCache[{0.145, Rational[400, 211]}, {0.145, 1.8957345971563981`}],
           RoundingRadius->0], 
          RectangleBox[{0.145, 0.}, 
           NCache[{0.15, Rational[400, 211]}, {0.15, 1.8957345971563981`}],
           RoundingRadius->0], RectangleBox[{0.15, 0.}, {0.155, 0},
           RoundingRadius->0], RectangleBox[{0.155, 0.}, {0.16, 0},
           RoundingRadius->0], RectangleBox[{0.16, 0.}, {0.165, 0},
           RoundingRadius->0], RectangleBox[{0.165, 0.}, {0.17, 0},
           RoundingRadius->0], 
          RectangleBox[{0.17, 0.}, 
           NCache[{0.175, Rational[200, 211]}, {0.175, 0.9478672985781991}],
           RoundingRadius->0], RectangleBox[{0.175, 0.}, {0.18, 0},
           RoundingRadius->0], RectangleBox[{0.18, 0.}, {0.185, 0},
           RoundingRadius->0], 
          RectangleBox[{0.185, 0.}, 
           NCache[{0.19, Rational[200, 211]}, {0.19, 0.9478672985781991}],
           RoundingRadius->0], 
          RectangleBox[{0.19, 0.}, 
           NCache[{0.195, Rational[400, 211]}, {0.195, 1.8957345971563981`}],
           RoundingRadius->0], RectangleBox[{0.195, 0.}, {0.2, 0},
           RoundingRadius->0], 
          RectangleBox[{0.2, 0.}, 
           NCache[{0.205, Rational[200, 211]}, {0.205, 0.9478672985781991}],
           RoundingRadius->0], RectangleBox[{0.205, 0.}, {0.21, 0},
           RoundingRadius->0], RectangleBox[{0.21, 0.}, {0.215, 0},
           RoundingRadius->0], RectangleBox[{0.215, 0.}, {0.22, 0},
           RoundingRadius->0], RectangleBox[{0.22, 0.}, {0.225, 0},
           RoundingRadius->0], RectangleBox[{0.225, 0.}, {0.23, 0},
           RoundingRadius->0], 
          RectangleBox[{0.23, 0.}, 
           NCache[{0.235, Rational[200, 211]}, {0.235, 0.9478672985781991}],
           RoundingRadius->0]}, {}, {}}}, {{}, {{}, {}, 
         {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
          LineBox[CompressedData["
1:eJxdUWlIk2EA1lA080Bx/lC0JjOvAkHyqr7nE8WjQvJISkVRKmU0NFJsHmDm
gUoHpJXKJHM21HJKSst0uKbucFOJzBkdTFwpaik1tR9Z+47+9MDLy3s918vN
K0y5tM/KyirUMqj5f5S798cby4rx8/GtP62bwSSzrsEvj3pvjdsxUuZTu5Ys
u40ml2EnqTScPW9GREmVvX91ONnWSgP+uXXZtiP/7nfggq8q098vlFxPpnY6
0fyw+YwsMYR9L8bNeXzzMgeRDgtdRScdJDALJ4Iz9H4sXw8Kn634TidyycCs
O6/NAU/R3VepTdvyZPn7cVjZ0LvX406KLa8Xugbg6Bq9U3DChdUbRJK3JPBI
oh0ZSuM5cqb18cd9rVn9IQSHWdXFftmF0hxgURiGk+t8sezzFhg/L8D1bJMt
Zq4ihRHEXrZK/FVlBOPvJaoUZ3eETwwwllGEIyitGllSLM+B8TsKk4ET5GWa
wlXKXtEYBK01IT79cjB0cmyWulVmpA6B+YVxcCLepxse9YLJMw6RaL/wDdGJ
BFpAASlfUB3NuQ8mnwJOYwP6rR9NoNQskjCIF2crKm6AyauEo4OZt95RAjrO
ghK2TR3fT/H5YPJPwCOvbfT0Ug4OUnZ8JiFM4IneWaeyfUziQYNAl54bh/zL
FKZQvkF+/GQTxfajQq/9ga7kD0dBsbn3qxBW65jhvHqI7UuNjbv31HKTG7Yp
OrMaaZE8seitDdufBi3cqDaBeJsgaEItDCaJ3C9mhWD61EKj6bbb7VgkaHu1
0/DgcyOvS7QE068OKieFsy7pFaHX0UBAzLVldWMfwfStx15LfZbxXDvBoQ3O
YDZ/MU4lbSSY/megit1q7xMJCZouaxaDjr+vuAQVEMx/zOH8WkIS72I68RdI
6HvQ
           "]]}, 
         {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
          LineBox[CompressedData["
1:eJxdUWlIk2EAntcMBU2aIzXmiW4RiNkBXs+nkkmiof6KlFDwCIqUppG3pZG4
tFhRW1iMTZekU5lXo0TTzc1NneaR9MMrNC+0Y0aW2b7jVw+8vLzXc72+mTdS
smxZLFaodZDz/yjmqM4vFgkxJKkXq++5EPS6CvuRz01tzzyJXl71RnJvHYQJ
dYshQl/m/DEeqV1knekBhFRCAZxGTZ2FCGTuv8BI7wnHhcQgYjOZ3JGhZU3w
2tgaxLxXwO3kTHtGVRDhNCvPi3RSwj8m9kv0TiDD14xud6NtrXMgIUirf2/h
t8AgsFxP3Qxg+FU4ZT8RfLTRn1BYX8/K27FK1LIDzvkxeh3Qpfaotj/6EKEU
1Ljkknn65xSP0e+ETUhmUpzdMWLQwrcqdKG6R/tgMt6D8dODpqlvsaUqLpFC
C2J5qT3nThiH8fcGGXGeDhs7bsRiEUmogUE0JFxRujJ+34J/O6pMr3cm8kl7
ee9wYQk8Xewhxn8fPCrZH3K5DgT9C/2Y/Lpm2oqwZfL042W4QXcx6wDxlMAA
Cl91/5J93gOdbwBPGiYEks1dkGpWSWRPu7tq8r+DzjuI4pbgAmnuDqg4s4MI
i/+jJkQboPMPQerfUXjlYAXepB2eFgrv+Ydi7jLoPrRId0xYLy+bR042CR26
beIUBeY50P0MQ8H2+iGzmwbJxlENg8UuXy3+bQbdlx610X7reRFG7JJ0Fj2u
hTftxTRrQfdngDzt1qj5yACiKMIRdM3g70KrBnSfI7h6ec6LL+8EZa/aiOCu
mk/LkjbQ/ZqwX+ItLt1WYtREAWaV6Kz3lgx036NQaMwNyhop3CmDY6jsr/Sq
yBGD7n8M90O4FeP2IlB0aeO4mdR3Zmn3Luj/MOOpT+LxqcMl+AfoqX6K
           
           "]]}}, {}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], Thickness[Large], Dashing[{Small, Small}], 
         LineBox[CompressedData["
1:eJwVV3c8Vv8XR4qQrOprhUjISjyE7rllz8xkJCSVjKwSIbL3Xtmj7L0yHzzm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          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesLabel->{None, None},
      AxesOrigin->{0., 0.},
      Epilog->{
        InsetBox[
         FormBox[
          StyleBox[
          "\"\\!\\(\\*SubscriptBox[\\(m\\), \\(0\\)]\\)=-0.3\"", 12, 
           FontFamily -> "Helvetica", StripOnInput -> False], 
          TraditionalForm], 
         NCache[
          Scaled[{
            Rational[7, 8], 
            Rational[3, 4]}], 
          Scaled[{0.875, 0.75}]]], 
        InsetBox[
         FormBox[
          StyleBox[
          "\"C\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
           False], TraditionalForm], 
         Scaled[{0.05, 0.95}]], {
         Directive[
          GrayLevel[0.5], 
          Thickness[Large]], 
         LineBox[{{-0.3, 10}, {-0.22, 10}}]}, {
         Directive[
          GrayLevel[0.5], 
          Thickness[Large]], 
         LineBox[{{-0.299, 9.5}, {-0.299, 10.5}}]}, {
         Directive[
          GrayLevel[0.5], 
          Thickness[Large]], 
         LineBox[{{-0.22, 9.5}, {-0.22, 10.5}}]}, {
         Directive[
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          Thickness[Large]], 
         LineBox[{{-0.3, 25}, {0.015, 25}}]}, {
         Directive[
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          Thickness[Large]], 
         LineBox[{{-0.299, 24.5}, {-0.299, 25.5}}]}, {
         Directive[
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          Thickness[Large]], 
         LineBox[{{0.015, 24.5}, {0.015, 25.5}}]}},
      Frame->{True, False, False, False},
      FrameLabel->{
        FormBox["\"Growth rate\"", TraditionalForm]},
      LabelStyle->Directive[12, FontFamily -> "Helvetica"],
      Method->{},
      PlotRange->{{-0.3, 0.25}, {0, 28}},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {189., -595.8203932499368}, 
     ImageScaled[{0.5, 0.5}], {360., 268.3281572999748}]}, {}},
  ContentSelectable->True,
  ImageSize->350,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.784902261646285*^9, {3.784902302069543*^9, 3.784902334803505*^9}, 
   3.784903499337367*^9}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Distribution of first-step growth rates in 2-step rescue genotypes (equation \
18)\
\>", "Subsection",
 CellChangeTimes->{{3.743875680612873*^9, 3.7438757115082808`*^9}, {
   3.7510749238325863`*^9, 3.751074927509233*^9}, {3.751077670599017*^9, 
   3.7510776715052757`*^9}, {3.769432512816828*^9, 3.7694325462852993`*^9}, {
   3.769433278045125*^9, 3.769433280116081*^9}, 3.769438839801771*^9, 
   3.771762253764779*^9}],

Cell["\<\
As, in the 1-step case, we can use the \[CapitalLambda]2 term to write the \
distribution of growth rates of rescue genotypes\
\>", "Text",
 CellChangeTimes->{{3.769445057755739*^9, 3.769445091227048*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"h2", "[", 
   RowBox[{
    RowBox[{"m_", "?", "NumericQ"}], ",", "m0_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"U", " ", 
    RowBox[{"fm", "[", 
     RowBox[{"m", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
    RowBox[{"prescuem", "[", 
     RowBox[{"m", ",", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], "]"}]}], 
   RowBox[{"\[CapitalLambda]2", "[", 
    RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
    "]"}]]}]], "Input",
 CellChangeTimes->{{3.769445121985815*^9, 3.7694451826509*^9}, {
  3.769445302224015*^9, 3.7694453161770477`*^9}}],

Cell["\<\
We can also use our approximations above to get a closed form approximation \
for this.\
\>", "Text",
 CellChangeTimes->{{3.76944254031229*^9, 3.769442564271085*^9}, {
   3.769445220040298*^9, 3.7694452204711847`*^9}, 3.7694460835254107`*^9}],

Cell["\<\
For sufficiently subcritical m near -m* we have\
\>", "Text",
 CellChangeTimes->{{3.769446085570972*^9, 3.769446105339437*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"small\[Psi]approx", "=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[Rho]max", " ", 
          SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]]}], 
     RowBox[{
      SqrtBox["\[Pi]"], " ", 
      SqrtBox["\[Rho]max"], " ", "\[Psi]"}]]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{"small\[Psi]approx", ",", 
    RowBox[{"{", 
     RowBox[{"\[Psi]", ",", "a", ",", "b"}], "}"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"a", "<", "b", "<", "0"}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 FractionBox["small\[Psi]approx", 
  RowBox[{" ", "%"}]], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SqrtBox[
                RowBox[{"1", "-", 
                 FractionBox["m", "mmax"]}]]}], ")"}]}], ",", "m"}], "]"}], 
          "%"}], "/.", 
         RowBox[{"a", "\[Rule]", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             SqrtBox[
              RowBox[{"1", "-", 
               FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}], "/.", 
        RowBox[{"b", "\[Rule]", " ", 
         RowBox[{"2", 
          RowBox[{"(", 
           RowBox[{"1", "-", " ", 
            SqrtBox[
             RowBox[{"1", "+", 
              FractionBox["mstar", "mmax"]}]]}], ")"}]}]}]}], "/.", 
       RowBox[{"mstar", "\[Rule]", 
        SqrtBox[
         RowBox[{"\[CapitalLambda]0approx", "/", "2"}]]}]}], "/.", 
      RowBox[{"\[Rho]max", "\[Rule]", 
       RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
     RowBox[{"\[Theta]", "\[Rule]", 
      RowBox[{"n", "/", "2"}]}]}], "/.", 
    RowBox[{"\[Psi]wt", "\[Rule]", 
     RowBox[{"2", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SqrtBox[
         RowBox[{"1", "-", 
          FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}], "/.", 
   RowBox[{"\[Psi]", "\[Rule]", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["m", "mmax"]}]]}], ")"}]}]}]}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.769443067577939*^9, 3.769443067754766*^9}, {
   3.769443317098393*^9, 3.769443327161993*^9}, {3.769446045149087*^9, 
   3.769446070219686*^9}, 3.769449128373431*^9, 3.769449431648337*^9, {
   3.7694502136972027`*^9, 3.769450215228792*^9}, 3.7822588734290657`*^9, 
   3.782258926349559*^9}],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"\[Psi]", " ", 
   RowBox[{"Log", "[", 
    FractionBox["b", "a"], "]"}]}]]], "Output",
 CellChangeTimes->{{3.7694460577439623`*^9, 3.7694460709038982`*^9}, 
   3.769449129054943*^9, 3.76944943278165*^9, 3.769450216258624*^9, 
   3.782258845843205*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SqrtBox[
       RowBox[{"1", "-", 
        FractionBox["m", "mmax"]}]]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox["m", "mmax"]}]], " ", "mmax", " ", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          SqrtBox[
           RowBox[{"U", " ", 
            SqrtBox[
             RowBox[{"mmax", " ", "\[Lambda]"}]]}]], 
          RowBox[{"mmax", " ", 
           SuperscriptBox["\[Pi]", 
            RowBox[{"1", "/", "4"}]]}]]}]]}], 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["mwt", "mmax"]}]]}]], "]"}]}]]}]], "Output",
 CellChangeTimes->{{3.7694460577439623`*^9, 3.7694460709038982`*^9}, 
   3.769449129054943*^9, 3.76944943278165*^9, 3.769450216258624*^9, 
   3.7822588459659452`*^9}]
}, Closed]],

Cell["\<\
Compare distribution of subcriticals\
\>", "Text",
 CellChangeTimes->{{3.769449972328154*^9, 3.7694499776744432`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.1"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"total", "=", 
    RowBox[{"U", " ", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fm", "[", 
         RowBox[{"m", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
        RowBox[{"prescuem", "[", 
         RowBox[{"m", ",", 
          RowBox[{"\[CapitalLambda]1", "[", 
           RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
           "]"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "\[Infinity]"}], ",", "0"}], "}"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      FractionBox[
       RowBox[{"U", " ", 
        RowBox[{"fm", "[", 
         RowBox[{"m", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
        RowBox[{"prescuem", "[", 
         RowBox[{"m", ",", 
          RowBox[{"\[CapitalLambda]1", "[", 
           RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
           "]"}]}], "]"}]}], "total"], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "0.2"}], ",", "0"}], "}"}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{",", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SqrtBox[
              RowBox[{"1", "-", 
               FractionBox["m", "mmax"]}]]}], ")"}], " ", 
           SqrtBox[
            RowBox[{"1", "-", 
             FractionBox["m", "mmax"]}]], " ", "mmax", " ", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{"1", "-", 
              SqrtBox[
               RowBox[{"1", "+", 
                FractionBox[
                 SqrtBox[
                  RowBox[{"U", " ", 
                   SqrtBox[
                    RowBox[{"mmax", " ", "\[Lambda]"}]]}]], 
                 RowBox[{"mmax", " ", 
                  SuperscriptBox["\[Pi]", 
                   RowBox[{"1", "/", "4"}]]}]]}]]}], 
             RowBox[{"1", "-", 
              SqrtBox[
               RowBox[{"1", "-", 
                FractionBox["mwt", "mmax"]}]]}]], "]"}]}]]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "0.2"}], ",", "0"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "70"}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<true\>\"", ",", "\"\<approx\>\""}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7510622484477882`*^9, 3.7510623899214077`*^9}, {
   3.751062473276165*^9, 3.751062530490876*^9}, 3.751062563427968*^9, {
   3.751062594941642*^9, 3.7510626740085497`*^9}, {3.751062706742158*^9, 
   3.7510627719753103`*^9}, {3.751062825650064*^9, 3.751062839069113*^9}, {
   3.751062891684408*^9, 3.7510628936156187`*^9}, {3.751062951583514*^9, 
   3.7510629518293257`*^9}, {3.7510751327453938`*^9, 3.751075187438393*^9}, {
   3.751075227865163*^9, 3.751075253129315*^9}, {3.751075331833404*^9, 
   3.751075338861655*^9}, {3.751075400453147*^9, 3.7510754285434923`*^9}, {
   3.751298603496088*^9, 3.751298619644992*^9}, {3.751298666312831*^9, 
   3.751298685790444*^9}, {3.7512987560965652`*^9, 3.75129876078164*^9}, 
   3.751298882585372*^9, {3.751299095508382*^9, 3.7512991099339523`*^9}, 
   3.7512991595807037`*^9, {3.769268148632958*^9, 3.769268191326717*^9}, {
   3.769268274695397*^9, 3.769268334384335*^9}, {3.7692683680850058`*^9, 
   3.7692683689144506`*^9}, {3.769268420749902*^9, 3.7692684229390297`*^9}, {
   3.769268853037169*^9, 3.769268869150824*^9}, 3.76926892183434*^9, {
   3.769445246914896*^9, 3.769445276483247*^9}, {3.769445324881626*^9, 
   3.769445398270315*^9}, {3.76944550632565*^9, 3.7694455461643744`*^9}, 
   3.769445579689747*^9, 3.769445609704138*^9, {3.769445650143132*^9, 
   3.769445718514558*^9}, {3.769445763735528*^9, 3.769445788498925*^9}, {
   3.769445818951551*^9, 3.769445938961893*^9}, {3.76944598970818*^9, 
   3.769446021603972*^9}, {3.76944611694064*^9, 3.769446153266705*^9}, {
   3.769448841596923*^9, 3.76944887086455*^9}, 3.769449315122406*^9, {
   3.7694496268301067`*^9, 3.769449627133671*^9}, {3.76944974606151*^9, 
   3.769449952712428*^9}, {3.769449991939508*^9, 3.769450001757079*^9}, {
   3.7694502218258743`*^9, 3.7694502445391293`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Hue[0.67, 0.6, 0.6], 
       LineBox[CompressedData["
1:eJwVxXk8FGgfAPBRrtwhlFuhDbUI6+p5WKIdV8qmhGJcIYokqZUr5QoRJfeR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        "]]}}, {{}, {}, {}, {
       Hue[0.9060679774997897, 0.6, 0.6], 
       LineBox[CompressedData["
1:eJwVxwc8FIwfx3FNtERHyT57X+Tw4O5nZDyEkJZdRkokKkUkI1vInhcdyQoN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        "]]}}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
    PlotRange -> {{-0.2, 0}, {0, All}}, PlotRangeClipping -> True, 
    PlotRangePadding -> {
      Scaled[0.02], Automatic}],
   TemplateBox[{"\"true\"", "\"approx\""}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.76944992732295*^9, 3.769449957132599*^9}, 
   3.769450006383308*^9, {3.7694502267653103`*^9, 3.769450253721489*^9}, 
   3.7699688454434433`*^9, 3.782258856447547*^9}]
}, Closed]],

Cell["and for large \[Rho]max we have", "Text",
 CellChangeTimes->{{3.7694489203453608`*^9, 3.769448927932375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"verylarge\[Rho]approx", "=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"32", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Psi]", "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}], ")"}]}]]}], 
     RowBox[{
      SqrtBox["\[Pi]"], " ", 
      SuperscriptBox["\[Rho]max", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["\[Psi]wt", "3"]}]]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{"verylarge\[Rho]approx", ",", 
    RowBox[{"{", 
     RowBox[{"\[Psi]", ",", 
      RowBox[{"-", "\[Infinity]"}], ",", "0"}], "}"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Rho]max", ">", "0"}], ",", 
       RowBox[{"\[Psi]wt", "<", "0"}]}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  FractionBox["verylarge\[Rho]approx", "%"], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                SqrtBox[
                 RowBox[{"1", "-", 
                  FractionBox["m", "mmax"]}]]}], ")"}]}], ",", "m"}], "]"}], 
           "%"}], "/.", 
          RowBox[{"a", "\[Rule]", 
           RowBox[{"2", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SqrtBox[
               RowBox[{"1", "-", 
                FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}], "/.", 
         RowBox[{"b", "\[Rule]", " ", 
          RowBox[{"2", 
           RowBox[{"(", 
            RowBox[{"1", "-", " ", 
             SqrtBox[
              RowBox[{"1", "+", 
               FractionBox["mstar", "mmax"]}]]}], ")"}]}]}]}], "/.", 
        RowBox[{"mstar", "\[Rule]", 
         SqrtBox[
          RowBox[{"\[CapitalLambda]0approx", "/", "2"}]]}]}], "/.", 
       RowBox[{"\[Rho]max", "\[Rule]", 
        RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
      RowBox[{"\[Theta]", "\[Rule]", 
       RowBox[{"n", "/", "2"}]}]}], "/.", 
     RowBox[{"\[Psi]wt", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SqrtBox[
          RowBox[{"1", "-", 
           FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}], "/.", 
    RowBox[{"\[Psi]", "\[Rule]", 
     RowBox[{"2", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SqrtBox[
         RowBox[{"1", "-", 
          FractionBox["m", "mmax"]}]]}], ")"}]}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"m", "<", "0"}], ",", 
     RowBox[{"mwt", "<", "0"}], ",", 
     RowBox[{"mmax", ">", "0"}], ",", 
     RowBox[{"\[Lambda]", ">", "0"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.769449026657213*^9, 3.769449033083315*^9}, 
   3.769449072923769*^9, 3.769449436085703*^9, {3.7694496121109333`*^9, 
   3.769449612415174*^9}, {3.769450278445756*^9, 3.769450279806321*^9}, {
   3.769450378604064*^9, 3.769450419295722*^9}, 3.782258889858121*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "4"]}], " ", "\[Rho]max", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Psi]", "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"\[Psi]", "-", "\[Psi]wt"}], ")"}], "2"]}], ")"}]}], "+", 
     FractionBox[
      RowBox[{"\[Rho]max", " ", 
       SuperscriptBox["\[Psi]wt", "2"]}], "8"]}]], " ", 
   SqrtBox[
    FractionBox["2", "\[Pi]"]], " ", 
   SqrtBox["\[Rho]max"]}], 
  RowBox[{"Erfc", "[", 
   FractionBox[
    RowBox[{
     SqrtBox["\[Rho]max"], " ", "\[Psi]wt"}], 
    RowBox[{"2", " ", 
     SqrtBox["2"]}]], "]"}]]], "Output",
 CellChangeTimes->{
  3.769449039254592*^9, 3.769449073856234*^9, 3.7694494369949837`*^9, 
   3.769449615134922*^9, 3.76945028049961*^9, {3.769450391694347*^9, 
   3.769450419887*^9}, 3.769968860717005*^9, 3.7822588586519547`*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    FractionBox[
     RowBox[{
      RowBox[{"4", " ", "m"}], "-", 
      RowBox[{"6", " ", "mmax"}], "+", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"mmax", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "m"}], "+", "mmax"}], ")"}]}]]}], "-", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"mmax", " ", 
         RowBox[{"(", 
          RowBox[{"mmax", "-", "mwt"}], ")"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "m"}], "+", "mmax"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"mmax", "-", "mwt"}], ")"}]}]]}], "+", "mwt"}], 
     RowBox[{"2", " ", "\[Lambda]"}]]], " ", 
   SqrtBox[
    FractionBox["2", "\[Pi]"]]}], 
  RowBox[{
   SqrtBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "m"}], "+", "mmax"}], ")"}], " ", "\[Lambda]"}]], " ", 
   RowBox[{"Erfc", "[", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SqrtBox[
         RowBox[{"1", "-", 
          FractionBox["mwt", "mmax"]}]]}], ")"}], " ", 
      SqrtBox[
       FractionBox["mmax", "\[Lambda]"]]}], 
     SqrtBox["2"]], "]"}]}]]], "Output",
 CellChangeTimes->{
  3.769449039254592*^9, 3.769449073856234*^9, 3.7694494369949837`*^9, 
   3.769449615134922*^9, 3.76945028049961*^9, {3.769450391694347*^9, 
   3.769450419887*^9}, 3.769968860717005*^9, 3.7822588590319023`*^9}]
}, Closed]],

Cell["\<\
Compare distribution of subcriticals\
\>", "Text",
 CellChangeTimes->{{3.769450029349228*^9, 3.7694500381406317`*^9}, 
   3.782258895635654*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.4"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"total", "=", 
    RowBox[{"U", " ", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fm", "[", 
         RowBox[{"m", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
        RowBox[{"prescuem", "[", 
         RowBox[{"m", ",", 
          RowBox[{"\[CapitalLambda]1", "[", 
           RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
           "]"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "\[Infinity]"}], ",", "0"}], "}"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      FractionBox[
       RowBox[{"U", " ", 
        RowBox[{"fm", "[", 
         RowBox[{"m", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
        RowBox[{"prescuem", "[", 
         RowBox[{"m", ",", 
          RowBox[{"\[CapitalLambda]1", "[", 
           RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
           "]"}]}], "]"}]}], "total"], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "0.4"}], ",", "0"}], "}"}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{",", 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           SqrtBox[
            RowBox[{"1", "-", 
             FractionBox["m", "mmax"]}]], " ", "mmax"}]], 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            FractionBox[
             RowBox[{
              RowBox[{"4", " ", "m"}], "+", "mwt", "+", 
              RowBox[{"mmax", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "6"}], "+", 
                 RowBox[{"4", " ", 
                  SqrtBox[
                   RowBox[{"1", "-", 
                    FractionBox["m", "mmax"]}]]}], "-", 
                 RowBox[{"2", " ", 
                  SqrtBox[
                   RowBox[{"1", "-", 
                    FractionBox["mwt", "mmax"]}]]}], "+", 
                 RowBox[{"4", " ", 
                  SqrtBox[
                   RowBox[{"1", "-", 
                    FractionBox["m", "mmax"]}]], " ", 
                  SqrtBox[
                   RowBox[{"1", "-", 
                    FractionBox["mwt", "mmax"]}]]}]}], ")"}]}]}], 
             RowBox[{"2", " ", "\[Lambda]"}]]], " ", 
           SqrtBox[
            FractionBox["2", "\[Pi]"]], " ", 
           SqrtBox[
            FractionBox["mmax", "\[Lambda]"]]}], 
          RowBox[{"Erfc", "[", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SqrtBox[
                RowBox[{"1", "-", 
                 FractionBox["mwt", "mmax"]}]]}], ")"}], " ", 
             SqrtBox[
              FractionBox["mmax", "\[Lambda]"]]}], 
            SqrtBox["2"]], "]"}]]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "0.4"}], ",", "0"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "70"}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<true\>\"", ",", "\"\<approx\>\""}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7510622484477882`*^9, 3.7510623899214077`*^9}, {
   3.751062473276165*^9, 3.751062530490876*^9}, 3.751062563427968*^9, {
   3.751062594941642*^9, 3.7510626740085497`*^9}, {3.751062706742158*^9, 
   3.7510627719753103`*^9}, {3.751062825650064*^9, 3.751062839069113*^9}, {
   3.751062891684408*^9, 3.7510628936156187`*^9}, {3.751062951583514*^9, 
   3.7510629518293257`*^9}, {3.7510751327453938`*^9, 3.751075187438393*^9}, {
   3.751075227865163*^9, 3.751075253129315*^9}, {3.751075331833404*^9, 
   3.751075338861655*^9}, {3.751075400453147*^9, 3.7510754285434923`*^9}, {
   3.751298603496088*^9, 3.751298619644992*^9}, {3.751298666312831*^9, 
   3.751298685790444*^9}, {3.7512987560965652`*^9, 3.75129876078164*^9}, 
   3.751298882585372*^9, {3.751299095508382*^9, 3.7512991099339523`*^9}, 
   3.7512991595807037`*^9, {3.769268148632958*^9, 3.769268191326717*^9}, {
   3.769268274695397*^9, 3.769268334384335*^9}, {3.7692683680850058`*^9, 
   3.7692683689144506`*^9}, {3.769268420749902*^9, 3.7692684229390297`*^9}, {
   3.769268853037169*^9, 3.769268869150824*^9}, 3.76926892183434*^9, {
   3.769445246914896*^9, 3.769445276483247*^9}, {3.769445324881626*^9, 
   3.769445398270315*^9}, {3.76944550632565*^9, 3.7694455461643744`*^9}, 
   3.769445579689747*^9, 3.769445609704138*^9, {3.769445650143132*^9, 
   3.769445718514558*^9}, {3.769445763735528*^9, 3.769445788498925*^9}, {
   3.769445818951551*^9, 3.769445938961893*^9}, {3.76944598970818*^9, 
   3.769446021603972*^9}, {3.76944611694064*^9, 3.769446153266705*^9}, {
   3.769448841596923*^9, 3.76944887086455*^9}, 3.769449315122406*^9, {
   3.7694496268301067`*^9, 3.769449627133671*^9}, {3.76944974606151*^9, 
   3.769449952712428*^9}, {3.769449991939508*^9, 3.769450001757079*^9}, {
   3.769450045734597*^9, 3.769450097211749*^9}, {3.7694501365178413`*^9, 
   3.769450182736156*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Hue[0.67, 0.6, 0.6], 
       LineBox[CompressedData["
1:eJwVi3k8FHgfgCfjPmpizGjJUaQ2bJpoXf1+CcnQIVkRypFWYpSkmiJs2JDc
YonkDCNXjnzHlbtmxhjjWBHZXUpLK2rFu+8fz+f553k0PALsvUUIBELSf/zf
NLvqqIyMYbh2pJDDeOiMxkbmdnWEDEOc/4P4O6Ou6O6F7X1//zQMWZ4g1Gw+
i/Z8dvZX2T8MKlsv/XO7zQONRCSSrCnDoKlHkvEheqPIzT3PriwJ4cuyGG09
wgfp5mw4lcMXQoFPvXCN7osEOkbLPVVCqPt4JqjG4xIKa2BkfE4UwlX+YpvC
BQaSjci2cw8QQoCZtU7X9csond63oYsuhLDPeVGV3UFIk/y1Zs9OIRy4W+XB
dLuGWGPavhmiQlg3VXG8hW4g0yenVEUmh8CqLt2wOugW6roUwfN9MQTxeWtB
jIgw5GBYeXcgYwi2u/75vCs0HE2ujRubBg+Ba7yMeFp1JOJ/cKgnnBqCSOND
/vP/3kVdYz37O2hDIJVEk7p0OwY19eLaGPkhYI6cab5+MBaxGmr3HV0QwJ3R
LebvbO6j/GKdKnmOAI54qy7cOP4Apafn6Q+VC8DWootkqJWEYqOUWJlxAmj2
cbM8pJ2CQoPj9c76CcComJ4S5ZyGnMz07/fSBYAEv7Tcq81Ae0X5Hw13C6DH
9NB7sk0Wku0NPp4nLYAzu/035W7JQTMPtlTKzQ4CzZusuEbORWynps3Xuwdh
9XOWjTo7D2WouV+eLhqEnh8Krswn5CPbsnxao88gCEjKO60ripBkhVmBp8Ug
eF2cfTWzvxS1swRKshqDYPBeOLl5tQyFPQu4V/2ND29H5j8ZhbGQabXk2pkR
PjQqeaWtaz5DKzW5DLE6PpRpfMddnq9C1XXGU2VJfNBZGrSYmahBuo1+XWu2
fPiklmN11boBHZ+yEyPq8KHUNZnrmN6EgmR+MJeQ4UOU6um4LkVA6TRSqMzs
AKR5zwYOTLJRk8tC46buAdhhaG8TbN+KJiJ4KwpFA2D8PMT39HgbEn1aZaAU
NQD5ebtslKI6EH31aoW65QCcuPPm5oRBN7J3t1s7pzEA9Ag3r6d+vcipVdPu
8TcejIuZtrD7+5Gb1mrm9DAPKoWpl1t0OcgremBWq5YHD2vv7tgXy0W+cyVG
Pok8+MspIP4GcQAxjoZHF/nz4Ksf2+L3ZD66RdbfsVubB+0m5Kl9MkLke8zg
JwVRHoRTeXKFfw0jx1+Nov+d4MK5R2sTLjOjSI9gPtv7kAvfrOuEPLUJ9J2J
lXL1NS5UqGqUnDs2icSDbWyzHLggfTp1Ij3hLRqfsy/328iFQbZqZ4DNO7TX
LqeY9YED/UMpCUYlM+hu+Vz+P30cGMt7+s1D+U+kGxiZybzHgYaai90xtDkU
xuOksn05wE7TUbEffY/4tK2JojYcsGlpcNyYOo+Yn2uiYyU5EFiWLsndtoC8
tBZ2K/e8hsO3H1gq0xYR1zXYamvEaxhmqr3+/tgnVPIq7KbG0ivwXowrXCxZ
QmdYKe92DfeDc2Tal5sLX1G6QWnyVGo/ROMD082HVxG/gX3oN4d+kO6Zj/lS
+A3RO+ZySZw+eBf1QpxtTsDGIwfdll/2QlGFW52TIxFfC2/8she6oXl+ldK+
LoXHhOnV6F4njASbead1kHAIJ3Ii5EgnTD3faydF24zJXQzZZxKdsD7r4vw5
ezOm11l7aUa+BPcMPyscKI9nyvcluJq/BDXyszXlIXkcXqDelEp4Cd4cN0qg
sQJuSFlRkLrVARPFrDMxKwpYmcj1bDLoAP9E5yumzmTMZBRXBcy3w3nVl5X9
dWQ89vsd4vbCdjhMkSxeJCliM7rzSYF7Owyx5Mo9vRVx9vO9j2OU2qFRmnlw
rFoRr2nJfDLltgHvdE2Q8roidk+aMv87pg04G2j06UMUzCY0JT42b4ML4gzq
WjgFv986X5C/2grW6+xXho0UvMVEvfFJbSu4mtUxUz9QsJWT/esCRitECfwu
L22h4stXI6cKv2+FKz2OGvqYinMSa5eLplugpFfXXucsFfdV/ClTkt0CKrxj
Dq+vU/FK33fqpU4tkHBcT0syjoq1Zm33PZVvAfENofd7MqhY3WHT715cNtTU
2lgJc6hYpZn7y9YENpQ+CpQ++IiKlXYm6wmOsoFh7vuHZCYVkxMdh+Ll2BDj
7vPzjwn//Sv6hPvpAD6NFiljof/1fbUnCBSAOkbmiLgvFZMemTwOTGqGWH1N
Qv9RKpYIYv/zltQMrucjpI/oUXE0TTXeOuIFWEe67tYVo2LpTze1y5eaIOn8
0mNtAQXHPhtmK1xogjxTh5CfcylY7vJ+5+sjjRB46XbZTh8KjtdP+TRu2win
lrev5WhTMGlhMdYCGkB+1jpm45QiVmCUw6b8enA7Fl89SVfEtG6d8Gm1etje
SM7yXyfjk9tKLeoznwNHt88moYKMk/iF3R5JdZDtt1svVZyMFYxyB2rCa6DK
4V9/pTR57OnmsmNNshKOCBoVVq9vxPki5+s9mCzY5Ks4mlgkh/vsJtPj31RA
ezIzPW5YFvPGZd6pl5XByhP3m1RLGXxKW0NmNukpBC4zXgnCpLEwwFC/6kYp
ZPgavHJpkcJvCOduWVoXQ0i7mTj1pCTOZtYtvT9YBIkHZnsXWBLYbUXOP9mk
ELSrdaxkFCWwapDXjIlBAegkjl34GCqOxz82uE3pPYGnQQTyvkUxnH1x89Cv
O/NBMyqqiuknht3+8Dm2d9tjCNHZMHP7oyhW9WzuHFbOgyjXqlBJpigeHyfj
O4q5IEkoOCuhIIq9PI0Tti3mQOgpdR+rciKWlaI/Mq//De6MxMT0OhFxdbkL
yyMsE54bs0QryUTs4uDHDj+cAXZvOttyp0WwyFcmJ29jGpz846QjqU8El+TE
TbQOJkP9NZuFyNci2N4y+++3WYnwi4nlcdklEfx1tpxA9EqADxIfYgcsiJhn
2xktVhEL5ssdY84viJjVtocklhoNK7fFpyf8RXG88cM00VuRMBldRIm4IIYv
VRLVRL3C4MddRfhFkzhOPT5iK5EaAl1zWae1QiWx/YEyF3EvBhRHZreYv5DG
Kk6EQWmvsyB3ziTsCkMOjwbt9LF9d6L5yugJOnU/Cf8PJBub2g==
        
        "]]}}, {{}, {}, {}, {
       Hue[0.9060679774997897, 0.6, 0.6], 
       LineBox[CompressedData["
1:eJwV13c8V98fB3BCmrLj84msECktKuNclCSbKKQlRUhJQ1ZlR8neK3vLpryt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        "]]}}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
    PlotRange -> {{-0.4, 0}, {0, All}}, PlotRangeClipping -> True, 
    PlotRangePadding -> {
      Scaled[0.02], Automatic}],
   TemplateBox[{"\"true\"", "\"approx\""}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.76944992732295*^9, 3.769449957132599*^9}, 
   3.769450006383308*^9, {3.769450051066534*^9, 3.7694501075431623`*^9}, {
   3.7694501502362823`*^9, 3.769450193629305*^9}, 3.7699688769777822`*^9, 
   3.7822588710012503`*^9}]
}, Closed]],

Cell["\<\
Our sufficiently critical approximation is\
\>", "Text",
 CellChangeTimes->{{3.7694495704143353`*^9, 3.769449579644019*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"fm", "[", 
    RowBox[{"0", ",", "m0", ",", "mmax", ",", "\[Lambda]", ",", "n"}], "]"}], 
   
   SqrtBox[
    RowBox[{"2", " ", 
     FractionBox[
      RowBox[{"2", " ", "U", " ", 
       SqrtBox[
        RowBox[{"mmax", " ", "\[Lambda]"}]]}], 
      SqrtBox["\[Pi]"]]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", 
      RowBox[{"-", 
       SqrtBox[
        RowBox[{" ", 
         FractionBox[
          RowBox[{" ", 
           RowBox[{"U", " ", 
            SqrtBox[
             RowBox[{"mmax", " ", "\[Lambda]"}]]}]}], 
          SqrtBox["\[Pi]"]]}]]}], ",", 
      SqrtBox[
       RowBox[{" ", 
        FractionBox[
         RowBox[{" ", 
          RowBox[{"U", " ", 
           SqrtBox[
            RowBox[{"mmax", " ", "\[Lambda]"}]]}]}], 
         SqrtBox["\[Pi]"]]}]]}], "}"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%%", "/", "%"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"mmax", ">", "0"}], ",", 
     RowBox[{"\[Lambda]", ">", "0"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7694504866851463`*^9, 3.769450564987321*^9}}],

Cell[BoxData[
 FractionBox[
  SuperscriptBox["\[Pi]", 
   RowBox[{"1", "/", "4"}]], 
  RowBox[{"2", " ", 
   SqrtBox["U"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"mmax", " ", "\[Lambda]"}], ")"}], 
    RowBox[{"1", "/", "4"}]]}]]], "Output",
 CellChangeTimes->{{3.769450537724309*^9, 3.769450565474152*^9}, 
   3.782258871160057*^9}]
}, Closed]],

Cell["\<\
Compare distributions of criticals\
\>", "Text",
 CellChangeTimes->{{3.7694506535365133`*^9, 3.769450658511326*^9}, 
   3.78225890493172*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pr0", "=", 
   SqrtBox[
    RowBox[{
     RowBox[{"\[CapitalLambda]1", "[", 
      RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], "]"}],
      "/", "2"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"total", "=", 
    RowBox[{"U", " ", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fm", "[", 
         RowBox[{"m", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
        RowBox[{"prescuem", "[", 
         RowBox[{"m", ",", 
          RowBox[{"\[CapitalLambda]1", "[", 
           RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
           "]"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", 
         RowBox[{"m", "/.", "mneg"}], ",", 
         RowBox[{"m", "/.", "mpos"}]}], "}"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      FractionBox[
       RowBox[{"U", " ", 
        RowBox[{"fm", "[", 
         RowBox[{"m", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
        RowBox[{"prescuem", "[", 
         RowBox[{"m", ",", 
          RowBox[{"\[CapitalLambda]1", "[", 
           RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
           "]"}]}], "]"}]}], "total"], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"m", "/.", "mneg"}], ",", 
        RowBox[{"m", "/.", "mpos"}]}], "}"}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{",", 
        FractionBox[
         SuperscriptBox["\[Pi]", 
          RowBox[{"1", "/", "4"}]], 
         RowBox[{"2", " ", 
          SqrtBox["U"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"mmax", " ", "\[Lambda]"}], ")"}], 
           RowBox[{"1", "/", "4"}]]}]]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", 
        RowBox[{"-", "pr0"}], ",", "pr0"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<true\>\"", ",", "\"\<approx\>\""}], "}"}]}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7510622484477882`*^9, 3.7510623899214077`*^9}, {
   3.751062473276165*^9, 3.751062530490876*^9}, 3.751062563427968*^9, {
   3.751062594941642*^9, 3.7510626740085497`*^9}, {3.751062706742158*^9, 
   3.7510627719753103`*^9}, {3.751062825650064*^9, 3.751062839069113*^9}, {
   3.751062891684408*^9, 3.7510628936156187`*^9}, {3.751062951583514*^9, 
   3.7510629518293257`*^9}, {3.7510751327453938`*^9, 3.751075187438393*^9}, {
   3.751075227865163*^9, 3.751075253129315*^9}, {3.751075331833404*^9, 
   3.751075338861655*^9}, {3.751075400453147*^9, 3.7510754285434923`*^9}, {
   3.751298603496088*^9, 3.751298619644992*^9}, {3.751298666312831*^9, 
   3.751298685790444*^9}, {3.7512987560965652`*^9, 3.75129876078164*^9}, 
   3.751298882585372*^9, {3.751299095508382*^9, 3.7512991099339523`*^9}, 
   3.7512991595807037`*^9, {3.769268148632958*^9, 3.769268191326717*^9}, {
   3.769268274695397*^9, 3.769268334384335*^9}, {3.7692683680850058`*^9, 
   3.7692683689144506`*^9}, {3.769268420749902*^9, 3.7692684229390297`*^9}, {
   3.769268853037169*^9, 3.769268869150824*^9}, 3.76926892183434*^9, {
   3.769445246914896*^9, 3.769445276483247*^9}, {3.769445324881626*^9, 
   3.769445398270315*^9}, {3.76944550632565*^9, 3.7694455461643744`*^9}, 
   3.769445579689747*^9, 3.769445609704138*^9, {3.769445650143132*^9, 
   3.769445718514558*^9}, {3.769445763735528*^9, 3.769445788498925*^9}, {
   3.769445818951551*^9, 3.769445938961893*^9}, {3.76944598970818*^9, 
   3.769446021603972*^9}, {3.76944611694064*^9, 3.769446153266705*^9}, {
   3.769448841596923*^9, 3.76944887086455*^9}, 3.769449315122406*^9, {
   3.7694496268301067`*^9, 3.769449627133671*^9}, {3.76944974606151*^9, 
   3.769449952712428*^9}, {3.769449991939508*^9, 3.769450001757079*^9}, {
   3.769450045734597*^9, 3.769450097211749*^9}, {3.7694501365178413`*^9, 
   3.769450182736156*^9}, {3.769450612332965*^9, 3.769450733323238*^9}, {
   3.7694508575398483`*^9, 3.769450928235241*^9}, 3.782258915372018*^9}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Hue[0.67, 0.6, 0.6], 
       LineBox[CompressedData["
1:eJwBIQPe/CFib1JlAgAAADEAAAACAAAADpc6t21Ucr9uGYDPvdRXQNRlSXlc
I3K/WKhX1b3qV0CaNFg7S/Jxv2ArTQzbAFhAJtJ1vyiQcb/C/vFGbS1YQD4N
scfjy3C/sv31XPKHWEA20lpZqkRuvxpCyL+QUllAOVWXBfQpa79nLNwpphda
QOD4BIHUHmi/Hv3JzkTgWkDhZ36lq9Fkvy4qBN8dwltAK6I7rOm8Yb+6yOMm
fZxcQJtPCbg8zFy/+eJVUzSRXUAonP210z1Wv6eXDXROiV5AR395eDggUL+v
7mdoZXdfQDLyGRoV/UK/RSXbUDBAYEBLtmAQ3XBBv1MlvjTeT2BAyPRODUrJ
P79zce9Yl19gQC0FauZpmDm/sP3L3ip/YEBgjffS+X82v6Ibmv0Ej2BAkhWF
v4lnM7+apf/W6Z5gQOxLQDFTbSq/vAT0LtO+YECYnb2ooFskv0REs6SGzmBA
id51QNyTHL+6oXTjQ95gQOKBcC93cBC/xD0YyQruYEDolKx5SDTxvlPjHjPb
/WBAtt1oyktZ/z5dNIvsq/FgQBWUnwO4+RM/4D8YaEPWYEBeeFKKjg4gP47P
cikLu2BAsibVEkEgJj92gXL2AqBgQFM+QEkGtiw/1bNjluSCYED6qtW/5aUx
P8ziCTb+ZWBAmsJA9qo7OD8WbjlG2CxgQO54i7Gas0I/+Rk4oz56X0AMe1KV
if1OP4WhZRAp611A4id16s4nVj/ffTOF6FNcQPbQ3mursVw/fnFpzoXcWkC8
cWAUXWVhP/0TQBEjk1lAo6/Fye2zZD+HjmCGRUNYQEEi55wXymc/ZvobvcQc
V0CFyfzGSiJrP3qaeZci8VVAJlDhIedqbj+aZ9aLet1UQL8FQU2OvXA/eCbU
jtXrU0C/fQu1rWZyP9hzp+mv9VJAfuoCfayXcj+7IgJfVNpSQD5X+kSryHI/
o20ryyy/UkC+MOnUqCpzPy0u1dt3iVJAfp3gnKdbcz/DOOyr6W5SQD0K2GSm
jHM/c6YAyo1UUkD8ds8spb1zPwU0gs1jOlJAvOPG9KPucz9LDIpOayBSQN2f
egw=
        "]]}}, {{}, {}, {}, {
       Hue[0.9060679774997897, 0.6, 0.6], 
       LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQvcWEQzZRvHh/c0Hl4vcd4Q6bJjHGFm0vgvM3fvg1
pzkcwX+lFjK3qb0Qzv920CbM62gBnO8ntzz+IRuCf+Tl+0srC/Lg/MkJG8KV
3ufA+bdO294N9s2G83fsPMessjkTzrctrJvdapIB51vJ/jZeMDUNzr87aZqt
j1AqnC/ebfpi2rRkOP9U+cLJs34lwvnKejob9KsS4PyXG9ln/94UC+fv4tkn
frUhCs6/8Wtj2cXWcDj/+UX76/ZeIXC+sw231EXXQDhfXv7hnhWMPnC+yIWd
JzWnucL5bv7SZg8N7eF8tUVa981MjRDmcxx0SQiRQPCVd1xysxC3h/GzN6iU
FG82gvNXcC1d5bnHDs6f9CDu7erHrnB+sWFs4w4vHzj/nm7Biv2KgXC+4K3p
fBvjQuD8758aJ9WnhMP569lSrwhER8H5ZYbrRAwmxcL5FU9iLMU8E+D8vbun
pke/TITzo0+uV+HPS4bzk0KOOai8ToHzP77ij2noSIPzb223YvPmyoDzvSbM
WB+zJhPOV372aft5t2w4P6xIz3/j0Rw4X4Br7tObKXlwvsqNN1yFL/Lh/AsT
5xw32VQA5wfZxnSGNBTC+YwtPZNWOxTB+VExp8LZ1iD40PwC5wMA2bqb9g==

        "]]}}}, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
    Axes -> True, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
    Method -> {}, PlotRange -> All, PlotRangeClipping -> True, 
    PlotRangePadding -> {
      Scaled[0.02], Automatic}],
   TemplateBox[{"\"true\"", "\"approx\""}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.769450738852656*^9, {3.7694508681572638`*^9, 3.769450929976203*^9}, 
   3.782258871329034*^9, 3.782258920618649*^9}]
}, Closed]],

Cell["\<\
And finally our distribution of supercriticals\
\>", "Text",
 CellChangeTimes->{{3.769450955809043*^9, 3.76945096596062*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"small\[Psi]approx", "=", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[Rho]max", " ", 
         SuperscriptBox["\[Psi]wt", "2"]}], "4"]}]]}], 
    RowBox[{
     SqrtBox["\[Pi]"], " ", 
     SqrtBox["\[Rho]max"], " ", "\[Psi]"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{"small\[Psi]approx", ",", 
    RowBox[{"{", 
     RowBox[{"\[Psi]", ",", "a", ",", "b"}], "}"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", "<", "a", "<", "b"}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 FractionBox["small\[Psi]approx", "%"], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"2", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              SqrtBox[
               RowBox[{"1", "-", 
                FractionBox["m", "mmax"]}]]}], ")"}]}], ",", "m"}], "]"}], 
         "%"}], "/.", 
        RowBox[{"a", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"(", " ", 
           RowBox[{"1", "-", " ", 
            SqrtBox[
             RowBox[{"1", "-", 
              FractionBox["mstar", "mmax"]}]]}], ")"}]}]}]}], "/.", 
       RowBox[{"b", "\[Rule]", 
        FractionBox[
         SqrtBox["2"], 
         SqrtBox["\[Rho]max"]]}]}], "/.", 
      RowBox[{"mstar", "\[Rule]", 
       SqrtBox[
        RowBox[{"\[CapitalLambda]0approx", "/", "2"}]]}]}], "/.", 
     RowBox[{"\[Rho]max", "\[Rule]", 
      RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "/.", 
    RowBox[{"\[Theta]", "\[Rule]", 
     RowBox[{"n", "/", "2"}]}]}], "/.", 
   RowBox[{"\[Psi]wt", "\[Rule]", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox["mwt", "mmax"]}]]}], ")"}]}]}]}], "/.", 
  RowBox[{"\[Psi]", "\[Rule]", 
   RowBox[{"2", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SqrtBox[
       RowBox[{"1", "-", 
        FractionBox["m", "mmax"]}]]}], ")"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.769344076056356*^9, 3.769344138219789*^9}, {
  3.769344314630602*^9, 3.769344395421007*^9}, {3.769348012899921*^9, 
  3.7693480354592457`*^9}, {3.769353801108457*^9, 3.7693538106511917`*^9}, {
  3.769358212881784*^9, 3.769358242178608*^9}, {3.769358474253397*^9, 
  3.7693584767145977`*^9}, {3.769374284840808*^9, 3.769374287131617*^9}, {
  3.769451175313019*^9, 3.769451215215384*^9}, {3.769451294866972*^9, 
  3.7694513123051367`*^9}}],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"\[Psi]", " ", 
   RowBox[{"Log", "[", 
    FractionBox["b", "a"], "]"}]}]]], "Output",
 CellChangeTimes->{3.782258871842767*^9}],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox["m", "mmax"]}]]}], ")"}], " ", 
   SqrtBox[
    RowBox[{"1", "-", 
     FractionBox["m", "mmax"]}]], " ", "mmax", " ", 
   RowBox[{"Log", "[", 
    FractionBox["1", 
     RowBox[{
      SqrtBox["2"], " ", 
      SqrtBox[
       FractionBox["mmax", "\[Lambda]"]], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SqrtBox[
         RowBox[{"1", "-", 
          FractionBox[
           SqrtBox[
            RowBox[{"U", " ", 
             SqrtBox[
              RowBox[{"mmax", " ", "\[Lambda]"}]]}]], 
           RowBox[{"mmax", " ", 
            SuperscriptBox["\[Pi]", 
             RowBox[{"1", "/", "4"}]]}]]}]]}], ")"}]}]], "]"}]}]]], "Output",
 CellChangeTimes->{3.782258871844677*^9}]
}, Closed]],

Cell["Note this is good only to", "Text",
 CellChangeTimes->{{3.769451494672278*^9, 3.769451509688155*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      FractionBox[
       SqrtBox["2"], 
       SqrtBox["\[Rho]max"]], "==", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SqrtBox[
          RowBox[{"1", "-", 
           FractionBox["m", "mmax"]}]]}], ")"}]}]}], ",", "m"}], "]"}], "/.", 
   
   RowBox[{"\[Rho]max", "\[Rule]", 
    RowBox[{"mmax", "/", "\[Lambda]"}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.769451352022834*^9, 3.769451392474039*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"m", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], "+", 
       RowBox[{
        SqrtBox["2"], " ", 
        SqrtBox[
         FractionBox["mmax", "\[Lambda]"]]}]}], ")"}], " ", "\[Lambda]"}]}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.769451217844757*^9, 3.769451313633059*^9, {3.769451365046619*^9, 
   3.769451392876306*^9}, 3.782258871891472*^9}]
}, Closed]],

Cell["\<\
Compare distn of supercriticals\
\>", "Text",
 CellChangeTimes->{{3.769451243746154*^9, 3.769451250952608*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"total", "=", 
    RowBox[{"U", " ", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fm", "[", 
         RowBox[{"m", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
        RowBox[{"prescuem", "[", 
         RowBox[{"m", ",", 
          RowBox[{"\[CapitalLambda]1", "[", 
           RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
           "]"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m", ",", "0", ",", "mmax"}], "}"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Plot", "[", 
     RowBox[{
      FractionBox[
       RowBox[{"U", " ", 
        RowBox[{"fm", "[", 
         RowBox[{"m", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
        RowBox[{"prescuem", "[", 
         RowBox[{"m", ",", 
          RowBox[{"\[CapitalLambda]1", "[", 
           RowBox[{"m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
           "]"}]}], "]"}]}], "total"], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "0", ",", "0.2"}], "}"}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{",", 
        FractionBox["1", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            SqrtBox[
             RowBox[{"1", "-", 
              FractionBox["m", "mmax"]}]]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"1", "-", 
            FractionBox["m", "mmax"]}]], " ", "mmax", " ", 
          RowBox[{"Log", "[", 
           FractionBox["1", 
            RowBox[{
             SqrtBox["2"], " ", 
             SqrtBox[
              FractionBox["mmax", "\[Lambda]"]], " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SqrtBox[
                RowBox[{"1", "-", 
                 FractionBox[
                  SqrtBox[
                   RowBox[{"U", " ", 
                    SqrtBox[
                    RowBox[{"mmax", " ", "\[Lambda]"}]]}]], 
                  RowBox[{"mmax", " ", 
                   SuperscriptBox["\[Pi]", 
                    RowBox[{"1", "/", "4"}]]}]]}]]}], ")"}]}]], "]"}]}]]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m", ",", "0", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "2"]}], "+", 
           RowBox[{
            SqrtBox["2"], " ", 
            SqrtBox[
             FractionBox["mmax", "\[Lambda]"]]}]}], ")"}], " ", 
         "\[Lambda]"}]}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "150"}], "}"}]}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<true\>\"", ",", "\"\<approx\>\""}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7510622484477882`*^9, 3.7510623899214077`*^9}, {
   3.751062473276165*^9, 3.751062530490876*^9}, 3.751062563427968*^9, {
   3.751062594941642*^9, 3.7510626740085497`*^9}, {3.751062706742158*^9, 
   3.7510627719753103`*^9}, {3.751062825650064*^9, 3.751062839069113*^9}, {
   3.751062891684408*^9, 3.7510628936156187`*^9}, {3.751062951583514*^9, 
   3.7510629518293257`*^9}, {3.7510751327453938`*^9, 3.751075187438393*^9}, {
   3.751075227865163*^9, 3.751075253129315*^9}, {3.751075331833404*^9, 
   3.751075338861655*^9}, {3.751075400453147*^9, 3.7510754285434923`*^9}, {
   3.751298603496088*^9, 3.751298619644992*^9}, {3.751298666312831*^9, 
   3.751298685790444*^9}, {3.7512987560965652`*^9, 3.75129876078164*^9}, 
   3.751298882585372*^9, {3.751299095508382*^9, 3.7512991099339523`*^9}, 
   3.7512991595807037`*^9, {3.769268148632958*^9, 3.769268191326717*^9}, {
   3.769268274695397*^9, 3.769268334384335*^9}, {3.7692683680850058`*^9, 
   3.7692683689144506`*^9}, {3.769268420749902*^9, 3.7692684229390297`*^9}, {
   3.769268853037169*^9, 3.769268869150824*^9}, 3.76926892183434*^9, {
   3.769445246914896*^9, 3.769445276483247*^9}, {3.769445324881626*^9, 
   3.769445398270315*^9}, {3.76944550632565*^9, 3.7694455461643744`*^9}, 
   3.769445579689747*^9, 3.769445609704138*^9, {3.769445650143132*^9, 
   3.769445718514558*^9}, {3.769445763735528*^9, 3.769445788498925*^9}, {
   3.769445818951551*^9, 3.769445938961893*^9}, {3.76944598970818*^9, 
   3.769446021603972*^9}, {3.76944611694064*^9, 3.769446153266705*^9}, {
   3.769448841596923*^9, 3.76944887086455*^9}, 3.769449315122406*^9, {
   3.7694496268301067`*^9, 3.769449627133671*^9}, {3.76944974606151*^9, 
   3.769449952712428*^9}, {3.769449991939508*^9, 3.769450001757079*^9}, {
   3.769450045734597*^9, 3.769450097211749*^9}, {3.7694501365178413`*^9, 
   3.769450182736156*^9}, {3.769451271671968*^9, 3.769451286756756*^9}, 
   3.7694513183309927`*^9, {3.769451400350457*^9, 3.7694514596526203`*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Hue[0.67, 0.6, 0.6], 
       LineBox[CompressedData["
1:eJwVxXc81QsDB2DE9Uq2JOSWJFlZmdf5/hwiq1BJRkYqKSNkXyQqhWwNm4iS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        "]]}}, {{}, {}, {}, {
       Hue[0.9060679774997897, 0.6, 0.6], 
       LineBox[CompressedData["
1:eJwVjXc4FYofh0k2pYwjlDjxS0RGZny/5xwz2cfIpoSsY4/IXmUXoZJkdKwc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        "]]}}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
    PlotRange -> {{0, 0.2}, {0, All}}, PlotRangeClipping -> True, 
    PlotRangePadding -> {
      Scaled[0.02], Automatic}],
   TemplateBox[{"\"true\"", "\"approx\""}, "LineLegend", 
    DisplayFunction -> (StyleBox[
      StyleBox[
       PaneBox[
        TagBox[
         GridBox[{{
            TagBox[
             GridBox[{{
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6]], {}}}, AspectRatio -> Full, 
                 ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                GraphicsBox[{{
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                   Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.9060679774997897, 0.6, 0.6]], {}}}, AspectRatio -> 
                 Full, ImageSize -> {20, 10}, PlotRangePadding -> None, 
                 ImagePadding -> 1, 
                 BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
              GridBoxAlignment -> {
               "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
              AutoDelete -> False, 
              GridBoxDividers -> {
               "Columns" -> {{False}}, "Rows" -> {{False}}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], 
             "Grid"]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], "Grid"], 
        Alignment -> Left, AppearanceElements -> None, 
        ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"], 
       LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
      Background -> Automatic, StripOnInput -> False]& ), Editable -> True, 
    InterpretationFunction :> (RowBox[{"LineLegend", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], "]"}], 
             ",", 
             RowBox[{"Directive", "[", 
               RowBox[{"Hue", "[", 
                 RowBox[{"0.9060679774997897`", ",", "0.6`", ",", "0.6`"}], 
                 "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
           RowBox[{#, ",", #2}], "}"}], ",", 
         RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.76944992732295*^9, 3.769449957132599*^9}, 
   3.769450006383308*^9, {3.769450051066534*^9, 3.7694501075431623`*^9}, {
   3.7694501502362823`*^9, 3.769450193629305*^9}, {3.7694514196237183`*^9, 
   3.7694514694732447`*^9}, 3.782258883679084*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot growth rates of rescue intermediates", "Subsection",
 CellChangeTimes->{{3.7694389967664127`*^9, 3.769439011733487*^9}}],

Cell[CellGroupData[{

Cell["As function of wildtype growth rate (figure 7)", "Subsubsection",
 CellChangeTimes->{{3.7566733855717278`*^9, 3.7566733875576344`*^9}, {
  3.756673727633417*^9, 3.756673728609564*^9}, {3.760637625474948*^9, 
  3.76063762745905*^9}, {3.769433508402923*^9, 3.769433509874899*^9}, {
  3.769439032936616*^9, 3.76943903839826*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"-", "0.3"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmax", "=", "0.15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymax", "=", "30"}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.1"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exact", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
     RowBox[{"prescuem", "[", 
      RowBox[{"m1", ",", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"critical", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"0", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     SqrtBox[
      RowBox[{"2", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}]], 
     RowBox[{"HeavisideTheta", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m1", "+", "pr0"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"pr0", "-", "m1"}], ")"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"subcritical", "=", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], 
     RowBox[{"Abs", "[", "m1", "]"}]], 
    RowBox[{"HeavisideTheta", "[", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "m1"}], "-", "pr0"}], ")"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"supercritical", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
     FractionBox[
      RowBox[{" ", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], 
      RowBox[{"Abs", "[", "m1", "]"}]], 
     RowBox[{"HeavisideTheta", "[", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "pr0"}], ")"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"allexact", "=", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{"exact", ",", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "mwt", ",", "0.1"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], ",", "\[IndentingNewLine]", 
    FractionBox[
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"pest", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}]}], 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fm", "[", 
         RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"pest", "[", 
         RowBox[{"m1", "-", "mwt"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], 
   "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory", "=", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{"%", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Filling", "\[Rule]", "Bottom"}], ","}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{"Gray", ",", "Thick", ",", "Dashed"}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Gray", ",", "Thick"}], "]"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{"\"\<random\>\"", ",", "\"\<established\>\""}], "}"}]}], 
          "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "8"}], ",", 
            RowBox[{"1.25", "/", "2"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    FractionBox["subcritical", "allexact"], ",", 
    FractionBox["critical", "allexact"], ",", 
    FractionBox["supercritical", "allexact"]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory", "=", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{"%", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"SwatchLegend", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Directive", "[", 
              RowBox[{
               RowBox[{"defaultcolors", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}], ",", 
             RowBox[{"Directive", "[", 
              RowBox[{
               RowBox[{"defaultcolors", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}], ",", 
             RowBox[{"Directive", "[", 
              RowBox[{
               RowBox[{"defaultcolors", "[", 
                RowBox[{"[", "3", "]"}], "]"}], ",", 
               RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}]}], "}"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{
             "\"\<subcritical\>\"", ",", "\"\<critical\>\"", ",", 
              "\"\<supercritical\>\""}], "}"}]}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "8"}], ",", 
            RowBox[{"0.65", "/", "2"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exactplot", "=", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"exact", "/", "allexact"}], ",", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", "Black"}], "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", "\"\<first-step\>\"", "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "8"}], ",", 
            RowBox[{"1.25", "/", "2"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "datadir", "<>", 
     "\"\<int_dfe_poisson_N10000_n4_U0.00200_Es0.01_mmax0.50_mwt-0.10_\
mutmax10_nreps100000.csv\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Select", "[", 
    RowBox[{"dat", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
   "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Histogram", "[", 
     RowBox[{"%", ",", "50", ",", "\"\<PDF\>\"", ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], ",", 
      RowBox[{"ChartStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Gray", ",", 
         RowBox[{"Opacity", "[", "0.25", "]"}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fig7a", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
    "oldtheory", ",", "data", ",", "theory", ",", "exactplot", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontColor", "\[Rule]", "White"}], ",", "Automatic", ",", 
        "Automatic", ",", "Automatic"}], "}"}]}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<\!\(\*SubscriptBox[\(m\), \(0\)]\)=\>\"", "<>", 
             RowBox[{"ToString", "[", "mwt", "]"}]}], ",", "12", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"7", "/", "8"}], ",", 
             RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<A\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.771259863315041*^9, 3.771259875817935*^9}, {
   3.77125993618959*^9, 3.7712599967791033`*^9}, {3.7712600806108303`*^9, 
   3.771260101998229*^9}, {3.7712601420091887`*^9, 3.771260164023238*^9}, {
   3.7712604866075153`*^9, 3.7712604916540623`*^9}, {3.771260596998*^9, 
   3.7712606779327497`*^9}, {3.771260742113587*^9, 3.77126078863237*^9}, {
   3.7712608356681213`*^9, 3.771260853796445*^9}, 3.77126088730492*^9, {
   3.771260950376927*^9, 3.771260951994858*^9}, {3.771260988204628*^9, 
   3.771261046264202*^9}, {3.771261095976034*^9, 3.771261100349186*^9}, {
   3.771261221602476*^9, 3.771261223165237*^9}, {3.7712612596219587`*^9, 
   3.771261376814014*^9}, {3.7712614254017878`*^9, 3.771261458422593*^9}, {
   3.771261523796259*^9, 3.771261558803645*^9}, {3.771525291980131*^9, 
   3.771525296404852*^9}, {3.771525340514213*^9, 3.771525362538801*^9}, {
   3.771525476715866*^9, 3.771525481529388*^9}, {3.771525527353706*^9, 
   3.771525572057776*^9}, {3.771525611182823*^9, 3.77152571017303*^9}, {
   3.771525850691698*^9, 3.771525923002439*^9}, {3.771525956576083*^9, 
   3.771525983790447*^9}, {3.771526019222022*^9, 3.7715260269883137`*^9}, {
   3.771526062519966*^9, 3.77152607841735*^9}, {3.771526152732314*^9, 
   3.771526160701219*^9}, {3.771526280292366*^9, 3.771526400673423*^9}, 
   3.771526440426137*^9, 3.782258968897572*^9, {3.784902441876593*^9, 
   3.784902446445827*^9}, 3.78490276252194*^9}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
       LineBox[CompressedData["
1:eJwVknk4FGofhpmULVlmVBNOPlpli0jI75Ula5YMHX0lCtmmEsl0UsiSvki0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        "]]}, 
      {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxFxw88FPYfx/FzKpw/l5R2/qw7+nMpx8gy4fNt/uZPo50/KbZMSKpJk/Tn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        "]]}}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[Opacity[0.189]], {}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.189]], 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.19, 0}, 
         NCache[{-0.185, Rational[40, 917]}, {-0.185, 0.04362050163576881}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.18, 0}, 
         NCache[{-0.175, Rational[20, 917]}, {-0.175, 0.021810250817884406`}],
         
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.17, 0}, 
         NCache[{-0.165, Rational[40, 917]}, {-0.165, 0.04362050163576881}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.165, 0}, 
         NCache[{-0.16, Rational[40, 917]}, {-0.16, 0.04362050163576881}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.16, 0}, 
         NCache[{-0.155, Rational[40, 917]}, {-0.155, 0.04362050163576881}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.155, 0}, 
         NCache[{-0.15, Rational[60, 917]}, {-0.15, 0.06543075245365322}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.15, 0}, 
         NCache[{-0.145, Rational[60, 917]}, {-0.145, 0.06543075245365322}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.145, 0}, 
         NCache[{-0.14, Rational[80, 917]}, {-0.14, 0.08724100327153762}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.14, 0}, 
         NCache[{-0.135, Rational[60, 917]}, {-0.135, 0.06543075245365322}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.135, 0}, 
         NCache[{-0.13, Rational[80, 917]}, {-0.13, 0.08724100327153762}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.13, 0}, 
         NCache[{-0.125, Rational[80, 917]}, {-0.125, 0.08724100327153762}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.125, 0}, 
         NCache[{-0.12, Rational[20, 131]}, {-0.12, 0.15267175572519084`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.12, 0}, 
         NCache[{-0.115, Rational[160, 917]}, {-0.115, 0.17448200654307525`}],
         
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.115, 0}, 
         NCache[{-0.11, Rational[200, 917]}, {-0.11, 0.21810250817884405`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.11, 0}, 
         NCache[{-0.105, Rational[260, 917]}, {-0.105, 0.2835332606324973}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.105, 0}, 
         NCache[{-0.1, Rational[540, 917]}, {-0.1, 0.5888767720828789}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.1, 0}, 
         NCache[{-0.095, Rational[600, 917]}, {-0.095, 0.6543075245365322}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.095, 0}, 
         NCache[{-0.09, Rational[620, 917]}, {-0.09, 0.6761177753544165}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.09, 0}, 
         NCache[{-0.085, Rational[520, 917]}, {-0.085, 0.5670665212649946}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.085, 0}, 
         NCache[{-0.08, Rational[720, 917]}, {-0.08, 0.7851690294438386}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.08, 0}, 
         NCache[{-0.075, Rational[880, 917]}, {-0.075, 0.9596510359869138}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.075, 0}, 
         NCache[{-0.07, Rational[1200, 917]}, {-0.07, 1.3086150490730644`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.07, 0}, 
         NCache[{-0.065, Rational[1420, 917]}, {-0.065, 1.5485278080697928`}],
         
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.065, 0}, 
         NCache[{-0.06, Rational[200, 131]}, {-0.06, 1.5267175572519085`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.06, 0}, 
         NCache[{-0.055, Rational[1580, 917]}, {-0.055, 1.723009814612868}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.055, 0}, 
         NCache[{-0.05, Rational[2220, 917]}, {-0.05, 2.420937840785169}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.05, 0}, 
         NCache[{-0.045, Rational[2300, 917]}, {-0.045, 2.5081788440567068`}],
         
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.045, 0}, 
         NCache[{-0.04, Rational[3420, 917]}, {-0.04, 3.7295528898582333`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.04, 0}, 
         NCache[{-0.035, Rational[3280, 917]}, {-0.035, 3.5768811341330427`}],
         
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.035, 0}, 
         NCache[{-0.03, Rational[4460, 917]}, {-0.03, 4.863685932388223}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.03, 0}, 
         NCache[{-0.025, Rational[5440, 917]}, {-0.025, 5.932388222464558}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.025, 0}, 
         NCache[{-0.02, Rational[6280, 917]}, {-0.02, 6.848418756815703}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.02, 0}, 
         NCache[{-0.015, Rational[6620, 917]}, {-0.015, 7.219193020719739}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.015, 0}, 
         NCache[{-0.01, Rational[9420, 917]}, {-0.01, 10.272628135223554`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.01, 0}, 
         NCache[{-0.005, Rational[11380, 917]}, {-0.005, 12.410032715376227`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{-0.005, 0}, 
         NCache[{0., Rational[15420, 917]}, {0., 16.815703380588875`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0., 0}, 
         NCache[{0.005, Rational[9780, 917]}, {0.005, 10.665212649945474`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.005, 0}, 
         NCache[{0.01, Rational[10240, 917]}, {0.01, 11.166848418756816`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.01, 0}, 
         NCache[{0.015, Rational[9360, 917]}, {0.015, 10.207197382769902`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.015, 0}, 
         NCache[{0.02, Rational[9200, 917]}, {0.02, 10.032715376226827`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.02, 0}, 
         NCache[{0.025, Rational[1300, 131]}, {0.025, 9.923664122137405}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.025, 0}, 
         NCache[{0.03, Rational[8140, 917]}, {0.03, 8.876772082878952}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.03, 0}, 
         NCache[{0.035, Rational[6600, 917]}, {0.035, 7.1973827699018535`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.035, 0}, 
         NCache[{0.04, Rational[6040, 917]}, {0.04, 6.586695747001091}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.04, 0}, 
         NCache[{0.045, Rational[5280, 917]}, {0.045, 5.757906215921483}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.045, 0}, 
         NCache[{0.05, Rational[4660, 917]}, {0.05, 5.081788440567067}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.05, 0}, 
         NCache[{0.055, Rational[580, 131]}, {0.055, 4.427480916030534}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.055, 0}, 
         NCache[{0.06, Rational[3800, 917]}, {0.06, 4.143947655398037}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.06, 0}, 
         NCache[{0.065, Rational[380, 131]}, {0.065, 2.900763358778626}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.065, 0}, 
         NCache[{0.07, Rational[2700, 917]}, {0.07, 2.9443838604143946`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.07, 0}, 
         NCache[{0.075, Rational[2080, 917]}, {0.075, 2.2682660850599783`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.075, 0}, 
         NCache[{0.08, Rational[1380, 917]}, {0.08, 1.504907306434024}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.08, 0}, 
         NCache[{0.085, Rational[1300, 917]}, {0.085, 1.4176663031624863`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.085, 0}, 
         NCache[{0.09, Rational[1360, 917]}, {0.09, 1.4830970556161396`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.09, 0}, 
         NCache[{0.095, Rational[1080, 917]}, {0.095, 1.1777535441657578`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.095, 0}, 
         NCache[{0.1, Rational[820, 917]}, {0.1, 0.8942202835332607}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.1, 0}, 
         NCache[{0.105, Rational[480, 917]}, {0.105, 0.5234460196292258}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.105, 0}, 
         NCache[{0.11, Rational[520, 917]}, {0.11, 0.5670665212649946}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.11, 0}, 
         NCache[{0.115, Rational[40, 131]}, {0.115, 0.3053435114503817}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.115, 0}, 
         NCache[{0.12, Rational[360, 917]}, {0.12, 0.3925845147219193}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.12, 0}, 
         NCache[{0.125, Rational[220, 917]}, {0.125, 0.23991275899672845`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.125, 0}, 
         NCache[{0.13, Rational[200, 917]}, {0.13, 0.21810250817884405`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.13, 0}, 
         NCache[{0.135, Rational[100, 917]}, {0.135, 0.10905125408942203`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.135, 0}, 
         NCache[{0.14, Rational[100, 917]}, {0.14, 0.10905125408942203`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.14, 0}, 
         NCache[{0.145, Rational[20, 131]}, {0.145, 0.15267175572519084`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.145, 0}, 
         NCache[{0.15, Rational[80, 917]}, {0.15, 0.08724100327153762}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.15, 0}, 
         NCache[{0.155, Rational[40, 917]}, {0.155, 0.04362050163576881}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.155, 0}, 
         NCache[{0.16, Rational[20, 917]}, {0.16, 0.021810250817884406`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.16, 0}, 
         NCache[{0.165, Rational[20, 917]}, {0.165, 0.021810250817884406`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.165, 0}, 
         NCache[{0.17, Rational[40, 917]}, {0.17, 0.04362050163576881}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.17, 0}, 
         NCache[{0.175, Rational[40, 917]}, {0.175, 0.04362050163576881}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.175, 0}, 
         NCache[{0.18, Rational[20, 917]}, {0.18, 0.021810250817884406`}],
         RoundingRadius->0]}, 
       {GrayLevel[0.5], Opacity[0.25], 
        RectangleBox[{0.18, 0}, 
         NCache[{0.185, Rational[20, 917]}, {0.185, 0.021810250817884406`}],
         RoundingRadius->0]}}, {}, {}}, GraphicsComplexBox[CompressedData["
1:eJztlnk0lWvfx02RcStRW+oUHbRlKEMi+3erUKQQckqJSkJk6oiK1MFJJSky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      "], {{{}, 
        {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
         GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwt0VdPEwAUBeAiKBt5ZpdNwt4jYYMoGrDsmVD2agl7I1NF/M98TfrwnfN6
b04wHA1FPgQCgQRu4h0UP/QBVdzTxTLZ/Oc7USr5RSdLfOaNUSJUcEcHi2Tx
jX3KuaWdBTL5yh5l8XvamCeDEXYp5ZpW5kjnH1/YoYQrWpgljVeG2aaYS5qZ
IZW/DLEV+58LmpgmhT8MskkR5zQyRTK/GWCDQs5oYJJPvNDPOgWcUs8EH3mm
jzXyOaGOEEk80csqeRxTy08SeaSHMLkcUcM4sX0f6GaFHA6pZox3ZpAmZw==

           "]]]}, {}, 
        {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
         GraphicsGroupBox[
          PolygonBox[{{192, 172, 196, 178, 188, 160, 197, 182}}]]}, {}, 
        {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
         GraphicsGroupBox[
          PolygonBox[{{272, 288, 223, 287, 252, 271, 233, 279, 243, 262, 222, 
           286, 251, 270, 232, 278, 242, 261, 221, 285, 250, 269, 231, 277, 
           241, 260, 220, 284, 249, 268, 230, 276, 240, 259, 219, 283, 248, 
           267, 229, 275, 239, 258, 218, 282, 247, 266, 228, 274, 238, 257, 
           217, 281, 246, 265, 227, 273, 237, 256, 216, 280, 245, 264, 
           226}}]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], 
         LineBox[{1, 79, 44, 114, 26, 97, 62, 130, 2, 80, 45, 115, 27, 98, 63,
           131, 3, 81, 46, 116, 28, 99, 64, 132, 4, 82, 47, 117, 29, 100, 65, 
          133, 5, 83, 48, 118, 30, 101, 66, 134, 6, 84, 49, 119, 31, 102, 67, 
          135, 7, 85, 50, 120, 32, 103, 68, 136, 8, 86, 51, 121, 33, 104, 69, 
          137, 9, 87, 52, 122, 34, 105, 70, 138, 10, 88, 53, 123, 35, 106, 71,
           139, 11, 89, 54, 124, 36, 107, 72, 12, 90, 55, 125, 37, 108, 73, 
          13, 91, 56, 126, 38, 109, 74, 14, 92, 57, 127, 39, 110, 75, 140, 15,
           93, 58, 128, 40, 111, 76, 141, 16, 94, 59, 129, 41, 112, 77, 142, 
          17, 95, 60, 42, 18, 19, 20, 21, 22, 23, 24, 96, 61, 43, 113, 78, 
          143, 25}]}, 
        {Hue[0.9060679774997897, 0.6, 0.6], 
         LineBox[{144, 185, 175, 169, 145, 146, 147, 148, 149, 150, 151, 152, 
          153, 154, 155, 156, 157, 158, 186, 176, 170, 191, 181, 159, 187, 
          177, 195, 171, 192, 182, 197, 160, 188, 178, 196, 172, 193, 183, 
          161, 189, 179, 173, 162, 163, 164, 165, 166, 167, 190, 180, 174, 
          194, 184, 198, 168}]}, 
        {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzdk2ggEYhtFfGZJMZSgZllty5tQF6DIrU2QOSaaEEMoYu4Nn7bW+9+Bb
XMksrfYEQbCsrH5VV0U55bWmdW1oU1sqaFs7KmpXe9rXgTq614UGPHjjof70
oDG3KiN8Z5JHDPiIcV5ykC2meNyd2WCcV4yyzRmWGOITE7zmED+Y5gnDfOYE
bxjjJ2d5yl6+cJK3HOYX53jGPjY5xRpH+M15ltnPV07zjqP84QLP+Q/yEjao

          "]]}}}], {{}, {}, 
      {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwVklc81f8fxzkkm1KKVDJKJ1tK4ry/JSPrFxktil+kiF9GkZKMSFmRkb2O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        "]]}}}, {InsetBox[
      TemplateBox[{
       StyleBox[
        "\"subcritical\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"critical\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"supercritical\"", StripOnInput -> False, FontFamily -> "Helvetica",
          FontSize -> 12]},
       "SwatchLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"SwatchLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    RowBox[{
                    "0.6`", ",", "0.5470136627990908`", ",", "0.24`"}], "]"}],
                     ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      NCache[Scaled[{Rational[1, 8], 0.325}], Scaled[{0.125, 0.325}]], 
      ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TagBox[GridBox[{
         {
          
          TemplateBox[{
           StyleBox[
            "\"random\"", StripOnInput -> False, FontFamily -> "Helvetica", 
             FontSize -> 12],StyleBox[
            "\"established\"", StripOnInput -> False, FontFamily -> 
             "Helvetica", FontSize -> 12]},
           "LineLegend",
           DisplayFunction->(StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
             False]& ),
           Editable->True,
           InterpretationFunction:>(RowBox[{"LineLegend", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
                  "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{#, ",", #2}], "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
              "]"}]& )]},
         {
          
          TemplateBox[{
           StyleBox[
            "\"first-step\"", StripOnInput -> False, FontFamily -> 
             "Helvetica", FontSize -> 12]},
           "LineLegend",
           DisplayFunction->(StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
             False]& ),
           Editable->True,
           InterpretationFunction:>(RowBox[{"LineLegend", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], "}"}], ",", 
                RowBox[{"{", #, "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{0}}}],
       "Grid"], NCache[
      Scaled[{Rational[1, 8], 0.625}], Scaled[{0.125, 0.625}]], ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesLabel->{None, None},
   AxesOrigin->{0, 0},
   Epilog->{
     InsetBox[
      FormBox[
       StyleBox[
       "\"\\!\\(\\*SubscriptBox[\\(m\\), \\(0\\)]\\)=-0.1\"", 12, FontFamily -> 
        "Helvetica", StripOnInput -> False], TraditionalForm], 
      NCache[
       Scaled[{
         Rational[7, 8], 
         Rational[3, 4]}], 
       Scaled[{0.875, 0.75}]]], 
     InsetBox[
      FormBox[
       StyleBox[
       "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
       TraditionalForm], 
      Scaled[{0.05, 0.95}]]},
   Frame->{True, False, False, False},
   FrameTicksStyle->{
    FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.3, 0.15}, {0, 30}},
   PlotRangeClipping->True,
   PlotRangePadding->{
     Scaled[0.02], Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          GrayLevel[0.5], 
          Thickness[Large], 
          Dashing[{Small, Small}]], 
         Line[CompressedData["
1:eJwVknk4FGofhpmULVlmVBNOPlpli0jI75Ula5YMHX0lCtmmEsl0UsiSvki0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          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          GrayLevel[0.5], 
          Thickness[Large]], 
         Line[CompressedData["
1:eJxFxw88FPYfx/FzKpw/l5R2/qw7+nMpx8gy4fNt/uZPo50/KbZMSKpJk/Tn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          "]]}}}, {
       Directive[
        EdgeForm[
         Opacity[0.189]], 
        RGBColor[
        0.798413061722744, 0.824719615472648, 0.968322270542458]], {{}, {
         Directive[
          EdgeForm[
           Opacity[0.189]], 
          RGBColor[
          0.798413061722744, 0.824719615472648, 0.968322270542458]], {{{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.19, 0}, {-0.185, 
              Rational[40, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.18, 0}, {-0.175, 
              Rational[20, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.17, 0}, {-0.165, 
              Rational[40, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.165, 0}, {-0.16, 
              Rational[40, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.16, 0}, {-0.155, 
              Rational[40, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.155, 0}, {-0.15, 
              Rational[60, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.15, 0}, {-0.145, 
              Rational[60, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.145, 0}, {-0.14, 
              Rational[80, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.14, 0}, {-0.135, 
              Rational[60, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.135, 0}, {-0.13, 
              Rational[80, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.13, 0}, {-0.125, 
              Rational[80, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.125, 0}, {-0.12, 
              Rational[20, 131]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.12, 0}, {-0.115, 
              Rational[160, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.115, 0}, {-0.11, 
              Rational[200, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.11, 0}, {-0.105, 
              Rational[260, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.105, 0}, {-0.1, 
              Rational[540, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.1, 0}, {-0.095, 
              Rational[600, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.095, 0}, {-0.09, 
              Rational[620, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.09, 0}, {-0.085, 
              Rational[520, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.085, 0}, {-0.08, 
              Rational[720, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.08, 0}, {-0.075, 
              Rational[880, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.075, 0}, {-0.07, 
              Rational[1200, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.07, 0}, {-0.065, 
              Rational[1420, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.065, 0}, {-0.06, 
              Rational[200, 131]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.06, 0}, {-0.055, 
              Rational[1580, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.055, 0}, {-0.05, 
              Rational[2220, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.05, 0}, {-0.045, 
              Rational[2300, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.045, 0}, {-0.04, 
              Rational[3420, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.04, 0}, {-0.035, 
              Rational[3280, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.035, 0}, {-0.03, 
              Rational[4460, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.03, 0}, {-0.025, 
              Rational[5440, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.025, 0}, {-0.02, 
              Rational[6280, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.02, 0}, {-0.015, 
              Rational[6620, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.015, 0}, {-0.01, 
              Rational[9420, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.01, 0}, {-0.005, 
              Rational[11380, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{-0.005, 0}, {0., 
              Rational[15420, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0., 0}, {0.005, 
              Rational[9780, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.005, 0}, {0.01, 
              Rational[10240, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.01, 0}, {0.015, 
              Rational[9360, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.015, 0}, {0.02, 
              Rational[9200, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.02, 0}, {0.025, 
              Rational[1300, 131]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.025, 0}, {0.03, 
              Rational[8140, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.03, 0}, {0.035, 
              Rational[6600, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.035, 0}, {0.04, 
              Rational[6040, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.04, 0}, {0.045, 
              Rational[5280, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.045, 0}, {0.05, 
              Rational[4660, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.05, 0}, {0.055, 
              Rational[580, 131]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.055, 0}, {0.06, 
              Rational[3800, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.06, 0}, {0.065, 
              Rational[380, 131]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.065, 0}, {0.07, 
              Rational[2700, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.07, 0}, {0.075, 
              Rational[2080, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.075, 0}, {0.08, 
              Rational[1380, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.08, 0}, {0.085, 
              Rational[1300, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.085, 0}, {0.09, 
              Rational[1360, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.09, 0}, {0.095, 
              Rational[1080, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.095, 0}, {0.1, 
              Rational[820, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.1, 0}, {0.105, 
              Rational[480, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.105, 0}, {0.11, 
              Rational[520, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.11, 0}, {0.115, 
              Rational[40, 131]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.115, 0}, {0.12, 
              Rational[360, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.12, 0}, {0.125, 
              Rational[220, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.125, 0}, {0.13, 
              Rational[200, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.13, 0}, {0.135, 
              Rational[100, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.135, 0}, {0.14, 
              Rational[100, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.14, 0}, {0.145, 
              Rational[20, 131]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.145, 0}, {0.15, 
              Rational[80, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.15, 0}, {0.155, 
              Rational[40, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.155, 0}, {0.16, 
              Rational[20, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.16, 0}, {0.165, 
              Rational[20, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.165, 0}, {0.17, 
              Rational[40, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.17, 0}, {0.175, 
              Rational[40, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.175, 0}, {0.18, 
              Rational[20, 917]}, "RoundingRadius" -> 0]}}, {{
            Directive[
             GrayLevel[0.5], 
             Opacity[0.25]], 
            Rectangle[{0.18, 0}, {0.185, 
              Rational[20, 917]}, "RoundingRadius" -> 0]}}}}, {}, {}}}, 
      GraphicsComplex[CompressedData["
1:eJztlnk0lWvfx02RcStRW+oUHbRlKEMi+3erUKQQckqJSkJk6oiK1MFJJSky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       "], {{{}, {
          EdgeForm[], 
          Directive[{
            Opacity[0.2], 
            Hue[0.67, 0.6, 0.6]}], 
          GraphicsGroup[{
            Polygon[CompressedData["
1:eJwt0VdPEwAUBeAiKBt5ZpdNwt4jYYMoGrDsmVD2agl7I1NF/M98TfrwnfN6
b04wHA1FPgQCgQRu4h0UP/QBVdzTxTLZ/Oc7USr5RSdLfOaNUSJUcEcHi2Tx
jX3KuaWdBTL5yh5l8XvamCeDEXYp5ZpW5kjnH1/YoYQrWpgljVeG2aaYS5qZ
IZW/DLEV+58LmpgmhT8MskkR5zQyRTK/GWCDQs5oYJJPvNDPOgWcUs8EH3mm
jzXyOaGOEEk80csqeRxTy08SeaSHMLkcUcM4sX0f6GaFHA6pZox3ZpAmZw==

             "]]}]}, {}, {
          EdgeForm[], 
          Directive[{
            Opacity[0.2], 
            Hue[0.9060679774997897, 0.6, 0.6]}], 
          GraphicsGroup[{
            Polygon[{{192, 172, 196, 178, 188, 160, 197, 182}}]}]}, {}, {
          EdgeForm[], 
          Directive[{
            Opacity[0.2], 
            Hue[0.1421359549995791, 0.6, 0.6]}], 
          GraphicsGroup[{
            
            Polygon[{{272, 288, 223, 287, 252, 271, 233, 279, 243, 262, 222, 
             286, 251, 270, 232, 278, 242, 261, 221, 285, 250, 269, 231, 277, 
             241, 260, 220, 284, 249, 268, 230, 276, 240, 259, 219, 283, 248, 
             267, 229, 275, 239, 258, 218, 282, 247, 266, 228, 274, 238, 257, 
             217, 281, 246, 265, 227, 273, 237, 256, 216, 280, 245, 264, 
             226}}]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, \
{}, {
          Hue[0.67, 0.6, 0.6], 
          
          Line[{1, 79, 44, 114, 26, 97, 62, 130, 2, 80, 45, 115, 27, 98, 63, 
           131, 3, 81, 46, 116, 28, 99, 64, 132, 4, 82, 47, 117, 29, 100, 65, 
           133, 5, 83, 48, 118, 30, 101, 66, 134, 6, 84, 49, 119, 31, 102, 67,
            135, 7, 85, 50, 120, 32, 103, 68, 136, 8, 86, 51, 121, 33, 104, 
           69, 137, 9, 87, 52, 122, 34, 105, 70, 138, 10, 88, 53, 123, 35, 
           106, 71, 139, 11, 89, 54, 124, 36, 107, 72, 12, 90, 55, 125, 37, 
           108, 73, 13, 91, 56, 126, 38, 109, 74, 14, 92, 57, 127, 39, 110, 
           75, 140, 15, 93, 58, 128, 40, 111, 76, 141, 16, 94, 59, 129, 41, 
           112, 77, 142, 17, 95, 60, 42, 18, 19, 20, 21, 22, 23, 24, 96, 61, 
           43, 113, 78, 143, 25}]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          
          Line[{144, 185, 175, 169, 145, 146, 147, 148, 149, 150, 151, 152, 
           153, 154, 155, 156, 157, 158, 186, 176, 170, 191, 181, 159, 187, 
           177, 195, 171, 192, 182, 197, 160, 188, 178, 196, 172, 193, 183, 
           161, 189, 179, 173, 162, 163, 164, 165, 166, 167, 190, 180, 174, 
           194, 184, 198, 168}]}, {
          Hue[0.1421359549995791, 0.6, 0.6], 
          Line[CompressedData["
1:eJwVzdk2ggEYhtFfGZJMZSgZllty5tQF6DIrU2QOSaaEEMoYu4Nn7bW+9+Bb
XMksrfYEQbCsrH5VV0U55bWmdW1oU1sqaFs7KmpXe9rXgTq614UGPHjjof70
oDG3KiN8Z5JHDPiIcV5ykC2meNyd2WCcV4yyzRmWGOITE7zmED+Y5gnDfOYE
bxjjJ2d5yl6+cJK3HOYX53jGPjY5xRpH+M15ltnPV07zjqP84QLP+Q/yEjao

           "]]}}}], {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          Thickness[Large], 
          GrayLevel[0]], 
         Line[CompressedData["
1:eJwVklc81f8fxzkkm1KKVDJKJ1tK4ry/JSPrFxktil+kiF9GkZKMSFmRkb2O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          "]]}}}}, {
     Frame -> {True, False, False, False}, 
      FrameTicksStyle -> {
       FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, 
      PlotRange -> {{-0.3, 0.15}, {0, 30}}, LabelStyle -> 
      Directive[12, FontFamily -> "Helvetica"], Epilog -> {
        Text[
         Style[
         "\!\(\*SubscriptBox[\(m\), \(0\)]\)=-0.1", 12, FontFamily -> 
          "Helvetica"], 
         Scaled[{
           Rational[7, 8], 
           Rational[3, 4]}]], 
        Text[
         Style["A", 14, Bold, FontFamily -> "Helvetica"], 
         Scaled[{0.05, 0.95}]]}, AspectRatio -> GoldenRatio^(-1), Axes -> 
      True, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
      PlotRange -> {{-0.3, 0.15}, {0, All}}, PlotRangeClipping -> True, 
      PlotRangePadding -> {
        Scaled[0.02], Automatic}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          Thickness[Large], 
          GrayLevel[0]]}, {
         Style["first-step", 12, FontFamily -> "Helvetica"]}, LegendLayout -> 
        "Column"]], 
      Scaled[{
        Rational[1, 8], 0.625}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{3.771525510234125*^9, 3.7715256009094276`*^9, 
  3.771525757082961*^9, 3.771525945477487*^9, 3.771526012114366*^9, 
  3.771526049084855*^9, 3.7715261034426117`*^9, 3.771526184585018*^9, 
  3.771526357338108*^9, 3.771526389498026*^9, 3.771526423875675*^9, 
  3.7822590224446793`*^9, 3.784902466688486*^9, 3.7849026164659157`*^9, 
  3.78490276924478*^9, 3.784902805353888*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exact", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
     RowBox[{"prescuem", "[", 
      RowBox[{"m1", ",", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"critical", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"0", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     SqrtBox[
      RowBox[{"2", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}]], 
     RowBox[{"HeavisideTheta", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m1", "+", "pr0"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"pr0", "-", "m1"}], ")"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"subcritical", "=", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], 
     RowBox[{"Abs", "[", "m1", "]"}]], 
    RowBox[{"HeavisideTheta", "[", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "m1"}], "-", "pr0"}], ")"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"supercritical", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
     FractionBox[
      RowBox[{" ", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], 
      RowBox[{"Abs", "[", "m1", "]"}]], 
     RowBox[{"HeavisideTheta", "[", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "pr0"}], ")"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"allexact", "=", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{"exact", ",", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "mwt", ",", "0.1"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], ",", "\[IndentingNewLine]", 
    FractionBox[
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"pest", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}]}], 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fm", "[", 
         RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"pest", "[", 
         RowBox[{"m1", "-", "mwt"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], 
   "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory", "=", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{"%", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Filling", "\[Rule]", "Bottom"}], ","}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{"Gray", ",", "Thick", ",", "Dashed"}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Gray", ",", "Thick"}], "]"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    FractionBox["subcritical", "allexact"], ",", 
    FractionBox["critical", "allexact"], ",", 
    FractionBox["supercritical", "allexact"]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory", "=", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{"%", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exactplot", "=", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"exact", "/", "allexact"}], ",", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", "Black"}], "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "\[IndentingNewLine]", 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "datadir", "<>", 
     "\"\<int_dfe_poisson_N10000_n4_U0.00200_Es0.01_mmax0.50_mwt-0.20_\
mutmax10_nreps100000.csv\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Select", "[", 
    RowBox[{"dat", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
   "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Histogram", "[", 
     RowBox[{"%", ",", "50", ",", "\"\<PDF\>\"", ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], ",", 
      RowBox[{"ChartStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Gray", ",", 
         RowBox[{"Opacity", "[", "0.25", "]"}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fig7b", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
    "oldtheory", ",", "data", ",", "theory", ",", "exactplot", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontColor", "\[Rule]", "White"}], ",", "Automatic", ",", 
        "Automatic", ",", "Automatic"}], "}"}]}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<\!\(\*SubscriptBox[\(m\), \(0\)]\)=\>\"", "<>", 
             RowBox[{"ToString", "[", "mwt", "]"}]}], ",", "12", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"7", "/", "8"}], ",", 
             RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<B\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.771259863315041*^9, 3.771259875817935*^9}, {
   3.77125993618959*^9, 3.7712599967791033`*^9}, {3.7712600806108303`*^9, 
   3.771260101998229*^9}, {3.7712601420091887`*^9, 3.771260164023238*^9}, {
   3.7712604866075153`*^9, 3.7712604916540623`*^9}, {3.771260596998*^9, 
   3.7712606779327497`*^9}, {3.771260742113587*^9, 3.77126078863237*^9}, {
   3.7712608356681213`*^9, 3.771260853796445*^9}, 3.77126088730492*^9, {
   3.771260950376927*^9, 3.771260951994858*^9}, {3.771260988204628*^9, 
   3.771261046264202*^9}, {3.771261095976034*^9, 3.771261100349186*^9}, {
   3.771261221602476*^9, 3.771261223165237*^9}, {3.7712612596219587`*^9, 
   3.771261376814014*^9}, {3.7712614254017878`*^9, 3.771261458422593*^9}, {
   3.771261523796259*^9, 3.771261558803645*^9}, {3.771525291980131*^9, 
   3.771525296404852*^9}, 3.771525340514213*^9, 3.782258993320249*^9, {
   3.784902452138974*^9, 3.784902456722024*^9}, 3.7849027686609297`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
     LineBox[CompressedData["
1:eJwVkWk4FGofhzUY6xgz06Yih3Kkkkgcpf8jS8o6ZElUSkhF9qVClBwtssTJ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      "]]}, 
    {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxFznc0FX4fB3AhW3hCrp0ilBE/4xF9vombjIzQbRjpl0pGZkiSCmkgsve4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      "]]}}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.34299999999999997`]], {}, 
    {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
     EdgeForm[Opacity[0.34299999999999997`]], 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.195, 0}, 
       NCache[{-0.19, Rational[200, 709]}, {-0.19, 0.2820874471086037}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.19, 0}, 
       NCache[{-0.185, Rational[200, 709]}, {-0.185, 0.2820874471086037}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.17, 0}, 
       NCache[{-0.165, Rational[200, 709]}, {-0.165, 0.2820874471086037}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.155, 0}, 
       NCache[{-0.15, Rational[600, 709]}, {-0.15, 0.846262341325811}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.15, 0}, 
       NCache[{-0.145, Rational[200, 709]}, {-0.145, 0.2820874471086037}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.145, 0}, 
       NCache[{-0.14, Rational[400, 709]}, {-0.14, 0.5641748942172073}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.14, 0}, 
       NCache[{-0.135, Rational[600, 709]}, {-0.135, 0.846262341325811}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.135, 0}, 
       NCache[{-0.13, Rational[600, 709]}, {-0.13, 0.846262341325811}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.13, 0}, 
       NCache[{-0.125, Rational[1000, 709]}, {-0.125, 1.4104372355430184`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.125, 0}, 
       NCache[{-0.12, Rational[600, 709]}, {-0.12, 0.846262341325811}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.12, 0}, 
       NCache[{-0.115, Rational[200, 709]}, {-0.115, 0.2820874471086037}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.115, 0}, 
       NCache[{-0.11, Rational[400, 709]}, {-0.11, 0.5641748942172073}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.11, 0}, 
       NCache[{-0.105, Rational[600, 709]}, {-0.105, 0.846262341325811}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.105, 0}, 
       NCache[{-0.1, Rational[1600, 709]}, {-0.1, 2.2566995768688294`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.1, 0}, 
       NCache[{-0.095, Rational[1000, 709]}, {-0.095, 1.4104372355430184`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.095, 0}, 
       NCache[{-0.09, Rational[600, 709]}, {-0.09, 0.846262341325811}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.09, 0}, 
       NCache[{-0.085, Rational[1800, 709]}, {-0.085, 2.538787023977433}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.085, 0}, 
       NCache[{-0.08, Rational[1200, 709]}, {-0.08, 1.692524682651622}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.08, 0}, 
       NCache[{-0.075, Rational[1800, 709]}, {-0.075, 2.538787023977433}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.075, 0}, 
       NCache[{-0.07, Rational[2200, 709]}, {-0.07, 3.1029619181946404`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.07, 0}, 
       NCache[{-0.065, Rational[1800, 709]}, {-0.065, 2.538787023977433}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.065, 0}, 
       NCache[{-0.06, Rational[4000, 709]}, {-0.06, 5.6417489421720735`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.06, 0}, 
       NCache[{-0.055, Rational[3200, 709]}, {-0.055, 4.513399153737659}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.055, 0}, 
       NCache[{-0.05, Rational[2600, 709]}, {-0.05, 3.6671368124118477`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.05, 0}, 
       NCache[{-0.045, Rational[3800, 709]}, {-0.045, 5.359661495063469}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.045, 0}, 
       NCache[{-0.04, Rational[2200, 709]}, {-0.04, 3.1029619181946404`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.04, 0}, 
       NCache[{-0.035, Rational[7200, 709]}, {-0.035, 10.155148095909732`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.035, 0}, 
       NCache[{-0.03, Rational[4000, 709]}, {-0.03, 5.6417489421720735`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.03, 0}, 
       NCache[{-0.025, Rational[5200, 709]}, {-0.025, 7.3342736248236955`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.025, 0}, 
       NCache[{-0.02, Rational[7400, 709]}, {-0.02, 10.437235543018335`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.02, 0}, 
       NCache[{-0.015, Rational[6200, 709]}, {-0.015, 8.744710860366714}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.015, 0}, 
       NCache[{-0.01, Rational[9400, 709]}, {-0.01, 13.258110014104373`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.01, 0}, 
       NCache[{-0.005, Rational[14600, 709]}, {-0.005, 20.59238363892807}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.005, 0}, 
       NCache[{0., Rational[13600, 709]}, {0., 19.181946403385048`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0., 0}, 
       NCache[{0.005, Rational[6000, 709]}, {0.005, 8.46262341325811}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.005, 0}, 
       NCache[{0.01, Rational[6200, 709]}, {0.01, 8.744710860366714}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.01, 0}, 
       NCache[{0.015, Rational[7200, 709]}, {0.015, 10.155148095909732`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.015, 0}, 
       NCache[{0.02, Rational[4600, 709]}, {0.02, 6.488011283497884}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.02, 0}, 
       NCache[{0.025, Rational[2600, 709]}, {0.025, 3.6671368124118477`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.025, 0}, 
       NCache[{0.03, Rational[4200, 709]}, {0.03, 5.923836389280677}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.03, 0}, 
       NCache[{0.035, Rational[1800, 709]}, {0.035, 2.538787023977433}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.035, 0}, 
       NCache[{0.04, Rational[2000, 709]}, {0.04, 2.8208744710860367`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.04, 0}, 
       NCache[{0.045, Rational[1400, 709]}, {0.045, 1.9746121297602257`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.045, 0}, 
       NCache[{0.05, Rational[600, 709]}, {0.05, 0.846262341325811}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.05, 0}, 
       NCache[{0.055, Rational[1600, 709]}, {0.055, 2.2566995768688294`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.055, 0}, 
       NCache[{0.06, Rational[200, 709]}, {0.06, 0.2820874471086037}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.06, 0}, 
       NCache[{0.065, Rational[600, 709]}, {0.065, 0.846262341325811}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.065, 0}, 
       NCache[{0.07, Rational[400, 709]}, {0.07, 0.5641748942172073}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.07, 0}, 
       NCache[{0.075, Rational[400, 709]}, {0.075, 0.5641748942172073}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.08, 0}, 
       NCache[{0.085, Rational[400, 709]}, {0.085, 0.5641748942172073}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.09, 0}, 
       NCache[{0.095, Rational[400, 709]}, {0.095, 0.5641748942172073}],
       RoundingRadius->0]}}, {}, {}}, GraphicsComplexBox[CompressedData["
1:eJztl3k0lH/7x0VJ9iUKkSxlKVmiUrluWZKlIkslFZWdIm18k1KSErJmXwcT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    "], {{{}, 
      {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwt0dVKgwEAhuHfbid4Zs8W3OwGu0WdswPU2cFmd9y6j7CD5/su4A0nUvFk
ZhAEGaTSX26W/C1tvDHCAWX8ssgNrbwyzD4hfljgmhZeGGKPUua5oplBdimh
iQF2KKaRfrYpYo5LGuhji0JmuaCeXjYpYIZzwjzTwwb5THNGHU90s04eU5xS
yyNdxMnlm0lOqOGBTtbI4YsJElRzTwcxsvlknGOquCPKKll8MMYRlekmEVb4
7/TOKIdUkKSdZf4A2VQe+g==
         "]]]}, {}, 
      {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{178, 158, 182, 164, 174, 146, 183, 168}}]]}, {}, 
      {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{258, 274, 209, 273, 238, 257, 219, 265, 229, 248, 208, 
         272, 237, 256, 218, 264, 228, 247, 207, 271, 236, 255, 217, 263, 227,
          246, 206, 270, 235, 254, 216, 262, 226, 245, 205, 269, 234, 253, 
         215, 261, 225, 244, 204, 268, 233, 252, 214, 260, 224, 243, 203, 267,
          232, 251, 213, 259, 223, 242, 202, 266, 231, 250, 
         212}}]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
      {Hue[0.67, 0.6, 0.6], 
       LineBox[{1, 77, 44, 110, 26, 95, 62, 121, 2, 78, 45, 111, 27, 96, 63, 
        122, 3, 79, 46, 112, 28, 97, 64, 123, 4, 80, 47, 113, 29, 98, 65, 124,
         5, 81, 48, 114, 30, 99, 66, 125, 6, 82, 49, 115, 31, 100, 67, 7, 83, 
        50, 116, 32, 101, 68, 8, 84, 51, 117, 33, 102, 69, 9, 85, 52, 34, 103,
         70, 10, 86, 53, 35, 104, 71, 11, 87, 54, 36, 12, 88, 55, 37, 13, 89, 
        56, 38, 105, 72, 14, 90, 57, 118, 39, 106, 73, 126, 15, 91, 58, 119, 
        40, 107, 74, 127, 16, 92, 59, 120, 41, 108, 75, 128, 17, 93, 60, 42, 
        18, 19, 20, 21, 22, 23, 24, 94, 61, 43, 109, 76, 129, 25}]}, 
      {Hue[0.9060679774997897, 0.6, 0.6], 
       LineBox[{130, 171, 161, 155, 131, 132, 133, 134, 135, 136, 137, 138, 
        139, 140, 141, 142, 143, 144, 172, 162, 156, 177, 167, 145, 173, 163, 
        181, 157, 178, 168, 183, 146, 174, 164, 182, 158, 179, 169, 147, 175, 
        165, 159, 148, 149, 150, 151, 152, 153, 176, 166, 160, 180, 170, 184, 
        154}]}, 
      {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzdk2ggEYhtFfGZJMl9AtdebUBXB9JTMNpsgckkwJIZQxdgd7Petd38EX
n5xOTPUEQTBBkidOKZJihjSzzDHPAossscwKq2TIkuOZM3b55IY8L5QJebqn
X9wStde0yTlhe1+/qTFkr+srFXrtA/3hjpi9oW9c0Gcf6i91hu1NfadKv32k
He4Zsbe0xSUD9rH+8cCoXdA2V0Tskgb6KGO6rR9cM2ifdM/a0HHd0X/KBz+8

        "]]}}}], {{}, {}, 
    {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwVkXk41HsfQG3JTsRtImrE1WRXkejzc20jS4hoUUi2VESIQrKXrFnDUMYS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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"\\!\\(\\*SubscriptBox[\\(m\\), \\(0\\)]\\)=-0.2\"", 12, FontFamily -> 
       "Helvetica", StripOnInput -> False], TraditionalForm], 
     NCache[
      Scaled[{
        Rational[7, 8], 
        Rational[3, 4]}], 
      Scaled[{0.875, 0.75}]]], 
    InsetBox[
     FormBox[
      StyleBox[
      "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
      TraditionalForm], 
     Scaled[{0.05, 0.95}]]},
  Frame->{True, False, False, False},
  FrameTicksStyle->{
   FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{-0.3, 0.15}, {0, 30}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{3.771261578014979*^9, 3.771525335138279*^9, 
  3.782259043890229*^9, 3.784902543437858*^9, 3.784902635221743*^9, 
  3.784902776148741*^9, 3.784902971319694*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.3"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exact", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
     RowBox[{"prescuem", "[", 
      RowBox[{"m1", ",", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"critical", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"0", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     SqrtBox[
      RowBox[{"2", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}]], 
     RowBox[{"HeavisideTheta", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m1", "+", "pr0"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"pr0", "-", "m1"}], ")"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"subcritical", "=", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], 
     RowBox[{"Abs", "[", "m1", "]"}]], 
    RowBox[{"HeavisideTheta", "[", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "m1"}], "-", "pr0"}], ")"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"supercritical", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
     FractionBox[
      RowBox[{" ", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], 
      RowBox[{"Abs", "[", "m1", "]"}]], 
     RowBox[{"HeavisideTheta", "[", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "pr0"}], ")"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"allexact", "=", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{"exact", ",", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "mwt", ",", "0.1"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], ",", "\[IndentingNewLine]", 
    FractionBox[
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"pest", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}]}], 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fm", "[", 
         RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"pest", "[", 
         RowBox[{"m1", "-", "mwt"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], 
   "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory", "=", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{"%", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Filling", "\[Rule]", "Bottom"}], ","}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{"Gray", ",", "Thick", ",", "Dashed"}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Gray", ",", "Thick"}], "]"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    FractionBox["subcritical", "allexact"], ",", 
    FractionBox["critical", "allexact"], ",", 
    FractionBox["supercritical", "allexact"]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory", "=", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{"%", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exactplot", "=", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"exact", "/", "allexact"}], ",", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", "Black"}], "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "\[IndentingNewLine]", 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "datadir", "<>", 
     "\"\<int_dfe_poisson_N10000_n4_U0.00200_Es0.01_mmax0.50_mwt-0.30_\
mutmax10_nreps1000000.csv\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Select", "[", 
    RowBox[{"dat", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
   "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Histogram", "[", 
     RowBox[{"%", ",", "50", ",", "\"\<PDF\>\"", ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], ",", 
      RowBox[{"ChartStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Gray", ",", 
         RowBox[{"Opacity", "[", "0.25", "]"}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fig7c", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
    "oldtheory", ",", "data", ",", "theory", ",", "exactplot", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", "\"\<Growth rate\>\"", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<\!\(\*SubscriptBox[\(m\), \(0\)]\)=\>\"", "<>", 
             RowBox[{"ToString", "[", "mwt", "]"}]}], ",", "12", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"7", "/", "8"}], ",", 
             RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<C\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.771259863315041*^9, 3.771259875817935*^9}, {
   3.77125993618959*^9, 3.7712599967791033`*^9}, {3.7712600806108303`*^9, 
   3.771260101998229*^9}, {3.7712601420091887`*^9, 3.771260164023238*^9}, {
   3.7712604866075153`*^9, 3.7712604916540623`*^9}, {3.771260596998*^9, 
   3.7712606779327497`*^9}, {3.771260742113587*^9, 3.77126078863237*^9}, {
   3.7712608356681213`*^9, 3.771260853796445*^9}, 3.77126088730492*^9, {
   3.771260950376927*^9, 3.771260951994858*^9}, {3.771260988204628*^9, 
   3.771261046264202*^9}, {3.771261095976034*^9, 3.771261100349186*^9}, {
   3.771261221602476*^9, 3.771261223165237*^9}, {3.7712612596219587`*^9, 
   3.771261376814014*^9}, {3.7712614254017878`*^9, 3.771261458422593*^9}, {
   3.771261523796259*^9, 3.771261558803645*^9}, {3.771261624373424*^9, 
   3.771261652523746*^9}, {3.77152531614041*^9, 3.771525316572042*^9}, 
   3.771525420747283*^9, 3.7822589889909277`*^9, {3.784902461045517*^9, 
   3.784902466240666*^9}, {3.7849026819018583`*^9, 3.784902685082704*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
     LineBox[CompressedData["
1:eJwVkWk8lHsfh4VkH1NRaDukRUgcS+L+3U4SJoVoE0U4GsuxhSRC1NGpSSPC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      "]]}, 
    {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJwVjnc81fsfgI2yZ0bWUVEZIXGVK77vDyIjXWTVlXVLoZQRRXZl5uimZEY4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      "]]}}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.35]], {}, 
    {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
     EdgeForm[Opacity[0.35]], 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.23, 0}, 
       NCache[{-0.225, Rational[200, 187]}, {-0.225, 1.0695187165775402`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.225, 0}, 
       NCache[{-0.22, Rational[200, 187]}, {-0.22, 1.0695187165775402`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.22, 0}, 
       NCache[{-0.215, Rational[200, 187]}, {-0.215, 1.0695187165775402`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.215, 0}, 
       NCache[{-0.21, Rational[400, 187]}, {-0.21, 2.1390374331550803`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.205, 0}, 
       NCache[{-0.2, Rational[200, 187]}, {-0.2, 1.0695187165775402`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.19, 0}, 
       NCache[{-0.185, Rational[200, 187]}, {-0.185, 1.0695187165775402`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.18, 0}, 
       NCache[{-0.175, Rational[200, 187]}, {-0.175, 1.0695187165775402`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.175, 0}, 
       NCache[{-0.17, Rational[200, 187]}, {-0.17, 1.0695187165775402`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.17, 0}, 
       NCache[{-0.165, Rational[800, 187]}, {-0.165, 4.278074866310161}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.165, 0}, 
       NCache[{-0.16, Rational[800, 187]}, {-0.16, 4.278074866310161}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.16, 0}, 
       NCache[{-0.155, Rational[400, 187]}, {-0.155, 2.1390374331550803`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.155, 0}, 
       NCache[{-0.15, Rational[600, 187]}, {-0.15, 3.2085561497326203`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.15, 0}, 
       NCache[{-0.145, Rational[600, 187]}, {-0.145, 3.2085561497326203`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.145, 0}, 
       NCache[{-0.14, Rational[600, 187]}, {-0.14, 3.2085561497326203`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.14, 0}, 
       NCache[{-0.135, Rational[800, 187]}, {-0.135, 4.278074866310161}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.135, 0}, 
       NCache[{-0.13, Rational[600, 187]}, {-0.13, 3.2085561497326203`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.13, 0}, 
       NCache[{-0.125, Rational[600, 187]}, {-0.125, 3.2085561497326203`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.125, 0}, 
       NCache[{-0.12, Rational[1000, 187]}, {-0.12, 5.347593582887701}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.12, 0}, 
       NCache[{-0.115, Rational[400, 187]}, {-0.115, 2.1390374331550803`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.115, 0}, 
       NCache[{-0.11, Rational[800, 187]}, {-0.11, 4.278074866310161}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.11, 0}, 
       NCache[{-0.105, Rational[800, 187]}, {-0.105, 4.278074866310161}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.105, 0}, 
       NCache[{-0.1, Rational[800, 187]}, {-0.1, 4.278074866310161}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.1, 0}, 
       NCache[{-0.095, Rational[400, 187]}, {-0.095, 2.1390374331550803`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.095, 0}, 
       NCache[{-0.09, Rational[1200, 187]}, {-0.09, 6.4171122994652405`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.09, 0}, 
       NCache[{-0.085, Rational[1400, 187]}, {-0.085, 7.4866310160427805`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.085, 0}, 
       NCache[{-0.08, Rational[1600, 187]}, {-0.08, 8.556149732620321}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.08, 0}, 
       NCache[{-0.075, Rational[1400, 187]}, {-0.075, 7.4866310160427805`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.075, 0}, 
       NCache[{-0.07, Rational[1200, 187]}, {-0.07, 6.4171122994652405`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.07, 0}, 
       NCache[{-0.065, Rational[400, 187]}, {-0.065, 2.1390374331550803`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.065, 0}, 
       NCache[{-0.06, Rational[200, 187]}, {-0.06, 1.0695187165775402`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.06, 0}, 
       NCache[{-0.055, Rational[800, 187]}, {-0.055, 4.278074866310161}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.055, 0}, 
       NCache[{-0.05, Rational[1200, 187]}, {-0.05, 6.4171122994652405`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.05, 0}, 
       NCache[{-0.045, Rational[800, 187]}, {-0.045, 4.278074866310161}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.045, 0}, 
       NCache[{-0.04, Rational[400, 187]}, {-0.04, 2.1390374331550803`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.04, 0}, 
       NCache[{-0.035, Rational[1200, 187]}, {-0.035, 6.4171122994652405`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.035, 0}, 
       NCache[{-0.03, Rational[1000, 187]}, {-0.03, 5.347593582887701}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.03, 0}, 
       NCache[{-0.025, Rational[1400, 187]}, {-0.025, 7.4866310160427805`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.025, 0}, 
       NCache[{-0.02, Rational[200, 17]}, {-0.02, 11.764705882352942`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.02, 0}, 
       NCache[{-0.015, Rational[800, 187]}, {-0.015, 4.278074866310161}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.015, 0}, 
       NCache[{-0.01, Rational[1600, 187]}, {-0.01, 8.556149732620321}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.01, 0}, 
       NCache[{-0.005, Rational[1600, 187]}, {-0.005, 8.556149732620321}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.005, 0}, 
       NCache[{0., Rational[1800, 187]}, {0., 9.62566844919786}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0., 0}, 
       NCache[{0.005, Rational[1000, 187]}, {0.005, 5.347593582887701}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.005, 0}, 
       NCache[{0.01, Rational[400, 187]}, {0.01, 2.1390374331550803`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.01, 0}, 
       NCache[{0.015, Rational[200, 187]}, {0.015, 1.0695187165775402`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.015, 0}, 
       NCache[{0.02, Rational[600, 187]}, {0.02, 3.2085561497326203`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.02, 0}, 
       NCache[{0.025, Rational[600, 187]}, {0.025, 3.2085561497326203`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.025, 0}, 
       NCache[{0.03, Rational[200, 187]}, {0.03, 1.0695187165775402`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.035, 0}, 
       NCache[{0.04, Rational[200, 187]}, {0.04, 1.0695187165775402`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.06, 0}, 
       NCache[{0.065, Rational[200, 187]}, {0.065, 1.0695187165775402`}],
       RoundingRadius->0]}}, {}, {}}, GraphicsComplexBox[CompressedData["
1:eJztlnk01P0ex5lshexjq6cikiTxVB7k85VMalLWiFTkkQo9thJF5QktkqUk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    "], {{{}, 
      {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwt0VdLggEYBeCvadO6zpYtg8q0YQXtTaWWLaFti5a2+/s9ghfPeTl3B95o
oZQrVgdBUMVj5TaL7Uof5pM58rTzxxYPxPhgllPa+GWTe4Z4Z4YTwmxwxyAl
UhzTyg/r3DJAkWmOaGGNAv1McVjeyyo39DFJjiYaiTLBAQ30kmSfECtc00OC
LPUsc0U3b4yToY4lLunilThpalnkgk5eGGOPGr5Z4JwIz4yyS/kPX8xzRgdP
jLDDPz9MGyQ=
         "]]]}, {}, 
      {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{170, 150, 174, 156, 166, 138, 175, 160}}]]}, {}, 
      {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{250, 266, 201, 265, 230, 249, 211, 257, 221, 240, 200, 
         264, 229, 248, 210, 256, 220, 239, 199, 263, 228, 247, 209, 255, 219,
          238, 198, 262, 227, 246, 208, 254, 218, 237, 197, 261, 226, 245, 
         207, 253, 217, 236, 196, 260, 225, 244, 206, 252, 216, 235, 195, 259,
          224, 243, 205, 251, 215, 234, 194, 258, 223, 242, 
         204}}]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
      {Hue[0.67, 0.6, 0.6], 
       LineBox[{1, 74, 43, 105, 26, 91, 60, 115, 2, 75, 44, 106, 27, 92, 61, 
        116, 3, 76, 45, 107, 28, 93, 62, 4, 77, 46, 108, 29, 94, 63, 5, 78, 
        47, 109, 30, 95, 64, 6, 79, 48, 31, 96, 65, 7, 80, 49, 32, 8, 81, 50, 
        33, 9, 10, 82, 51, 34, 97, 66, 11, 83, 52, 35, 98, 67, 12, 84, 53, 
        110, 36, 99, 68, 117, 13, 85, 54, 111, 37, 100, 69, 14, 86, 55, 112, 
        38, 101, 70, 118, 15, 87, 56, 113, 39, 102, 71, 119, 16, 88, 57, 114, 
        40, 103, 72, 120, 17, 89, 58, 41, 18, 19, 20, 21, 22, 23, 24, 90, 59, 
        42, 104, 73, 121, 25}]}, 
      {Hue[0.9060679774997897, 0.6, 0.6], 
       LineBox[{122, 163, 153, 147, 123, 124, 125, 126, 127, 128, 129, 130, 
        131, 132, 133, 134, 135, 136, 164, 154, 148, 169, 159, 137, 165, 155, 
        173, 149, 170, 160, 175, 138, 166, 156, 174, 150, 171, 161, 139, 167, 
        157, 151, 140, 141, 142, 143, 144, 145, 168, 158, 152, 172, 162, 176, 
        146}]}, 
      {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJwVztk2ggEYhtFfGXIZ3ZKzTl0A10YZSmYaTJE5JJkSQihj7A72eta33pMv
Ojw6NNITBEGMMW7ZY41x4iSYYJIppkmSYoY0s8wxzwI19lnnhTKL3HHAFxs0
OSfkiSWtc8g3m7xSIWxf1nuO+GGLNy7ota/oA8f8UuCdKn32VX2kRIdtWlzS
b89ogxP+2KHNFQP2rD5xSuAuygfXRNw5feasO7t39ZMbBt15/QcBbETs
        
        "]]}}}], {{}, {}, 
    {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwVkGk8FGofQG2hYSxhjKUFcaUsUZTwf1psSSGTSirVlazJUtG13nBLIbLv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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"\\!\\(\\*SubscriptBox[\\(m\\), \\(0\\)]\\)=-0.3\"", 12, FontFamily -> 
       "Helvetica", StripOnInput -> False], TraditionalForm], 
     NCache[
      Scaled[{
        Rational[7, 8], 
        Rational[3, 4]}], 
      Scaled[{0.875, 0.75}]]], 
    InsetBox[
     FormBox[
      StyleBox[
      "\"C\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
      TraditionalForm], 
     Scaled[{0.05, 0.95}]]},
  Frame->{True, False, False, False},
  FrameLabel->{
    FormBox["\"Growth rate\"", TraditionalForm]},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{-0.3, 0.15}, {0, 30}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{3.771261671457974*^9, 3.771525424967771*^9, 
  3.782259065323072*^9, 3.784902562034231*^9, 3.784902653834408*^9, 
  3.784902778565583*^9, 3.7849029899873753`*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"ymax", ",", "xmin", ",", "xmax"}], "]"}]], "Input",
 CellChangeTimes->{{3.7715264481677027`*^9, 3.7715264529375877`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GraphicsColumn", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"fig7a", ",", "fig7b", ",", "fig7c"}], "}"}], ",", 
   RowBox[{"Spacings", "\[Rule]", 
    RowBox[{"-", "30"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{"figdir", "<>", "\"\<Figure7.pdf\>\""}], ",", "%"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.784902510656822*^9, 3.784902518005883*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     FormBox[
      TagBox[
       FormBox[
        GraphicsBox[{{{{}, {}, 
            {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
             LineBox[CompressedData["
1:eJwVknk4FGofhpmULVlmVBNOPlpli0jI75Ula5YMHX0lCtmmEsl0UsiSvki0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              "]]}, 
            {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxFxw88FPYfx/FzKpw/l5R2/qw7+nMpx8gy4fNt/uZPo50/KbZMSKpJk/Tn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              "]]}}, 
           {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458],
             EdgeForm[Opacity[0.189]], {}, 
            {RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458], 
             EdgeForm[Opacity[0.189]], 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.19, 0}, 
               NCache[{-0.185, Rational[40, 917]}, {-0.185, 
                0.04362050163576881}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.18, 0}, 
               NCache[{-0.175, Rational[20, 917]}, {-0.175, 
                0.021810250817884406`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.17, 0}, 
               NCache[{-0.165, Rational[40, 917]}, {-0.165, 
                0.04362050163576881}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.165, 0}, 
               NCache[{-0.16, Rational[40, 917]}, {-0.16, 
                0.04362050163576881}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.16, 0}, 
               NCache[{-0.155, Rational[40, 917]}, {-0.155, 
                0.04362050163576881}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.155, 0}, 
               NCache[{-0.15, Rational[60, 917]}, {-0.15, 
                0.06543075245365322}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.15, 0}, 
               NCache[{-0.145, Rational[60, 917]}, {-0.145, 
                0.06543075245365322}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.145, 0}, 
               NCache[{-0.14, Rational[80, 917]}, {-0.14, 
                0.08724100327153762}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.14, 0}, 
               NCache[{-0.135, Rational[60, 917]}, {-0.135, 
                0.06543075245365322}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.135, 0}, 
               NCache[{-0.13, Rational[80, 917]}, {-0.13, 
                0.08724100327153762}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.13, 0}, 
               NCache[{-0.125, Rational[80, 917]}, {-0.125, 
                0.08724100327153762}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.125, 0}, 
               NCache[{-0.12, Rational[20, 131]}, {-0.12, 
                0.15267175572519084`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.12, 0}, 
               NCache[{-0.115, Rational[160, 917]}, {-0.115, 
                0.17448200654307525`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.115, 0}, 
               NCache[{-0.11, Rational[200, 917]}, {-0.11, 
                0.21810250817884405`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.11, 0}, 
               NCache[{-0.105, Rational[260, 917]}, {-0.105, 
                0.2835332606324973}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.105, 0}, 
               NCache[{-0.1, Rational[540, 917]}, {-0.1, 0.5888767720828789}],
               
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.1, 0}, 
               NCache[{-0.095, Rational[600, 917]}, {-0.095, 
                0.6543075245365322}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.095, 0}, 
               NCache[{-0.09, Rational[620, 917]}, {-0.09, 
                0.6761177753544165}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.09, 0}, 
               NCache[{-0.085, Rational[520, 917]}, {-0.085, 
                0.5670665212649946}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.085, 0}, 
               NCache[{-0.08, Rational[720, 917]}, {-0.08, 
                0.7851690294438386}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.08, 0}, 
               NCache[{-0.075, Rational[880, 917]}, {-0.075, 
                0.9596510359869138}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.075, 0}, 
               NCache[{-0.07, Rational[1200, 917]}, {-0.07, 
                1.3086150490730644`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.07, 0}, 
               NCache[{-0.065, Rational[1420, 917]}, {-0.065, 
                1.5485278080697928`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.065, 0}, 
               NCache[{-0.06, Rational[200, 131]}, {-0.06, 
                1.5267175572519085`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.06, 0}, 
               NCache[{-0.055, Rational[1580, 917]}, {-0.055, 
                1.723009814612868}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.055, 0}, 
               NCache[{-0.05, Rational[2220, 917]}, {-0.05, 
                2.420937840785169}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.05, 0}, 
               NCache[{-0.045, Rational[2300, 917]}, {-0.045, 
                2.5081788440567068`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.045, 0}, 
               NCache[{-0.04, Rational[3420, 917]}, {-0.04, 
                3.7295528898582333`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.04, 0}, 
               NCache[{-0.035, Rational[3280, 917]}, {-0.035, 
                3.5768811341330427`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.035, 0}, 
               NCache[{-0.03, Rational[4460, 917]}, {-0.03, 
                4.863685932388223}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.03, 0}, 
               NCache[{-0.025, Rational[5440, 917]}, {-0.025, 
                5.932388222464558}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.025, 0}, 
               NCache[{-0.02, Rational[6280, 917]}, {-0.02, 
                6.848418756815703}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.02, 0}, 
               NCache[{-0.015, Rational[6620, 917]}, {-0.015, 
                7.219193020719739}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.015, 0}, 
               NCache[{-0.01, Rational[9420, 917]}, {-0.01, 
                10.272628135223554`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.01, 0}, 
               NCache[{-0.005, Rational[11380, 917]}, {-0.005, 
                12.410032715376227`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{-0.005, 0}, 
               NCache[{0., Rational[15420, 917]}, {0., 16.815703380588875`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0., 0}, 
               NCache[{0.005, Rational[9780, 917]}, {0.005, 
                10.665212649945474`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.005, 0}, 
               NCache[{0.01, Rational[10240, 917]}, {0.01, 
                11.166848418756816`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.01, 0}, 
               NCache[{0.015, Rational[9360, 917]}, {0.015, 
                10.207197382769902`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.015, 0}, 
               NCache[{0.02, Rational[9200, 917]}, {0.02, 
                10.032715376226827`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.02, 0}, 
               NCache[{0.025, Rational[1300, 131]}, {0.025, 
                9.923664122137405}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.025, 0}, 
               NCache[{0.03, Rational[8140, 917]}, {0.03, 8.876772082878952}],
               
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.03, 0}, 
               NCache[{0.035, Rational[6600, 917]}, {0.035, 
                7.1973827699018535`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.035, 0}, 
               NCache[{0.04, Rational[6040, 917]}, {0.04, 6.586695747001091}],
               
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.04, 0}, 
               NCache[{0.045, Rational[5280, 917]}, {0.045, 
                5.757906215921483}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.045, 0}, 
               NCache[{0.05, Rational[4660, 917]}, {0.05, 5.081788440567067}],
               
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.05, 0}, 
               NCache[{0.055, Rational[580, 131]}, {0.055, 4.427480916030534}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.055, 0}, 
               NCache[{0.06, Rational[3800, 917]}, {0.06, 4.143947655398037}],
               
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.06, 0}, 
               NCache[{0.065, Rational[380, 131]}, {0.065, 2.900763358778626}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.065, 0}, 
               NCache[{0.07, Rational[2700, 917]}, {0.07, 
                2.9443838604143946`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.07, 0}, 
               NCache[{0.075, Rational[2080, 917]}, {0.075, 
                2.2682660850599783`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.075, 0}, 
               NCache[{0.08, Rational[1380, 917]}, {0.08, 1.504907306434024}],
               
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.08, 0}, 
               NCache[{0.085, Rational[1300, 917]}, {0.085, 
                1.4176663031624863`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.085, 0}, 
               NCache[{0.09, Rational[1360, 917]}, {0.09, 
                1.4830970556161396`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.09, 0}, 
               NCache[{0.095, Rational[1080, 917]}, {0.095, 
                1.1777535441657578`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.095, 0}, 
               NCache[{0.1, Rational[820, 917]}, {0.1, 0.8942202835332607}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.1, 0}, 
               NCache[{0.105, Rational[480, 917]}, {0.105, 
                0.5234460196292258}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.105, 0}, 
               NCache[{0.11, Rational[520, 917]}, {0.11, 0.5670665212649946}],
               
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.11, 0}, 
               NCache[{0.115, Rational[40, 131]}, {0.115, 0.3053435114503817}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.115, 0}, 
               NCache[{0.12, Rational[360, 917]}, {0.12, 0.3925845147219193}],
               
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.12, 0}, 
               NCache[{0.125, Rational[220, 917]}, {0.125, 
                0.23991275899672845`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.125, 0}, 
               NCache[{0.13, Rational[200, 917]}, {0.13, 
                0.21810250817884405`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.13, 0}, 
               NCache[{0.135, Rational[100, 917]}, {0.135, 
                0.10905125408942203`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.135, 0}, 
               NCache[{0.14, Rational[100, 917]}, {0.14, 
                0.10905125408942203`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.14, 0}, 
               NCache[{0.145, Rational[20, 131]}, {0.145, 
                0.15267175572519084`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.145, 0}, 
               NCache[{0.15, Rational[80, 917]}, {0.15, 0.08724100327153762}],
               
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.15, 0}, 
               NCache[{0.155, Rational[40, 917]}, {0.155, 
                0.04362050163576881}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.155, 0}, 
               NCache[{0.16, Rational[20, 917]}, {0.16, 
                0.021810250817884406`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.16, 0}, 
               NCache[{0.165, Rational[20, 917]}, {0.165, 
                0.021810250817884406`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.165, 0}, 
               NCache[{0.17, Rational[40, 917]}, {0.17, 0.04362050163576881}],
               
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.17, 0}, 
               NCache[{0.175, Rational[40, 917]}, {0.175, 
                0.04362050163576881}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.175, 0}, 
               NCache[{0.18, Rational[20, 917]}, {0.18, 
                0.021810250817884406`}],
               RoundingRadius->0]}, 
             {GrayLevel[0.5], Opacity[0.25], 
              RectangleBox[{0.18, 0}, 
               NCache[{0.185, Rational[20, 917]}, {0.185, 
                0.021810250817884406`}],
               RoundingRadius->0]}}, {}, {}}, 
           GraphicsComplexBox[CompressedData["
1:eJztlnk0lWvfx02RcStRW+oUHbRlKEMi+3erUKQQckqJSkJk6oiK1MFJJSky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            "], {{{}, 
              {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
               GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwt0VdPEwAUBeAiKBt5ZpdNwt4jYYMoGrDsmVD2agl7I1NF/M98TfrwnfN6
b04wHA1FPgQCgQRu4h0UP/QBVdzTxTLZ/Oc7USr5RSdLfOaNUSJUcEcHi2Tx
jX3KuaWdBTL5yh5l8XvamCeDEXYp5ZpW5kjnH1/YoYQrWpgljVeG2aaYS5qZ
IZW/DLEV+58LmpgmhT8MskkR5zQyRTK/GWCDQs5oYJJPvNDPOgWcUs8EH3mm
jzXyOaGOEEk80csqeRxTy08SeaSHMLkcUcM4sX0f6GaFHA6pZox3ZpAmZw==

                 "]]]}, {}, 
              {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[
               None], GraphicsGroupBox[
                PolygonBox[{{192, 172, 196, 178, 188, 160, 197, 
                 182}}]]}, {}, 
              {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[
               None], GraphicsGroupBox[
                PolygonBox[{{272, 288, 223, 287, 252, 271, 233, 279, 243, 262,
                  222, 286, 251, 270, 232, 278, 242, 261, 221, 285, 250, 269, 
                 231, 277, 241, 260, 220, 284, 249, 268, 230, 276, 240, 259, 
                 219, 283, 248, 267, 229, 275, 239, 258, 218, 282, 247, 266, 
                 228, 274, 238, 257, 217, 281, 246, 265, 227, 273, 237, 256, 
                 216, 280, 245, 264, 
                 226}}]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, \
{{}, {}, 
              {Hue[0.67, 0.6, 0.6], 
               LineBox[{1, 79, 44, 114, 26, 97, 62, 130, 2, 80, 45, 115, 27, 
                98, 63, 131, 3, 81, 46, 116, 28, 99, 64, 132, 4, 82, 47, 117, 
                29, 100, 65, 133, 5, 83, 48, 118, 30, 101, 66, 134, 6, 84, 49,
                 119, 31, 102, 67, 135, 7, 85, 50, 120, 32, 103, 68, 136, 8, 
                86, 51, 121, 33, 104, 69, 137, 9, 87, 52, 122, 34, 105, 70, 
                138, 10, 88, 53, 123, 35, 106, 71, 139, 11, 89, 54, 124, 36, 
                107, 72, 12, 90, 55, 125, 37, 108, 73, 13, 91, 56, 126, 38, 
                109, 74, 14, 92, 57, 127, 39, 110, 75, 140, 15, 93, 58, 128, 
                40, 111, 76, 141, 16, 94, 59, 129, 41, 112, 77, 142, 17, 95, 
                60, 42, 18, 19, 20, 21, 22, 23, 24, 96, 61, 43, 113, 78, 143, 
                25}]}, 
              {Hue[0.9060679774997897, 0.6, 0.6], 
               LineBox[{144, 185, 175, 169, 145, 146, 147, 148, 149, 150, 151,
                 152, 153, 154, 155, 156, 157, 158, 186, 176, 170, 191, 181, 
                159, 187, 177, 195, 171, 192, 182, 197, 160, 188, 178, 196, 
                172, 193, 183, 161, 189, 179, 173, 162, 163, 164, 165, 166, 
                167, 190, 180, 174, 194, 184, 198, 168}]}, 
              {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzdk2ggEYhtFfGZJMZSgZllty5tQF6DIrU2QOSaaEEMoYu4Nn7bW+9+Bb
XMksrfYEQbCsrH5VV0U55bWmdW1oU1sqaFs7KmpXe9rXgTq614UGPHjjof70
oDG3KiN8Z5JHDPiIcV5ykC2meNyd2WCcV4yyzRmWGOITE7zmED+Y5gnDfOYE
bxjjJ2d5yl6+cJK3HOYX53jGPjY5xRpH+M15ltnPV07zjqP84QLP+Q/yEjao

                "]]}}}], {{}, {}, 
            {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwVklc81f8fxzkkm1KKVDJKJ1tK4ry/JSPrFxktil+kiF9GkZKMSFmRkb2O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              "]]}}}, {InsetBox[
            
            TemplateBox[{
             StyleBox[
              "\"subcritical\"", StripOnInput -> False, FontFamily -> 
               "Helvetica", FontSize -> 12],StyleBox[
              "\"critical\"", StripOnInput -> False, FontFamily -> 
               "Helvetica", FontSize -> 12],StyleBox[
              "\"supercritical\"", StripOnInput -> False, FontFamily -> 
               "Helvetica", FontSize -> 12]},
             "SwatchLegend",
             DisplayFunction->(StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
               False]& ),
             Editable->True,
             InterpretationFunction:>(RowBox[{"SwatchLegend", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.24720000000000014`", ",", "0.24`", ",", 
                    "0.6`"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.6`", ",", "0.24`", ",", 
                    "0.4428931686004542`"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.6`", ",", "0.5470136627990908`", ",", 
                    "0.24`"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}]}], "}"}], 
                  ",", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                  RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                "]"}]& )], NCache[
            Scaled[{Rational[1, 8], 0.325}], Scaled[{0.125, 0.325}]], 
            ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm], InsetBox[
            TagBox[GridBox[{
               {
                
                TemplateBox[{
                 StyleBox[
                  "\"random\"", StripOnInput -> False, FontFamily -> 
                   "Helvetica", FontSize -> 12],StyleBox[
                  "\"established\"", StripOnInput -> False, FontFamily -> 
                   "Helvetica", FontSize -> 12]},
                 "LineLegend",
                 DisplayFunction->(StyleBox[
                   StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                   FontFamily -> "Times"}, Background -> Automatic, 
                   StripOnInput -> False]& ),
                 Editable->True,
                 InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
                    "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                    "]"}]& )]},
               {
                
                TemplateBox[{
                 StyleBox[
                  "\"first-step\"", StripOnInput -> False, FontFamily -> 
                   "Helvetica", FontSize -> 12]},
                 "LineLegend",
                 DisplayFunction->(StyleBox[
                   StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                   FontFamily -> "Times"}, Background -> Automatic, 
                   StripOnInput -> False]& ),
                 Editable->True,
                 InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], "}"}], ",", 
                    RowBox[{"{", #, "}"}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                    "]"}]& )]}
              },
              AutoDelete->False,
              GridBoxAlignment->{"Columns" -> {{Left}}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
              GridBoxSpacings->{"Columns" -> {{0}}}],
             "Grid"], NCache[
            Scaled[{Rational[1, 8], 0.625}], Scaled[{0.125, 0.625}]], 
            ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm]}},
         AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
         Axes->True,
         AxesLabel->{None, None},
         AxesOrigin->{0, 0},
         Epilog->{
           InsetBox[
            FormBox[
             StyleBox[
             "\"\\!\\(\\*SubscriptBox[\\(m\\), \\(0\\)]\\)=-0.1\"", 12, 
              FontFamily -> "Helvetica", StripOnInput -> False], 
             TraditionalForm], 
            NCache[
             Scaled[{
               Rational[7, 8], 
               Rational[3, 4]}], 
             Scaled[{0.875, 0.75}]]], 
           InsetBox[
            FormBox[
             StyleBox[
             "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
              False], TraditionalForm], 
            Scaled[{0.05, 0.95}]]},
         Frame->{True, False, False, False},
         FrameTicksStyle->{
          FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
         LabelStyle->Directive[12, FontFamily -> "Helvetica"],
         Method->{},
         PlotRange->{{-0.3, 0.15}, {0, 30}},
         PlotRangeClipping->True,
         PlotRangePadding->{
           Scaled[0.02], Automatic}],
        TraditionalForm],
       InterpretTemplate[Legended[
         Graphics[{{{{}, {}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               GrayLevel[0.5], 
               Thickness[Large], 
               Dashing[{Small, Small}]], 
              Line[CompressedData["
1:eJwVknk4FGofhpmULVlmVBNOPlpli0jI75Ula5YMHX0lCtmmEsl0UsiSvki0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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               GrayLevel[0.5], 
               Thickness[Large]], 
              Line[CompressedData["
1:eJxFxw88FPYfx/FzKpw/l5R2/qw7+nMpx8gy4fNt/uZPo50/KbZMSKpJk/Tn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               "]]}}}, {
            Directive[
             EdgeForm[
              Opacity[0.189]], 
             RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458]], {{}, {
             
              Directive[
               EdgeForm[
                Opacity[0.189]], 
               RGBColor[
               0.798413061722744, 0.824719615472648, 0.968322270542458]], {{{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.19, 0}, {-0.185, 
                   Rational[40, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.18, 0}, {-0.175, 
                   Rational[20, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.17, 0}, {-0.165, 
                   Rational[40, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.165, 0}, {-0.16, 
                   Rational[40, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.16, 0}, {-0.155, 
                   Rational[40, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.155, 0}, {-0.15, 
                   Rational[60, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.15, 0}, {-0.145, 
                   Rational[60, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.145, 0}, {-0.14, 
                   Rational[80, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.14, 0}, {-0.135, 
                   Rational[60, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.135, 0}, {-0.13, 
                   Rational[80, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.13, 0}, {-0.125, 
                   Rational[80, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.125, 0}, {-0.12, 
                   Rational[20, 131]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.12, 0}, {-0.115, 
                   Rational[160, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.115, 0}, {-0.11, 
                   Rational[200, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.11, 0}, {-0.105, 
                   Rational[260, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.105, 0}, {-0.1, 
                   Rational[540, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.1, 0}, {-0.095, 
                   Rational[600, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.095, 0}, {-0.09, 
                   Rational[620, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.09, 0}, {-0.085, 
                   Rational[520, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.085, 0}, {-0.08, 
                   Rational[720, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.08, 0}, {-0.075, 
                   Rational[880, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.075, 0}, {-0.07, 
                   Rational[1200, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.07, 0}, {-0.065, 
                   Rational[1420, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.065, 0}, {-0.06, 
                   Rational[200, 131]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.06, 0}, {-0.055, 
                   Rational[1580, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.055, 0}, {-0.05, 
                   Rational[2220, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.05, 0}, {-0.045, 
                   Rational[2300, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.045, 0}, {-0.04, 
                   Rational[3420, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.04, 0}, {-0.035, 
                   Rational[3280, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.035, 0}, {-0.03, 
                   Rational[4460, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.03, 0}, {-0.025, 
                   Rational[5440, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.025, 0}, {-0.02, 
                   Rational[6280, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.02, 0}, {-0.015, 
                   Rational[6620, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.015, 0}, {-0.01, 
                   Rational[9420, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.01, 0}, {-0.005, 
                   Rational[11380, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{-0.005, 0}, {0., 
                   Rational[15420, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0., 0}, {0.005, 
                   Rational[9780, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.005, 0}, {0.01, 
                   Rational[10240, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.01, 0}, {0.015, 
                   Rational[9360, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.015, 0}, {0.02, 
                   Rational[9200, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.02, 0}, {0.025, 
                   Rational[1300, 131]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.025, 0}, {0.03, 
                   Rational[8140, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.03, 0}, {0.035, 
                   Rational[6600, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.035, 0}, {0.04, 
                   Rational[6040, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.04, 0}, {0.045, 
                   Rational[5280, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.045, 0}, {0.05, 
                   Rational[4660, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.05, 0}, {0.055, 
                   Rational[580, 131]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.055, 0}, {0.06, 
                   Rational[3800, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.06, 0}, {0.065, 
                   Rational[380, 131]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.065, 0}, {0.07, 
                   Rational[2700, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.07, 0}, {0.075, 
                   Rational[2080, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.075, 0}, {0.08, 
                   Rational[1380, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.08, 0}, {0.085, 
                   Rational[1300, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.085, 0}, {0.09, 
                   Rational[1360, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.09, 0}, {0.095, 
                   Rational[1080, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.095, 0}, {0.1, 
                   Rational[820, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.1, 0}, {0.105, 
                   Rational[480, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.105, 0}, {0.11, 
                   Rational[520, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.11, 0}, {0.115, 
                   Rational[40, 131]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.115, 0}, {0.12, 
                   Rational[360, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.12, 0}, {0.125, 
                   Rational[220, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.125, 0}, {0.13, 
                   Rational[200, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.13, 0}, {0.135, 
                   Rational[100, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.135, 0}, {0.14, 
                   Rational[100, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.14, 0}, {0.145, 
                   Rational[20, 131]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.145, 0}, {0.15, 
                   Rational[80, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.15, 0}, {0.155, 
                   Rational[40, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.155, 0}, {0.16, 
                   Rational[20, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.16, 0}, {0.165, 
                   Rational[20, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.165, 0}, {0.17, 
                   Rational[40, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.17, 0}, {0.175, 
                   Rational[40, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.175, 0}, {0.18, 
                   Rational[20, 917]}, "RoundingRadius" -> 0]}}, {{
                 Directive[
                  GrayLevel[0.5], 
                  Opacity[0.25]], 
                 Rectangle[{0.18, 0}, {0.185, 
                   Rational[20, 917]}, "RoundingRadius" -> 0]}}}}, {}, {}}}, 
           GraphicsComplex[CompressedData["
1:eJztlnk0lWvfx02RcStRW+oUHbRlKEMi+3erUKQQckqJSkJk6oiK1MFJJSky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            
            "], {{{}, {
               EdgeForm[], 
               Directive[{
                 Opacity[0.2], 
                 Hue[0.67, 0.6, 0.6]}], 
               GraphicsGroup[{
                 Polygon[CompressedData["
1:eJwt0VdPEwAUBeAiKBt5ZpdNwt4jYYMoGrDsmVD2agl7I1NF/M98TfrwnfN6
b04wHA1FPgQCgQRu4h0UP/QBVdzTxTLZ/Oc7USr5RSdLfOaNUSJUcEcHi2Tx
jX3KuaWdBTL5yh5l8XvamCeDEXYp5ZpW5kjnH1/YoYQrWpgljVeG2aaYS5qZ
IZW/DLEV+58LmpgmhT8MskkR5zQyRTK/GWCDQs5oYJJPvNDPOgWcUs8EH3mm
jzXyOaGOEEk80csqeRxTy08SeaSHMLkcUcM4sX0f6GaFHA6pZox3ZpAmZw==

                  "]]}]}, {}, {
               EdgeForm[], 
               Directive[{
                 Opacity[0.2], 
                 Hue[0.9060679774997897, 0.6, 0.6]}], 
               GraphicsGroup[{
                 Polygon[{{192, 172, 196, 178, 188, 160, 197, 182}}]}]}, {}, {
              
               EdgeForm[], 
               Directive[{
                 Opacity[0.2], 
                 Hue[0.1421359549995791, 0.6, 0.6]}], 
               GraphicsGroup[{
                 
                 Polygon[{{272, 288, 223, 287, 252, 271, 233, 279, 243, 262, 
                  222, 286, 251, 270, 232, 278, 242, 261, 221, 285, 250, 269, 
                  231, 277, 241, 260, 220, 284, 249, 268, 230, 276, 240, 259, 
                  219, 283, 248, 267, 229, 275, 239, 258, 218, 282, 247, 266, 
                  228, 274, 238, 257, 217, 281, 246, 265, 227, 273, 237, 256, 
                  216, 280, 245, 264, 
                  226}}]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, \
{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               
               Line[{1, 79, 44, 114, 26, 97, 62, 130, 2, 80, 45, 115, 27, 98, 
                63, 131, 3, 81, 46, 116, 28, 99, 64, 132, 4, 82, 47, 117, 29, 
                100, 65, 133, 5, 83, 48, 118, 30, 101, 66, 134, 6, 84, 49, 
                119, 31, 102, 67, 135, 7, 85, 50, 120, 32, 103, 68, 136, 8, 
                86, 51, 121, 33, 104, 69, 137, 9, 87, 52, 122, 34, 105, 70, 
                138, 10, 88, 53, 123, 35, 106, 71, 139, 11, 89, 54, 124, 36, 
                107, 72, 12, 90, 55, 125, 37, 108, 73, 13, 91, 56, 126, 38, 
                109, 74, 14, 92, 57, 127, 39, 110, 75, 140, 15, 93, 58, 128, 
                40, 111, 76, 141, 16, 94, 59, 129, 41, 112, 77, 142, 17, 95, 
                60, 42, 18, 19, 20, 21, 22, 23, 24, 96, 61, 43, 113, 78, 143, 
                25}]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               
               Line[{144, 185, 175, 169, 145, 146, 147, 148, 149, 150, 151, 
                152, 153, 154, 155, 156, 157, 158, 186, 176, 170, 191, 181, 
                159, 187, 177, 195, 171, 192, 182, 197, 160, 188, 178, 196, 
                172, 193, 183, 161, 189, 179, 173, 162, 163, 164, 165, 166, 
                167, 190, 180, 174, 194, 184, 198, 168}]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Line[CompressedData["
1:eJwVzdk2ggEYhtFfGZJMZSgZllty5tQF6DIrU2QOSaaEEMoYu4Nn7bW+9+Bb
XMksrfYEQbCsrH5VV0U55bWmdW1oU1sqaFs7KmpXe9rXgTq614UGPHjjof70
oDG3KiN8Z5JHDPiIcV5ykC2meNyd2WCcV4yyzRmWGOITE7zmED+Y5gnDfOYE
bxjjJ2d5yl6+cJK3HOYX53jGPjY5xRpH+M15ltnPV07zjqP84QLP+Q/yEjao

                "]]}}}], {{{}, {}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               Thickness[Large], 
               GrayLevel[0]], 
              Line[CompressedData["
1:eJwVklc81f8fxzkkm1KKVDJKJ1tK4ry/JSPrFxktil+kiF9GkZKMSFmRkb2O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               "]]}}}}, {
          Frame -> {True, False, False, False}, 
           FrameTicksStyle -> {
            FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, 
           PlotRange -> {{-0.3, 0.15}, {0, 30}}, LabelStyle -> 
           Directive[12, FontFamily -> "Helvetica"], Epilog -> {
             Text[
              Style[
              "\!\(\*SubscriptBox[\(m\), \(0\)]\)=-0.1", 12, FontFamily -> 
               "Helvetica"], 
              Scaled[{
                Rational[7, 8], 
                Rational[3, 4]}]], 
             Text[
              Style["A", 14, Bold, FontFamily -> "Helvetica"], 
              Scaled[{0.05, 0.95}]]}, AspectRatio -> GoldenRatio^(-1), Axes -> 
           True, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
           Method -> {}, PlotRange -> {{-0.3, 0.15}, {0, All}}, 
           PlotRangeClipping -> True, PlotRangePadding -> {
             Scaled[0.02], Automatic}}], {
          Placed[
           Unevaluated[
            LineLegend[{
              Directive[
               Thickness[Large], 
               GrayLevel[0]]}, {
              Style["first-step", 12, FontFamily -> "Helvetica"]}, 
             LegendLayout -> "Column"]], 
           Scaled[{
             Rational[1, 8], 0.625}], Identity]}]& ],
       AutoDelete->True,
       Editable->True,
       SelectWithContents->False,
       Selectable->True],
      TraditionalForm], {189., -119.16407864998737`}, {
     Center, Center}, {360., 268.32815729997475`}], InsetBox[
     GraphicsBox[{{{}, {}, 
        {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
         LineBox[CompressedData["
1:eJwVkWk4FGofhzUY6xgz06Yih3Kkkkgcpf8jS8o6ZElUSkhF9qVClBwtssTJ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          "]]}, 
        {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxFznc0FX4fB3AhW3hCrp0ilBE/4xF9vombjIzQbRjpl0pGZkiSCmkgsve4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          "]]}}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        EdgeForm[Opacity[0.34299999999999997`]], {}, 
        {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
         EdgeForm[Opacity[0.34299999999999997`]], 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.195, 0}, 
           NCache[{-0.19, Rational[200, 709]}, {-0.19, 0.2820874471086037}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.19, 0}, 
           NCache[{-0.185, Rational[200, 709]}, {-0.185, 0.2820874471086037}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.17, 0}, 
           NCache[{-0.165, Rational[200, 709]}, {-0.165, 0.2820874471086037}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.155, 0}, 
           NCache[{-0.15, Rational[600, 709]}, {-0.15, 0.846262341325811}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.15, 0}, 
           NCache[{-0.145, Rational[200, 709]}, {-0.145, 0.2820874471086037}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.145, 0}, 
           NCache[{-0.14, Rational[400, 709]}, {-0.14, 0.5641748942172073}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.14, 0}, 
           NCache[{-0.135, Rational[600, 709]}, {-0.135, 0.846262341325811}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.135, 0}, 
           NCache[{-0.13, Rational[600, 709]}, {-0.13, 0.846262341325811}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.13, 0}, 
           NCache[{-0.125, Rational[1000, 709]}, {-0.125, 
            1.4104372355430184`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.125, 0}, 
           NCache[{-0.12, Rational[600, 709]}, {-0.12, 0.846262341325811}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.12, 0}, 
           NCache[{-0.115, Rational[200, 709]}, {-0.115, 0.2820874471086037}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.115, 0}, 
           NCache[{-0.11, Rational[400, 709]}, {-0.11, 0.5641748942172073}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.11, 0}, 
           NCache[{-0.105, Rational[600, 709]}, {-0.105, 0.846262341325811}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.105, 0}, 
           NCache[{-0.1, Rational[1600, 709]}, {-0.1, 2.2566995768688294`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.1, 0}, 
           NCache[{-0.095, Rational[1000, 709]}, {-0.095, 
            1.4104372355430184`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.095, 0}, 
           NCache[{-0.09, Rational[600, 709]}, {-0.09, 0.846262341325811}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.09, 0}, 
           NCache[{-0.085, Rational[1800, 709]}, {-0.085, 2.538787023977433}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.085, 0}, 
           NCache[{-0.08, Rational[1200, 709]}, {-0.08, 1.692524682651622}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.08, 0}, 
           NCache[{-0.075, Rational[1800, 709]}, {-0.075, 2.538787023977433}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.075, 0}, 
           NCache[{-0.07, Rational[2200, 709]}, {-0.07, 3.1029619181946404`}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.07, 0}, 
           NCache[{-0.065, Rational[1800, 709]}, {-0.065, 2.538787023977433}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.065, 0}, 
           NCache[{-0.06, Rational[4000, 709]}, {-0.06, 5.6417489421720735`}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.06, 0}, 
           NCache[{-0.055, Rational[3200, 709]}, {-0.055, 4.513399153737659}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.055, 0}, 
           NCache[{-0.05, Rational[2600, 709]}, {-0.05, 3.6671368124118477`}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.05, 0}, 
           NCache[{-0.045, Rational[3800, 709]}, {-0.045, 5.359661495063469}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.045, 0}, 
           NCache[{-0.04, Rational[2200, 709]}, {-0.04, 3.1029619181946404`}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.04, 0}, 
           NCache[{-0.035, Rational[7200, 709]}, {-0.035, 
            10.155148095909732`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.035, 0}, 
           NCache[{-0.03, Rational[4000, 709]}, {-0.03, 5.6417489421720735`}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.03, 0}, 
           NCache[{-0.025, Rational[5200, 709]}, {-0.025, 
            7.3342736248236955`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.025, 0}, 
           NCache[{-0.02, Rational[7400, 709]}, {-0.02, 10.437235543018335`}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.02, 0}, 
           NCache[{-0.015, Rational[6200, 709]}, {-0.015, 8.744710860366714}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.015, 0}, 
           NCache[{-0.01, Rational[9400, 709]}, {-0.01, 13.258110014104373`}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.01, 0}, 
           NCache[{-0.005, Rational[14600, 709]}, {-0.005, 20.59238363892807}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.005, 0}, 
           NCache[{0., Rational[13600, 709]}, {0., 19.181946403385048`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0., 0}, 
           NCache[{0.005, Rational[6000, 709]}, {0.005, 8.46262341325811}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.005, 0}, 
           NCache[{0.01, Rational[6200, 709]}, {0.01, 8.744710860366714}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.01, 0}, 
           NCache[{0.015, Rational[7200, 709]}, {0.015, 10.155148095909732`}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.015, 0}, 
           NCache[{0.02, Rational[4600, 709]}, {0.02, 6.488011283497884}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.02, 0}, 
           NCache[{0.025, Rational[2600, 709]}, {0.025, 3.6671368124118477`}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.025, 0}, 
           NCache[{0.03, Rational[4200, 709]}, {0.03, 5.923836389280677}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.03, 0}, 
           NCache[{0.035, Rational[1800, 709]}, {0.035, 2.538787023977433}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.035, 0}, 
           NCache[{0.04, Rational[2000, 709]}, {0.04, 2.8208744710860367`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.04, 0}, 
           NCache[{0.045, Rational[1400, 709]}, {0.045, 1.9746121297602257`}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.045, 0}, 
           NCache[{0.05, Rational[600, 709]}, {0.05, 0.846262341325811}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.05, 0}, 
           NCache[{0.055, Rational[1600, 709]}, {0.055, 2.2566995768688294`}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.055, 0}, 
           NCache[{0.06, Rational[200, 709]}, {0.06, 0.2820874471086037}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.06, 0}, 
           NCache[{0.065, Rational[600, 709]}, {0.065, 0.846262341325811}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.065, 0}, 
           NCache[{0.07, Rational[400, 709]}, {0.07, 0.5641748942172073}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.07, 0}, 
           NCache[{0.075, Rational[400, 709]}, {0.075, 0.5641748942172073}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.08, 0}, 
           NCache[{0.085, Rational[400, 709]}, {0.085, 0.5641748942172073}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.09, 0}, 
           NCache[{0.095, Rational[400, 709]}, {0.095, 0.5641748942172073}],
           RoundingRadius->0]}}, {}, {}}, GraphicsComplexBox[CompressedData["
1:eJztl3k0lH/7x0VJ9iUKkSxlKVmiUrluWZKlIkslFZWdIm18k1KSErJmXwcT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        "], {{{}, 
          {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
           GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwt0dVKgwEAhuHfbid4Zs8W3OwGu0WdswPU2cFmd9y6j7CD5/su4A0nUvFk
ZhAEGaTSX26W/C1tvDHCAWX8ssgNrbwyzD4hfljgmhZeGGKPUua5oplBdimh
iQF2KKaRfrYpYo5LGuhji0JmuaCeXjYpYIZzwjzTwwb5THNGHU90s04eU5xS
yyNdxMnlm0lOqOGBTtbI4YsJElRzTwcxsvlknGOquCPKKll8MMYRlekmEVb4
7/TOKIdUkKSdZf4A2VQe+g==
             "]]]}, {}, 
          {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
           GraphicsGroupBox[
            PolygonBox[{{178, 158, 182, 164, 174, 146, 183, 168}}]]}, {}, 
          {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
           GraphicsGroupBox[
            PolygonBox[{{258, 274, 209, 273, 238, 257, 219, 265, 229, 248, 
             208, 272, 237, 256, 218, 264, 228, 247, 207, 271, 236, 255, 217, 
             263, 227, 246, 206, 270, 235, 254, 216, 262, 226, 245, 205, 269, 
             234, 253, 215, 261, 225, 244, 204, 268, 233, 252, 214, 260, 224, 
             243, 203, 267, 232, 251, 213, 259, 223, 242, 202, 266, 231, 250, 
             
             212}}]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, \
{}, 
          {Hue[0.67, 0.6, 0.6], 
           LineBox[{1, 77, 44, 110, 26, 95, 62, 121, 2, 78, 45, 111, 27, 96, 
            63, 122, 3, 79, 46, 112, 28, 97, 64, 123, 4, 80, 47, 113, 29, 98, 
            65, 124, 5, 81, 48, 114, 30, 99, 66, 125, 6, 82, 49, 115, 31, 100,
             67, 7, 83, 50, 116, 32, 101, 68, 8, 84, 51, 117, 33, 102, 69, 9, 
            85, 52, 34, 103, 70, 10, 86, 53, 35, 104, 71, 11, 87, 54, 36, 12, 
            88, 55, 37, 13, 89, 56, 38, 105, 72, 14, 90, 57, 118, 39, 106, 73,
             126, 15, 91, 58, 119, 40, 107, 74, 127, 16, 92, 59, 120, 41, 108,
             75, 128, 17, 93, 60, 42, 18, 19, 20, 21, 22, 23, 24, 94, 61, 43, 
            109, 76, 129, 25}]}, 
          {Hue[0.9060679774997897, 0.6, 0.6], 
           LineBox[{130, 171, 161, 155, 131, 132, 133, 134, 135, 136, 137, 
            138, 139, 140, 141, 142, 143, 144, 172, 162, 156, 177, 167, 145, 
            173, 163, 181, 157, 178, 168, 183, 146, 174, 164, 182, 158, 179, 
            169, 147, 175, 165, 159, 148, 149, 150, 151, 152, 153, 176, 166, 
            160, 180, 170, 184, 154}]}, 
          {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzdk2ggEYhtFfGZJMl9AtdebUBXB9JTMNpsgckkwJIZQxdgd7Petd38EX
n5xOTPUEQTBBkidOKZJihjSzzDHPAossscwKq2TIkuOZM3b55IY8L5QJebqn
X9wStde0yTlhe1+/qTFkr+srFXrtA/3hjpi9oW9c0Gcf6i91hu1NfadKv32k
He4Zsbe0xSUD9rH+8cCoXdA2V0Tskgb6KGO6rR9cM2ifdM/a0HHd0X/KBz+8

            "]]}}}], {{}, {}, 
        {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwVkXk41HsfQG3JTsRtImrE1WRXkejzc20jS4hoUUi2VESIQrKXrFnDUMYS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          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      Epilog->{
        InsetBox[
         FormBox[
          StyleBox[
          "\"\\!\\(\\*SubscriptBox[\\(m\\), \\(0\\)]\\)=-0.2\"", 12, 
           FontFamily -> "Helvetica", StripOnInput -> False], 
          TraditionalForm], 
         NCache[
          Scaled[{
            Rational[7, 8], 
            Rational[3, 4]}], 
          Scaled[{0.875, 0.75}]]], 
        InsetBox[
         FormBox[
          StyleBox[
          "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
           False], TraditionalForm], 
         Scaled[{0.05, 0.95}]]},
      Frame->{True, False, False, False},
      FrameTicksStyle->{
       FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
      LabelStyle->Directive[12, FontFamily -> "Helvetica"],
      Method->{},
      PlotRange->{{-0.3, 0.15}, {0, 30}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], Automatic}], {189., -357.49223594996215`}, 
     ImageScaled[{0.5, 0.5}], {360., 268.32815729997475`}], InsetBox[
     GraphicsBox[{{{}, {}, 
        {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
         LineBox[CompressedData["
1:eJwVkWk8lHsfh4VkH1NRaDukRUgcS+L+3U4SJoVoE0U4GsuxhSRC1NGpSSPC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          "]]}, 
        {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJwVjnc81fsfgI2yZ0bWUVEZIXGVK77vDyIjXWTVlXVLoZQRRXZl5uimZEY4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          "]]}}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        EdgeForm[Opacity[0.35]], {}, 
        {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
         EdgeForm[Opacity[0.35]], 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.23, 0}, 
           NCache[{-0.225, Rational[200, 187]}, {-0.225, 1.0695187165775402`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.225, 0}, 
           NCache[{-0.22, Rational[200, 187]}, {-0.22, 1.0695187165775402`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.22, 0}, 
           NCache[{-0.215, Rational[200, 187]}, {-0.215, 1.0695187165775402`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.215, 0}, 
           NCache[{-0.21, Rational[400, 187]}, {-0.21, 2.1390374331550803`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.205, 0}, 
           NCache[{-0.2, Rational[200, 187]}, {-0.2, 1.0695187165775402`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.19, 0}, 
           NCache[{-0.185, Rational[200, 187]}, {-0.185, 1.0695187165775402`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.18, 0}, 
           NCache[{-0.175, Rational[200, 187]}, {-0.175, 1.0695187165775402`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.175, 0}, 
           NCache[{-0.17, Rational[200, 187]}, {-0.17, 1.0695187165775402`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.17, 0}, 
           NCache[{-0.165, Rational[800, 187]}, {-0.165, 4.278074866310161}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.165, 0}, 
           NCache[{-0.16, Rational[800, 187]}, {-0.16, 4.278074866310161}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.16, 0}, 
           NCache[{-0.155, Rational[400, 187]}, {-0.155, 2.1390374331550803`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.155, 0}, 
           NCache[{-0.15, Rational[600, 187]}, {-0.15, 3.2085561497326203`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.15, 0}, 
           NCache[{-0.145, Rational[600, 187]}, {-0.145, 3.2085561497326203`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.145, 0}, 
           NCache[{-0.14, Rational[600, 187]}, {-0.14, 3.2085561497326203`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.14, 0}, 
           NCache[{-0.135, Rational[800, 187]}, {-0.135, 4.278074866310161}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.135, 0}, 
           NCache[{-0.13, Rational[600, 187]}, {-0.13, 3.2085561497326203`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.13, 0}, 
           NCache[{-0.125, Rational[600, 187]}, {-0.125, 3.2085561497326203`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.125, 0}, 
           NCache[{-0.12, Rational[1000, 187]}, {-0.12, 5.347593582887701}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.12, 0}, 
           NCache[{-0.115, Rational[400, 187]}, {-0.115, 2.1390374331550803`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.115, 0}, 
           NCache[{-0.11, Rational[800, 187]}, {-0.11, 4.278074866310161}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.11, 0}, 
           NCache[{-0.105, Rational[800, 187]}, {-0.105, 4.278074866310161}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.105, 0}, 
           NCache[{-0.1, Rational[800, 187]}, {-0.1, 4.278074866310161}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.1, 0}, 
           NCache[{-0.095, Rational[400, 187]}, {-0.095, 2.1390374331550803`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.095, 0}, 
           NCache[{-0.09, Rational[1200, 187]}, {-0.09, 6.4171122994652405`}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.09, 0}, 
           NCache[{-0.085, Rational[1400, 187]}, {-0.085, 
            7.4866310160427805`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.085, 0}, 
           NCache[{-0.08, Rational[1600, 187]}, {-0.08, 8.556149732620321}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.08, 0}, 
           NCache[{-0.075, Rational[1400, 187]}, {-0.075, 
            7.4866310160427805`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.075, 0}, 
           NCache[{-0.07, Rational[1200, 187]}, {-0.07, 6.4171122994652405`}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.07, 0}, 
           NCache[{-0.065, Rational[400, 187]}, {-0.065, 2.1390374331550803`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.065, 0}, 
           NCache[{-0.06, Rational[200, 187]}, {-0.06, 1.0695187165775402`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.06, 0}, 
           NCache[{-0.055, Rational[800, 187]}, {-0.055, 4.278074866310161}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.055, 0}, 
           NCache[{-0.05, Rational[1200, 187]}, {-0.05, 6.4171122994652405`}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.05, 0}, 
           NCache[{-0.045, Rational[800, 187]}, {-0.045, 4.278074866310161}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.045, 0}, 
           NCache[{-0.04, Rational[400, 187]}, {-0.04, 2.1390374331550803`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.04, 0}, 
           NCache[{-0.035, Rational[1200, 187]}, {-0.035, 
            6.4171122994652405`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.035, 0}, 
           NCache[{-0.03, Rational[1000, 187]}, {-0.03, 5.347593582887701}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.03, 0}, 
           NCache[{-0.025, Rational[1400, 187]}, {-0.025, 
            7.4866310160427805`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.025, 0}, 
           NCache[{-0.02, Rational[200, 17]}, {-0.02, 11.764705882352942`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.02, 0}, 
           NCache[{-0.015, Rational[800, 187]}, {-0.015, 4.278074866310161}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.015, 0}, 
           NCache[{-0.01, Rational[1600, 187]}, {-0.01, 8.556149732620321}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.01, 0}, 
           NCache[{-0.005, Rational[1600, 187]}, {-0.005, 8.556149732620321}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.005, 0}, 
           NCache[{0., Rational[1800, 187]}, {0., 9.62566844919786}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0., 0}, 
           NCache[{0.005, Rational[1000, 187]}, {0.005, 5.347593582887701}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.005, 0}, 
           NCache[{0.01, Rational[400, 187]}, {0.01, 2.1390374331550803`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.01, 0}, 
           NCache[{0.015, Rational[200, 187]}, {0.015, 1.0695187165775402`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.015, 0}, 
           NCache[{0.02, Rational[600, 187]}, {0.02, 3.2085561497326203`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.02, 0}, 
           NCache[{0.025, Rational[600, 187]}, {0.025, 3.2085561497326203`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.025, 0}, 
           NCache[{0.03, Rational[200, 187]}, {0.03, 1.0695187165775402`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.035, 0}, 
           NCache[{0.04, Rational[200, 187]}, {0.04, 1.0695187165775402`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.06, 0}, 
           NCache[{0.065, Rational[200, 187]}, {0.065, 1.0695187165775402`}],
           RoundingRadius->0]}}, {}, {}}, GraphicsComplexBox[CompressedData["
1:eJztlnk01P0ex5lshexjq6cikiTxVB7k85VMalLWiFTkkQo9thJF5QktkqUk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        "], {{{}, 
          {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
           GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwt0VdLggEYBeCvadO6zpYtg8q0YQXtTaWWLaFti5a2+/s9ghfPeTl3B95o
oZQrVgdBUMVj5TaL7Uof5pM58rTzxxYPxPhgllPa+GWTe4Z4Z4YTwmxwxyAl
UhzTyg/r3DJAkWmOaGGNAv1McVjeyyo39DFJjiYaiTLBAQ30kmSfECtc00OC
LPUsc0U3b4yToY4lLunilThpalnkgk5eGGOPGr5Z4JwIz4yyS/kPX8xzRgdP
jLDDPz9MGyQ=
             "]]]}, {}, 
          {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
           GraphicsGroupBox[
            PolygonBox[{{170, 150, 174, 156, 166, 138, 175, 160}}]]}, {}, 
          {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
           GraphicsGroupBox[
            PolygonBox[{{250, 266, 201, 265, 230, 249, 211, 257, 221, 240, 
             200, 264, 229, 248, 210, 256, 220, 239, 199, 263, 228, 247, 209, 
             255, 219, 238, 198, 262, 227, 246, 208, 254, 218, 237, 197, 261, 
             226, 245, 207, 253, 217, 236, 196, 260, 225, 244, 206, 252, 216, 
             235, 195, 259, 224, 243, 205, 251, 215, 234, 194, 258, 223, 242, 
             204}}]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, \
{}, 
          {Hue[0.67, 0.6, 0.6], 
           LineBox[{1, 74, 43, 105, 26, 91, 60, 115, 2, 75, 44, 106, 27, 92, 
            61, 116, 3, 76, 45, 107, 28, 93, 62, 4, 77, 46, 108, 29, 94, 63, 
            5, 78, 47, 109, 30, 95, 64, 6, 79, 48, 31, 96, 65, 7, 80, 49, 32, 
            8, 81, 50, 33, 9, 10, 82, 51, 34, 97, 66, 11, 83, 52, 35, 98, 67, 
            12, 84, 53, 110, 36, 99, 68, 117, 13, 85, 54, 111, 37, 100, 69, 
            14, 86, 55, 112, 38, 101, 70, 118, 15, 87, 56, 113, 39, 102, 71, 
            119, 16, 88, 57, 114, 40, 103, 72, 120, 17, 89, 58, 41, 18, 19, 
            20, 21, 22, 23, 24, 90, 59, 42, 104, 73, 121, 25}]}, 
          {Hue[0.9060679774997897, 0.6, 0.6], 
           LineBox[{122, 163, 153, 147, 123, 124, 125, 126, 127, 128, 129, 
            130, 131, 132, 133, 134, 135, 136, 164, 154, 148, 169, 159, 137, 
            165, 155, 173, 149, 170, 160, 175, 138, 166, 156, 174, 150, 171, 
            161, 139, 167, 157, 151, 140, 141, 142, 143, 144, 145, 168, 158, 
            152, 172, 162, 176, 146}]}, 
          {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJwVztk2ggEYhtFfGXIZ3ZKzTl0A10YZSmYaTJE5JJkSQihj7A72eta33pMv
Ojw6NNITBEGMMW7ZY41x4iSYYJIppkmSYoY0s8wxzwI19lnnhTKL3HHAFxs0
OSfkiSWtc8g3m7xSIWxf1nuO+GGLNy7ota/oA8f8UuCdKn32VX2kRIdtWlzS
b89ogxP+2KHNFQP2rD5xSuAuygfXRNw5feasO7t39ZMbBt15/QcBbETs
            
            "]]}}}], {{}, {}, 
        {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwVkGk8FGofQG2hYSxhjKUFcaUsUZTwf1psSSGTSirVlazJUtG13nBLIbLv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          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      Epilog->{
        InsetBox[
         FormBox[
          StyleBox[
          "\"\\!\\(\\*SubscriptBox[\\(m\\), \\(0\\)]\\)=-0.3\"", 12, 
           FontFamily -> "Helvetica", StripOnInput -> False], 
          TraditionalForm], 
         NCache[
          Scaled[{
            Rational[7, 8], 
            Rational[3, 4]}], 
          Scaled[{0.875, 0.75}]]], 
        InsetBox[
         FormBox[
          StyleBox[
          "\"C\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
           False], TraditionalForm], 
         Scaled[{0.05, 0.95}]]},
      Frame->{True, False, False, False},
      FrameLabel->{
        FormBox["\"Growth rate\"", TraditionalForm]},
      LabelStyle->Directive[12, FontFamily -> "Helvetica"],
      Method->{},
      PlotRange->{{-0.3, 0.15}, {0, 30}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], Automatic}], {189., -595.8203932499368}, 
     ImageScaled[{0.5, 0.5}], {360., 268.3281572999748}]}, {}},
  ContentSelectable->True,
  ImageSize->350,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.784902565022216*^9, 3.784902654097386*^9, 
  3.7849029923489532`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
As function of mutation (figure S2)\
\>", "Subsubsection",
 CellChangeTimes->{{3.751078668443429*^9, 3.751078715980172*^9}, {
   3.760637574665436*^9, 3.760637583137683*^9}, 3.760637621897007*^9, {
   3.769433526188387*^9, 3.769433532707746*^9}, {3.7694390170713797`*^9, 
   3.769439044062275*^9}, 3.77125627294351*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmin", "=", "mwt"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmax", "=", 
   RowBox[{
    RowBox[{"-", "mwt"}], "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymax", "=", "70"}], ";"}]}], "Input",
 CellChangeTimes->{{3.771526569808242*^9, 3.771526570808013*^9}, {
  3.771526672372382*^9, 3.771526673372223*^9}, {3.771526779430848*^9, 
  3.771526832301539*^9}, {3.771527020244812*^9, 3.771527020343626*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "4"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.2"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exact", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
     RowBox[{"prescuem", "[", 
      RowBox[{"m1", ",", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"critical", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"0", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     SqrtBox[
      RowBox[{"2", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}]], 
     RowBox[{"HeavisideTheta", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m1", "+", "pr0"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"pr0", "-", "m1"}], ")"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"subcritical", "=", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], 
     RowBox[{"Abs", "[", "m1", "]"}]], 
    RowBox[{"HeavisideTheta", "[", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "m1"}], "-", "pr0"}], ")"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"supercritical", "=", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], 
     RowBox[{"Abs", "[", "m1", "]"}]], 
    RowBox[{"HeavisideTheta", "[", 
     RowBox[{"(", 
      RowBox[{"m1", "-", "pr0"}], ")"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"total", "=", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{"exact", ",", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "mwt", ",", "0.1"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figS2a", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Plot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"subcritical", "/", "total"}], ",", 
         RowBox[{"critical", "/", "total"}], ",", 
         RowBox[{"supercritical", "/", "total"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ","}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameTicksStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontColor", "\[Rule]", "White"}], ",", "Automatic", ",", 
          "Automatic", ",", "Automatic"}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", "\[IndentingNewLine]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"SwatchLegend", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Directive", "[", 
               RowBox[{
                RowBox[{"defaultcolors", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", 
                RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}], ",", 
              RowBox[{"Directive", "[", 
               RowBox[{
                RowBox[{"defaultcolors", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], ",", 
                RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}], ",", 
              RowBox[{"Directive", "[", 
               RowBox[{
                RowBox[{"defaultcolors", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], ",", 
                RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}]}], "}"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"#", ",", "12", ",", 
                RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
               "]"}], "&"}], "/@", 
             RowBox[{"{", 
              RowBox[{
              "\"\<subcritical\>\"", ",", "\"\<critical\>\"", ",", 
               "\"\<supercritical\>\""}], "}"}]}]}], "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"1", "/", "8"}], ",", "0.5"}], "}"}]}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<\!\(\*
StyleBox[\"U\",
FontSlant->\"Italic\"]\)=\!\(\*SuperscriptBox[\(10\), \(-4\)]\)\>\"", ",", 
              "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             ",", 
            RowBox[{"Scaled", "@", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"7", "/", "8"}], ",", 
               RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<A\>\"", ",", "14", ",", "Bold", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             ",", 
            RowBox[{"Scaled", "@", 
             RowBox[{"{", 
              RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}], "}"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"exact", "/", "total"}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Black"}], "]"}]}], ",", 
       RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", "\"\<first-step\>\"", "}"}]}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"1", "/", "8"}], ",", "0.7"}], "}"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7510622484477882`*^9, 3.7510623899214077`*^9}, {
   3.751062473276165*^9, 3.751062530490876*^9}, 3.751062563427968*^9, {
   3.751062594941642*^9, 3.7510626740085497`*^9}, {3.751062706742158*^9, 
   3.7510627719753103`*^9}, {3.751062825650064*^9, 3.751062839069113*^9}, {
   3.751062891684408*^9, 3.7510628936156187`*^9}, {3.751062951583514*^9, 
   3.7510629518293257`*^9}, {3.7510751327453938`*^9, 3.751075187438393*^9}, {
   3.751075227865163*^9, 3.751075253129315*^9}, {3.751075331833404*^9, 
   3.751075338861655*^9}, {3.751075400453147*^9, 3.7510754285434923`*^9}, {
   3.7510760676115513`*^9, 3.751076171924214*^9}, {3.7510762608235283`*^9, 
   3.751076261191457*^9}, {3.751076340797235*^9, 3.751076362147587*^9}, {
   3.75107872574929*^9, 3.751078735003438*^9}, {3.7606353531207438`*^9, 
   3.760635473464669*^9}, {3.760635743957357*^9, 3.7606360112862873`*^9}, {
   3.760636222903706*^9, 3.7606362356929493`*^9}, {3.760636989718989*^9, 
   3.76063699150007*^9}, {3.760637150079793*^9, 3.760637202314322*^9}, {
   3.760637455278749*^9, 3.760637456597685*^9}, {3.7606377774846687`*^9, 
   3.760637781467527*^9}, {3.760637835526574*^9, 3.760637844231641*^9}, {
   3.7606379301216507`*^9, 3.7606380192032557`*^9}, {3.769455745020947*^9, 
   3.7694558055578814`*^9}, {3.769456644988007*^9, 3.769456719183614*^9}, {
   3.769456749396174*^9, 3.769456764282476*^9}, {3.7694567960953493`*^9, 
   3.769456863965176*^9}, {3.769456896766629*^9, 3.769456911345119*^9}, {
   3.769456975282057*^9, 3.769456975825665*^9}, {3.769457153449222*^9, 
   3.7694572145297194`*^9}, {3.76945769323803*^9, 3.769457812534103*^9}, {
   3.7694578592401114`*^9, 3.7694579015202093`*^9}, 3.769459137092601*^9, {
   3.769968925600108*^9, 3.76996895177884*^9}, 3.7699689900805397`*^9, {
   3.7715264858505793`*^9, 3.7715265158117237`*^9}, {3.7715265901165867`*^9, 
   3.771526590555331*^9}, {3.771526625498386*^9, 3.771526710358515*^9}, 
   3.7715267535632277`*^9, {3.77152682008486*^9, 3.77152694891249*^9}, {
   3.771526979290783*^9, 3.771526994626341*^9}, {3.771527034179276*^9, 
   3.771527099645104*^9}, {3.77152712977761*^9, 3.7715271307136183`*^9}, 
   3.771527336512355*^9, 3.782259098591134*^9, {3.782274846279129*^9, 
   3.7822748465467176`*^9}, {3.7849048298752403`*^9, 3.784904847437385*^9}}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJztlXkw1Xsfx5UlSjlZTg7STddyhUqPpOTzpZtL5JaEtJDlkixFilQUsnVK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      "], {{{}, 
        {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
         GraphicsGroupBox[
          PolygonBox[{{1, 248, 17, 100, 66, 93, 38, 97, 53, 80, 16, 99, 65, 
           92, 37, 96, 52, 79, 15, 98, 64, 91, 36, 95, 51, 78, 14, 63, 90, 35,
            50, 77, 13, 62, 89, 34, 49, 76, 12, 11, 10, 9, 33, 48, 75, 8, 32, 
           47, 74, 7, 61, 88, 31, 46, 73, 6, 60, 87, 30, 45, 72, 5, 59, 86, 
           29, 44, 71, 4, 58, 85, 28, 43, 70, 3, 57, 84, 27, 42, 69, 2, 56, 
           83, 26, 41, 68}}]]}, {}, 
        {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
         GraphicsGroupBox[PolygonBox[{{155, 136, 146, 118}}]]}, {}, 
        {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
         GraphicsGroupBox[
          PolygonBox[{{213, 247, 181, 246, 210, 229, 191, 237, 201, 220, 180, 
           245, 209, 228, 190, 236, 200, 219, 179, 244, 208, 227, 189, 235, 
           199, 218, 178, 243, 207, 226, 188, 234, 198, 217, 177, 242, 206, 
           225, 187, 233, 197, 216, 176, 241, 205, 224, 186, 232, 196, 215, 
           175, 240, 204, 223, 185, 231, 195, 214, 174, 239, 203, 222, 184, 
           230, 194}}]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, \
{{}, {}, 
        {Hue[0.67, 0.6, 0.6], 
         LineBox[{1, 68, 41, 26, 83, 56, 2, 69, 42, 27, 84, 57, 3, 70, 43, 28,
           85, 58, 4, 71, 44, 29, 86, 59, 5, 72, 45, 30, 87, 60, 6, 73, 46, 
          31, 88, 61, 7, 74, 47, 32, 8, 75, 48, 33, 9, 10, 11, 12, 76, 49, 34,
           89, 62, 13, 77, 50, 35, 90, 63, 14, 78, 51, 95, 36, 91, 64, 98, 15,
           79, 52, 96, 37, 92, 65, 99, 16, 80, 53, 97, 38, 93, 66, 100, 17, 
          81, 54, 39, 18, 19, 20, 21, 22, 23, 24, 82, 55, 40, 94, 67, 101, 
          25}]}, 
        {Hue[0.9060679774997897, 0.6, 0.6], 
         LineBox[{102, 143, 133, 127, 103, 104, 105, 106, 107, 108, 109, 110, 
          111, 112, 113, 114, 115, 116, 144, 134, 128, 149, 139, 117, 145, 
          135, 153, 129, 150, 140, 155, 118, 146, 136, 154, 130, 151, 141, 
          119, 147, 137, 131, 120, 121, 122, 123, 124, 125, 148, 138, 132, 
          152, 142, 156, 126}]}, 
        {Hue[0.1421359549995791, 0.6, 0.6], 
         LineBox[{157, 211, 192, 182, 158, 159, 160, 161, 162, 163, 164, 165, 
          166, 167, 168, 169, 170, 171, 172, 212, 193, 183, 221, 202, 238, 
          173, 213, 194, 230, 184, 222, 203, 239, 174, 214, 195, 231, 185, 
          223, 204, 240, 175, 215, 196, 232, 186, 224, 205, 241, 176, 216, 
          197, 233, 187, 225, 206, 242, 177, 217, 198, 234, 188, 226, 207, 
          243, 178, 218, 199, 235, 189, 227, 208, 244, 179, 219, 200, 236, 
          190, 228, 209, 245, 180, 220, 201, 237, 191, 229, 210, 246, 
          181}]}}}], {{}, {}, 
      {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwVxXk8FGgfAPBZJINyhCjZsCPr2NKGCL9HRW/J1ObIK1cokmxEq2xRw7oW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        "]]}}}, {InsetBox[
      TemplateBox[{
       StyleBox[
        "\"subcritical\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"critical\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"supercritical\"", StripOnInput -> False, FontFamily -> "Helvetica",
          FontSize -> 12]},
       "SwatchLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"SwatchLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.5470136627990908`", ",", "0.24`"}], "]"}],
                     ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      NCache[Scaled[{Rational[1, 8], 0.5}], Scaled[{0.125, 0.5}]], 
      ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TemplateBox[{
       StyleBox[
        "\"first-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"Directive", "[", 
                RowBox[{
                  RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                  RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], "}"}], ",", 
            RowBox[{"{", #, "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      NCache[Scaled[{Rational[1, 8], 0.7}], Scaled[{0.125, 0.7}]], 
      ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesOrigin->{0, 0},
   Epilog->{
     InsetBox[
      FormBox[
       StyleBox[
       "\"\\!\\(\\*\\nStyleBox[\\\"U\\\",\\nFontSlant->\\\"Italic\\\"]\\)=\\!\
\\(\\*SuperscriptBox[\\(10\\), \\(-4\\)]\\)\"", 12, FontFamily -> "Helvetica",
         StripOnInput -> False], TraditionalForm], 
      NCache[
       Scaled[{
         Rational[7, 8], 
         Rational[3, 4]}], 
       Scaled[{0.875, 0.75}]]], 
     InsetBox[
      FormBox[
       StyleBox[
       "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
       TraditionalForm], 
      Scaled[{0.05, 0.95}]]},
   Frame->{True, False, False, False},
   FrameLabel->{None, None},
   FrameTicksStyle->{
    FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{"AxesInFront" -> True},
   PlotRange->{{-0.2, 0.1}, {0, 70}},
   PlotRangeClipping->True,
   PlotRangePadding->{
     Scaled[0.02], Automatic}],
  InterpretTemplate[Legended[
    Graphics[{
      GraphicsComplex[CompressedData["
1:eJztlXkw1Xsfx5UlSjlZTg7STddyhUqPpOTzpZtL5JaEtJDlkixFilQUsnVK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       "], {{{}, {
          EdgeForm[], 
          Directive[{
            Opacity[0.2], 
            Hue[0.67, 0.6, 0.6]}], 
          GraphicsGroup[{
            
            Polygon[{{1, 248, 17, 100, 66, 93, 38, 97, 53, 80, 16, 99, 65, 92,
              37, 96, 52, 79, 15, 98, 64, 91, 36, 95, 51, 78, 14, 63, 90, 35, 
             50, 77, 13, 62, 89, 34, 49, 76, 12, 11, 10, 9, 33, 48, 75, 8, 32,
              47, 74, 7, 61, 88, 31, 46, 73, 6, 60, 87, 30, 45, 72, 5, 59, 86,
              29, 44, 71, 4, 58, 85, 28, 43, 70, 3, 57, 84, 27, 42, 69, 2, 56,
              83, 26, 41, 68}}]}]}, {}, {
          EdgeForm[], 
          Directive[{
            Opacity[0.2], 
            Hue[0.9060679774997897, 0.6, 0.6]}], 
          GraphicsGroup[{
            Polygon[{{155, 136, 146, 118}}]}]}, {}, {
          EdgeForm[], 
          Directive[{
            Opacity[0.2], 
            Hue[0.1421359549995791, 0.6, 0.6]}], 
          GraphicsGroup[{
            
            Polygon[{{213, 247, 181, 246, 210, 229, 191, 237, 201, 220, 180, 
             245, 209, 228, 190, 236, 200, 219, 179, 244, 208, 227, 189, 235, 
             199, 218, 178, 243, 207, 226, 188, 234, 198, 217, 177, 242, 206, 
             225, 187, 233, 197, 216, 176, 241, 205, 224, 186, 232, 196, 215, 
             175, 240, 204, 223, 185, 231, 195, 214, 174, 239, 203, 222, 184, 
             230, 194}}]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, \
{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          
          Line[{1, 68, 41, 26, 83, 56, 2, 69, 42, 27, 84, 57, 3, 70, 43, 28, 
           85, 58, 4, 71, 44, 29, 86, 59, 5, 72, 45, 30, 87, 60, 6, 73, 46, 
           31, 88, 61, 7, 74, 47, 32, 8, 75, 48, 33, 9, 10, 11, 12, 76, 49, 
           34, 89, 62, 13, 77, 50, 35, 90, 63, 14, 78, 51, 95, 36, 91, 64, 98,
            15, 79, 52, 96, 37, 92, 65, 99, 16, 80, 53, 97, 38, 93, 66, 100, 
           17, 81, 54, 39, 18, 19, 20, 21, 22, 23, 24, 82, 55, 40, 94, 67, 
           101, 25}]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          
          Line[{102, 143, 133, 127, 103, 104, 105, 106, 107, 108, 109, 110, 
           111, 112, 113, 114, 115, 116, 144, 134, 128, 149, 139, 117, 145, 
           135, 153, 129, 150, 140, 155, 118, 146, 136, 154, 130, 151, 141, 
           119, 147, 137, 131, 120, 121, 122, 123, 124, 125, 148, 138, 132, 
           152, 142, 156, 126}]}, {
          Hue[0.1421359549995791, 0.6, 0.6], 
          
          Line[{157, 211, 192, 182, 158, 159, 160, 161, 162, 163, 164, 165, 
           166, 167, 168, 169, 170, 171, 172, 212, 193, 183, 221, 202, 238, 
           173, 213, 194, 230, 184, 222, 203, 239, 174, 214, 195, 231, 185, 
           223, 204, 240, 175, 215, 196, 232, 186, 224, 205, 241, 176, 216, 
           197, 233, 187, 225, 206, 242, 177, 217, 198, 234, 188, 226, 207, 
           243, 178, 218, 199, 235, 189, 227, 208, 244, 179, 219, 200, 236, 
           190, 228, 209, 245, 180, 220, 201, 237, 191, 229, 210, 246, 
           181}]}}}], {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          Thickness[Large], 
          GrayLevel[0]], 
         Line[CompressedData["
1:eJwVxXk8FGgfAPBZJINyhCjZsCPr2NKGCL9HRW/J1ObIK1cokmxEq2xRw7oW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          "]]}}}}, {
     PlotRange -> {{-0.2, 0.1}, {0, 70}}, AspectRatio -> GoldenRatio^(-1), 
      Axes -> True, AxesOrigin -> {0, 0}, Epilog -> {
        Text[
         Style[
         "\!\(\*\nStyleBox[\"U\",\n\
FontSlant->\"Italic\"]\)=\!\(\*SuperscriptBox[\(10\), \(-4\)]\)", 12, 
          FontFamily -> "Helvetica"], 
         Scaled[{
           Rational[7, 8], 
           Rational[3, 4]}]], 
        Text[
         Style["A", 14, Bold, FontFamily -> "Helvetica"], 
         Scaled[{0.05, 0.95}]]}, Frame -> {True, False, False, False}, 
      FrameLabel -> {None, None}, 
      FrameTicksStyle -> {
       FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, 
      LabelStyle -> Directive[12, FontFamily -> "Helvetica"], 
      Method -> {"AxesInFront" -> True}, PlotRange -> {{-0.2, 0.1}, {0, All}},
       PlotRangeClipping -> True, PlotRangePadding -> {
        Scaled[0.02], Automatic}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          Thickness[Large], 
          GrayLevel[0]]}, {
         Style["first-step", 12, FontFamily -> "Helvetica"]}, LegendLayout -> 
        "Column"]], 
      Scaled[{
        Rational[1, 8], 0.7}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.751076169745583*^9, 3.751076212624262*^9, 3.751076302304141*^9, 
   3.751076439674859*^9, 3.751078915891127*^9, 3.7606362768960953`*^9, 
   3.7606363620987587`*^9, 3.7606366101685753`*^9, 3.760636668714695*^9, 
   3.7606367924425*^9, 3.760636832628543*^9, 3.760636873685384*^9, 
   3.760636919837865*^9, 3.7606369726718407`*^9, 3.760637096436326*^9, 
   3.760637267856926*^9, 3.760637516251833*^9, 3.7606376030313883`*^9, 
   3.7606379007662086`*^9, 3.760638076518441*^9, 3.769455949438485*^9, 
   3.76945668800782*^9, 3.7694567711522417`*^9, {3.769456812956952*^9, 
   3.769456876307622*^9}, {3.7694569115912113`*^9, 3.7694569233915443`*^9}, 
   3.769456994229353*^9, {3.7694571817882023`*^9, 3.769457225810411*^9}, 
   3.7694578441422653`*^9, 3.769457880941661*^9, 3.769457913731599*^9, 
   3.7699689769458103`*^9, 3.7715265018108788`*^9, 3.7715266090332203`*^9, 
   3.771526736779524*^9, {3.771526772209893*^9, 3.771526823657448*^9}, 
   3.771526941803445*^9, 3.771527014429962*^9, {3.771527051523841*^9, 
   3.771527077381094*^9}, 3.771527116910943*^9, 3.782259132604218*^9, 
   3.7822748690707903`*^9, {3.7822750034908743`*^9, 3.782275030077466*^9}, 
   3.7849048738893023`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exact", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
     RowBox[{"prescuem", "[", 
      RowBox[{"m1", ",", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"critical", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"0", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     SqrtBox[
      RowBox[{"2", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}]], 
     RowBox[{"HeavisideTheta", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m1", "+", "pr0"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"pr0", "-", "m1"}], ")"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"subcritical", "=", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], 
     RowBox[{"Abs", "[", "m1", "]"}]], 
    RowBox[{"HeavisideTheta", "[", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "m1"}], "-", "pr0"}], ")"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"supercritical", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
     FractionBox[
      RowBox[{" ", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], 
      RowBox[{"Abs", "[", "m1", "]"}]], 
     RowBox[{"HeavisideTheta", "[", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "pr0"}], ")"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"total", "=", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{"exact", ",", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "mwt", ",", "0.1"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figS2b", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Plot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"subcritical", "/", "total"}], ",", 
         RowBox[{"critical", "/", "total"}], ",", 
         RowBox[{"supercritical", "/", "total"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ","}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameTicksStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontColor", "\[Rule]", "White"}], ",", "Automatic", ",", 
          "Automatic", ",", "Automatic"}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<\!\(\*
StyleBox[\"U\",
FontSlant->\"Italic\"]\)=\!\(\*SuperscriptBox[\(10\), \(-3\)]\)\>\"", ",", 
              "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             ",", 
            RowBox[{"Scaled", "@", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"7", "/", "8"}], ",", 
               RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<B\>\"", ",", "14", ",", "Bold", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             ",", 
            RowBox[{"Scaled", "@", 
             RowBox[{"{", 
              RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}], "}"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"exact", "/", "total"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Black"}], "]"}]}], ",", 
       RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}]}], 
      RowBox[{"(*", 
       RowBox[{",", 
        RowBox[{"Filling", "\[Rule]", "Bottom"}]}], "*)"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7510622484477882`*^9, 3.7510623899214077`*^9}, {
   3.751062473276165*^9, 3.751062530490876*^9}, 3.751062563427968*^9, {
   3.751062594941642*^9, 3.7510626740085497`*^9}, {3.751062706742158*^9, 
   3.7510627719753103`*^9}, {3.751062825650064*^9, 3.751062839069113*^9}, {
   3.751062891684408*^9, 3.7510628936156187`*^9}, {3.751062951583514*^9, 
   3.7510629518293257`*^9}, {3.7510751327453938`*^9, 3.751075187438393*^9}, {
   3.751075227865163*^9, 3.751075253129315*^9}, {3.751075331833404*^9, 
   3.751075338861655*^9}, {3.751075400453147*^9, 3.7510754285434923`*^9}, {
   3.7510760676115513`*^9, 3.751076171924214*^9}, {3.7510762608235283`*^9, 
   3.751076261191457*^9}, {3.751076340797235*^9, 3.751076362147587*^9}, {
   3.75107872574929*^9, 3.751078735003438*^9}, {3.7606353531207438`*^9, 
   3.760635473464669*^9}, {3.760635743957357*^9, 3.7606360112862873`*^9}, {
   3.760636222903706*^9, 3.7606362356929493`*^9}, 3.7606370488778877`*^9, {
   3.76063722165112*^9, 3.760637246088497*^9}, {3.760637445638267*^9, 
   3.7606374759641323`*^9}, {3.7694559777693167`*^9, 3.769455990057811*^9}, {
   3.7694569368878*^9, 3.76945697017407*^9}, {3.769457006541617*^9, 
   3.769457018431264*^9}, {3.7694570715595617`*^9, 3.769457078541491*^9}, {
   3.769457119168889*^9, 3.769457125760105*^9}, 3.769457241097843*^9, 
   3.769457672075338*^9, 3.7694591418340282`*^9, {3.769968961761126*^9, 
   3.7699689960727253`*^9}, 3.771526494843226*^9, {3.771527067805583*^9, 
   3.771527074068317*^9}, {3.771527135370178*^9, 3.771527153239704*^9}, 
   3.771527331092053*^9, {3.782259087974625*^9, 3.782259090920125*^9}, {
   3.7822748264482193`*^9, 3.782274826655416*^9}, {3.784904857275097*^9, 
   3.784904865316122*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJztlnk01esehx0HocHQRsaixAkZSuLQ923QCVFJkiGuKRXKGMmQOKic0GCI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    "], {{{}, 
      {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{1, 247, 66, 93, 38, 97, 53, 80, 16, 99, 65, 92, 37, 96, 
         52, 79, 15, 98, 64, 91, 36, 95, 51, 78, 14, 63, 90, 35, 50, 77, 13, 
         62, 89, 34, 49, 76, 12, 11, 10, 9, 33, 48, 75, 8, 32, 47, 74, 7, 61, 
         88, 31, 46, 73, 6, 60, 87, 30, 45, 72, 5, 59, 86, 29, 44, 71, 4, 58, 
         85, 28, 43, 70, 3, 57, 84, 27, 42, 69, 2, 56, 83, 26, 41, 
         68}}]]}, {}, 
      {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{150, 130, 154, 136, 146, 118, 155, 140}}]]}, {}, 
      {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{230, 246, 181, 245, 210, 229, 191, 237, 201, 220, 180, 
         244, 209, 228, 190, 236, 200, 219, 179, 243, 208, 227, 189, 235, 199,
          218, 178, 242, 207, 226, 188, 234, 198, 217, 177, 241, 206, 225, 
         187, 233, 197, 216, 176, 240, 205, 224, 186, 232, 196, 215, 175, 239,
          204, 223, 185, 231, 195, 214, 174, 238, 203, 222, 
         184}}]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
      {Hue[0.67, 0.6, 0.6], 
       LineBox[{1, 68, 41, 26, 83, 56, 2, 69, 42, 27, 84, 57, 3, 70, 43, 28, 
        85, 58, 4, 71, 44, 29, 86, 59, 5, 72, 45, 30, 87, 60, 6, 73, 46, 31, 
        88, 61, 7, 74, 47, 32, 8, 75, 48, 33, 9, 10, 11, 12, 76, 49, 34, 89, 
        62, 13, 77, 50, 35, 90, 63, 14, 78, 51, 95, 36, 91, 64, 98, 15, 79, 
        52, 96, 37, 92, 65, 99, 16, 80, 53, 97, 38, 93, 66, 100, 17, 81, 54, 
        39, 18, 19, 20, 21, 22, 23, 24, 82, 55, 40, 94, 67, 101, 25}]}, 
      {Hue[0.9060679774997897, 0.6, 0.6], 
       LineBox[{102, 143, 133, 127, 103, 104, 105, 106, 107, 108, 109, 110, 
        111, 112, 113, 114, 115, 116, 144, 134, 128, 149, 139, 117, 145, 135, 
        153, 129, 150, 140, 155, 118, 146, 136, 154, 130, 151, 141, 119, 147, 
        137, 131, 120, 121, 122, 123, 124, 125, 148, 138, 132, 152, 142, 156, 
        126}]}, 
      {Hue[0.1421359549995791, 0.6, 0.6], 
       LineBox[{157, 211, 192, 182, 158, 159, 160, 161, 162, 163, 164, 165, 
        166, 167, 168, 169, 170, 171, 172, 212, 193, 183, 221, 202, 173, 213, 
        194, 230, 184, 222, 203, 238, 174, 214, 195, 231, 185, 223, 204, 239, 
        175, 215, 196, 232, 186, 224, 205, 240, 176, 216, 197, 233, 187, 225, 
        206, 241, 177, 217, 198, 234, 188, 226, 207, 242, 178, 218, 199, 235, 
        189, 227, 208, 243, 179, 219, 200, 236, 190, 228, 209, 244, 180, 220, 
        201, 237, 191, 229, 210, 245, 181}]}}}], {{}, {}, 
    {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwV1Pc/FfofwHGJQsrIDolQHBVdM7w/6qqvUC6ySipkJBchJGRkpZKyVwcn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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"\\!\\(\\*\\nStyleBox[\\\"U\\\",\\nFontSlant->\\\"Italic\\\"]\\)=\\!\\\
(\\*SuperscriptBox[\\(10\\), \\(-3\\)]\\)\"", 12, FontFamily -> "Helvetica", 
       StripOnInput -> False], TraditionalForm], 
     NCache[
      Scaled[{
        Rational[7, 8], 
        Rational[3, 4]}], 
      Scaled[{0.875, 0.75}]]], 
    InsetBox[
     FormBox[
      StyleBox[
      "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
      TraditionalForm], 
     Scaled[{0.05, 0.95}]]},
  Frame->{True, False, False, False},
  FrameLabel->{None, None},
  FrameTicksStyle->{
   FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{"AxesInFront" -> True},
  PlotRange->{{-0.2, 0.1}, {0, 70}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{
  3.751076169745583*^9, 3.751076212624262*^9, 3.751076302304141*^9, 
   3.751076439674859*^9, 3.751078915891127*^9, 3.7606362768960953`*^9, 
   3.7606363620987587`*^9, 3.7606366101685753`*^9, 3.760636668714695*^9, 
   3.7606367924425*^9, 3.760636832628543*^9, 3.760636873685384*^9, 
   3.760636919837865*^9, 3.7606369726718407`*^9, 3.760637164098074*^9, 
   3.760637652707996*^9, 3.769456216800243*^9, {3.769456956128572*^9, 
   3.7694569830553913`*^9}, 3.769457030930669*^9, 3.769457089652773*^9, 
   3.76945713739599*^9, 3.769457252052031*^9, 3.76945768728054*^9, 
   3.769968989580216*^9, 3.771527181370056*^9, 3.782259153856691*^9, {
   3.7822698016659327`*^9, 3.782269830504139*^9}, 3.782274838626471*^9, 
   3.782274889259521*^9, 3.784904892445694*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"U", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "2"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exact", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
     RowBox[{"prescuem", "[", 
      RowBox[{"m1", ",", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"critical", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"0", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     SqrtBox[
      RowBox[{"2", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}]], 
     RowBox[{"HeavisideTheta", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m1", "+", "pr0"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"pr0", "-", "m1"}], ")"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"subcritical", "=", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], 
     RowBox[{"Abs", "[", "m1", "]"}]], 
    RowBox[{"HeavisideTheta", "[", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "m1"}], "-", "pr0"}], ")"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"supercritical", "=", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], 
     RowBox[{"Abs", "[", "m1", "]"}]], 
    RowBox[{"HeavisideTheta", "[", 
     RowBox[{"(", 
      RowBox[{"m1", "-", "pr0"}], ")"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"total", "=", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{"exact", ",", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "mwt", ",", "0.1"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figS2c", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Plot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"subcritical", "/", "total"}], ",", 
         RowBox[{"critical", "/", "total"}], ",", 
         RowBox[{"supercritical", "/", "total"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<Growth rate\>\"", ",", "\"\<\>\""}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Epilog", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<\!\(\*
StyleBox[\"U\",
FontSlant->\"Italic\"]\)=\!\(\*SuperscriptBox[\(10\), \(-2\)]\)\>\"", ",", 
              "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             ",", 
            RowBox[{"Scaled", "@", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"7", "/", "8"}], ",", 
               RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
          RowBox[{"Text", "[", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<C\>\"", ",", "14", ",", "Bold", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             ",", 
            RowBox[{"Scaled", "@", 
             RowBox[{"{", 
              RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}], "}"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"exact", "/", "total"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Black"}], "]"}]}], ",", 
       RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7510622484477882`*^9, 3.7510623899214077`*^9}, {
   3.751062473276165*^9, 3.751062530490876*^9}, 3.751062563427968*^9, {
   3.751062594941642*^9, 3.7510626740085497`*^9}, {3.751062706742158*^9, 
   3.7510627719753103`*^9}, {3.751062825650064*^9, 3.751062839069113*^9}, {
   3.751062891684408*^9, 3.7510628936156187`*^9}, {3.751062951583514*^9, 
   3.7510629518293257`*^9}, {3.7510751327453938`*^9, 3.751075187438393*^9}, {
   3.751075227865163*^9, 3.751075253129315*^9}, {3.751075331833404*^9, 
   3.751075338861655*^9}, {3.751075400453147*^9, 3.7510754285434923`*^9}, {
   3.7510760676115513`*^9, 3.751076171924214*^9}, {3.7510762608235283`*^9, 
   3.751076261191457*^9}, {3.751076340797235*^9, 3.751076362147587*^9}, {
   3.75107872574929*^9, 3.751078735003438*^9}, {3.7606353531207438`*^9, 
   3.760635473464669*^9}, {3.760635743957357*^9, 3.7606360112862873`*^9}, {
   3.760636222903706*^9, 3.7606362356929493`*^9}, {3.760637523556905*^9, 
   3.760637523847105*^9}, 3.76945600846598*^9, {3.7694564256636047`*^9, 
   3.769456544267025*^9}, {3.7694570015070553`*^9, 3.769457029726619*^9}, {
   3.769457259507011*^9, 3.769457372290498*^9}, {3.769457421859777*^9, 
   3.7694574856791353`*^9}, {3.7694575345579243`*^9, 3.7694575414890537`*^9}, 
   3.769457592474533*^9, {3.769457646555657*^9, 3.769457646898512*^9}, 
   3.769459145894307*^9, {3.769968973567841*^9, 3.7699690034492283`*^9}, {
   3.771527181786672*^9, 3.771527234795993*^9}, 3.7715273253275337`*^9, 
   3.782259083007683*^9, {3.7849048710886803`*^9, 3.784904879193561*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJztlns01GkfwK1ch0pyC6lcGomKthWrvo9Km6aytagtQihKis0k7SIRsraN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    "], {{{}, 
      {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{1, 235, 16, 93, 63, 88, 37, 91, 51, 76, 15, 92, 62, 87, 
         36, 90, 50, 75, 14, 61, 86, 35, 49, 74, 13, 60, 85, 34, 48, 73, 12, 
         11, 10, 9, 33, 47, 72, 8, 32, 46, 71, 7, 59, 84, 31, 45, 70, 6, 58, 
         83, 30, 44, 69, 5, 57, 82, 29, 43, 68, 4, 56, 81, 28, 42, 67, 3, 55, 
         80, 27, 41, 66, 2, 54, 79, 26, 40, 65}}]]}, {}, 
      {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{150, 125, 149, 131, 141, 112, 124, 111, 123, 
         110}}]]}, {}, 
      {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{220, 234, 176, 233, 202, 219, 185, 226, 194, 211, 175, 
         232, 201, 218, 184, 225, 193, 210, 174, 231, 200, 217, 183, 224, 192,
          209, 173, 230, 199, 216, 182, 223, 191, 208, 172, 229, 198, 215, 
         181, 222, 190, 207, 171, 228, 197, 214, 180, 221, 189, 206, 170, 227,
          196, 213, 
         179}}]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
      {Hue[0.67, 0.6, 0.6], 
       LineBox[{1, 65, 40, 26, 79, 54, 2, 66, 41, 27, 80, 55, 3, 67, 42, 28, 
        81, 56, 4, 68, 43, 29, 82, 57, 5, 69, 44, 30, 83, 58, 6, 70, 45, 31, 
        84, 59, 7, 71, 46, 32, 8, 72, 47, 33, 9, 10, 11, 12, 73, 48, 34, 85, 
        60, 13, 74, 49, 35, 86, 61, 14, 75, 50, 90, 36, 87, 62, 92, 15, 76, 
        51, 91, 37, 88, 63, 93, 16, 77, 52, 38, 17, 18, 19, 20, 21, 22, 23, 
        24, 78, 53, 39, 89, 64, 94, 25}]}, 
      {Hue[0.9060679774997897, 0.6, 0.6], 
       LineBox[{95, 138, 128, 120, 96, 97, 98, 99, 100, 101, 102, 103, 104, 
        105, 106, 107, 108, 139, 129, 121, 144, 134, 109, 140, 130, 148, 122, 
        145, 135, 150, 110, 123, 111, 124, 112, 141, 131, 149, 125, 146, 136, 
        113, 142, 132, 126, 114, 115, 116, 117, 118, 143, 133, 127, 147, 137, 
        151, 119}]}, 
      {Hue[0.1421359549995791, 0.6, 0.6], 
       LineBox[{152, 203, 186, 177, 153, 154, 155, 156, 157, 158, 159, 160, 
        161, 162, 163, 164, 165, 166, 167, 168, 204, 187, 178, 212, 195, 169, 
        205, 188, 220, 179, 213, 196, 227, 170, 206, 189, 221, 180, 214, 197, 
        228, 171, 207, 190, 222, 181, 215, 198, 229, 172, 208, 191, 223, 182, 
        216, 199, 230, 173, 209, 192, 224, 183, 217, 200, 231, 174, 210, 193, 
        225, 184, 218, 201, 232, 175, 211, 194, 226, 185, 219, 202, 233, 
        176}]}}}], {{}, {}, 
    {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwVz3c8FP4fwPH7ZWQVFUK2hJBRVuH9oRBpCYVsh0rDTBQKIam4zFTc6ULX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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"\\!\\(\\*\\nStyleBox[\\\"U\\\",\\nFontSlant->\\\"Italic\\\"]\\)=\\!\\\
(\\*SuperscriptBox[\\(10\\), \\(-2\\)]\\)\"", 12, FontFamily -> "Helvetica", 
       StripOnInput -> False], TraditionalForm], 
     NCache[
      Scaled[{
        Rational[7, 8], 
        Rational[3, 4]}], 
      Scaled[{0.875, 0.75}]]], 
    InsetBox[
     FormBox[
      StyleBox[
      "\"C\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
      TraditionalForm], 
     Scaled[{0.05, 0.95}]]},
  Frame->{True, False, False, False},
  FrameLabel->{{
     FormBox["\"\"", TraditionalForm], None}, {
     FormBox["\"Growth rate\"", TraditionalForm], None}},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{"AxesInFront" -> True},
  PlotRange->{{-0.2, 0.1}, {0, 70}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{
  3.760637691046157*^9, 3.769456392932271*^9, 3.769456544922377*^9, 
   3.7694565882466917`*^9, {3.769457322143525*^9, 3.769457382753418*^9}, 
   3.7694575792066*^9, 3.7694576192016373`*^9, 3.769457658977379*^9, 
   3.769969000998363*^9, 3.7715272074302597`*^9, 3.771527253710305*^9, 
   3.782259171447166*^9, 3.7822698487892513`*^9, 3.784904907887785*^9}]
}, Closed]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"ymax", ",", "xmin", ",", "xmax"}], "]"}]], "Input",
 CellChangeTimes->{{3.77152734307722*^9, 3.771527354154502*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GraphicsColumn", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"figS2a", ",", "figS2b", ",", "figS2c"}], "}"}], ",", 
   RowBox[{"Spacings", "\[Rule]", 
    RowBox[{"-", "30"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{"supfigdir", "<>", "\"\<FigureS2.eps\>\""}], ",", "%"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.784904899089479*^9, 3.784904918187162*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     FormBox[
      TagBox[
       FormBox[
        GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJztlXkw1Xsfx5UlSjlZTg7STddyhUqPpOTzpZtL5JaEtJDlkixFilQUsnVK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            "], {{{}, 
              {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
               GraphicsGroupBox[
                PolygonBox[{{1, 248, 17, 100, 66, 93, 38, 97, 53, 80, 16, 99, 
                 65, 92, 37, 96, 52, 79, 15, 98, 64, 91, 36, 95, 51, 78, 14, 
                 63, 90, 35, 50, 77, 13, 62, 89, 34, 49, 76, 12, 11, 10, 9, 
                 33, 48, 75, 8, 32, 47, 74, 7, 61, 88, 31, 46, 73, 6, 60, 87, 
                 30, 45, 72, 5, 59, 86, 29, 44, 71, 4, 58, 85, 28, 43, 70, 3, 
                 57, 84, 27, 42, 69, 2, 56, 83, 26, 41, 68}}]]}, {}, 
              {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[
               None], GraphicsGroupBox[
                PolygonBox[{{155, 136, 146, 118}}]]}, {}, 
              {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[
               None], GraphicsGroupBox[
                PolygonBox[{{213, 247, 181, 246, 210, 229, 191, 237, 201, 220,
                  180, 245, 209, 228, 190, 236, 200, 219, 179, 244, 208, 227, 
                 189, 235, 199, 218, 178, 243, 207, 226, 188, 234, 198, 217, 
                 177, 242, 206, 225, 187, 233, 197, 216, 176, 241, 205, 224, 
                 186, 232, 196, 215, 175, 240, 204, 223, 185, 231, 195, 214, 
                 174, 239, 203, 222, 184, 230, 
                 194}}]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, \
{{}, {}, 
              {Hue[0.67, 0.6, 0.6], 
               LineBox[{1, 68, 41, 26, 83, 56, 2, 69, 42, 27, 84, 57, 3, 70, 
                43, 28, 85, 58, 4, 71, 44, 29, 86, 59, 5, 72, 45, 30, 87, 60, 
                6, 73, 46, 31, 88, 61, 7, 74, 47, 32, 8, 75, 48, 33, 9, 10, 
                11, 12, 76, 49, 34, 89, 62, 13, 77, 50, 35, 90, 63, 14, 78, 
                51, 95, 36, 91, 64, 98, 15, 79, 52, 96, 37, 92, 65, 99, 16, 
                80, 53, 97, 38, 93, 66, 100, 17, 81, 54, 39, 18, 19, 20, 21, 
                22, 23, 24, 82, 55, 40, 94, 67, 101, 25}]}, 
              {Hue[0.9060679774997897, 0.6, 0.6], 
               LineBox[{102, 143, 133, 127, 103, 104, 105, 106, 107, 108, 109,
                 110, 111, 112, 113, 114, 115, 116, 144, 134, 128, 149, 139, 
                117, 145, 135, 153, 129, 150, 140, 155, 118, 146, 136, 154, 
                130, 151, 141, 119, 147, 137, 131, 120, 121, 122, 123, 124, 
                125, 148, 138, 132, 152, 142, 156, 126}]}, 
              {Hue[0.1421359549995791, 0.6, 0.6], 
               LineBox[{157, 211, 192, 182, 158, 159, 160, 161, 162, 163, 164,
                 165, 166, 167, 168, 169, 170, 171, 172, 212, 193, 183, 221, 
                202, 238, 173, 213, 194, 230, 184, 222, 203, 239, 174, 214, 
                195, 231, 185, 223, 204, 240, 175, 215, 196, 232, 186, 224, 
                205, 241, 176, 216, 197, 233, 187, 225, 206, 242, 177, 217, 
                198, 234, 188, 226, 207, 243, 178, 218, 199, 235, 189, 227, 
                208, 244, 179, 219, 200, 236, 190, 228, 209, 245, 180, 220, 
                201, 237, 191, 229, 210, 246, 181}]}}}], {{}, {}, 
            {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwVxXk8FGgfAPBZJINyhCjZsCPr2NKGCL9HRW/J1ObIK1cokmxEq2xRw7oW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              "]]}}}, {InsetBox[
            
            TemplateBox[{
             StyleBox[
              "\"subcritical\"", StripOnInput -> False, FontFamily -> 
               "Helvetica", FontSize -> 12],StyleBox[
              "\"critical\"", StripOnInput -> False, FontFamily -> 
               "Helvetica", FontSize -> 12],StyleBox[
              "\"supercritical\"", StripOnInput -> False, FontFamily -> 
               "Helvetica", FontSize -> 12]},
             "SwatchLegend",
             DisplayFunction->(StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
               False]& ),
             Editable->True,
             InterpretationFunction:>(RowBox[{"SwatchLegend", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.24720000000000014`", ",", "0.24`", ",", 
                    "0.6`"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.6`", ",", "0.24`", ",", 
                    "0.4428931686004542`"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.6`", ",", "0.5470136627990908`", ",", 
                    "0.24`"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}]}], "}"}], 
                  ",", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                  RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                "]"}]& )], NCache[
            Scaled[{Rational[1, 8], 0.5}], Scaled[{0.125, 0.5}]], 
            ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm], InsetBox[
            
            TemplateBox[{
             StyleBox[
              "\"first-step\"", StripOnInput -> False, FontFamily -> 
               "Helvetica", FontSize -> 12]},
             "LineLegend",
             DisplayFunction->(StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, 
                   GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
               False]& ),
             Editable->True,
             InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], "}"}], ",", 
                  RowBox[{"{", #, "}"}], ",", 
                  RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                "]"}]& )], NCache[
            Scaled[{Rational[1, 8], 0.7}], Scaled[{0.125, 0.7}]], 
            ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm]}},
         AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
         Axes->True,
         AxesOrigin->{0, 0},
         Epilog->{
           InsetBox[
            FormBox[
             StyleBox[
             "\"\\!\\(\\*\\nStyleBox[\\\"U\\\",\\nFontSlant->\\\"Italic\\\"]\\\
)=\\!\\(\\*SuperscriptBox[\\(10\\), \\(-4\\)]\\)\"", 12, FontFamily -> 
              "Helvetica", StripOnInput -> False], TraditionalForm], 
            NCache[
             Scaled[{
               Rational[7, 8], 
               Rational[3, 4]}], 
             Scaled[{0.875, 0.75}]]], 
           InsetBox[
            FormBox[
             StyleBox[
             "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
              False], TraditionalForm], 
            Scaled[{0.05, 0.95}]]},
         Frame->{True, False, False, False},
         FrameLabel->{None, None},
         FrameTicksStyle->{
          FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
         LabelStyle->Directive[12, FontFamily -> "Helvetica"],
         Method->{"AxesInFront" -> True},
         PlotRange->{{-0.2, 0.1}, {0, 70}},
         PlotRangeClipping->True,
         PlotRangePadding->{
           Scaled[0.02], Automatic}],
        TraditionalForm],
       InterpretTemplate[Legended[
         Graphics[{
           GraphicsComplex[CompressedData["
1:eJztlXkw1Xsfx5UlSjlZTg7STddyhUqPpOTzpZtL5JaEtJDlkixFilQUsnVK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            "], {{{}, {
               EdgeForm[], 
               Directive[{
                 Opacity[0.2], 
                 Hue[0.67, 0.6, 0.6]}], 
               GraphicsGroup[{
                 
                 Polygon[{{1, 248, 17, 100, 66, 93, 38, 97, 53, 80, 16, 99, 
                  65, 92, 37, 96, 52, 79, 15, 98, 64, 91, 36, 95, 51, 78, 14, 
                  63, 90, 35, 50, 77, 13, 62, 89, 34, 49, 76, 12, 11, 10, 9, 
                  33, 48, 75, 8, 32, 47, 74, 7, 61, 88, 31, 46, 73, 6, 60, 87,
                   30, 45, 72, 5, 59, 86, 29, 44, 71, 4, 58, 85, 28, 43, 70, 
                  3, 57, 84, 27, 42, 69, 2, 56, 83, 26, 41, 68}}]}]}, {}, {
               EdgeForm[], 
               Directive[{
                 Opacity[0.2], 
                 Hue[0.9060679774997897, 0.6, 0.6]}], 
               GraphicsGroup[{
                 Polygon[{{155, 136, 146, 118}}]}]}, {}, {
               EdgeForm[], 
               Directive[{
                 Opacity[0.2], 
                 Hue[0.1421359549995791, 0.6, 0.6]}], 
               GraphicsGroup[{
                 
                 Polygon[{{213, 247, 181, 246, 210, 229, 191, 237, 201, 220, 
                  180, 245, 209, 228, 190, 236, 200, 219, 179, 244, 208, 227, 
                  189, 235, 199, 218, 178, 243, 207, 226, 188, 234, 198, 217, 
                  177, 242, 206, 225, 187, 233, 197, 216, 176, 241, 205, 224, 
                  186, 232, 196, 215, 175, 240, 204, 223, 185, 231, 195, 214, 
                  174, 239, 203, 222, 184, 230, 
                  194}}]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, \
{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               
               Line[{1, 68, 41, 26, 83, 56, 2, 69, 42, 27, 84, 57, 3, 70, 43, 
                28, 85, 58, 4, 71, 44, 29, 86, 59, 5, 72, 45, 30, 87, 60, 6, 
                73, 46, 31, 88, 61, 7, 74, 47, 32, 8, 75, 48, 33, 9, 10, 11, 
                12, 76, 49, 34, 89, 62, 13, 77, 50, 35, 90, 63, 14, 78, 51, 
                95, 36, 91, 64, 98, 15, 79, 52, 96, 37, 92, 65, 99, 16, 80, 
                53, 97, 38, 93, 66, 100, 17, 81, 54, 39, 18, 19, 20, 21, 22, 
                23, 24, 82, 55, 40, 94, 67, 101, 25}]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               
               Line[{102, 143, 133, 127, 103, 104, 105, 106, 107, 108, 109, 
                110, 111, 112, 113, 114, 115, 116, 144, 134, 128, 149, 139, 
                117, 145, 135, 153, 129, 150, 140, 155, 118, 146, 136, 154, 
                130, 151, 141, 119, 147, 137, 131, 120, 121, 122, 123, 124, 
                125, 148, 138, 132, 152, 142, 156, 126}]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               
               Line[{157, 211, 192, 182, 158, 159, 160, 161, 162, 163, 164, 
                165, 166, 167, 168, 169, 170, 171, 172, 212, 193, 183, 221, 
                202, 238, 173, 213, 194, 230, 184, 222, 203, 239, 174, 214, 
                195, 231, 185, 223, 204, 240, 175, 215, 196, 232, 186, 224, 
                205, 241, 176, 216, 197, 233, 187, 225, 206, 242, 177, 217, 
                198, 234, 188, 226, 207, 243, 178, 218, 199, 235, 189, 227, 
                208, 244, 179, 219, 200, 236, 190, 228, 209, 245, 180, 220, 
                201, 237, 191, 229, 210, 246, 181}]}}}], {{{}, {}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               Thickness[Large], 
               GrayLevel[0]], 
              Line[CompressedData["
1:eJwVxXk8FGgfAPBZJINyhCjZsCPr2NKGCL9HRW/J1ObIK1cokmxEq2xRw7oW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               "]]}}}}, {
          PlotRange -> {{-0.2, 0.1}, {0, 70}}, AspectRatio -> 
           GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0, 0}, Epilog -> {
             Text[
              Style[
              "\!\(\*\nStyleBox[\"U\",\n\
FontSlant->\"Italic\"]\)=\!\(\*SuperscriptBox[\(10\), \(-4\)]\)", 12, 
               FontFamily -> "Helvetica"], 
              Scaled[{
                Rational[7, 8], 
                Rational[3, 4]}]], 
             Text[
              Style["A", 14, Bold, FontFamily -> "Helvetica"], 
              Scaled[{0.05, 0.95}]]}, Frame -> {True, False, False, False}, 
           FrameLabel -> {None, None}, 
           FrameTicksStyle -> {
            FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, 
           LabelStyle -> Directive[12, FontFamily -> "Helvetica"], 
           Method -> {"AxesInFront" -> True}, 
           PlotRange -> {{-0.2, 0.1}, {0, All}}, PlotRangeClipping -> True, 
           PlotRangePadding -> {
             Scaled[0.02], Automatic}}], {
          Placed[
           Unevaluated[
            LineLegend[{
              Directive[
               Thickness[Large], 
               GrayLevel[0]]}, {
              Style["first-step", 12, FontFamily -> "Helvetica"]}, 
             LegendLayout -> "Column"]], 
           Scaled[{
             Rational[1, 8], 0.7}], Identity]}]& ],
       AutoDelete->True,
       Editable->True,
       SelectWithContents->False,
       Selectable->True],
      TraditionalForm], {189., -119.16407864998737`}, {
     Center, Center}, {360., 268.32815729997475`}], InsetBox[
     GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJztlnk01esehx0HocHQRsaixAkZSuLQ923QCVFJkiGuKRXKGMmQOKic0GCI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        "], {{{}, 
          {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
           GraphicsGroupBox[
            PolygonBox[{{1, 247, 66, 93, 38, 97, 53, 80, 16, 99, 65, 92, 37, 
             96, 52, 79, 15, 98, 64, 91, 36, 95, 51, 78, 14, 63, 90, 35, 50, 
             77, 13, 62, 89, 34, 49, 76, 12, 11, 10, 9, 33, 48, 75, 8, 32, 47,
              74, 7, 61, 88, 31, 46, 73, 6, 60, 87, 30, 45, 72, 5, 59, 86, 29,
              44, 71, 4, 58, 85, 28, 43, 70, 3, 57, 84, 27, 42, 69, 2, 56, 83,
              26, 41, 68}}]]}, {}, 
          {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
           GraphicsGroupBox[
            PolygonBox[{{150, 130, 154, 136, 146, 118, 155, 140}}]]}, {}, 
          {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
           GraphicsGroupBox[
            PolygonBox[{{230, 246, 181, 245, 210, 229, 191, 237, 201, 220, 
             180, 244, 209, 228, 190, 236, 200, 219, 179, 243, 208, 227, 189, 
             235, 199, 218, 178, 242, 207, 226, 188, 234, 198, 217, 177, 241, 
             206, 225, 187, 233, 197, 216, 176, 240, 205, 224, 186, 232, 196, 
             215, 175, 239, 204, 223, 185, 231, 195, 214, 174, 238, 203, 222, 
             184}}]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, \
{}, 
          {Hue[0.67, 0.6, 0.6], 
           LineBox[{1, 68, 41, 26, 83, 56, 2, 69, 42, 27, 84, 57, 3, 70, 43, 
            28, 85, 58, 4, 71, 44, 29, 86, 59, 5, 72, 45, 30, 87, 60, 6, 73, 
            46, 31, 88, 61, 7, 74, 47, 32, 8, 75, 48, 33, 9, 10, 11, 12, 76, 
            49, 34, 89, 62, 13, 77, 50, 35, 90, 63, 14, 78, 51, 95, 36, 91, 
            64, 98, 15, 79, 52, 96, 37, 92, 65, 99, 16, 80, 53, 97, 38, 93, 
            66, 100, 17, 81, 54, 39, 18, 19, 20, 21, 22, 23, 24, 82, 55, 40, 
            94, 67, 101, 25}]}, 
          {Hue[0.9060679774997897, 0.6, 0.6], 
           LineBox[{102, 143, 133, 127, 103, 104, 105, 106, 107, 108, 109, 
            110, 111, 112, 113, 114, 115, 116, 144, 134, 128, 149, 139, 117, 
            145, 135, 153, 129, 150, 140, 155, 118, 146, 136, 154, 130, 151, 
            141, 119, 147, 137, 131, 120, 121, 122, 123, 124, 125, 148, 138, 
            132, 152, 142, 156, 126}]}, 
          {Hue[0.1421359549995791, 0.6, 0.6], 
           LineBox[{157, 211, 192, 182, 158, 159, 160, 161, 162, 163, 164, 
            165, 166, 167, 168, 169, 170, 171, 172, 212, 193, 183, 221, 202, 
            173, 213, 194, 230, 184, 222, 203, 238, 174, 214, 195, 231, 185, 
            223, 204, 239, 175, 215, 196, 232, 186, 224, 205, 240, 176, 216, 
            197, 233, 187, 225, 206, 241, 177, 217, 198, 234, 188, 226, 207, 
            242, 178, 218, 199, 235, 189, 227, 208, 243, 179, 219, 200, 236, 
            190, 228, 209, 244, 180, 220, 201, 237, 191, 229, 210, 245, 
            181}]}}}], {{}, {}, 
        {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwV1Pc/FfofwHGJQsrIDolQHBVdM7w/6qqvUC6ySipkJBchJGRkpZKyVwcn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          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Epilog->{
        InsetBox[
         FormBox[
          StyleBox[
          "\"\\!\\(\\*\\nStyleBox[\\\"U\\\",\\nFontSlant->\\\"Italic\\\"]\\)=\
\\!\\(\\*SuperscriptBox[\\(10\\), \\(-3\\)]\\)\"", 12, FontFamily -> 
           "Helvetica", StripOnInput -> False], TraditionalForm], 
         NCache[
          Scaled[{
            Rational[7, 8], 
            Rational[3, 4]}], 
          Scaled[{0.875, 0.75}]]], 
        InsetBox[
         FormBox[
          StyleBox[
          "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
           False], TraditionalForm], 
         Scaled[{0.05, 0.95}]]},
      Frame->{True, False, False, False},
      FrameLabel->{None, None},
      FrameTicksStyle->{
       FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
      LabelStyle->Directive[12, FontFamily -> "Helvetica"],
      Method->{"AxesInFront" -> True},
      PlotRange->{{-0.2, 0.1}, {0, 70}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], Automatic}], {189., -357.49223594996215`}, 
     ImageScaled[{0.5, 0.5}], {360., 268.32815729997475`}], InsetBox[
     GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJztlns01GkfwK1ch0pyC6lcGomKthWrvo9Km6aytagtQihKis0k7SIRsraN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        "], {{{}, 
          {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
           GraphicsGroupBox[
            PolygonBox[{{1, 235, 16, 93, 63, 88, 37, 91, 51, 76, 15, 92, 62, 
             87, 36, 90, 50, 75, 14, 61, 86, 35, 49, 74, 13, 60, 85, 34, 48, 
             73, 12, 11, 10, 9, 33, 47, 72, 8, 32, 46, 71, 7, 59, 84, 31, 45, 
             70, 6, 58, 83, 30, 44, 69, 5, 57, 82, 29, 43, 68, 4, 56, 81, 28, 
             42, 67, 3, 55, 80, 27, 41, 66, 2, 54, 79, 26, 40, 65}}]]}, {}, 
          {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
           GraphicsGroupBox[
            PolygonBox[{{150, 125, 149, 131, 141, 112, 124, 111, 123, 
             110}}]]}, {}, 
          {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
           GraphicsGroupBox[
            PolygonBox[{{220, 234, 176, 233, 202, 219, 185, 226, 194, 211, 
             175, 232, 201, 218, 184, 225, 193, 210, 174, 231, 200, 217, 183, 
             224, 192, 209, 173, 230, 199, 216, 182, 223, 191, 208, 172, 229, 
             198, 215, 181, 222, 190, 207, 171, 228, 197, 214, 180, 221, 189, 
             206, 170, 227, 196, 213, 
             179}}]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, \
{}, 
          {Hue[0.67, 0.6, 0.6], 
           LineBox[{1, 65, 40, 26, 79, 54, 2, 66, 41, 27, 80, 55, 3, 67, 42, 
            28, 81, 56, 4, 68, 43, 29, 82, 57, 5, 69, 44, 30, 83, 58, 6, 70, 
            45, 31, 84, 59, 7, 71, 46, 32, 8, 72, 47, 33, 9, 10, 11, 12, 73, 
            48, 34, 85, 60, 13, 74, 49, 35, 86, 61, 14, 75, 50, 90, 36, 87, 
            62, 92, 15, 76, 51, 91, 37, 88, 63, 93, 16, 77, 52, 38, 17, 18, 
            19, 20, 21, 22, 23, 24, 78, 53, 39, 89, 64, 94, 25}]}, 
          {Hue[0.9060679774997897, 0.6, 0.6], 
           LineBox[{95, 138, 128, 120, 96, 97, 98, 99, 100, 101, 102, 103, 
            104, 105, 106, 107, 108, 139, 129, 121, 144, 134, 109, 140, 130, 
            148, 122, 145, 135, 150, 110, 123, 111, 124, 112, 141, 131, 149, 
            125, 146, 136, 113, 142, 132, 126, 114, 115, 116, 117, 118, 143, 
            133, 127, 147, 137, 151, 119}]}, 
          {Hue[0.1421359549995791, 0.6, 0.6], 
           LineBox[{152, 203, 186, 177, 153, 154, 155, 156, 157, 158, 159, 
            160, 161, 162, 163, 164, 165, 166, 167, 168, 204, 187, 178, 212, 
            195, 169, 205, 188, 220, 179, 213, 196, 227, 170, 206, 189, 221, 
            180, 214, 197, 228, 171, 207, 190, 222, 181, 215, 198, 229, 172, 
            208, 191, 223, 182, 216, 199, 230, 173, 209, 192, 224, 183, 217, 
            200, 231, 174, 210, 193, 225, 184, 218, 201, 232, 175, 211, 194, 
            226, 185, 219, 202, 233, 176}]}}}], {{}, {}, 
        {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwVz3c8FP4fwPH7ZWQVFUK2hJBRVuH9oRBpCYVsh0rDTBQKIam4zFTc6ULX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          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      Epilog->{
        InsetBox[
         FormBox[
          StyleBox[
          "\"\\!\\(\\*\\nStyleBox[\\\"U\\\",\\nFontSlant->\\\"Italic\\\"]\\)=\
\\!\\(\\*SuperscriptBox[\\(10\\), \\(-2\\)]\\)\"", 12, FontFamily -> 
           "Helvetica", StripOnInput -> False], TraditionalForm], 
         NCache[
          Scaled[{
            Rational[7, 8], 
            Rational[3, 4]}], 
          Scaled[{0.875, 0.75}]]], 
        InsetBox[
         FormBox[
          StyleBox[
          "\"C\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
           False], TraditionalForm], 
         Scaled[{0.05, 0.95}]]},
      Frame->{True, False, False, False},
      FrameLabel->{{
         FormBox["\"\"", TraditionalForm], None}, {
         FormBox["\"Growth rate\"", TraditionalForm], None}},
      LabelStyle->Directive[12, FontFamily -> "Helvetica"],
      Method->{"AxesInFront" -> True},
      PlotRange->{{-0.2, 0.1}, {0, 70}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], Automatic}], {189., -595.8203932499368}, 
     ImageScaled[{0.5, 0.5}], {360., 268.3281572999748}]}, {}},
  ContentSelectable->True,
  ImageSize->350,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.784904919057825*^9}]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Kurtosis", "Section",
 CellChangeTimes->{{3.778607789007319*^9, 3.778607790452826*^9}}],

Cell[CellGroupData[{

Cell["Mutational distributions (figure S3A)", "Subsection",
 CellChangeTimes->{{3.7800683038791447`*^9, 3.780068329398244*^9}}],

Cell["\<\
Let\[CloseCurlyQuote]s compare our results when we take mutational \
distributions of phenotypic changes with the same mean (0), variance (\
\[Lambda]), and skewness (0), but different kurtosis. \
\>", "Text",
 CellChangeTimes->{{3.778608376862977*^9, 3.778608446743327*^9}, {
  3.778608484928484*^9, 3.77860850632126*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "4"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"phenotypic", " ", "dimensions"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Es", "=", "0.01"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"mean", " ", "mutational", " ", "selective", " ", "effect"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Lambda]", "=", 
    RowBox[{"2", 
     RowBox[{"Es", "/", "n"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"mutational", " ", "variance", " ", "per", " ", "trait"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"styl", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"styles", " ", "of", " ", "axes", " ", "and", " ", "legend"}], 
   "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"PDF", "[", 
     RowBox[{
      RowBox[{"WignerSemicircleDistribution", "[", 
       SqrtBox[
        RowBox[{"4", "\[Lambda]"}]], "]"}], ",", "z"}], "]"}], ",", 
    RowBox[{"PDF", "[", 
     RowBox[{
      RowBox[{"NormalDistribution", "[", 
       RowBox[{"0", ",", 
        SqrtBox["\[Lambda]"]}], "]"}], ",", "z"}], "]"}], ",", 
    RowBox[{"PDF", "[", 
     RowBox[{
      RowBox[{"LaplaceDistribution", "[", 
       RowBox[{"0", ",", 
        SqrtBox[
         RowBox[{"\[Lambda]", "/", "2"}]]}], "]"}], ",", "z"}], "]"}]}], 
   "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figS3a", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{"%", ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", 
       RowBox[{
        RowBox[{"-", "4"}], 
        SqrtBox["\[Lambda]"]}], ",", 
       RowBox[{"4", 
        SqrtBox["\[Lambda]"]}]}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", 
          RowBox[{"Dashing", "[", "Medium", "]"}], ",", "Black"}], "]"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Black"}], "]"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Dotted", ",", "Black"}], "]"}]}], "}"}]}], 
     ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "All"}], "}"}]}], ",", 
     RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", 
     RowBox[{"FillingStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", 
        RowBox[{"Opacity", "[", "0.1", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotLegends", "\[Rule]", 
      RowBox[{"Placed", "[", 
       RowBox[{
        RowBox[{"LineLegend", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"#", ",", "labelstyle"}], "]"}], "&"}], "/@", 
          RowBox[{"{", 
           RowBox[{
           "\"\<platykurtic\>\"", ",", "\"\<normal\>\"", ",", 
            "\"\<leptokurtic\>\""}], "}"}]}], "]"}], ",", 
        RowBox[{"Scaled", "@", 
         RowBox[{"{", 
          RowBox[{"0.8", ",", "0.8"}], "}"}]}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{
      "{", "\"\<\!\(\*SubscriptBox[\(\[CapitalDelta]z\), \(i\)]\)\>\"", 
       "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameStyle", "\[Rule]", "labelstyle"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<A\>\"", ",", "14", ",", "Bold", ",", 
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
         ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "n", ",", "Es", ",", "\[Lambda]", ",", "styl", ",", "platy", ",", "meso", 
   ",", "lepto"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.7307420178763027`*^9, {3.7307420919548197`*^9, 3.730742140080029*^9}, {
   3.7307422008167887`*^9, 3.730742486553404*^9}, {3.73074254252099*^9, 
   3.730742542642627*^9}, {3.730742794163145*^9, 3.730742934535372*^9}, {
   3.730743298153899*^9, 3.7307433631678457`*^9}, {3.730743401341844*^9, 
   3.730743417078063*^9}, {3.730748966693226*^9, 3.730749128539439*^9}, {
   3.73074920743021*^9, 3.730749247197057*^9}, {3.730749283260601*^9, 
   3.730749287719013*^9}, {3.730749324608781*^9, 3.730749557532645*^9}, {
   3.730749607062332*^9, 3.7307496118140507`*^9}, {3.730749696305119*^9, 
   3.7307497855057497`*^9}, {3.730749823597776*^9, 3.730749827582512*^9}, {
   3.730749898218234*^9, 3.73074989873744*^9}, {3.7307499646600657`*^9, 
   3.7307499884070253`*^9}, {3.730750031912035*^9, 3.730750078969554*^9}, {
   3.730750119330454*^9, 3.7307502945406437`*^9}, {3.7307503559230337`*^9, 
   3.730750356528187*^9}, {3.730750450656543*^9, 3.730750451401882*^9}, {
   3.7348754601204*^9, 3.734875488510385*^9}, {3.7348755208819923`*^9, 
   3.734875523114094*^9}, {3.734875560133151*^9, 3.734875561427981*^9}, {
   3.7348756385256166`*^9, 3.734875647924037*^9}, {3.7348757389675903`*^9, 
   3.7348758575465384`*^9}, {3.734875889176434*^9, 3.73487591157351*^9}, {
   3.734875949280768*^9, 3.734875950101717*^9}, {3.734876035305752*^9, 
   3.734876047580271*^9}, {3.7348761009733877`*^9, 3.734876101605463*^9}, 
   3.736600970204051*^9, {3.7438795693147993`*^9, 3.743879611828753*^9}, {
   3.77859833356594*^9, 3.778598491237404*^9}, {3.778598558616508*^9, 
   3.7785985675832443`*^9}, {3.778603743199943*^9, 3.778603981133185*^9}, {
   3.778604330804193*^9, 3.778604492668686*^9}, {3.7786045261689167`*^9, 
   3.778604612651762*^9}, {3.7786046602941*^9, 3.778604714927908*^9}, {
   3.778604762425007*^9, 3.7786047816627693`*^9}, {3.778604823814034*^9, 
   3.778604849602952*^9}, {3.7786069918549623`*^9, 3.778607334797833*^9}, {
   3.778607379783366*^9, 3.778607381023628*^9}, 3.77860748547569*^9, {
   3.778607610928849*^9, 3.7786077247925386`*^9}, {3.778607799883803*^9, 
   3.7786078071916723`*^9}, {3.7786078583881083`*^9, 
   3.7786079583980513`*^9}, {3.778608003097253*^9, 3.778608223389823*^9}, {
   3.7786085141288853`*^9, 3.77860856460448*^9}, {3.778608635395794*^9, 
   3.7786087276529007`*^9}, {3.780063595557458*^9, 3.7800637819259577`*^9}, {
   3.780064079152919*^9, 3.780064124019085*^9}, {3.78006431735084*^9, 
   3.780064354250193*^9}, {3.7800652575542603`*^9, 3.780065361649014*^9}, {
   3.780066002629507*^9, 3.780066027336459*^9}, {3.784903857367408*^9, 
   3.784903879671929*^9}}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxc3Hc8Vv//P3A7K1zGpZ3SUCpRiZLnSSoNokkkZJZSIQ0lI4RKVijKyIrM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     "], {{{}, 
       {GrayLevel[0], Opacity[0.1], EdgeForm[None], 
        GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl01WQl2UUB+A/KaKCdMMuLIpegDRIl9TuhUuDEotKzdAgIaikktKhMyyx
SkkLGEvMUIrS7YWidKhjYAHjc8aLZ8/vnJ1lXt7zfskZQ9IH50wkEjl4w49f
1dN5EokzbNC/qT+jDuAQ+ThOF3awxe/7qHv4RW6ifkCa/JjanV18qv+bNnIW
A+Xcaof4N3hf/y3PytOpLO/hIWn69UyUN/MzjeNvSJV38xet9WvirPJyLvGM
fhop8gQ28RONzJbTXu7PMi5SxWwqleI++Ji7NDRbRju5H0u5wNNmU6goj2cj
d2hgtpS28mss4TxPmU0mOe6CV1nMOSqbTyIp/i+8wiLOkmL+NhXkF+jLwtgN
lczforw8jg3c5nmzJbSSM1gQu6Vi7JVy8ljWc4v6ZotpGTtlPqdIjrunrDyG
ddykntkiWsi7+DPOpl9Nb3keJ0nST6CMnM0DUvXreF1eyw3q6hfSXN7JPVrp
V9FLzqWms5n39CeokOP/d1tafkJ9Kd4aX8T9qfu5L7dX1zI69q0e5BGO0Znt
fBTnjbOTzXX9V2odFtAsdqEO4gj5OUE3dvJJ3K/al338of867pOV9Iy3ox4g
Jy+yibnmveLM8W3J5dXxlJIfV3uwm8/1/9IuzsooOa/aiW18qL9GbXk+TeUd
/E4LfSYvy3M4Rjn9OErKI8niKrXM5tFE3s5vNNeviPuVZ/MNZfVjKSGPYA1X
qBn7obHcg1lxD5QxG0NxeTir+ZEacQc0krszk6OUjvdBMXkYq/iB6mZzaCh3
Y0bsiVKxX4rG90dX3uVLSsZ9USS+C7rwDkcoYT6SwvEN0JnpHKa4+QgKxXun
E9M4RDHz4TwpD2Ull3nObDZ15Y5M5SBFzYZRUB5CJt9TzWxWvDO5A1M4QBGz
oRSQP+Mf2saeGSznUTuyNXaj/46q8kxqywPVwzxK13if8U7MT6kZ7OU/dcW7
Zw==
          "]]]}, {}, 
       {GrayLevel[0], Opacity[0.1], EdgeForm[None], 
        GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1GW4FlUUBtCPRrpbkBZFURrsRLAxCekSle5G6VJBJZRQWlJFKQkFBFFQ
SrpB6ZQu1378sZ6z3z3z3dkzZ+YWbNCyeoukiUQiCfcodis2pEgkNpJBTpU8
kRiVLJG4xf18xCU2OlbCOoDTdJV/Ipe6I3soJ6+nqLoPx6ktf8UV3pSXkV7d
heXklDuwm7LyOoqoP+AYteQvucwb8lLSqTuzjBxye3ZRRv6dwur3OUpNeQKX
eF1eQlp1J5aSXW7HTkrLv1FI3Zsj1JDHc5HX5B9Jo+7IErLJbdkRzyvukXFc
4FW9xdym7sCPZJXbsJ374p4Yy7+8oreI1Or2LCaL3JptlIp74AvOU11vIanU
7VhEZrkVW7k3ZuZzzvGy3gJSqtuykExyS/5K9v/78CpjOMtLevNJoW7DAjLK
LdhCyZiZ0ZzhRb0fSK5uzXwyyO+xmbtjZkZxmhf0vieZuhU/kF5+l03cFTMz
klM8rzePpOqWfE86+Z14PykRM/MZJ3lO7zuSqO+M+fiUEzyr/y0JdfGYhU84
TjX9b+Ib8G3c5AbXucZVisUsjOAYVZ07lyuOFY3rMpyjPKM/h8uOxYc3j7Ry
czZQJGbhY45QRW92fHPxXcbc6v6ciucof0ca9dv8SWF5LQXVvfiHavLd1kGc
jW9Y/oen1bO46G/fZ/0w6vg7ce/WaxSnHydjH+JZWm/EuxHP3f+GIdbz8ewc
Sy4Pj/uOdzyepdzM+geFHE8pj1TfjHcx9lkeav2XXx1PIY9QX+WO2Ce5p/Vv
qsZeWa/He8BAzsTM8aziecZ56qesM7ngnkpZh0UdMzhWzNqXE/GOyCWtgzkX
+yuntjZlPQXlNRRQ9+Awz8jDOMyT8oyY3XWay3NJJTdhXcwvrya/ujuHqCIP
5RBPyF/Hs/P7t+U58XzkxvxOgdgfhnCQx/Wmx6zOzx/3yWAO8Jj+tNhbx85w
mlOc5AS3x7wMYj+POncqxx3LF7MwkH08oj+FY47ljesygL08rD+Zo441k2fH
nsmN+I08MQv92cNDepM44vym8qx4R+SGrCV3zEI/dvOg3sR4Z53fRJ5JMrlB
vB/kivnoyy4e0Psq9t35jeUZJJXrs4acMTN92EllvS9jL53fSP6aJHI9VpMj
ZuYDdlBJb0LsnfMbytNJyHX5hewxM++znYp64zno/AbyNG5RR28V2WJmerON
CnrjOOD8+vJUbvKW3kqyqn/hdnW3+LtUlnuxlfLyWPb7fT15CjeorbeCLOpV
5FN3jetQSe7JX5STv2Cf39eVJ3OdWno/k1m9krzqLnEdKso92EJZ+XP2+n0d
eRLXqKn3E5nUK8ij7hzXoYLcnc2Ukcewx+/fkidylRp6y8mo/pnc6k5xHcrL
3dhEaXk0/wG2CSiK
          "]]]}, {}, 
       {GrayLevel[0], Opacity[0.1], EdgeForm[None], 
        GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwV0mlTTmEAx+HDMINEImRrIku0KFt9CUulfV9sLxjbMEzv7FuytcmeNvkA
VMOgrBWy+wDC+Ayu8+Ka+/z+5839PHPiK/dk7R4fBME4Rnk0MQiGGSFzQhC8
ctYywFqO8Ix/3qU5D/GEbv2XVM8H6WeXbuEncbqGh2ToLv6Qog/Qx07dzA8W
6Wp62KB30MR3FtqqeMB6vZ1GvrHAVhneh3V6Gw18Zb6tgq7wt+garvGFebZy
Olmjq7nKZ2JtZXSQrqu4wifm2kppJ0138ptkvZ/e8D76MqPM0SXcZ7Wu4BIf
mW0rpo1UXU49H4ixFXGPFF3GRd4zy1bIXZJ1KXWMMNNWwB2SdAkXGCbals9t
VulizjPEDFset1ipizjHO6JsudwkURdylrdMt23lBit0AWd4wzRbDq0s1/mc
5jWRtmyus0zncSr8/phqy6KFpTqXk7wkwraFZhJ0B2Mk6X08Du+jTzDIFL2Z
JpboHI4zwGTbJhpZrLM5xgsm2TbSQLxuJ93zYZ7ySx91Pg//SwbZy3/h3meF

           "]], PolygonBox[CompressedData["
1:eJwV0kVTVXEcx+EDgt3dgq0rZxwLA0RFEZOX4MIC7sVCUaTsbld2rVS6LBR1
xo2+A7tWjordPmfxzPl/vnfzW9zEJdHMSGwQBDE00zouCB7GB8EjMr0f+BZw
n7Hk08Q7v43xzaORLfoerbznc5wEfYm3jNa5NLBYl3KXlnoexxikF1FCE/G2
DI4yUF/kDaN0lHoW6mLuEKfncoQBegFF3KaFLZ3D9NcXeM1IHaEuvFsX0kis
nsMh+unzvGKEzqE2vFtv5hYxejYH6aszKOAmgS2NA/TR53jJcJ1NTXi33sQN
/jHLtp/e3uls5Dp/mWnfRy/vs7xgmM6iOrxb53ONP8yw7aWn9xmeM1SvpCq8
W2+ggd+k2vbQwzuN9dTzi+n23XQPbySPOn6SYt9Ft/BG1lHLD5LtO+ka3sNa
avjONPsOunif5hlD9AoqSdVrqOYbU23b6Rzew2qq+MoU+zY6eZ/iKYP1cipI
0auo5AuTbVvp6H2SJyTqZZSTrHOp4DNJ4X+dDuHdRCnnE5PspbQPbyRCGc1M
tJfQLryRHK7ykQn2YtqG95DNFT4w3l5EG+8TPCZBL6WMJJ3FZd4zzlbIf0Hs
d34=
           
           "]]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
       {GrayLevel[0], Thickness[Large], Dashing[Medium], 
        LineBox[{1, 365, 272, 193, 129, 80, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 
         11, 12, 366, 273, 194, 130, 81, 52, 394, 301, 222, 158, 109, 13, 367,
          274, 195, 131, 429, 336, 257, 451, 358, 82, 414, 321, 459}], 
        LineBox[CompressedData["
1:eJwt01WQlmUYBuAVBEUQRLpZUjyQUjqk0wM6VViQcgYUBRMRJJWwe0bBIFUa
UQxmFBQTsDkAQTAAdezC8bpnPLj2uZ9n//33e+MrLJo2cOoZBQUFN/vxk/qa
WsR+Num3qsMpxR6mcIn5XepFHJKfYKM8mBJM1T+r9uEv+SXKco2+Am/I8xhE
K5aYNeWw/CTTKMe1ZhV5U57PYFqz1KwZX8or8r2cx3SzSuyWFzCENpTnOvPK
WYO8kKG05XyuN6/CW/IihtGOCswwr8rb8mKG056KzDSvxl75TkbQgWVmzTki
r8w6qMQNZtV5J/vHSDqy3KwFR+Wnsg4qc6NZDd7NHjGKTtxt1pKv5KezNqpw
k1lN3sseMTpno+/Kz/JmOnOP/mKOyc9k/VT9/w7U4v2sgctzHvpu/CJv4VLu
zR3geM6ZTfIQSjJDv0rty9/yy7woj6JM9kt/i1qbD+Sd6pUsl59XB1Asd4SJ
XJEzVrtnH/hV/7o6jgNs1W9TR/Ah5+QcuZqP6eL396mtck58rX9FHcM+VmVf
1KFZN2flvjGJmX63Wu3HP/IudTw75R3qaM7NmepvVevkGXI+vCAPpHjWl3ug
9uC3PC9duV/fmm/yf3I/WKPvz+k8JzWYpa+b583ZMSb3RN+T3+XtdOMBfRu+
zffk/lCT28wK807n7BhLdx40a8t38trcH2ox26xe9jd7RxE9eMisHSfkdbkv
1OZ2s/p8lDUxjp7UYY55g5xFno/x9KIuc80b8kmehavoTSF3mDfi0/xfJtCH
h83ac1Jen7tEPeaZNeazfIaJ9OURsw6ckp/LOVGf+WYX8Hk+wyT68ahZR77P
fcze04AFZk34Ip9hct49fS/+yB2nP4/pO/FD7kD2Pnurv4x/5VdpyEL9hRzM
37BBHsSZTMl7qfbmz9y1nLE8ktL5Lv3jamd+zHeqY9mQd1QdlneLs9nN5JwN
s3Nu6n9pprmy
         "]], 
        LineBox[{334, 461, 255, 450, 357, 191, 442, 349, 270, 38, 392, 299, 
         220, 156, 107, 78, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 393, 
         300, 221, 157, 108, 79, 413, 320, 241, 177, 128, 428, 335, 256, 192, 
         443, 350, 271, 457, 364, 470, 50}]}, 
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwl1WWYVGUYgOFhaREQBJGWFGmluxGlBFSQDiVUOqS7S7oVlJBSUrqVRhoJ
aaVbur2/yx/3dd7nPWd2ZmfO7KZr3Lp6q2iRSCRbVCRyyjA5eiTyHod0d/Jz
RncmOVt0QjaZP+OJeSb1OO3xU+zycFj3oABndRdS8Jt+jc3m2jw1z6J+eB6P
n2qXlyO6JwU5p7uSkt91IraY6/DMPJsG4Xk8fppdPv7UvSjEed2NVGzVifnN
XJfn5jk0DM/j8d/Z5eeo7k1h/tbdSc02/Tq/m+vxwvwTjcLzePz3dgU4pvtQ
hCRstavPS/NcGoef6/rpdgU5rvtSlKRss2tAhHm6Cf+4foYuxAndj2K8wXa7
hkRjvv6cC67/QRfmL92f4iRjh10joligv+Ci63/URTipB1CCN9lp15joLNRN
ueT6mboop/RASpKcXXZNiMHPuhmXXT9LF+O0HkQpUrDb7nNi8otuzhXXz9bF
OaMHU5qUXHVujn0JzuohlCEV15z7yb4k5/RQypKa687d4Ca3uM0d5rq2FOdd
M4xypOFf5+bZl+ZvPZzypGWP3RfEYpFuwV3Xz9dl+EeP4P3w2ekepGG7fos/
zE2JzWL9Jfc8foEuywU9kgrhs9Q9ScsOnY695mbEYUl4rY7DyM5X4Xd1HEBm
9un7jiPJxX3Ps9CxHBede+Q4mm/Ntx2HkDV8vxjPB+H+cOwV7rEYXn/47jM2
fGZ6Z3jt5hHhHtE5w3eDieH90emd32duHu5pHdfxMWPCPaKXhvfOPDzckzpH
+G4yga+du+E4kLfD3wzGsd/+QXjN5OaB3+lnx/Jccm4Ud8xDycaH4Z517E06
dukM7De34BWW6ZbcNA8iCwf0Qz/7F/P7XNajqUhGDth9STyW61bh/XT9Il2B
K3oMlcjEY+cWh/eUq3oslcnME+ee8oznvOAlS8Lr55prxlGFt4mw1L4i183j
qUoWorHMvhI3zBP4iHc4GO4RXuVX3ZooluvK3DRPpBpZORQ+B+KzQrchOr/q
KtwyT6J61P//Sw7btSQBK3VbYrBCV+W2eTI1yM4Ru1YkZJVuR0xW6o+4Y57C
x+TgT7vWvMZq3Z5YrNLV+Nc8lU/IyVG7NiRije5AbFbr6tw1T+NTcnHMri2J
Was7Eoc1ugb3zN9Rk9wct2vH66zTnYjLWv1x+L6Zv6cW73LCrj1JWK+/4RXW
6U/CvWyezmdc1n1Iz279Hn+ZO5CUDboz8VivP+WheQa1uaL7koE9Og8nzR15
g426C6+yQdfkkfkH6nBV9yMjf+i8nDJ3IhmbdFfis1HXCt9t84/U5ZruTyb2
6nycNn/Dm2zW3bhlHsw7HAzfOcdRvMtLJhHb34YEzv0H+H8m2Q==
         "]]}, 
       {GrayLevel[0], Thickness[Large], Dashing[{0, Small}], 
        LineBox[CompressedData["
1:eJwV0sVyFFEABdAOJLi7k+CwoorC4u5B8gkssCSTYIFAcHdnhdsKdw8EqOIn
cFtRBHc5b3Fq7r0z3VXd85KmVZfH4qIoaqJVfBQtS4iisbyXT1FBMmdt00nk
sb6f1izXx9Ekn6aSFNqwwj6eD/IZqkilLSvtE/gY7k2MNNqxyj6RT/I5qkmn
PavtyXyWz1NDRvidbQZJPNEP0IE1egpf5AvMITNca5vJIJ7qB+nIWj2Vr/JF
5pJFJ9bZ0/gmX2Ie2eG+tlkM5pl+iM6s19P5Ll9mPjl0YYM9gx/yFRaQS1c2
2jP5KV+lljy6scmexS/5GgvJpzub7dn8lq+ziILwHLbZDOG5fpgebNFz+CPf
oI7C8Gy2CobyQj9CT7bqufyVb7KYInqxzZ7HP/kWSygOz22rZBgv9aP0Zrue
T8RtvZ4S+rDDVkAcd/SllIb3pFcxnFf6MfqyUy+kGQ3hDFMW3p0eYwSv9eP0
Y5deRHPuhjPMJPqz21ZMPPfCGWZyeNd6NSN5o59gAHv0EhJoDOeaKQxkr62U
FtwP55qp4b/RaxjFW/0kiezTy2jJg3DWaZBrGc07vdFnHWN4SD2PKPfdf0jO
ddU=
         "]], LineBox[CompressedData["
1:eJwV0tdOVGEYhtFtoom9Ya8BRZQqiO0mVHpvA9gONLZoIJ7ZexdQsIMiegG2
YBA7FlSwXYCK8Rpc/8HKzPNOJnuS+eJjW3O3DIuiqJ8HI6JoGy9I4RmN/Boe
RU+97iGLDh3PRe/XMJJevY88EmiyrWUUz/V+8llAs20do8Oz9AEKeKi3k8pv
fZuFtOgcxvBSH6SQRC7ZchnLK32IIhZx2ZbHOF7rwxSTRKstn/G80UcoYTFt
tgIm8FYfpZQlXLEVMpE+fYwykrlqK2IS7/Rxyknhmq2YybzXJ6ggleu2EuL4
oE9SSRo3bKVM4aM+RRXp3LSVMZV+fZpqMrhlK2can/QZalhKu62C6XzWZ4nx
SO8gjT/6Dpl06Epm8EWfo5as8B/ZqpjJgD5PHcvC923VzGJQX6CebDptNczm
a7gl1rOcu7YYc/gWbokNrKDLVstcvodbYiMruWerYx4/wt2wicd6J+kMhWez
ivu6nvn8DLfEZp7oXWTwN/weur3fTSb/dI/XBrLDfbM33B+rffYf4XVl2A==

         "]]}, 
       {GrayLevel[0], Opacity[0.1], LineBox[{473, 475, 472}], 
        LineBox[{474, 476, 471}], 
        LineBox[{1483, 1484, 1482}]}}, {{}, {}, {}, {}, {}}}], InsetBox[
     TemplateBox[{
      StyleBox["\"platykurtic\"", StripOnInput -> False, FontFamily -> 
        "Helvetica", FontSize -> 12],StyleBox[
       "\"normal\"", StripOnInput -> False, FontFamily -> "Helvetica", 
        FontSize -> 12],StyleBox[
       "\"leptokurtic\"", StripOnInput -> False, FontFamily -> "Helvetica", 
        FontSize -> 12]},
      "LineLegend",
      DisplayFunction->(StyleBox[
        StyleBox[
         PaneBox[
          TagBox[
           GridBox[{{
              TagBox[
               GridBox[{{
                  GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    Dashing[Medium], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    Dashing[Medium], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                   ImageSize -> {20, 10}, PlotRangePadding -> None, 
                   ImagePadding -> 1, 
                   BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                  GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                   ImageSize -> {20, 10}, PlotRangePadding -> None, 
                   ImagePadding -> 1, 
                   BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                  GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    Dashing[{0, Small}], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    Dashing[{0, Small}], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                   ImageSize -> {20, 10}, PlotRangePadding -> None, 
                   ImagePadding -> 1, 
                   BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                GridBoxAlignment -> {
                 "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                AutoDelete -> False, 
                GridBoxDividers -> {
                 "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
                GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0.8}}}],
                "Grid"]}}, 
            GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
            AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
           "Grid"], Alignment -> Left, AppearanceElements -> None, 
          ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> "ResizeToFit"],
          LineIndent -> 0, StripOnInput -> False], {FontFamily -> "Times"}, 
        Background -> Automatic, StripOnInput -> False]& ),
      Editable->True,
      InterpretationFunction:>(RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                   RowBox[{"Dashing", "[", "Medium", "]"}], ",", 
                   RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                   RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                   RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Small"}], "}"}], "]"}], ",", 
                   RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
     Scaled[{0.8, 0.8}], ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesOrigin->{0, 0},
   Epilog->{
     InsetBox[
      FormBox[
       StyleBox[
       "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
       TraditionalForm], 
      Scaled[{0.05, 0.95}]]},
   Frame->{True, False, False, False},
   FrameLabel->{{None, None}, {
      FormBox[
      "\"\\!\\(\\*SubscriptBox[\\(\[CapitalDelta]z\\), \\(i\\)]\\)\"", 
       TraditionalForm], None}},
   FrameStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{"AxesInFront" -> True},
   PlotRange->{{-0.282842712474619, 0.282842712474619}, {0, All}},
   PlotRangeClipping->True,
   PlotRangePadding->None],
  InterpretTemplate[Legended[
    Graphics[
     GraphicsComplex[CompressedData["
1:eJxc3Hc8Vv//P3A7K1zGpZ3SUCpRiZLnSSoNokkkZJZSIQ0lI4RKVijKyIrM
bF4ue7uoZK8k2Tuyftfnd/ucl8/t+/6n2+t2Hde5znqdc96P++2xwcDirBEL
ExPTN3Ympv/8y8QZeHTFqjrE9N//5nzkYIdhLR5HStO/jwXT8bhXsNPNr6oG
jx8US0w8NazGY7MAgzf0lko8ftcVN3DEogKPd53qf7TmZxkep6VJ+e7SLcVj
x8BneobjxXj8+V2V0aJZER6vEdm6NvdfAR7bv3bRTfXKx+OjO5sahXhpyKUx
4gL7gWl488SWbzsgJCKzr1lvNwuh3ynROiWRjVoP5J6XCeUgVp3+iWQ3ZCCq
/2d37wEuQissjyNXNRU1G+e8ZNLlJS7IO9D4DyWj+CK9Gw32fERDlnFHlF4C
unahfMUinwCx+59uz4qXMUhlbJfarTwB4oUH795im3B0h0fEK/gohRgZXvRm
8wlC7x3Lue5+oBCZNJtXEUdeI+mw1ubcDgphRx286U+xQWofZy2n5ikEh/am
DXJs9+CD2pqREwsUQuq+rY5m1msQj9dcOdxGIey3bhJ7tikIFI79bFIPY3z/
zbXcyrRwkNSin5AmKMSRdF6dq19jIGo9j31AhgBRKNw8Zq2YAD7BA7Y+ogJE
zMuKgjvqyeBU15OZZs1HcK0J2L1lVyp882mPvH+Pl3gYovncZD4dFJXKIIeP
m9jVu+dWG1c2PLVaM6VcykFoKw0MLe/KBdGBDcJbK1iIX7s6HmfM5sGPgYDL
SoPToFUsd1bFPB/I41Gv5fYu6HsBHk9U/Yl9caUIj2sq9vNcrijG41Mx3lK0
S6V4THfqLRtqKcNjwT+SSdPHK/B4cudjvaDaSjz2ncvWWXe4Go8VSyarjaJr
8FhZPph1kz8dj0u+ph9zVKvF4/9eD3j8RM1MaSNauh7Uzv04lHls6fy71r57
jVENDeka1bmE5v8BFVmP298u5CHv4N68Ec5FmIuvsxZIyUED3eU/6v3YiFyq
czX1YyZq6mXq9tbnJDL/alx7mJaGtvK3i7/fx0NcurWh27goBR1ce3vNwpPl
hN/DCfWW6kSk5XpEs/4yPzEi53fuS2QcmrzAlaNyU4DQLdj3YtghEqk9VXj5
YxmFUFLigO4PIejD/Y6D/fcoxPeGrNffb7xBwhz134cKKcTlZeMxvJwu6LPJ
kxj2cQrhmeZeyVYvhuhOj9YGMwsSIy+LDI0VXCD1g+7v/DEK0XBGPXfI4g38
jg+528j4+4Y8UdWC6BCgGeucvcL4/lVCIska5ZHA2ufC+4WZQvTc7vywOSoO
qGUaexQYvy9N41yzZUkiCP08MLGgy09cviDz7xRKgdbkJilFx+VEftt0S7Fv
GtiZ3h1xP8tDfFMung11zATmrGuzL59xEsoinrumrHPgy4eZI8ZDbASXxKcD
erJ50Ci+89Y4GxPx/iFvL1MKDU5cLNaZowzBCk/9v2NiS+db981txaopS8cX
PjErBw0sHc99e+12Zn9YOp535XRylksvzSfF0ns2TyTkob0lXmY7O2bh5Jut
SkEPclGO46ON87dZCQHbH985TLLQRcpQ84bny4i+kMDXmubpaKFNN9DGl5to
4Lxj7fX8C+JR7hh7MMZLTGkd5Jp6loSOpOoU7RzlI9QbpN0c98ajH1eYWH1A
gCjRLZd34oxGwb4nrXV/CRCmJs/lL/CGoZLpaOfDVymEQXer4KBdIEo8dIZa
lkwhTI6OdseWeKCY7LG91X0UQsFKw0fF3wRpCXfVRzMJEgfaPh04vN4e2HP6
0csZCsFmaPwizNcHAhyq9eh1FOJ0n88Qy7oPsM9tncHMCwrxjAhoKz8aAXzT
CuvFNlIIH2GbJ/mHYqFv94cCdx8BQnGP6O8JlkTYuSXdQLScn2AZW2hrW5YC
9Sxus4GLywnj+VLnqc5UmG66a3mol4fYavlK6VleBtj0x57gVuciMhb01fpQ
NpQzR3gc+8lOyJ7YIGMSieCh6o7Xtg+ZifzzUzKtl2iQd/nScYXQCZCTrAoP
Kv6f+UTsjrOp/dLxNL0rpZY+sHS8zjuzP8q+SUPFboF7h63Hwce63MZsEiF9
Mf921M9EfC59HO04lI3OmQYL7I5gJzwD/q35vSoWHdo3wbXPX4CY2hrScXn+
I3J1k7Tu3Uoh1q51VLbc9wHlZ9jFhXlQCJWqAIHcSz5I/D7buz9fKYRq2cRt
cxV71MQXWWDC2L8n59E/l8dG4IbaX35l7P9IaH/prvUCtPvzeLv/UIjYgweG
5U8GgovVu1H2LxTC8E3gJ8d9YXB9x/R1Sx0K8fmXp0uDWjR8Du907GoTINbl
Sex5cyIdVrCEfexJ4SbsqfMpeceyIPBq75q1n5cRdMlcPpYduVBxaR335d+s
hM2noy28AXkgohEaF5M7B7YfNgZtEsiHmQTRMPb2OhjL7GTf83tp/31orCq8
zLp0/4/adG5zTtXS9fCve3R5l/7S/nWOd150bMtDazvl3LvX/4MR7rNR11py
kc2abcKXv7EQ6bueNi6UZKHDp66o+4guI1j+5kaVFKcjlswX97cqcRMr6lco
RvV/QdtiNj06Es1LRJTp/nLoTEIfHmg9UMjkI5ii7D72/YtH3go12yK3ChC2
scKeahXRaI9/MSH7VYD4N1Oeujw/DN3pupMdf5ZCbOu79XWa6x2KqVvYahhD
IW4ZjjA/jnyFDr7YlszcQyHUerl12m7dQSG9doKuixQih0fx1JUNtrAYmKa2
a44xf90anXgs4Q1sNHmnVY0Ugnch4snRhGDQjBOVGPSnEAcuaVu5OH6EMm3D
LZbSFMK85/Cgp+snuHhqY49WpADBvGnG/MuHBGDNrDK4Ms9PXCSMNCRik0F0
0CzR/CAfkc6bqM3nmgr6F8PDlXbzEurcE0ZTuhmgFafLWZnARViNn9TtNswG
/uuvYkMvcRClRc6emcoIBI2W7+zdwkJ8O3xDs2IbDXLSnj282z0FpdMOs3cD
lq4HtX8+PZMmS8ez2YD1WMbKpePXIvO2wjOYhjYXWPr0OY3A83Q5P2WJPGTV
72I3q8BEXFCI4j+pkYPWSf38uHoDO0GYqcipdcai+mzLF1RHxvOCdb/s5rwI
tLZdbNuOFRQiIb6QJtn/Acnv99vM7kAh+L5ury3r9EVdykUHEyspxPne8RcK
Ek7oafE/uDNFIWoP/43bevs8sKyzSbzNuL+cNqmbmT7pBpBJLPMbohD5R4su
Crf6w7KSz56SORRi3Q4t2zCLUPg1l5aeZMa4PubOrvX1iILGCY7ggBEB4naN
AGf8cBoY2vCp5rHxEDFx+g3SvzJB/e+TlW6rOQk3sch1c/Qc0P/31kD9JhuR
Z3bfPdUkDx4v0Kk77i7Ayxdv8gW7aHBHzE0l73wP3PBhN86rWtp/fe7F5vJM
+SjDklX8hnEbvGs7fbZz0h8dPyb4JSSbQuhtGStp+f0c8Untz9s0TCG+SK3q
jPqoid6aHqjXZmyfb2p6zdedTqBY2c91g7H9Q1rNm8tY/GDXQysZAcb+OdvT
+oeLPQ/qfl4R6y1kIhJM7JcPP6OBvrmg3WbKGFQ2WmzvVaChprjK0w5zk+Bx
vj9SrtYW9cnpWfyZpRD1O5T4n+jfhqA3x2OKGeczM+8UhX+vJ3iHib6K7aYQ
uwYFd14rz4O0s2k16/r+wfXkOBtZxaXz5UFnzsePTEvPN/SRPc8y+Jau/641
h0IOdS+dP4pZCrKnHy5d/8a3EgZOTeahrY3fkyRlZqBQ2aS5eDlCPz7R9593
ZCF4Xc83P5zOQnnVhU76rRzEyw0aexfH05G4uKNOpCg3kZ5tvjF5TSrKL73u
0+3ISzyxv33uBH8yqnlnekI+mI8YOO69kl8qAVUEXs+5vlqAuPhVPit5Rwyq
HD2n11MmQCgX3Jj8syYc6RUJbN5/mnG93kxLXqh+h3LOPa6y/Ughpmf2uya5
eyLuW44rLH5SCOPFWcODhBUqk91MVDGepw32SKeWCz4A7eqBgNOM5+1N46kS
/Xe8IOjI9gdCLRSi2MvojFFfEKSKh47vDqYQvgYKyGjjR/j6RCO7W45CaJ6J
3DS98xMkt8wauycIEAZr+uJ9LRLgO52fQ55HgHhq4s+t+iQZRDKDHudr8hF6
wpuPrdJOhfai6CS/c7zErwsRf3ftyoB0gYXCNR1cRO1NMNbfnw23BNWdTDw5
CEGnDDAUQhDfzn9x8QELoZO++Ua+IA3cjNu0hIb/gmd7a0Srw9Lx5P4d4aeg
vXT+CmsP0uR3Lx0/Ma6e8X+pNLT9bmWbROggmNoYOPJCHmrPjtmxvHARJO7l
KMU55CCOifqIjy1sxAqN4SJ75TjE2p+TefS+AOH0TsDAbUMkOqRuxyQiQCFm
7hsxcR4LQQ23TT652FKIsQuWiTURfii61uF8ZymF+GFj+W6T/zNkc9JidfkE
hWgvNxI2uaAEu9f1XPFlXB/rZk/Fxxe4goaXi3DOCIWoKndzs9/iDxbmVywo
NArx6F66YTJvKPSXWLqsuk0h0LK9ppaSUeDuPxB7YEaAWPnDaSwzPw1e/RXM
75HkIWBG6Pr1lEwwBsXsKXVO4nfg2y0PwnIgSdPE/85nNqK7lHKN50werHpm
GqJweBGobGe/c1XQ4PPpQb/AJ30gYS9KXUZb2n9n19tulhLOR2tojT3dolVg
p+8r8zszAP0Skuk6lk4hur/cqS+85I6Op33bwzlIIXiOWTi8nNRHznZS1QKM
7TM9KfPMLcIBtit03Vw+zdhfbR+0ZE/7wsYhSSG7Ggox6DbkkNOA4EYqr/of
MWZCvu2gWM8tGvz9usL5htE4CCRknj17gYa0ZlaqjhdMgLdlXyFnoh26m6co
nfaPsX8kQ3mVxG6AxXyziDbj+eLbJ6PGbx0v4XzZRXat34z55XQsW3piHuQN
Trn2N8zC+DZTt51bl84X2eqaCwPjS9ubyhf5y+bE0vVtHronguXgTXS+9O7Q
Fsb3r+g+2TEsZQdBJhc5hxnrP1WRcPQbQYOuqmXUNxWT4K+jHrbFmYbmBbSj
a5aPAV3Tyu58ugM6kSQrNvuXQsgEZ9W+/XIVutodRXcz9g+7aGv86hka/HYt
dt4v0QkRXx4p1/ymoaj7RGnjtl8QGfHpoVneSdTCrjfixlheYrT43993NBjt
s4ovfz8CzvsG3ExHH6AxoTbHBcb9e+jInhXNMpbwkWpxgsqYD7sUxg3hwtL2
Zk98mtRdvjTfmc4Z/zIVXprvFlfItD8eXrpe9LYYnLR3Xtof9apHf8Yz0ZCK
xrDzg7Rp+Nw5anV/C0LlC+INKy+zEKkpii3pAtloPCVy/A/iIL7JrvoXyJ2B
tv+7sGI3CzfBmeDnI7cvFcndcbnIeoeXuH7lgduOLcnI5IPBB2FPPqKLeX6u
+XgCeuY91HBARIAoMK5UN74Sg1aeTdKXKhIgerdmC2ueDEfE71OtQyoU4snn
5jB76SD0leVT02wohWhs/eEe+9sTmbcpxa/qYlyPblZ//kRZI47GZ1pGjPlu
b0nMDXt3GxhjOXmthjHfxXwJyA+hegHHhskxp1bG/NdauN/aJQgMe2r1iz4w
3h97Y7u/jYZD/1WJkFcKFKKa9XLeJ6ZPYOyq2Er9IkB4+xvUsl9KABt+cz9z
igAhMittctUkGRbfVqw5YcJH7F1x9eAH5VQoMpv6LmLESyQ8siMqRDLA0XSs
2uEvF8H0Sb7vvVg2OO02zb0by0HI/jwrmvEvF065n3erCWUhPow7TBxaRoPz
vdd0P1hMw8RZ9zkvm6XjadoaP9R+fun8lb7Utfjg4NLxU7Li4dxdQEOcO3fL
XC3sh4aLfx/cPpmHJqdYuSRNFkFQSKVF920OCm55It2XwUawFeV7rL4Xhy6Y
FxRX3hUgRqXC/iqcjUSfddmEZ3koRHDrl/X3LEOQByFxPufBf57X34Sc5XqD
9KKemQ0UUwh/SA5boe6MWN5yv+hnvE9PZTzLr4Ad0Hfz2MEgxvm7rIiTm4fJ
FS5Mum4qHGVcny9ubpKreAP35OQkZ/IZx2N1r+bB5hCYf9ruRlgyni9fhL/o
+hcJuaULn23nBYihptzfRGwaLNvpfvUE8BDc6weTON5lAtPoHOXKDU6C2uAb
k+aRA6pXBGo9q9mIe/fbqr8o5YFb4fj3ixGLcBnidZ8hGnzf5al77tIAONuI
3YrJXNp/6lWy0Q2bls73kdCMjdfXBiL6d/YrvKkUIuJxYms6vweKbLv6c6if
cb5c0XPvLzZEaSwe9A7G/KAhPNz+q8se/um/latjzHdPQhzHB0Z84BTv+RuS
tRRCsM/lsmAegnvaMacXVJmJJysDovWv0eA1/TzPI44JkFndYeyiT0PxEjL8
nesnwJ35i9l9z6dIzLpQTIgx3xgIJ7L+UjOFrG/P6YGM9eVab9y7e+1LMNy3
8CW0lzEfz96/bfAxD7jucNa1nZ6D/AiHJ8xiS+eLT2FD3KvBpe1teFA5E3th
aXvzdbx+SHHcRvULwotNjPmjz6bQNyLqMXzkuVjhxXje8uTgqzmzjwbBjYOz
A1pTkFlinabtRUNPAw5Oz6mOgpdYirPKbUf0hn1rgzxjvmO53Yg6BS9DUuGh
rnOM43/y7AH5N4OM+/dftmCHvp9QKhaiyTZBQzLatW9SbnaBE7NczRDLOTSx
YabjHmN58x2bnCxf0yB7IO+ou84ocBXdCFDXf4QKuG2DbRjznUF6pveO8juw
f0fK9B3G791yX30o88TS9q7qT1FlWbY03zVZOnZ4/LiLVvw5K7GLsTyxdbtc
c6Aq1FhoPHNmrK+udOLUy3oaDIS+37LMvhd4//Y/vcWbj+7vu3H1/up66Lky
N2agoouuG7LR5RnL+yh5i7wfvQnsyzx0hRnH4/MQN3OSzP/s7zD7WqVD//M+
7q4U9NHsOuJPG+24wVhepqd6dHusAfSXr9dgZ3xfXrPdlg9s+TBdk2V2NLkZ
nE5e3B3YTENfLKRSi71/g7tPdVzfpCJaNHNm82csr7sQGpQltLR9ex2e+hKi
S/M535sdC2snl+aDkWarb289ln7Py5xXbfocNFSjNnNm1YNp2Lg77XCtDEJT
vqrXVI8ynl8rklt+rMlGwaqB+6iJHIQNbaGlVyQD5RDtT40Z81dC9CfVR4dT
UfUIRcLZhJfQq5jfHCydjC7W3now48pHtLYl3lI6n4Bkw3ZarxMUIB4m+L5F
1jHod7zIanq+AHHgsuEmfv1w9OKAafrx4xRif83g6gKDIGRvJ8+XHkIhymsi
X0SLvEY7YoaTbnZSiHR6guThK/eQ38LH4l2M+Xzta5PilpJ7sDdHPnE5YzxA
deef730Nw4U2IwfaGPOLw4Tk/IUg0GXNU+Bl3B9WShrZeDSGQ9Kz8Hf6ihSC
U3fPS/a+GJhnYj6hlSZAxNav68o5mQDVnQIL9sICREfhE99e7WSIL/9h5niL
j1i3am7fNflUWLWzvqj8Ji/hyzdgGMCVAawRUpabWbmJN2WyO0AkG+xXWAwa
ZDLeX73WO14bygWVsy/3cKexEEqvpTMeMdNAAQyHKj5PQwSvQeTgnaXzxV8z
JTBRY+n6JL63rFt1eOn41W1b53WyjIbke/rEH5f2gWfxYeuN6nlI5s3BT/Jy
i+Civzw6LTIHDZ2hBN2IYiP+Pdlxu/dlHNLRVN/Me1uAiHpgruR3PRId9ctw
6uOiECP8ulI73UKQ3wl94sJ9CrEmPXqlz4E3iN1kLGWoiEI8ED8XKRjrjAa+
XXZ+wJjPL7T57TSqgixqUJPFf/7/6Nw2kzS5YBdQ7XZ4pTzGeD8Y0r3jHfQG
PNZcONRXQCEODy2etcsPgY0WlSJ0KwpxhK4jFtgVCa5SnZTARQGioUW7izUk
DUZ11D8OqfAQw4laP769ygTlqrjntvc5ibgpr4GL9jnwkEr57NTGRhD0QjZ3
hTyweW4ve6ZhEeZarogXZNCAmWXvMUG5QfgytmmVbdrS/ut0OLFnfPvS+R5d
UBH4SS0Q1StQ6vpTKISzvkZn0g0PtFp/weYqYz5P6G3gD5QyRl+iDu4pZlyf
xx6ovhCyt4d58Q9O0jMUgsZiTagU+IAY/7G6BcZ8Hh5wvjg7GQGN7fj8GUNm
Qizt+K33V2jQpOqXOX9+AgroYyMhJjT06Nq963EV42D+6/zNuwNP0Ya5eu1c
xvfVu8rZyfYYA9u9g/zpjPUlNT3tvJL1Au6U2Zkr/6EQn89djdj/Pg/8d67k
43Seg/8+jwP5PF4ArVr6fUvbaybV7liivbS9rqHVK10ybyOqrI1pEmO++3bY
foT5ly0IjQ34dDLmc5nwbO8XUjTIkAnW/vh+Ck49dj18z5+G1LuNFuL7RsCS
7bybUqUj0vMSv1fPeH/v0+xNdTp8CcrkVbZdYxz/geHe+W+/aSD5Y2J5pMQv
0KpP7lr3j4aC1LbbP+vugHcrtjWc+nYBuTtzHLzOWJ6vvE4l0Z0GJaMil6rS
RqHc49MH5ZW2SHNc6rY0Yz5/d/eJxneRO3Aka6d0EOP3loosJk0fWbo+Thpn
zHxlXZrvPmSgjd3uliiRjdVngXH9C8wc37Jh+jgYy7LWvmSsz8o4TKCSToMT
zxfvjjn9gaDYBe7ngvloNx+lScCSDnaZU/PtHnoo1d9z1xbG8pxpq16PuJpD
+YGqADnG8VD3yCga3rG0/s1aPtpXjizt3w5q1obzdTeQyy+V4ycZy0dcvnjT
9og+sC4r917N+D6DB7v6WxdoEJiRJWck1Q4iTGaZKZ00JDF+YEjTpAfu3S8z
jV97FBWJN2l5MZZ/8SDyxAuBpe3TkV/GftlIHir55iQDGZ//936O1+9f+5vj
kO411N3R9HmGsX6/EuqZGxv+5/7nUl6q2K0DiqrnWpQYfx+V4m6lNU4D75vz
7Sl+XWDed6z4tbQ6etIrUmrP+Dx9O8fH8mANaNKrfmjLGD863Dh1jiMflex9
8HLUpwmqj/H0sdtoo3v+nkmn/vP+qlirb8CdD8KCJ4rZUn7Adjlut3sJe9DV
J8YjbxmfSzkGj/6hLm3P/32f/L/PJ//3/P6/28t9bVFjxSrG+v7/5znw3zEi
x2R+W3nxW9gFlqtA5rcFCi4S+snmQOa3DrFblKT2PQIyv2UdT11/RcQVyPx2
xF3vZ91rHyDzW793p7a1dIUAmd+u/HTgKtv+OCDzW9+sbcI1kulA5rdSh8+O
PFYqADK/bZ/rWMXHVAVkfrt5rkDt/ex3IPPbZKv+HdO+7UDmt983Ds92zP0C
Mr99Yr+b42TYEM5vddwG1+7RmgAyv6XUBwaI9v8DMr/V/yXtpiLHjPPb+iHa
oRoxdpzf3ksScaFFceH8VvzAB1E0sxznt1dvKaI4xv2RzG8bOTqUORSEcH4r
W7kitD5fGOe3m1hOSBoNi+D8Vv6egAqzHRXntzYXGg6EPqXi/Fbpx4/4sB4R
nN+y3aYeqq0RxvnttYw6l4bNQji/ZRrco3RjCwXnt0J0mc+jO/hwftv/y+u4
pzsXzm/5193tUFNjx/kts+F8YaIJM85vV/3wRop7ZoHMbzuoj36N8U8Cmd9u
zdgjyMs7jPPbv41nWSdye4DMbx2STfVYdDqAzG9f+G27YX+kHsj8tq0qUOXu
qWog81vmwYKqWyYFQOa39dfu/ZbQTgcyv/3ruNBhkPcZyPz2sNbL3KFtoUDm
t0+XM+spRfgCmd9KZSUbG91+DmR+uy5o7Xb2qkdA5reas/ym57/fIq8HIK8H
Mr9tJa6oj0kYwdlrTm6vmGvRqAp9fc03S3h55cPydiU6Wpabd+iahAMkDDgh
npU1iCvFrvWp1ysYjS8qivpQhXp97ZPXy78FFkVOJe4tleiRtrXn7qEI+OV3
eu/u6HKUznqicqw5Ce7av3D9KFaGVtucV5kIzoW10U0Py6JK0OH5TbapKSXg
/3bbz8RdxejaT/arPP218EvzIU03qRAdt2DKHLnVBGS+3JTAPfgroQvIfDlX
PVVvLW8fzpdzvnf5VX8Zxfnylcrfrw8+/gtkHmzapDf3+5ggzoM9rdiOWvMI
4zx49q0RV/11EZwHPwwovpKkQsV58M9NYcknX1NxHpw+LzNtepyK8+Btv4fe
32H8PZkHizu0vhDgEsZ58AHv/pvmUoI4v/X2SDfRY5kGMr8t+1r47tvmMSDz
W4/zO854RfXh/HbMhvnrGa2f8EsoM9w3oBCuaqisX0Nthq5KgRZL4WIwP6yW
1nijDpZnGQW9eF0CYWYcFV4XSuGlaO7cpVVlsCgrf1KrKRdGZblzLb3KwbHV
FE6ZJYOT+3muCt5KSDeLD9iWHglHRYLarjyvAoLp87ffG95Bn36jiNJkNVxc
v/zpYrgn3H3pYX1Dlg7LbquYibc7gLOz5Mdz43QwpTrlny60AjJfjqr+4DA1
ZgRkvpypsfyajZgBbLVt626VqUUrPFZ98ui6DYHH00d7b9ORspfvsvPWdlC5
KLNZw7IG7S+yG7X3d4d9B/+2+LBUo2KZ+Yfq8W8g9cYX85v2laisPEveQTkc
8hQeCxzgrUCZdvZZPe8SQN1YgaXTvgyVbREMoh3Iguu72TltWUvR6oysdmWD
IuB7+2MDz+ti9PTKNXmxjXQo/xcmJMVXhG7WXGDvXt8AZP59Ijbw2EfpTiDz
79/C3s2j47+BzL8lFgpSux+N4PzbQqT1clfnJJB5teLa0fSfhRScV1PbH0Y8
jxDCefWA/fJAgdUiOK8Wnn6QdF6MivPq+kv30x08qDivPpbS9Y7fjIrz6tSs
OR+7WBGcVz/6fSrqyG1hnFcXjU6WKsYJ4nzZoCzo/XrvGSDz5cTIiUr31+NA
5sue606r55YP4HzZ4fvhc+EL3dAmG/ohYH8hXNrNIttc0Qo3VB8XMmUUgedA
59fbyt/gVoHaN8tdJRBk4/lr/c4KGOiQ8OPNKIXjoqwEjwYNOq7MHEncXw4f
bD4ph+R/gVMH8lr1Yyrg2rHz7ds5P0HQhhfvH++sAokDpWa6C++BkDolv/st
Y948frn48KIXcGY47nrFTgehWfmktUPP4Fe74besIjq8HPt1tJPnPpD5d2PJ
VREp7uuQM0onIl/XosbzXklB0aZge3L77sN0OtppkKzfDTZgb+m67bswHWnq
erwKG3QCn8Z6reLcatRcIWjqy+kFcZt8PmcrVqHPQ58zJw++hzMC2qKR5RVo
YosgbfXvaOAeXa255Vg5om43LcjV/QI+79r4rqNS9C9U9sBPxnM0fUPCIFWt
BF3QdJ00OVQO4u8ehWtWFiHrzAr3S61fgSlN3eLlxUL0S2hq+UBfC5B5/VRY
tnnciW4g8/WypuOyOteFcb4+eqwmNjtRBOfr1oEZXaqmVJyvc8YpfDr3gorz
dZv3+hwtq6k4Xw+UlRAqFhMhyPybInJqtiu8F/5OTJ5QeVQAh9vGvwlVd8LA
SG3U69lC2MHWqSrj0wCap8PHeyyK4Yi1wvXQNDrEJtkaR06UwJPL065/UBFI
qZ27FvaoDKIkk4Z/WGQBi8BqOdlBxvzClMgvdDIRslt69+61qITucW7D+8Xh
MMgZt1bxVxWcPsZ3vyzJH3x8TMbOnamBCwb2SbrrX0DzNd/s4yZ0aI+jBE/v
ewpbdo5Z94vVwgrTdIX1vXdwXv/c1c9ovY0BkHl9pNT1queFeuDlyiP47FQt
En3I+jFW3AI+KBT+HHShI6eeu0WLSo/hMhd3g+WHGrRa4nVod+lz+MHk2eu2
pxqFue83KhHyA08WXpb18ZVI8O/z9Wt4wuDzK9+F3EMVSGZNZF7GtnhADULo
SVIZahn8clYwOgMErALVvu8uRZN+cSuUTxdCaeAu2v78YiTt/8W7wL8asivS
FUQVipDmfs8t7pw/gPQEe5cL86o+6gDSE1y7Nxh0YaIHSE/ga/bp4ceyYewJ
uIy7CvasngQy/2eRveB01IGC8/+f02xj43eEcP6fqrRi0+ywMM7/a5dx0/o5
qTj/fxHmcbvBmYrzf26WO7S196g4/5+UUVb1LhfB+f8M87zMshBhnP8rGkyV
H+wTxHm9jnaFjIr+PyDz+gd/gkZM1SaAzOtF53+F2/weXMrrP82uvtr8Cy6r
+AW/5SgETwnL0pkD7ZDwIlnuuHsRLM6KreSE7xB8vGC4Z64Ycg9XZ4klV8K7
o21dxq6lkPa8mCv2Qj5ojo5wqHOXQ/GDXaExHGnwmTJ1fOeDCojVfTgfUB8L
ZVvZn75YrISGMir1HW8I9Imwndp6qxpSlV3NI1R8IPLdgohSUw18it97YvS9
C/h4MA8Mf6aDw4ktfGdaHgDpCaKfe9oGXjKHdWJBNMOoWlTslGYBjcbw++Kl
K729dLTZb8Rv30NrcDX1Wd0kSUeOvjn81+0cYePPON4//dWIM4iyU7LDE870
7chMsqhCUiwLjV7bg0AiMjFWc7oCVevONh/Vi4LpI3uPfbIpR/9EnSiPhFOA
lT+1YtlIKepbd7AgUj4P7hkd3Xv7UQmK3HI7gnesFNre1h15Nl+ESjiqfjW3
1cGYi5H/PadCVF48eWxXZDOQ/iFTyu4A98OfQHqFbbcfj8YfFMZe4aKw8q0b
r0SwVxh0dGJ9q0XFXiF77UZWE08q9gquJ6i9zTJU7BWO7ha853ZMhCA9gdfK
WY2p0D/gmv/pw1q1AvjX/Nj4sWcXmLIUR3iXF4LeviC5+upGCPJoMtmpVAwT
bKeun3tRCy2yo/arCkpg7k3WimqWEmhL4kyYP1kGSjNjq/pW5sDDMMHZb6gc
auPGojLOJoFYyrr3i4cqYTTd6OfavRGwkn/zgmpaFdjTE8WvXgkEeCTGdmpj
Dbg+XsOqu+kVbJkRCGhUo8P+uQ3pQU/sob7x5Yv13LXgvtXd9t0JS+wfGuus
ppaJG0Kb7b6C9u+1KOeuSGa03zXItkhMk13FeF7+vN3JV/Uu+JyNXfypRUdR
f8P65H8/BcUp7bu7jtWg6LeO1fRnL8DbWrc2uLYK9b8+9OSPUQD2E5bSP4o4
lUWwn1DREmcP2EfFfuK3/suHC6+o2E+46h0ibBnHw1fFa6t8aTV01e6hc5W9
hhxxzrPza+mw3qLipqiWE8juKc12aaFDwY3rnXSte3DluOqW5sBaEJ5+q5j4
xwT7idBzrq+KrajYTwSwl3tSXKnYT7SGlq64w0IlSB/xlMv/XfiAHpA+4ky0
7o+u9XpQwhca1XCpFnW5/2n0/3UTNu0v17ntTUe+h6cuxuy3hQ0vraXZ02rQ
+q6mDWn9rhB1TWeI/XQ1cpGS8E884wtzqmmVf4sq0ZkDyjHdVqGwOSPE2v5i
BXov9+Nn2Y7PMPXaLqiqvAzdSTZbMfo7HbpFfo3aHy9FnTOXvDuKCiBiVZNA
dVMxGs9w7V1ZXsV4fjuiwXOuCMlc3fOn4mk9kH5j97Mkf6ONHUD6DVrhV11/
mx4g/UbXaJ+33b5h7De+3Zj2DsqYANJbzG0V+/hGj4K9hcew+f6tl4Swt7A1
jmuKbhTG3iJgoj/lxpwI9hbD57IvyThSsbc4F7f1buIjKvYWczYeFi0NIthb
fJcKMohNF8beQnaqTH0/pxD2EW3BV2+Vl/0D0kdc3s1y2f/zBJA+YnbU1qjo
/hD2EcXs28NOn+6BFRqeQWuGCuCFFj0y+2871MVV371uVQTvRtFhtrzvkPr8
8WOx7mJ4jCzPTdpWwcRfOS7h24znuX3rpjpa8kE4y9z0/XgZJHAx6dA/p4He
vMC8l14FiBwQLZkviYP27Ydv+/ZWguBDpamDASFAPO/4GnqpGvIKrXRaJnxg
TPrh2FdaDfylvlst7+QKA101f5+H0WFz+w1Ne/pDIP1GCc9JnX2eN0FtP6tD
QXItulVZBXLzRrCmdXD84CQd7YvRLnsbZgU81wJ9dPbTkXnHF15qrQP8MVlp
/JClBs21pvb7nPUEMdUZtNO1Cu19Mjw8tfMd+I7p2EjzV6K5EsXXSeGRcOsm
kXPTsxxF/z1uy3svGQ6Uboi5yFmGrucsG9zpjODkMs8fa7xKUIbE6nNRGqWQ
tfqJ92pqMZobOGQZdq0OzEeGY6+/LUTfDQ+hMK5mIL1JnJoja4zwTyB9yLvc
z28KxIWxDxlaOPvU9LEI9iFtLeJrbmpQsQ8h+pQa1jHeN0kfYjgboXjnEBX7
EO7zfVqZmiIE6Td2bNtfVLupD9SjOU677i8AiJaJEJ3ogi08eR+FkwpBXkA6
uf12E+TFToaoSxbDMacRms1sLUzc/8R/PqYE7FS157Yz/pU1ulYfI1MGPBqL
0sf/5oDszZc6m6LLocK6yPZgSxLUvZc/b7S5Ej5pC75WHo8AKUH9oQsfqmDd
Yy27MwpvwWdozqOYpwa8LdXrn6z0hMoCNZdQJTrkKWtuqpR0gF27rwRkLNCh
N3smK4XVCnuTU46N+85xGAGfz1tHxc5a9PpXs7NkgwGMTR5Xc9tSi24LzLyO
9rkDoqpJ942N6MhV1M/wrtpTYH9UUoF0alDo1+txmu4eYNiw/cfKvipk0F//
ZqOLP/Yqh6RHZGulRLBX4fMXazwoScVeRYmAJ84vqdir+Eg2HvXTpxJ9WbcS
UhKrwcCFuE7X9wKDoaNEMYUOXrSYTWvFnsHL536lG2rpwJL1WkBSygZW7b1a
v+FlLVQnHrriPGGKvYpu2QtUe4uKvQrf63j9aTcq9ip3hLLNLfmpBPYo40GU
ljh9wP7EJllt/DkV+xMi1S70twWVIH1JWkrYvYOM30v6ks33gw6LM+4fpB9Z
iBP06mPcv0kvcsuD1i75kIq9yJmYJ7feO1EJ0odwT1kW7NijB6QPuTSy4pL/
+6vQpTFoyaJbi9IKvghynmJMRntVA6QD6Miu5A39wpdH4KQu2aaaX4OOK75D
SXauIOCrdOeIZjX6ZnBvx8KwDySN88oY1lYiUdurO3UkQ6Gjamtil0EFGoju
C2ZLjAOvW194J+vLUNy53J7Dz9Oh2tjtSMPZUiQaOblY41gAPk3xcit/FyMr
2rCjvWEV3DV11X6mW4Towja1Pw/VA+lX/BPfxrMMtgPpVwSVMvfMyfcA6Ves
tnW3bxkYwn5l61qtdqXnE0B6kxL2zctjzlCwN3mz1kMi5IQQ9ialJ1x01auF
sTd5EOy2e2ZSBHuTSE2x7ZL2VOxNODS9Dyg+oWJvIqR7SIfeLoK9yeZfGjNq
hcLYm+RMlmgJiQphH8JWusbceOEfkD7kgKegolj7BJA+JDT68eNt+UPYh9CY
2n+aPusBmwvL17Z2FsCfMKbUNMkO+HmohX/OlPF8PXZ2113mesiPuayc86MY
dC5ffhz0swrENIzf9V0rhWSzNVlZGwpg7P32lcd7y2CTdOUfK7Z0kLcM/nH0
fAUc3yRwR/XIZ7i+46rpytZKuPf5py6lk/F8na/mr3e6GnTPH9j5+7Qv+M+l
dbz7UgMzAjfq1WZcYQVf2nx9EB2cp84yf1F9BKRfUdYYFtspfQt6lGS77mbU
ImMepn0bvIxgv5g8Mpqlox/XI1mIg1ZwWm9t7dpDdPSoMG8Lj60DnN5eI1iw
vAbF3644bbjcE1yftCvd8KlCu3cvX++X9BZO+ye1BK2qRPZOwaq1KpGw3aF4
uvpdOUqU4Q25J5EM9eGXVj4RLkPhnSIc9RQEezX3bbMMKkGv5faw5rOUQkzz
uSzjjcXI7OlVVratdYz3t31p3RGFyHiPwffhrCYgvc2JRO3PPl1dQPoYJpGV
3lGiwtjHBBaeXyttJYJ9zJ0t/qobVKnYxwhuf3v0GGO+J33MOfnOlqdKVOxj
bjnJbP6oL0KQfkWCBclbG/dBypqUkEM7CsCbtrHQbstPcOY/tPn7x0KIqdve
TS1ogloFVuhaXwynbhQ66u2pA6ZA1/qRoBLY8C3qgs5iCRjkeprZbymD9lLT
bFHTXBA+e3p5ZVA5oKxVZuobk+GTSMmuFSsZ7106w2Nz5yMhU8iup9GnCmS+
Wfcd+fwWQOKGhhNTDfw+f+lQmq4nrI++ueCsQIdOpdwX8U4OcFlb+T3HDB0O
7OZ32HnNCnsbdZHvKlaPjCDiffXPwZ5a5B4hVffokQHwynuvTNlRi86s/jxZ
eOAOaJ7c92XrDTpC9bEpI6xPwfTQ4/ucpjVIgcvUbk7AAyq5KJcvTVWh1GRt
Tt1V/kB6HRnegSH7zSLY6xyzuXi/cTMVex1DttuCfi+o2OvwK8RTTIwYz9eT
LVZ3I6oh6uP7vNF4L/jy1TAthocO5l8z3hxwfgaZKY+rb1XQgcqkwf7mnQ3c
3266q8ilFjoPyPfPPDbDXueZ9uZPITeo2OvM7NV+uN+Dir2OTUwnc5YIlSA9
zvnSW/o2FAMg/U2YdtVJG8bzOOlvDNYH/KVaUgnS15wdXjZpe4WKfU1aUUJw
PWO+J/1M3j15NmfGfE96mfWn9Ha521Cxl1nZwdtjxnj/J31MO+eg8eRLPSB9
DK/sgxLqMyr2MeN1GubfGN9H+hf6kMvfc4z1kf4l7gK7iR/j/kT6lqowTevT
7lTsWwSebh8+zbi/kn6lSPHYxh2M8530KxE8Pesdk64C6Vda+W9YBqpfBYtx
Ly1R/VqklpQp3bBgDhzJL/cLvqOjJt7PZ+etHkGqtPPesZIaVB294/7Zk65Q
GPdFxkC3GsUf62xJy/OBl8Vphqt+VKJ7o8vVZzlCQbGhT03IrALZvciXrbSM
gw4d9ULO1jKkaLhOQv9yOijxXzF31CxFnOZNSvzXCsAjM7BScbAYuar5XRKX
qQJPlk96SoZFSDHzy664NfVA+pqTUyy5RrR2IH3NxwcZ9rqre4D0NVeU3sxG
lQxhX4PcOT9I35kA0sOY1sik7zxOwR6mVjxDtV5JCHuY6V5/pzelwtjDaBqJ
6CSPiWAPU9rH9WrVU+qSh+n0PG9tR8UeZsXIrtWKP0Wwh3n+znCbcLkw9jCB
q9/R768Twn5lTcFuvooVs0D6lcm1xfJP/04A6Vd89hIT3L+HsF+ZKzn2Wiy0
ByJ+VOjkNBfA8UKxhuojHTDAfq1N+VoR3DmX9NpoYz2oHCyLdK8thogcgS0G
otWQOj/36/uVUpjhNlz5ULkA9L2ejwZ2lcFqIqY6Viodtuz6pbxerQLMtB6s
eG//GXbvvGWo/aMSPiz4NOuyh0Je+7OH6Fg1OLl3Wl5/4Av9nfWX7ONrQOg9
i0vA3ufwOSzm6XwgHSpUL7GsfPEISF8zs9fmT6PDLUgqPeN1MrsWCXE0KKpe
MYJCWlv4wwU6att7LqN8mRUMtulaLABj/vkdv4XnrAM84dluZiJUg+ZP72Ay
qH8FCm/OsrkFViGNHSPLgq3fwtYbV/jPi1Ui11m7VVqrI8HV47nfYmg5er4Q
HSXIkgybvMfor1eVIULnb7BsQy5EMXGeXRdWgpjvNLKGNJdASJbiGQ+JYjTw
9sHAGGcdFOdeyg6JLUQZ05xIy7cJSA/EdcTZIaGsC0i/88RnaPQ1RRj7nT+p
OhyuFiLY7/TfdJEbOknFfqePy0/9NOP6I/2O2ha/lhllKvY7Gz7tkOI3FiFI
XxNqkOFm5dIHxvVup/23FECdknhxE/yE1Nezhl/eF4LuweBPdgNN0MTmtlxy
VTGI50YsuJ2pA+ftf+XRmxJwMQ0ovri9FKavb002FyuDA/NaW7hDcsFB+dOv
9f7l0OjZPJxwNBn86cvfjQpWwuBpybuGzpHwVPhl1+pXVTAp8s2v/fdbED4a
uufnv2qQNACJDHtPKF09L/9Ang70elXOtEQHGBnZv3HnFB2e3ZX64+JthT1Q
6VY+j95UI7i7ude76E8tUt9wOrxQ1QACm+QWS6VqUXx4TJYl3x2YKb13jvMW
HWkLgOfpXDsIXNdQHXuT8T7p/+eW4zd3eLrRafW9uSp0wsai4EP3GyA9kU9n
uIOqmAj2RJLnTPVWi1OxJ1pgGcwXYNxvSE9UejZEjzChEtcFhS/VfqgGrS7W
OMsfXqB7bGLsHScdQppDF8cynoH6yTsavqV0yIlb0bP41QYiP5o3+TnVQrmD
3ZOsAjPsiRZ0LBXmzKjYE0m/XT1SxrjfkJ7I5dFpTfoKKkF6ofiK5l1cygZA
+qBnQaxysS5U7IOUYv/dem9FJUj/03pijZmnNhX7n32PJHeLM+4HpO/Z7JkZ
fIwxJj3P2/u12jvvUbHn+WTmJKLE+H7S7wwdL3n7KkcPSL+TLPT7twTj/YP0
O8ERPCwLjO8jfQ7XuGXAKOP+QfqcrfL7804x3p9If6MDVMVwxpj0N3KW3+9l
M5YnfY0073QGP+N8J31NCf8J3jl2PSB9Dd28dkiW8Tnpaa7rGUcIMv6e9DM6
nDxn7Bn3O9LLrNCmxWQzfh/pZQorj4qGMsakj3ley+kfx1ie9DBWB1vKgfH9
pIdp683Wm9a6ir1KmfEG2lxXCPYqzeaK6W8vRGCvcqjH1WHGLBZ7FamvD4QL
yhKxVxF5Fv7cbUcq9ioO8bQj3tuysVe5cWd9YGMADXsVie2FlRevF2OvIhjp
t6HyRiX2Kl3eDjTfrFrsVRosxe57uddjr6Kdtu5Bwb4W7FWG73b3nPDqxF6F
sKUG31HtwV5FJTPCmqmlH3uVCDmmyseZo9ir2IZ/qy2+NwWkVzH2mJRwZ50D
7FWa50/OVDBjr8L6SbqT/zAH9ioFFZoCRy/zYq/idSP58JnZpb6BzEm1Sc+7
VOxVngfer2F7sQZ7lYE1Km+92zZgr6J1KUB009QG7FUeHvSI9z65BnuV1J9X
3kSFUbFX6cpeJ/CvZKlvYGqWSXJ8OS/2KvQNb8e/2XJgryIpoxu0KpEZexWz
NyGR7CfmgPQq5vo/bP9+mQLSq4TlFxcX/BrFXsWnMuyAZ/QA9ipZ9gVb05x7
sFfZOf2th2e+E3uVbOvw78ebW7BXUdS8+9Q7bcmr5Lzuj+uWrMNexaJmXMvI
tRJ7FcGZTwtsT4uxVwkQXGMutywfexWz1hS1ZdrZ2KukuAiLPIhKxV5FVFR+
zEYqCXuV16nMG+MiYrFX+ffIirNqKAJ7FfJ6IL3K2LbXYhlzYdirmJfapLJI
R2OvYhX+YPF4RTz2KgFVbE+IlmTsVQyn97SdZuxX0qscaWzhvmWLsFcZ5//x
8mdLAfYqpwZgz9NDZdirvJTbHxKMarBXKan/6PBx4Sv2Kp63VZKE5BqxV3G6
YjBtY9uOvcqHDRuF6BU/sVf5tNxv797BXuxVji+qbxu+OQxkH0Kks8z6qolx
IPsQYgw+KMyLzADZh5BsrvIky3sRyD6EphwO/089rLgP4dXaVV+s13HhPoTk
lGKFwCF+7F8U125cflR0yb+cLXlh2KG+EvuX6mNfjj8eXU8Yt/MtTwrfiuKL
fzW+GhTH/sVtIvrbjs712L/IiRBfGtVWYv/Ct/vJ0BmBJf+yICRK4/Hjx30I
t8xGnZYxfh/Zh4Au1tvuGWPFfQjn/97Mqg5dBLIP4fP4ZjZ9zRkg+xDseGJk
5bdNAOlp6k7JyY+wjmBPo6O5J6/b9A/2NDauyTuJDd3Y03j5dOgorunAnoZJ
wNDNNrARexr9a/alJzW+YU/zQO3z/saVdOxpNK1gxORiGfY0E5ZWCaPihdjT
+DwR0Q+YQdjT3HXJ7v+lmYE9TWW/3GuX0ynY05ysOaQzLZ6APQ1LX5EGT2g0
9jRWH6V5aolw7GlErUIKDXtDsafJlX8Tp5YeiT1NVsrAkQd8n7GnyYw0CEuu
SMKeJmWt58utbmnY02g37uXZVJKDPY1/h6P4+6R87Gk2cmmFSZeVYE8TsPnm
4QGuauxpVtKWJd38Voc9Tf42oUKFhh/Y03DyvwoPqGrFnmZaMIv1dUQX9jTb
uk3057x/Y09zWEbEU+bNIJB9Etk7zzTsqxkDsk+iLuPYs/U5f4Hsk7iv7Hhl
PmceyD4JuuIvm8paFtwnIWv/ISU6fBnuk4jgVH1cR+XDPqdp3Ys91cxLPmdI
qL0uvl4U+xy1zRZvKHvWYZ8jue76tFHnRuxzpFJMdof3i2GfI3n/F5dw/irs
c7itR2s51UWwz/n3Ksl6kiaA+ySIaTv2AHdu3CfhZa0+XbCTHfdJDPg97HbL
ZMJ9EitFHmfoFf8Dsk9i/y05r06jSSC9z7Q085FtQyPY+wT/2zuVONeHvU/B
WzNlnVO/sPcpFy7+x8bRib1Pn6xjoMWuZux9Ku+tuNj66Dv2PlVdcSnNq2qx
93kydDtL6Wc59j699fVKwSeKsPdREJLt2v4vD3sfZNhoJlmTib1P7rGImT13
v2Dvw/7N1KJvQyL2PizWY03vVn7C3uenx+wpiRcfsffpWUgd/Cr2EXudrxt4
64w/5mGvw5RxdzxnZRH2OdO6e7XXltBxH4aEj93z7Zf7gOzDsPU3k55KGAE3
Va5971jSkH+3HOtNh3+w/22cf75oIuL4xsJlxbPUl2Gl6POyPp4b92O8NLBW
f6mw5HX+3dhIaegWw17HVs6x4NS/jbjvolh68sq5n4IE6Wt2GG9pajhTjf1L
ptCh0GrFKOxfVqugwiecYdi//LMJ0++4For9i2valOhJtkjsX265juw/Kh+H
/QuPbt27CZUk7F9WfVS8m92Qiv3LpheGzg8ms7F/kRLWU127KR/7l8BMs+lt
oiXYv5x79T18YX8V9i/FOidUe47WYf9y4UvHam+pJf9y4LpteOdCC/YvORJh
zrqrurB/sdr1pO3OUA/2Lzll2zyVUgeA7NPY/P5GcZXSGJB9GiLMfaVJon+B
7NO4CP7pVq1zQPZpFMv55vKpsuA+jfVOP5slRzhwn4aQj9luxX3LsafhtZkY
zLYVxJ7mK58tjG8QxZ4mRcFLUOTKWuxpZrd3LuzV3Yg9zWheMMvvWxuwp7no
nL/K33E19jQcF5gfqPwVwZ4mS4M5g+PIUp/GmTHup6tO8uA+DTlxPY+yOnbc
p3H4Mlq/ci8z7tMYKXU8wftsFsg+jY2ntHab80wB6XPqrCq0FU1Hsc95NTT5
oaemH/ucmD9mCnU9v7DPWWbBHfrNrhP7nOxIOaFI5hbsc+x5pF46idZjn8Mf
nUc7E1KLfU7gtb91yUkV2Oeoimy99amrCPucAEdXj9gnNOxzWjW9+c55ZS35
nJQ7uXt5UrHP6ZZron2OSMQ+5/u9Hx36rZ+wz2mf4w0/eDAC+xyJA2xByCMc
+5qn+5tPy+zOw76mqqD0V//9QuxpaM9Kg1s06LgPZNW6kdbNIX+A7AP5GKIe
KiwzAqGhO0/zXElDcz8lbRLLZqCHu9bqjGUiOhtte47Nhg33hdwf/uCwppsL
94MMbR5W7IwUxr7mutJzEL8phn3Nbtlp3x/24rjvIwglCnrYCBGkh9klGiq9
VrEGe5Uw/fVaE4NR2KsoPt+37GBoGJB+ZNG8dApMxbHfUA4JV7lnGYr9huCU
uPDcxlDsN8z50xJOxkZgv6HXOfG3mx6L/Uagsm56P2cS9htztne+LdinYr+h
uFzxJv1lNvYbXY9CM63baNhv+FwYU1mTV4z9hvX7py67Ge8NpN+4+sdktzzj
d5J+42GZSe5iy5Lf6BKQKQ0JaMF+42Mjsqj73on9Bne+2gODoB7sN3Y/Lp9V
UxkAsn/jcP/nlE0Lo0D2b2hX/ov/XDwFZP+GxNVu2XiLOSD7N5wfigcJ8LLg
/o1j56IPTrzhwP0bU885dUaLebEH0dFwIbwPCmIP8iysUz+gjIo9iE+eNv/Z
iTXYgzzbd6ZvfO1G7EHa7r/RYUvagD1ISX28g2HPauxBzCob5mpPU7EH8Uzr
VGF5ttS/oaL0xlPrEw/u37isYrlqx1YO3L8R2q75Z9tdZty/MV2e3KvTMwtk
/0bAzYc6/HpTQPqS/YXGT15HjGJf4ij8MuHPwQHsS55Qjn7dK9uDfcluu5lq
5txO7EtOn+LeH3mzBfsSjqJM6rxxPfYls4VBq4R7arEvYeYwfkFbU4l9ifSF
m3mVu4uxL+k0aFSyyKdhX7LPLmH1zGQW9iViol99T2ulYl8y7+FR69mXiH3J
N2EJpfOHY7Ev4RaV/KHhE4F9CVtDgIWCcjj2IamttI6gQYR9CL1uslZ9eyH2
IBbR7uO3V9Bxfwg7z3ivx7E/uD9kJtjyy7reYdhVhX4ouaUhMUWpCDmLGcjN
7+oSCUlEHmydvRd3LfWLDN90CX3+lAv3iWQ9h3rBq8LYh0Sc8TB2lRHDPuTi
CdV2jhJx3A/SxZlgcrlAiCA9R0vBsi3/0mqwt/B5PWhz9Xg09hYH+e8Y9Y6E
AekfVtE45HU2iWN/IOvUrm+cEwqkJ7CO8tEIPCSOPUFw7d9HwnHi2AvcduHr
jd4eir2A0oLIQjtLKPYCm+Ye2JQ9jcBeIDfG5y8RFIu9wEOLhFcH/yRiL7Be
k/i6+lIq9gLnlAM+selkYy9w4m+4LUc2DXsBjdp9dQK+xdgLNIx63dQIrsRe
IKG006G4tRZ7AddjOwI3pSx5AV1Fz2xnkxbsBcTHLvwdTO7EXuCqPvXhMese
7AW+xZ6wHacMANl3sYBk5aRbRoHsu2ir3XP/TfAUkH0XXx4dNDKTnwOy7yIi
LUK1t58Z913ctkn/e8mcA/dd7HKbcjHx5MX+YGXsltzzqwWxP7irc1+tP4iK
/UHlzxLux3lrsD94Trdr3rqwAfuDqMlNCeNfN2B/sKzv1J0zK9Ys9V2MR18U
uk/F/iBhLspMN2Kp74LbsxQ9bOHBfRe84gctfmhw4L6Lu1HfhJxfM+O+i7gh
1+lnonNA9l2IzPg9bXKbAtIzHL8t7cFXPIo9w7Wv3Btc7w5gz3Dv43Shhm4P
9gxvArN4b7R2Ys8wa7FT6Eh4C/YMXn+entn0askz5KHRt02cddgzKD4rVtc7
W4k9w3O7TYVHNYuxZ/j9c7gsqZuGPYPXsuftZyWysWeIlnBhzXuaij1Dzvor
9j95k7BnyFLW8PpqGYs9g07WFhsDWgT2DJ9PsLBri4Vjj8DOttzqawrCHmH5
hy3IirUQ+4MDm4xW803X4L4O4k9NVfrKP7ivw3n1RebKmGGw6nINavuQhuo2
WrhZKs1ATHD/ypm0RIRE62T1uZf6PBTVl29XP8OF+zv4TnpReQ8KY49Qp6/y
+rmIGPYIHWv8Nf79Ecd9HK6Um/Pxf4QI0g8MpDSbB07W4Hz/9O9R9hdW0Tjf
X8fUwfRlRTiQebtXiXJQAYs4zrs1I84TVV2hQObXxErN3sCr4ji/Zo/S6nd3
E8f59LHZ93/61UKBzKMlyj8WqoeL4zyZTRgJNdWI4zz505UPKfEcoThPduMp
Ofl7LATnyXKcETISNyJwnlxQyJn62jEW58kNz1wM7jcm4jw5apkSc9nhVJwn
x7c8S81TysZ5st/8VMnvGBrOk6tnZmOi7YpxntySW/SG9VklzpMN7vsOfKys
xXnyGvXld+reL+XJ4UZWkoFqLThP7ugs+yMU1onzZP+Lb6TO6ffgPHlR6u7U
wFQ/kH0NPqURLmcqRoHsa6B8e385gnH9kX0NhjvoejfXzQHZ1zCesDb6TzMz
7msIbZ+6HX2RA/c1bFzTYX7Cmhfn00JC9r9O8gjifFru/+3Uqi3GHWLw+Wle
p4S4rctk4PPT7oZbjoe9U4TPT5/jm72T+akifH66sqsxJs1QBj4/vYiLueBy
rxh8fjpVeYmLynbEeQ2BzDYsOl+54ec1TCqc9dA7nQ1+XsOLNWlungsZ4ec1
LGFa+cnK4I897LyGMqOPO+MWfLOHzXczNCyWfXT1I3y+e+PMb6//9b6Bz3cb
VgknVBc9g893F+pLNZi8fQif75bL4ffesf8OfL7baP3LB0GLEfPdBzpWa4VL
XYLPd89RrGYIyz0Dn+8+z3F0kkzOMfh89/zkDf5vvx6Ez3evYG/fvtBxD3y+
+88tjQuTp2yDz3eXXDlfqSq3CT7fvXi1Fodp7xr4fPfO1uIynhvL4PPdetyC
mk18S+Dz1dcWuWlNmbEfPl89K2LXZaUPh+Hz0/caze6fvH0eft5E25vTM3OY
X8LPmzgtyPzCr+e9vXhuboPOmu37f+2qmqSn89N+AU/B1qzDG/f3tWnn1P1g
hp9HId6+UOq6GSf8/AkBNqVFCpoi8PnqutDMxbLsCrDxZ3vY+DPsPIl5v3sX
fvsj7ACbX25tFt7izXUBPv97Q1uZ26l7JXz+d5eXN99OHWC9Bp2PPTSvrIj3
kxJ8PpSvoGnJnK+L7GHzm/Oer926sUAZPr854bJlSlylMnz+8vbhYhaNxEX2
sPnKbPUjuku2KsPnGxV0bBfk71OGzzdyv665u1hiEXy+0c99z7OKG8rw+cG5
S/49Dn6oDJ8f7DPbHX32y0J7dP+jj8df++t9W7Jo4W4YH/38cph6ND7O853R
9aPLw/bvo+/Xh/EBnsSU9A==
      "], {{{}, {
         EdgeForm[], 
         Directive[
          GrayLevel[0], 
          Opacity[0.1]], 
         GraphicsGroup[{
           Polygon[CompressedData["
1:eJwl01WQl2UUB+A/KaKCdMMuLIpegDRIl9TuhUuDEotKzdAgIaikktKhMyyx
SkkLGEvMUIrS7YWidKhjYAHjc8aLZ8/vnJ1lXt7zfskZQ9IH50wkEjl4w49f
1dN5EokzbNC/qT+jDuAQ+ThOF3awxe/7qHv4RW6ifkCa/JjanV18qv+bNnIW
A+Xcaof4N3hf/y3PytOpLO/hIWn69UyUN/MzjeNvSJV38xet9WvirPJyLvGM
fhop8gQ28RONzJbTXu7PMi5SxWwqleI++Ji7NDRbRju5H0u5wNNmU6goj2cj
d2hgtpS28mss4TxPmU0mOe6CV1nMOSqbTyIp/i+8wiLOkmL+NhXkF+jLwtgN
lczforw8jg3c5nmzJbSSM1gQu6Vi7JVy8ljWc4v6ZotpGTtlPqdIjrunrDyG
ddykntkiWsi7+DPOpl9Nb3keJ0nST6CMnM0DUvXreF1eyw3q6hfSXN7JPVrp
V9FLzqWms5n39CeokOP/d1tafkJ9Kd4aX8T9qfu5L7dX1zI69q0e5BGO0Znt
fBTnjbOTzXX9V2odFtAsdqEO4gj5OUE3dvJJ3K/al338of867pOV9Iy3ox4g
Jy+yibnmveLM8W3J5dXxlJIfV3uwm8/1/9IuzsooOa/aiW18qL9GbXk+TeUd
/E4LfSYvy3M4Rjn9OErKI8niKrXM5tFE3s5vNNeviPuVZ/MNZfVjKSGPYA1X
qBn7obHcg1lxD5QxG0NxeTir+ZEacQc0krszk6OUjvdBMXkYq/iB6mZzaCh3
Y0bsiVKxX4rG90dX3uVLSsZ9USS+C7rwDkcoYT6SwvEN0JnpHKa4+QgKxXun
E9M4RDHz4TwpD2Ull3nObDZ15Y5M5SBFzYZRUB5CJt9TzWxWvDO5A1M4QBGz
oRSQP+Mf2saeGSznUTuyNXaj/46q8kxqywPVwzxK13if8U7MT6kZ7OU/dcW7
Zw==
            "]]}]}, {}, {
         EdgeForm[], 
         Directive[
          GrayLevel[0], 
          Opacity[0.1]], 
         GraphicsGroup[{
           Polygon[CompressedData["
1:eJwl1GW4FlUUBtCPRrpbkBZFURrsRLAxCekSle5G6VJBJZRQWlJFKQkFBFFQ
SrpB6ZQu1378sZ6z3z3z3dkzZ+YWbNCyeoukiUQiCfcodis2pEgkNpJBTpU8
kRiVLJG4xf18xCU2OlbCOoDTdJV/Ipe6I3soJ6+nqLoPx6ktf8UV3pSXkV7d
heXklDuwm7LyOoqoP+AYteQvucwb8lLSqTuzjBxye3ZRRv6dwur3OUpNeQKX
eF1eQlp1J5aSXW7HTkrLv1FI3Zsj1JDHc5HX5B9Jo+7IErLJbdkRzyvukXFc
4FW9xdym7sCPZJXbsJ374p4Yy7+8oreI1Or2LCaL3JptlIp74AvOU11vIanU
7VhEZrkVW7k3ZuZzzvGy3gJSqtuykExyS/5K9v/78CpjOMtLevNJoW7DAjLK
LdhCyZiZ0ZzhRb0fSK5uzXwyyO+xmbtjZkZxmhf0vieZuhU/kF5+l03cFTMz
klM8rzePpOqWfE86+Z14PykRM/MZJ3lO7zuSqO+M+fiUEzyr/y0JdfGYhU84
TjX9b+Ib8G3c5AbXucZVisUsjOAYVZ07lyuOFY3rMpyjPKM/h8uOxYc3j7Ry
czZQJGbhY45QRW92fHPxXcbc6v6ciucof0ca9dv8SWF5LQXVvfiHavLd1kGc
jW9Y/oen1bO46G/fZ/0w6vg7ce/WaxSnHydjH+JZWm/EuxHP3f+GIdbz8ewc
Sy4Pj/uOdzyepdzM+geFHE8pj1TfjHcx9lkeav2XXx1PIY9QX+WO2Ce5p/Vv
qsZeWa/He8BAzsTM8aziecZ56qesM7ngnkpZh0UdMzhWzNqXE/GOyCWtgzkX
+yuntjZlPQXlNRRQ9+Awz8jDOMyT8oyY3XWay3NJJTdhXcwvrya/ujuHqCIP
5RBPyF/Hs/P7t+U58XzkxvxOgdgfhnCQx/Wmx6zOzx/3yWAO8Jj+tNhbx85w
mlOc5AS3x7wMYj+POncqxx3LF7MwkH08oj+FY47ljesygL08rD+Zo441k2fH
nsmN+I08MQv92cNDepM44vym8qx4R+SGrCV3zEI/dvOg3sR4Z53fRJ5JMrlB
vB/kivnoyy4e0Psq9t35jeUZJJXrs4acMTN92EllvS9jL53fSP6aJHI9VpMj
ZuYDdlBJb0LsnfMbytNJyHX5hewxM++znYp64zno/AbyNG5RR28V2WJmerON
CnrjOOD8+vJUbvKW3kqyqn/hdnW3+LtUlnuxlfLyWPb7fT15CjeorbeCLOpV
5FN3jetQSe7JX5STv2Cf39eVJ3OdWno/k1m9krzqLnEdKso92EJZ+XP2+n0d
eRLXqKn3E5nUK8ij7hzXoYLcnc2Ukcewx+/fkidylRp6y8mo/pnc6k5xHcrL
3dhEaXk0/wG2CSiK
            "]]}]}, {}, {
         EdgeForm[], 
         Directive[
          GrayLevel[0], 
          Opacity[0.1]], 
         GraphicsGroup[{
           Polygon[CompressedData["
1:eJwV0mlTTmEAx+HDMINEImRrIku0KFt9CUulfV9sLxjbMEzv7FuytcmeNvkA
VMOgrBWy+wDC+Ayu8+Ka+/z+5839PHPiK/dk7R4fBME4Rnk0MQiGGSFzQhC8
ctYywFqO8Ix/3qU5D/GEbv2XVM8H6WeXbuEncbqGh2ToLv6Qog/Qx07dzA8W
6Wp62KB30MR3FtqqeMB6vZ1GvrHAVhneh3V6Gw18Zb6tgq7wt+garvGFebZy
Olmjq7nKZ2JtZXSQrqu4wifm2kppJ0138ptkvZ/e8D76MqPM0SXcZ7Wu4BIf
mW0rpo1UXU49H4ixFXGPFF3GRd4zy1bIXZJ1KXWMMNNWwB2SdAkXGCbals9t
VulizjPEDFset1ipizjHO6JsudwkURdylrdMt23lBit0AWd4wzRbDq0s1/mc
5jWRtmyus0zncSr8/phqy6KFpTqXk7wkwraFZhJ0B2Mk6X08Du+jTzDIFL2Z
JpboHI4zwGTbJhpZrLM5xgsm2TbSQLxuJ93zYZ7ySx91Pg//SwbZy3/h3meF

            "]], 
           Polygon[CompressedData["
1:eJwV0kVTVXEcx+EDgt3dgq0rZxwLA0RFEZOX4MIC7sVCUaTsbld2rVS6LBR1
xo2+A7tWjordPmfxzPl/vnfzW9zEJdHMSGwQBDE00zouCB7GB8EjMr0f+BZw
n7Hk08Q7v43xzaORLfoerbznc5wEfYm3jNa5NLBYl3KXlnoexxikF1FCE/G2
DI4yUF/kDaN0lHoW6mLuEKfncoQBegFF3KaFLZ3D9NcXeM1IHaEuvFsX0kis
nsMh+unzvGKEzqE2vFtv5hYxejYH6aszKOAmgS2NA/TR53jJcJ1NTXi33sQN
/jHLtp/e3uls5Dp/mWnfRy/vs7xgmM6iOrxb53ONP8yw7aWn9xmeM1SvpCq8
W2+ggd+k2vbQwzuN9dTzi+n23XQPbySPOn6SYt9Ft/BG1lHLD5LtO+ka3sNa
avjONPsOunif5hlD9AoqSdVrqOYbU23b6Rzew2qq+MoU+zY6eZ/iKYP1cipI
0auo5AuTbVvp6H2SJyTqZZSTrHOp4DNJ4X+dDuHdRCnnE5PspbQPbyRCGc1M
tJfQLryRHK7ykQn2YtqG95DNFT4w3l5EG+8TPCZBL6WMJJ3FZd4zzlbIf0Hs
d34=
            
            "]]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          Thickness[Large], 
          Dashing[Medium], 
          GrayLevel[0]], 
         Line[{1, 365, 272, 193, 129, 80, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
          12, 366, 273, 194, 130, 81, 52, 394, 301, 222, 158, 109, 13, 367, 
          274, 195, 131, 429, 336, 257, 451, 358, 82, 414, 321, 459}], 
         Line[CompressedData["
1:eJwt01WQlmUYBuAVBEUQRLpZUjyQUjqk0wM6VViQcgYUBRMRJJWwe0bBIFUa
UQxmFBQTsDkAQTAAdezC8bpnPLj2uZ9n//33e+MrLJo2cOoZBQUFN/vxk/qa
WsR+Num3qsMpxR6mcIn5XepFHJKfYKM8mBJM1T+r9uEv+SXKco2+Am/I8xhE
K5aYNeWw/CTTKMe1ZhV5U57PYFqz1KwZX8or8r2cx3SzSuyWFzCENpTnOvPK
WYO8kKG05XyuN6/CW/IihtGOCswwr8rb8mKG056KzDSvxl75TkbQgWVmzTki
r8w6qMQNZtV5J/vHSDqy3KwFR+Wnsg4qc6NZDd7NHjGKTtxt1pKv5KezNqpw
k1lN3sseMTpno+/Kz/JmOnOP/mKOyc9k/VT9/w7U4v2sgctzHvpu/CJv4VLu
zR3geM6ZTfIQSjJDv0rty9/yy7woj6JM9kt/i1qbD+Sd6pUsl59XB1Asd4SJ
XJEzVrtnH/hV/7o6jgNs1W9TR/Ah5+QcuZqP6eL396mtck58rX9FHcM+VmVf
1KFZN2flvjGJmX63Wu3HP/IudTw75R3qaM7NmepvVevkGXI+vCAPpHjWl3ug
9uC3PC9duV/fmm/yf3I/WKPvz+k8JzWYpa+b583ZMSb3RN+T3+XtdOMBfRu+
zffk/lCT28wK807n7BhLdx40a8t38trcH2ox26xe9jd7RxE9eMisHSfkdbkv
1OZ2s/p8lDUxjp7UYY55g5xFno/x9KIuc80b8kmehavoTSF3mDfi0/xfJtCH
h83ac1Jen7tEPeaZNeazfIaJ9OURsw6ckp/LOVGf+WYX8Hk+wyT68ahZR77P
fcze04AFZk34Ip9hct49fS/+yB2nP4/pO/FD7kD2Pnurv4x/5VdpyEL9hRzM
37BBHsSZTMl7qfbmz9y1nLE8ktL5Lv3jamd+zHeqY9mQd1QdlneLs9nN5JwN
s3Nu6n9pprmy
          "]], 
         Line[{334, 461, 255, 450, 357, 191, 442, 349, 270, 38, 392, 299, 220,
           156, 107, 78, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 393, 300,
           221, 157, 108, 79, 413, 320, 241, 177, 128, 428, 335, 256, 192, 
          443, 350, 271, 457, 364, 470, 50}]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          Thickness[Large], 
          GrayLevel[0]], 
         Line[CompressedData["
1:eJwl1WWYVGUYgOFhaREQBJGWFGmluxGlBFSQDiVUOqS7S7oVlJBSUrqVRhoJ
aaVbur2/yx/3dd7nPWd2ZmfO7KZr3Lp6q2iRSCRbVCRyyjA5eiTyHod0d/Jz
RncmOVt0QjaZP+OJeSb1OO3xU+zycFj3oABndRdS8Jt+jc3m2jw1z6J+eB6P
n2qXlyO6JwU5p7uSkt91IraY6/DMPJsG4Xk8fppdPv7UvSjEed2NVGzVifnN
XJfn5jk0DM/j8d/Z5eeo7k1h/tbdSc02/Tq/m+vxwvwTjcLzePz3dgU4pvtQ
hCRstavPS/NcGoef6/rpdgU5rvtSlKRss2tAhHm6Cf+4foYuxAndj2K8wXa7
hkRjvv6cC67/QRfmL92f4iRjh10joligv+Ci63/URTipB1CCN9lp15joLNRN
ueT6mboop/RASpKcXXZNiMHPuhmXXT9LF+O0HkQpUrDb7nNi8otuzhXXz9bF
OaMHU5qUXHVujn0JzuohlCEV15z7yb4k5/RQypKa687d4Ca3uM0d5rq2FOdd
M4xypOFf5+bZl+ZvPZzypGWP3RfEYpFuwV3Xz9dl+EeP4P3w2ekepGG7fos/
zE2JzWL9Jfc8foEuywU9kgrhs9Q9ScsOnY695mbEYUl4rY7DyM5X4Xd1HEBm
9un7jiPJxX3Ps9CxHBede+Q4mm/Ntx2HkDV8vxjPB+H+cOwV7rEYXn/47jM2
fGZ6Z3jt5hHhHtE5w3eDieH90emd32duHu5pHdfxMWPCPaKXhvfOPDzckzpH
+G4yga+du+E4kLfD3wzGsd/+QXjN5OaB3+lnx/Jccm4Ud8xDycaH4Z517E06
dukM7De34BWW6ZbcNA8iCwf0Qz/7F/P7XNajqUhGDth9STyW61bh/XT9Il2B
K3oMlcjEY+cWh/eUq3oslcnME+ee8oznvOAlS8Lr55prxlGFt4mw1L4i183j
qUoWorHMvhI3zBP4iHc4GO4RXuVX3ZooluvK3DRPpBpZORQ+B+KzQrchOr/q
KtwyT6J61P//Sw7btSQBK3VbYrBCV+W2eTI1yM4Ru1YkZJVuR0xW6o+4Y57C
x+TgT7vWvMZq3Z5YrNLV+Nc8lU/IyVG7NiRije5AbFbr6tw1T+NTcnHMri2J
Was7Eoc1ugb3zN9Rk9wct2vH66zTnYjLWv1x+L6Zv6cW73LCrj1JWK+/4RXW
6U/CvWyezmdc1n1Iz279Hn+ZO5CUDboz8VivP+WheQa1uaL7koE9Og8nzR15
g426C6+yQdfkkfkH6nBV9yMjf+i8nDJ3IhmbdFfis1HXCt9t84/U5ZruTyb2
6nycNn/Dm2zW3bhlHsw7HAzfOcdRvMtLJhHb34YEzv0H+H8m2Q==
          "]]}, {
         Hue[0.1421359549995791, 0.6, 0.6], 
         Directive[
          Thickness[Large], 
          Dashing[{0, Small}], 
          GrayLevel[0]], 
         Line[CompressedData["
1:eJwV0sVyFFEABdAOJLi7k+CwoorC4u5B8gkssCSTYIFAcHdnhdsKdw8EqOIn
cFtRBHc5b3Fq7r0z3VXd85KmVZfH4qIoaqJVfBQtS4iisbyXT1FBMmdt00nk
sb6f1izXx9Ekn6aSFNqwwj6eD/IZqkilLSvtE/gY7k2MNNqxyj6RT/I5qkmn
PavtyXyWz1NDRvidbQZJPNEP0IE1egpf5AvMITNca5vJIJ7qB+nIWj2Vr/JF
5pJFJ9bZ0/gmX2Ie2eG+tlkM5pl+iM6s19P5Ll9mPjl0YYM9gx/yFRaQS1c2
2jP5KV+lljy6scmexS/5GgvJpzub7dn8lq+ziILwHLbZDOG5fpgebNFz+CPf
oI7C8Gy2CobyQj9CT7bqufyVb7KYInqxzZ7HP/kWSygOz22rZBgv9aP0Zrue
T8RtvZ4S+rDDVkAcd/SllIb3pFcxnFf6MfqyUy+kGQ3hDFMW3p0eYwSv9eP0
Y5deRHPuhjPMJPqz21ZMPPfCGWZyeNd6NSN5o59gAHv0EhJoDOeaKQxkr62U
FtwP55qp4b/RaxjFW/0kiezTy2jJg3DWaZBrGc07vdFnHWN4SD2PKPfdf0jO
ddU=
          "]], 
         Line[CompressedData["
1:eJwV0tdOVGEYhtFtoom9Ya8BRZQqiO0mVHpvA9gONLZoIJ7ZexdQsIMiegG2
YBA7FlSwXYCK8Rpc/8HKzPNOJnuS+eJjW3O3DIuiqJ8HI6JoGy9I4RmN/Boe
RU+97iGLDh3PRe/XMJJevY88EmiyrWUUz/V+8llAs20do8Oz9AEKeKi3k8pv
fZuFtOgcxvBSH6SQRC7ZchnLK32IIhZx2ZbHOF7rwxSTRKstn/G80UcoYTFt
tgIm8FYfpZQlXLEVMpE+fYwykrlqK2IS7/Rxyknhmq2YybzXJ6ggleu2EuL4
oE9SSRo3bKVM4aM+RRXp3LSVMZV+fZpqMrhlK2can/QZalhKu62C6XzWZ4nx
SO8gjT/6Dpl06Epm8EWfo5as8B/ZqpjJgD5PHcvC923VzGJQX6CebDptNczm
a7gl1rOcu7YYc/gWbokNrKDLVstcvodbYiMruWerYx4/wt2wicd6J+kMhWez
ivu6nvn8DLfEZp7oXWTwN/weur3fTSb/dI/XBrLDfbM33B+rffYf4XVl2A==

          "]]}, {
         Directive[
          GrayLevel[0], 
          Opacity[0.1]], 
         Line[{473, 475, 472}], 
         Line[{474, 476, 471}], 
         Line[{1483, 1484, 1482}]}}, {{}, {}, {}, {}, {}}}], {
     AspectRatio -> GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0, 0}, 
      Epilog -> {
        Text[
         Style["A", 14, Bold, FontFamily -> "Helvetica"], 
         Scaled[{0.05, 0.95}]]}, Frame -> {True, False, False, False}, 
      FrameLabel -> {{None, None}, {
        "\!\(\*SubscriptBox[\(\[CapitalDelta]z\), \(i\)]\)", None}}, 
      FrameStyle -> Directive[12, FontFamily -> "Helvetica"], 
      Method -> {"AxesInFront" -> True}, 
      PlotRange -> {{-0.282842712474619, 0.282842712474619}, {0, All}}, 
      PlotRangeClipping -> True, PlotRangePadding -> None}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          Thickness[Large], 
          Dashing[Medium], 
          GrayLevel[0]], 
         Directive[
          Thickness[Large], 
          GrayLevel[0]], 
         Directive[
          Thickness[Large], 
          Dashing[{0, Small}], 
          GrayLevel[0]]}, {
         Style["platykurtic", 
          Directive[12, FontFamily -> "Helvetica"]], 
         Style["normal", 
          Directive[12, FontFamily -> "Helvetica"]], 
         Style["leptokurtic", 
          Directive[12, FontFamily -> "Helvetica"]]}, LegendLayout -> 
        "Column"]], 
      Scaled[{0.8, 0.8}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.778607796473894*^9, 3.778607862858529*^9, {3.77860803144316*^9, 
   3.778608085606251*^9}, {3.7786081287251062`*^9, 3.7786081563342543`*^9}, {
   3.778608187357092*^9, 3.778608224144137*^9}, 3.778608638972677*^9, {
   3.778608670130989*^9, 3.7786086878629093`*^9}, 3.778608728347258*^9, {
   3.780063749151841*^9, 3.7800637829351883`*^9}, {3.7800641071598043`*^9, 
   3.780064124638514*^9}, 3.780064358779571*^9, 3.78006439867348*^9, {
   3.7800652861555443`*^9, 3.780065362171155*^9}, {3.780066006644466*^9, 
   3.780066027660462*^9}, 3.782259196869876*^9, 3.7849038811106253`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Probability of rescue (figure S3B,C)", "Subsection",
 CellChangeTimes->{{3.7794828334607143`*^9, 3.779482837011142*^9}, {
  3.780068332774658*^9, 3.780068337310753*^9}}],

Cell[CellGroupData[{

Cell["Interpolation function", "Subsubsection",
 CellChangeTimes->{{3.782243947281623*^9, 3.782243950993575*^9}}],

Cell["\<\
The probability of rescue by k steps involves k integrals, and so with even \
small k (e.g, k=3) they are very slow to compute in their exact form. We can, \
however, combine an approximation (don\[CloseCurlyQuote]t integrate below \
mmin) with interpolation functions to greatly speed things up (with some loss \
of accuaracy)\
\>", "Text",
 CellChangeTimes->{{3.771000901605348*^9, 3.771000917677836*^9}, {
  3.7710034684445353`*^9, 3.771003501426825*^9}, {3.77100386989631*^9, 
  3.771003887694422*^9}, {3.771004038362863*^9, 3.771004040562957*^9}, {
  3.771246003260221*^9, 3.77124604165723*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mTempmin", "=", 
   RowBox[{"-", "0.4"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mTempmax", "=", 
   RowBox[{"-", "0.01"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"step", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mmin", "=", "mTempmin"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "\[CapitalLambda]1Interpolated", ",", "\[CapitalLambda]2Interpolated", ",",
     "\[CapitalLambda]3Interpolated", ",", "\[CapitalLambda]4Interpolated"}], 
   "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalLambda]1Interpolated", "[", 
    RowBox[{"m0_", ",", "mmax_", ",", "\[Lambda]_", ",", "n_", ",", "U_"}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{"\[CapitalLambda]1Interpolated", "[", 
     RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], "]"}],
     "=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f", "=", 
        RowBox[{"Interpolation", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"mTemp", ",", 
             RowBox[{"U", " ", 
              RowBox[{"NIntegrate", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"fm", "[", 
                  RowBox[{
                  "m", ",", "mTemp", ",", "mmax", ",", "\[Lambda]", ",", 
                   "n"}], "]"}], 
                 RowBox[{"pest", "[", "m", "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"m", ",", "0", ",", "mmax"}], "}"}], ",", 
                RowBox[{"Method", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"Automatic", ",", 
                   RowBox[{"\"\<SymbolicProcessing\>\"", "\[Rule]", "0"}]}], 
                  "}"}]}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"mTemp", ",", "mTempmin", ",", "mTempmax", ",", "step"}], 
            "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"f", "[", "m0", "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalLambda]2Interpolated", "[", 
    RowBox[{"m0_", ",", "mmax_", ",", "\[Lambda]_", ",", "n_", ",", "U_"}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{"\[CapitalLambda]2Interpolated", "[", 
     RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], "]"}],
     "=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f", "=", 
        RowBox[{"Interpolation", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"mTemp", ",", 
             RowBox[{"U", " ", 
              RowBox[{"NIntegrate", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"fm", "[", 
                  RowBox[{
                  "m", ",", "mTemp", ",", "mmax", ",", "\[Lambda]", ",", 
                   "n"}], "]"}], 
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
                 RowBox[{"prescuem", "[", 
                  RowBox[{"m", ",", 
                   RowBox[{"\[CapitalLambda]1Interpolated", "[", 
                    RowBox[{
                    "m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
                    "]"}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"m", ",", "mmin", ",", "mmax"}], "}"}], ",", 
                RowBox[{"Method", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"Automatic", ",", 
                   RowBox[{"\"\<SymbolicProcessing\>\"", "\[Rule]", "0"}]}], 
                  "}"}]}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"mTemp", ",", "mTempmin", ",", "mTempmax", ",", "step"}], 
            "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"f", "[", "m0", "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalLambda]3Interpolated", "[", 
    RowBox[{"m0_", ",", "mmax_", ",", "\[Lambda]_", ",", "n_", ",", "U_"}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{"\[CapitalLambda]3Interpolated", "[", 
     RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], "]"}],
     "=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f", "=", 
        RowBox[{"Interpolation", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"mTemp", ",", 
             RowBox[{"U", " ", 
              RowBox[{"NIntegrate", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"fm", "[", 
                  RowBox[{
                  "m", ",", "mTemp", ",", "mmax", ",", "\[Lambda]", ",", 
                   "n"}], "]"}], 
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
                 RowBox[{"prescuem", "[", 
                  RowBox[{"m", ",", 
                   RowBox[{"\[CapitalLambda]2Interpolated", "[", 
                    RowBox[{
                    "m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
                    "]"}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"m", ",", "mmin", ",", "mmax"}], "}"}], ",", 
                RowBox[{"Method", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"Automatic", ",", 
                   RowBox[{"\"\<SymbolicProcessing\>\"", "\[Rule]", "0"}]}], 
                  "}"}]}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"mTemp", ",", "mTempmin", ",", "mTempmax", ",", "step"}], 
            "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"f", "[", "m0", "]"}]}]}], "\[IndentingNewLine]", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalLambda]4Interpolated", "[", 
   RowBox[{"m0_", ",", "mmax_", ",", "\[Lambda]_", ",", "n_", ",", "U_"}], 
   "]"}], ":=", 
  RowBox[{
   RowBox[{"\[CapitalLambda]4Interpolated", "[", 
    RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], "]"}], 
   "=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"f", "=", 
       RowBox[{"Interpolation", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"mTemp", ",", 
            RowBox[{"U", " ", 
             RowBox[{"NIntegrate", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"fm", "[", 
                 RowBox[{
                 "m", ",", "mTemp", ",", "mmax", ",", "\[Lambda]", ",", "n"}],
                  "]"}], 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  RowBox[{"pest", "[", "m", "]"}]}], ")"}], 
                RowBox[{"prescuem", "[", 
                 RowBox[{"m", ",", 
                  RowBox[{"\[CapitalLambda]3Interpolated", "[", 
                   RowBox[{
                   "m", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
                   "]"}]}], "]"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"m", ",", "mmin", ",", "mmax"}], "}"}], ",", 
               RowBox[{"Method", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{"Automatic", ",", 
                  RowBox[{"\"\<SymbolicProcessing\>\"", "\[Rule]", "0"}]}], 
                 "}"}]}]}], "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"mTemp", ",", "mTempmin", ",", "mTempmax", ",", "step"}], 
           "}"}]}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"f", "[", "m0", "]"}]}]}], "\[IndentingNewLine]", 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.7710006339642363`*^9, 3.771000651261798*^9}, {
   3.7710006849732113`*^9, 3.771000807511991*^9}, 3.7710009000604353`*^9, {
   3.77100102319551*^9, 3.7710010233705263`*^9}, {3.7710011165927973`*^9, 
   3.7710011198500853`*^9}, {3.771001353744179*^9, 3.771001378704712*^9}, {
   3.771001501438855*^9, 3.7710015427566843`*^9}, {3.771001609200037*^9, 
   3.7710016233596582`*^9}, {3.7710029708224497`*^9, 3.771002979497155*^9}, 
   3.771003069824634*^9, 3.771003100981645*^9, {3.77100313615471*^9, 
   3.771003143787877*^9}, {3.771003216851419*^9, 3.771003224224443*^9}, {
   3.771003383067137*^9, 3.771003395942892*^9}, 3.7710035538762283`*^9, 
   3.771003743292034*^9, {3.7712440458668127`*^9, 3.771244056209272*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Numerical data (for normal distribution)\
\>", "Subsubsection",
 CellChangeTimes->{{3.782243962170609*^9, 3.782243970146096*^9}, 
   3.782244119422256*^9, {3.782259288518285*^9, 3.782259296714872*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"N0", "=", 
    SuperscriptBox["10", "4"]}], ";", "\[IndentingNewLine]", 
   RowBox[{"mmax", "=", "0.5"}], ";", "\[IndentingNewLine]", 
   RowBox[{"\[Lambda]", "=", 
    RowBox[{"2", 
     RowBox[{"Es", "/", "n"}]}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"Es", "=", "0.01"}], ";", "\[IndentingNewLine]", 
   RowBox[{"n", "=", "4"}], ";", "\[IndentingNewLine]", 
   RowBox[{"U", "=", 
    RowBox[{"2", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}]}], ";", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"m0min", "=", "mTempmin"}], ";", "\[IndentingNewLine]", 
   RowBox[{"m0max", "=", "mTempmax"}], ";", "\[IndentingNewLine]", 
   RowBox[{"mstep", "=", "step"}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate4", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"\[CapitalLambda]4Interpolated", "[", 
         RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate3", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"\[CapitalLambda]3Interpolated", "[", 
         RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate2", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"\[CapitalLambda]2Interpolated", "[", 
         RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate1", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"\[CapitalLambda]1Interpolated", "[", 
         RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"m0list", "=", 
    RowBox[{"Table", "[", 
     RowBox[{"m0", ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"theory", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m0list", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{
              RowBox[{"m0list", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"rate1", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m0list", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{
              RowBox[{"m0list", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"rate2", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m0list", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{
              RowBox[{"m0list", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"rate3", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m0list", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{
              RowBox[{"m0list", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"rate4", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}]}], 
     "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"alltheory", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"m0list", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"prescue", "/.", 
         RowBox[{"p0", "\[Rule]", 
          RowBox[{"prescuem", "[", 
           RowBox[{
            RowBox[{"m0list", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"rate1", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate2", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate3", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate4", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "]"}]}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}]}], ";", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", 
    RowBox[{
    "N0", ",", "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", 
     "m0min", ",", "m0max"}], "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.771243438404381*^9, 3.771243505591201*^9}, {
   3.771243660674692*^9, 3.771243770343318*^9}, {3.7712438051594973`*^9, 
   3.771243806769825*^9}, {3.77124384246271*^9, 3.7712439832452*^9}, {
   3.771244074547236*^9, 3.771244075614129*^9}, {3.771244170126183*^9, 
   3.771244240128414*^9}, {3.771244491552649*^9, 3.771244539467946*^9}, {
   3.771244637848792*^9, 3.771244771807975*^9}, {3.77124482635817*^9, 
   3.771245429892724*^9}, 3.771246073841148*^9, 3.771246637425001*^9, {
   3.771252282261911*^9, 3.771252288712202*^9}, 3.771254690716058*^9, {
   3.771254724632944*^9, 3.771254752430646*^9}, 3.77125504889705*^9, {
   3.7715446486731167`*^9, 3.771544649294244*^9}, {3.782234584891123*^9, 
   3.7822346390847397`*^9}, {3.782234732642061*^9, 3.7822347636693287`*^9}, {
   3.78223479425648*^9, 3.7822347970725822`*^9}, {3.782234919595743*^9, 
   3.782235065283053*^9}, {3.782235166298839*^9, 3.78223519538727*^9}, {
   3.7822352881132936`*^9, 3.7822352951175117`*^9}, {3.782235335234043*^9, 
   3.7822353377596684`*^9}, {3.782235496732168*^9, 3.7822355628278933`*^9}, {
   3.7822356043396177`*^9, 3.78223562461322*^9}, {3.7822359261903057`*^9, 
   3.782235929907751*^9}, {3.782235969286677*^9, 3.782236093293007*^9}, {
   3.782236124427341*^9, 3.782236163439129*^9}, {3.782236242968176*^9, 
   3.78223627257775*^9}, {3.7822363121939707`*^9, 3.782236329090472*^9}, {
   3.782236361611968*^9, 3.7822364008620358`*^9}, {3.7822364623523283`*^9, 
   3.782236523610194*^9}, {3.7822365640112658`*^9, 3.782236676208467*^9}, {
   3.78223672330368*^9, 3.7822367856352873`*^9}, {3.782236860747128*^9, 
   3.7822370287832003`*^9}, {3.782237076093791*^9, 3.7822370930134077`*^9}, {
   3.7822371354078617`*^9, 3.782237144380975*^9}, {3.7822371817988567`*^9, 
   3.782237186287504*^9}, {3.7822374864599247`*^9, 3.7822377028467484`*^9}, {
   3.782238097767778*^9, 3.782238119564167*^9}, {3.78223942976235*^9, 
   3.7822396342799883`*^9}, 3.782239876069955*^9, {3.782240230407597*^9, 
   3.782240269444977*^9}, {3.782240326799062*^9, 3.782240338972478*^9}, 
   3.78224041065661*^9, {3.782243997493153*^9, 3.7822440072288113`*^9}, 
   3.782252402877418*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"theory", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "5.472398814099222`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39`"}], ",", "9.745688406281872`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38`"}], ",", "1.7238895513305152`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37`"}], ",", "3.0285772651961196`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36000000000000004`"}], ",", 
         "5.2841014319682245`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "9.155420059081543`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34`"}], ",", "0.000015751880195202794`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33`"}], ",", "0.00002690955788409166`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32`"}], ",", "0.000045643083578017496`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31000000000000005`"}], ",", 
         "0.0000768622102641503`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", 
         "0.00012849810996373723`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29000000000000004`"}], ",", 
         "0.0002132574731799064`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28`"}], ",", "0.0003513291377449379`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27`"}], ",", "0.000574520974723769`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26`"}], ",", "0.0009325213318174264`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.0015022797840921198`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24000000000000002`"}], ",", 
         "0.0024019086800984857`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23`"}], ",", "0.0038110379258926574`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22000000000000003`"}], ",", "0.00600020901304088`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21000000000000002`"}], ",", "0.00937261491044139`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.014522096798011974`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19000000000000003`"}], ",", 
         "0.022311337733202485`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18000000000000002`"}], ",", "0.03397263148001661`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17`"}], ",", "0.0512283883233019`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16000000000000003`"}], ",", "0.07641581098977057`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", "0.11257347217569635`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14`"}], ",", "0.16339795924448708`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13`"}], ",", "0.23289952993154328`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12`"}], ",", "0.3244893834485655`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11000000000000004`"}], ",", "0.43919411790398366`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10000000000000003`"}], ",", "0.5729341370203966`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09000000000000002`"}], ",", "0.7137213876566558`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08000000000000002`"}], ",", "0.8414602539868381`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07`"}], ",", "0.9344415307620567`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06`"}], ",", "0.9829032755970813`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", "0.9979187459679042`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.040000000000000036`"}], ",", "0.9999341480370483`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.030000000000000027`"}], ",", "0.9999998505645212`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.020000000000000018`"}], ",", "0.9999999999991431`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.010000000000000009`"}], ",", "1.`"}], "}"}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "7.1817194564616216`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39`"}], ",", "0.000010382868435687698`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38`"}], ",", "0.000015004899198478583`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37`"}], ",", "0.000021674932411452907`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36000000000000004`"}], ",", 
         "0.000031295722740964926`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "0.00004516336475557381`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34`"}], ",", "0.00006513527103491068`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33`"}], ",", "0.00009386674884392932`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32`"}], ",", "0.00013514257904490012`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31000000000000005`"}], ",", 
         "0.0001943394640103735`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", 
         "0.00027906144855771586`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29000000000000004`"}], ",", 
         "0.00040002244449899305`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28`"}], ",", "0.0005722318522486392`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27`"}], ",", "0.0008166042269467377`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26`"}], ",", "0.0011621019720312598`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.0016485639043937184`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24000000000000002`"}], ",", 
         "0.002330394186973561`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23`"}], ",", "0.0032813120522319217`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22000000000000003`"}], ",", 
         "0.0046003825714453495`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21000000000000002`"}], ",", 
         "0.006419557828723499`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.008912948912746632`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19000000000000003`"}], ",", 
         "0.012308013245967753`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18000000000000002`"}], ",", "0.01689876878901897`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17`"}], ",", "0.02306102686962941`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16000000000000003`"}], ",", 
         "0.031269462419949656`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", 
         "0.042116115688766054`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14`"}], ",", "0.05632965853148175`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13`"}], ",", "0.07479449506069946`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12`"}], ",", "0.09856854888921651`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11000000000000004`"}], ",", "0.12889844527072303`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10000000000000003`"}], ",", "0.1672306176682965`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09000000000000002`"}], ",", "0.21521607762716344`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08000000000000002`"}], ",", "0.2747032194313106`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07`"}], ",", "0.3477011299288638`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06`"}], ",", "0.4362577296013713`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", "0.5420788502184701`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.040000000000000036`"}], ",", "0.6653477290582192`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.030000000000000027`"}], ",", "0.8010818232849237`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.020000000000000018`"}], ",", "0.9286233811012167`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.010000000000000009`"}], ",", "0.9962496646879948`"}],
         "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "2.672518644497579`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39`"}], ",", "3.6200066483305093`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38`"}], ",", "4.9024286813414975`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37`"}], ",", "6.639033992561494`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36000000000000004`"}], ",", 
         "8.99229424278225`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "0.000012183830842893428`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34`"}], ",", "0.000016516674993138913`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33`"}], ",", "0.00002240514549411987`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32`"}], ",", "0.000030416485379602953`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31000000000000005`"}], ",", 
         "0.000041327352556463914`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", 
         "0.00005620069935863281`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29000000000000004`"}], ",", 
         "0.00007648968361839703`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28`"}], ",", "0.0001041772194614321`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27`"}], ",", "0.00014196192976223543`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26`"}], ",", "0.00019350379587734778`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.0002637455775598152`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24000000000000002`"}], ",", 
         "0.0003593290092440693`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23`"}], ",", "0.0004891277868906974`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22000000000000003`"}], ",", 
         "0.0006649222935298793`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21000000000000002`"}], ",", 
         "0.0009022438378168962`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.0012214190541605108`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19000000000000003`"}], ",", 
         "0.0016488487049626244`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18000000000000002`"}], ",", 
         "0.0022185608705778126`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17`"}], ",", "0.0029740895246452848`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16000000000000003`"}], ",", 
         "0.003970751527472172`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", 
         "0.0052784386334274735`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14`"}], ",", "0.006985125056896413`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13`"}], ",", "0.009201449505447323`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12`"}], ",", "0.012067026227695399`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11000000000000004`"}], ",", 
         "0.015759693621743676`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10000000000000003`"}], ",", 
         "0.020509966391728862`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09000000000000002`"}], ",", "0.02662504581244618`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08000000000000002`"}], ",", "0.03453108060938248`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07`"}], ",", "0.04485200223554198`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06`"}], ",", "0.0585665300648599`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", "0.0773474840786541`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.040000000000000036`"}], ",", 
         "0.10438028623999529`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.030000000000000027`"}], ",", 
         "0.14667096966766024`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.020000000000000018`"}], ",", "0.2233073280524227`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.010000000000000009`"}], ",", "0.4098900908454398`"}],
         "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "3.665400664099039`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39`"}], ",", "4.882948413387211`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38`"}], ",", "6.507825516255394`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37`"}], ",", "8.679175866888045`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36000000000000004`"}], ",", 
         "1.1585392625246271`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "1.548213704460899`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34`"}], ",", "2.071738417153135`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33`"}], ",", "2.776581790708832`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32`"}], ",", "3.727611290194055`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31000000000000005`"}], ",", 
         "5.013589215119296`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", 
         "6.756030736299046`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29000000000000004`"}], ",", 
         "9.12124881535803`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28`"}], ",", "0.00001233658455390696`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27`"}], ",", "0.000016712145389896627`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26`"}], ",", "0.00002266963795427568`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.000030780242171069006`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24000000000000002`"}], ",", 
         "0.00004181381972367948`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23`"}], ",", "0.000056802136495281985`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22000000000000003`"}], ",", 
         "0.00007711911056884624`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21000000000000002`"}], ",", 
         "0.00010458146610448082`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.0001415735100674942`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19000000000000003`"}], ",", 
         "0.00019120021529694942`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18000000000000002`"}], ",", 
         "0.0002574735404686779`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17`"}], ",", "0.00034553832838446485`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16000000000000003`"}], ",", 
         "0.0004619470399811476`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", 
         "0.0006149981944676419`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14`"}], ",", "0.0008151642974213447`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13`"}], ",", "0.0010756555359718867`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12`"}], ",", "0.0014132038091301258`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11000000000000004`"}], ",", 
         "0.0018492239194836113`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10000000000000003`"}], ",", 
         "0.002411647781310755`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09000000000000002`"}], ",", 
         "0.003138005818001832`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08000000000000002`"}], ",", 
         "0.004080917925158634`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07`"}], ",", "0.005318491045821605`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06`"}], ",", "0.006975434272220693`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", 
         "0.009269923451119766`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.040000000000000036`"}], ",", 
         "0.012631023980203326`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.030000000000000027`"}], ",", 
         "0.01804961542287531`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.020000000000000018`"}], ",", "0.0284671089107692`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.010000000000000009`"}], ",", 
         "0.05823795851907776`"}], "}"}]}], "}"}]}], "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.7822523768220987`*^9, 3.782252383120124*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"alltheory", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.4`"}], ",", "0.000010767989638504893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.39`"}], ",", "0.000015465680252679803`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.38`"}], ",", "0.000022281877958607588`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.37`"}], ",", "0.00003221020658283891`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.36000000000000004`"}], ",", 
       "0.00004673011156652862`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.35000000000000003`"}], ",", 
       "0.00006804965109896699`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.34`"}], ",", "0.00009947299961354794`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.33`"}], ",", "0.0001459524027258574`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.32`"}], ",", "0.00021491729975098295`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.31000000000000005`"}], ",", 
       "0.00031751489398534893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.30000000000000004`"}], ",", "0.0004704543728014654`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.29000000000000004`"}], ",", "0.0006987523028609832`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.28`"}], ",", "0.0010397647754660788`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.27`"}], ",", "0.0015491068347829318`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.26`"}], ",", "0.0023092555158806816`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.25`"}], ",", "0.0034419561736643844`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.24000000000000002`"}], ",", "0.005125934145003619`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.23`"}], ",", "0.007621874910163862`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.22000000000000003`"}], ",", "0.011307117362613917`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.21000000000000002`"}], ",", "0.01672286182842886`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.2`"}], ",", "0.024636589665609887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.19000000000000003`"}], ",", "0.03612111665412221`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.18000000000000002`"}], ",", "0.0526478810505413`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.17`"}], ",", "0.07618321541025108`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.16000000000000003`"}], ",", "0.10925842311524103`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.15000000000000002`"}], ",", "0.154951959045035`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.14`"}], ",", "0.21667029213726385`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.13`"}], ",", "0.29754827077524637`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.12`"}], ",", "0.39924782631433087`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.11000000000000004`"}], ",", "0.5200288215021587`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.10000000000000003`"}], ",", "0.6524246688522214`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.09000000000000002`"}], ",", "0.7819169338181124`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.08000000000000002`"}], ",", "0.8893420776854711`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.07`"}], ",", "0.9592948833994817`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.06`"}], ",", "0.9909501188644341`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.04999999999999999`"}], ",", "0.9991194054587093`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.040000000000000036`"}], ",", "0.9999799413255674`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.030000000000000027`"}], ",", "0.999999972757273`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.020000000000000018`"}], ",", "0.9999999999999342`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.010000000000000009`"}], ",", "1.`"}], "}"}]}], "}"}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.782252389645158*^9, 3.782252394760631*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Platykurtic (semicircle, panel B)\
\>", "Subsubsection",
 CellChangeTimes->{{3.780063000496079*^9, 3.7800630010482483`*^9}, 
   3.78006395787187*^9, {3.7849039635653143`*^9, 3.784903964483255*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"N0", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwts", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.1"}], ",", 
     RowBox[{"-", "0.2"}], ",", 
     RowBox[{"-", "0.3"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"type", "=", "\"\<platy\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nreps", "=", "100000"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"file", "=", 
        RowBox[{"StringForm", "[", 
         RowBox[{
          RowBox[{
          "datadir", "<>", 
           "\"\<dfe_``_N``_n``_U``_Es``_mmax``_mwt``_nreps``.csv\>\""}], ",", 
          "type", ",", "N0", ",", "n", ",", 
          RowBox[{"NumberForm", "[", 
           RowBox[{
            RowBox[{"U", "//", "N"}], ",", 
            RowBox[{"{", 
             RowBox[{"6", ",", "5"}], "}"}]}], "]"}], ",", 
          RowBox[{"NumberForm", "[", 
           RowBox[{"Es", ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"NumberForm", "[", 
           RowBox[{"mmax", ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"mwts", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", "nreps"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dat", "=", 
        RowBox[{"Import", "[", 
         RowBox[{"ToString", "[", "file", "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"onestep", "=", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Select", "[", 
           RowBox[{"dat", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], "&"}]}], 
           "]"}], "]"}], "/", "nreps"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"twostep", "=", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Select", "[", 
           RowBox[{"dat", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], 
           "]"}], "]"}], "/", "nreps"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"threestep", "=", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Select", "[", 
           RowBox[{"dat", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "3"}], "&"}]}], 
           "]"}], "]"}], "/", "nreps"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"fourstep", "=", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Select", "[", 
           RowBox[{"dat", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "4"}], "&"}]}], 
           "]"}], "]"}], "/", "nreps"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"total", "=", 
        RowBox[{
        "onestep", "+", "twostep", "+", "threestep", "+", "fourstep"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "onestep", ",", "twostep", ",", "threestep", ",", "fourstep", ",", 
          "total"}], "}"}], "//", "N"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "mwts", "]"}]}], "}"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mwts", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "mwts", "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"Length", "[", 
       RowBox[{"data", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dataplot", "=", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"%", ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.4"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           SuperscriptBox["10", 
            RowBox[{"-", "6"}]], ",", "1"}], "}"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Frame", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"defaultcolors", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", "Thick", ",", 
           RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"defaultcolors", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", "Thick", ",", 
           RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"defaultcolors", "[", 
            RowBox[{"[", "3", "]"}], "]"}], ",", "Thick", ",", 
           RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"defaultcolors", "[", 
            RowBox[{"[", "4", "]"}], "]"}], ",", "Thick", ",", 
           RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", 
           RowBox[{"Thickness", "[", "0.005", "]"}], ",", 
           RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotMarkers", "\[Rule]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Dashing", "[", "None", "]"}], ",", 
             RowBox[{"Thickness", "[", "Medium", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", 
             RowBox[{"Circle", "[", "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Dashing", "[", "None", "]"}], ",", 
             RowBox[{"Thickness", "[", "Medium", "]"}], ",", 
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Dashing", "[", "None", "]"}], ",", 
             RowBox[{"Thickness", "[", "Medium", "]"}], ",", 
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Dashing", "[", "None", "]"}], ",", 
             RowBox[{"Thickness", "[", "Medium", "]"}], ",", 
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"Disk", "[", "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "8"}]}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figS3b", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
      RowBox[{"theory", ",", "\[IndentingNewLine]", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", 
          RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"5", "*", 
             SuperscriptBox["10", 
              RowBox[{"-", "7"}]]}], ",", "1"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"(*", "\"\<Wildtype growth rate\>\"", "*)"}], 
         RowBox[{",", ",", ",", "\"\<Probability of rescue\>\""}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameTicksStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"FontColor", "\[Rule]", "White"}], ",", "Automatic", ",", 
          "Automatic", ",", "Automatic"}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"LineLegend", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{
             "\"\<1-step\>\"", ",", "\"\<2-step\>\"", ",", "\"\<3-step\>\"", 
              ",", "\"\<4-step\>\""}], "}"}]}], "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.85", ",", "0.22"}], "}"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ListLogPlot", "[", 
      RowBox[{"alltheory", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick", ",", 
          RowBox[{"Opacity", "[", "0.5", "]"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"LineLegend", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", "\"\<total\>\"", "}"}]}], "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.56", ",", "0.22"}], "}"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", "dataplot", 
     ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRangePadding", "\[Rule]", "0"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"ImagePadding", "\[Rule]", "probpadding"}], ","}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<B\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<platykurtic\>\"", ",", "14", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.25", ",", "0.85"}], "}"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Opacity", "[", "0.5", "]"}], ",", 
          RowBox[{"braceLabel", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "0.125"}], ",", 
                RowBox[{"Log", "@", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "6"}]]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "0.125"}], ",", 
                RowBox[{"Log", "@", 
                 RowBox[{"(", 
                  RowBox[{"1.5", "*", 
                   SuperscriptBox["10", 
                    RowBox[{"-", "4"}]]}], ")"}]}]}], "}"}]}], "}"}], ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<\>\"", ",", "Larger"}], "]"}]}], "]"}]}], "}"}]}], 
       "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "N0", ",", "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", 
   "mwts", ",", "type", ",", "nreps"}], "]"}]}], "Input",
 CellChangeTimes->{{3.779482934569633*^9, 3.779483103494062*^9}, {
   3.779483139966634*^9, 3.7794832104291897`*^9}, {3.779483265054079*^9, 
   3.779483561394548*^9}, {3.779483608971405*^9, 3.779483614108574*^9}, {
   3.779483645649742*^9, 3.7794838481810427`*^9}, {3.77948390045612*^9, 
   3.779483904729929*^9}, {3.779484621479521*^9, 3.779484766442582*^9}, 
   3.779484915854886*^9, 3.779484995412224*^9, {3.780059637485427*^9, 
   3.780059637624366*^9}, {3.780059917993656*^9, 3.780059927050202*^9}, {
   3.780059966908615*^9, 3.780059977924687*^9}, {3.780060012342165*^9, 
   3.780060024297332*^9}, {3.7800600606007023`*^9, 3.780060090074156*^9}, {
   3.78006023261409*^9, 3.780060237927293*^9}, {3.7800602729538193`*^9, 
   3.78006027625637*^9}, {3.7800605509619017`*^9, 3.780060563827641*^9}, {
   3.780060597173071*^9, 3.780060665131921*^9}, {3.780060695673909*^9, 
   3.780060700275309*^9}, {3.780060744730639*^9, 3.7800607753668413`*^9}, {
   3.7800608493945847`*^9, 3.780060875336527*^9}, {3.7800609301774817`*^9, 
   3.780061094675621*^9}, {3.780061290389022*^9, 3.7800613346892223`*^9}, {
   3.7800614144410458`*^9, 3.780061472389244*^9}, {3.780061504811533*^9, 
   3.780061570723612*^9}, {3.7800616073277493`*^9, 3.7800616649700737`*^9}, {
   3.7800617801226377`*^9, 3.780061825032199*^9}, {3.780061909278323*^9, 
   3.780061972429881*^9}, {3.780062151922361*^9, 3.780062209318268*^9}, {
   3.780064731356447*^9, 3.7800647409448147`*^9}, {3.7800652010090437`*^9, 
   3.780065210948414*^9}, {3.780065378770928*^9, 3.78006541506747*^9}, {
   3.780065478566609*^9, 3.780065492555863*^9}, {3.78006553130892*^9, 
   3.7800656085263767`*^9}, {3.780065714810272*^9, 3.7800657152350283`*^9}, {
   3.78006578807406*^9, 3.780065789978553*^9}, {3.780065993668397*^9, 
   3.780065995933609*^9}, {3.780066038730044*^9, 3.7800660453433027`*^9}, {
   3.782238300475013*^9, 3.7822383075084*^9}, {3.782238341826033*^9, 
   3.782238344573032*^9}, 3.782238377816503*^9, {3.782238409597775*^9, 
   3.7822384555656137`*^9}, {3.782238571506858*^9, 3.782238577944655*^9}, {
   3.7822386352408752`*^9, 3.782238745590126*^9}, {3.782238866709251*^9, 
   3.7822388720777063`*^9}, {3.7822389083290043`*^9, 3.782238919286851*^9}, 
   3.782239003533145*^9, {3.782239055573841*^9, 3.7822390677886457`*^9}, {
   3.78223912686559*^9, 3.7822391547036858`*^9}, {3.7822392219408712`*^9, 
   3.782239228615234*^9}, {3.782239269260306*^9, 3.782239368307418*^9}, {
   3.7822396678306723`*^9, 3.7822396716631308`*^9}, 3.782239765361809*^9, {
   3.782239836501832*^9, 3.782239840441825*^9}, {3.78223995238204*^9, 
   3.782239961997314*^9}, 3.782240903608727*^9, {3.782240934873399*^9, 
   3.782240987458087*^9}, {3.782259303350173*^9, 3.7822593044527683`*^9}, 
   3.782259367697536*^9, {3.78490390798593*^9, 3.7849039413473167`*^9}}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], Opacity[0.5], 
        LineBox[CompressedData["
1:eJwtkF1I01EYxv9pZKhNVzOWoc6PdE7TUOdVrcKLZRTojMASpKlFBWrQRO3z
QgkinUuTirKLCdaFk2W2abXnTdPlSnHOua0LaX2wygSz1AiLdv7bA4fD4Zzz
e5/nSVTXqKpCOI6T+hfb795h8iD956pJPptJK9Iy7fCyGyM1Y2HPDBmkMsc3
zxe7kd8ywZmuy8ig9DaKDC4sVxj1OWfSKcKlr90T7kKW71d//mEpnTrJNIu8
gQLnm9w0GllmQCeWFJ3lf+JSKcFPM8c7cb7eqrFF7KALIkacwZVm4fuCv8nk
5nEO3P/RKa5eSqK8XCYHsha9+UXzidQ2zIDT6PMpfi/6JPS9mBm0Q90X1do7
lUAHmD2lHT0dsf1RnjjqZjj9FB6rNzhFX7cTx2sKC5vUu21cLA2yeOZJVBZa
S/ZKxHSOPa+dQLnePnRNuZVkrA7pW/hqDzZY6kT0geG9Nkw+fWcPN2ymQH/j
mEnZWNWzEE0lfF+voR1XZXjOCoL9WLHr9NFPFkFEsI9R7Ouqb28ZDaOLfP5X
yBq9HKq7uT6YdwRzW6Ty5IZ1wXwvodO0K3aurSGQh9CVI7vRWLQKfpzZgm3a
mDlByBIyeb/PEZ1Wqrt05Bvu8f4GETqkybZPexHJ+zHBkf3l88AtJwLznyCm
QptySDyGwDwjRMqOBzhuDPIN+KeTf2x9qMNtnvcIK0mFkv3CE7jK/+9GpLm0
rKpACOLfd+FYXWV9m6DJErjvQJ7AX3tq9YvAuQlcUP8Bo3NLMw==
         "]]}, 
       {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], Opacity[0.5], 
        LineBox[CompressedData["
1:eJwtkF9Ik1EYxtcKpC2W01nJUnPZmhFp2rKbNVqExhi0CRERYemqm8pZFKkX
I0wRJ2qWbZGZzBGlzYqB3yj2vk1tFpttU9saBG1+JNjoj5sjaBd5vn0PHA6H
c87vfZ6n+PxVnZ7L4XBka4vsDy1EX2CQjmwueLkbU7IzPe7VMKSs7W3nElLU
UYV3fmjDoLrmUEQOStFeHW0W2UNwu2P0ial5F/JD1kYFLwQJbdzS7CrBixeI
PkNyZtE9xi3ByVUCXIA/3KZgefVOLFqjUYULEJ7P8+WbJNgiIsR5kAsFQmOg
GMMMbg78iesu49ZiPFBJNAfBulNdyrM7sNdNgEGYUlVxp9RFGNcSgwFYCX4/
Jv1agDXEXnUAbgrSpesM23GE4Kx+OKzRWxxZYuQw8sMJm2LIOpyPThKPmoVU
3/1UhXIbGsjzRh9U8YbfeL5twT2kDpkXLtn61e/b8zBG8NGPIBdXnu7bL8JM
fx8gEXMqO6M5WMv0NQPjHXQL/4GQ7ccD5fEb+iZdNtvHNMR6636VygTYyuSf
ghVbja6b4rN5J8EtftpgP7mRzfcOBiSfNCXrs9g8CD4v39Tq2oDMOMoFxw23
6EOdXNzL+H0L6aDd463n4CPGnxPkZZO0fDANmxg/E0DfpZLL/X8hM98BDS9+
HlWPJSEz7xVcHqpVZS/9hgzfDpKJ7iVD1zKYGd4z8ONzns68CEbm/wgcGTXv
G8iNADLvH0NBRa5jvN7L3t+Dfz20P2f1NXtug7JpTXLWcwX+AxnkWJE=
         "]]}, 
       {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], Opacity[0.5], 
        LineBox[CompressedData["
1:eJwtkGtI01EYxrdRIqtV6qjZ2tbMXcwCwUV+yKhUNCRCqzWjICxXYjDFGJub
4IeK6kMXZ+h0WeaIWTTK1P23yvdNu9jQpblrtWxGLMz6EK0LRuX5+3/gcDic
c37v8zzSSl15FYfFYinnF9nbrUQRaJWEk7bcysIfyoMXhxJh6HnnuhFdloXl
lPj057IwHIr6q631SnQWxxr4zhC08qd694cVuCTUXZvPDYErT7ONla/AY1qi
IBzvv7zZ3CXH4QQBBmBvjUjRt1iOknkaJQ7AdIXMcaVahiY+IfqBvS+XShnL
xDCNmwQjW/dVnJOJqlyiSfBtdXg9zevw0hABvgJrmy0+8z0DZ8uIwQlIPQOB
R+oMLCH2iifAd3KgpZSSop3gusfBZOVb+tOlyKI1DhV3d2yUm9aim8SjfGB7
bddec0uwjjyvHQONLic52CjG9aQO5ShYVEFHTYEIpwk+5gXO4evGGHcNLvT3
Aq6WaHd5/KtxD93XCDxTP1Dru9KZfp7D25aG6IU6AdPHUzAk4vG6olVopvM/
gaYiG9UoWsnkHYbmjp0f5n7zmXyPwVN/ziJ8k8bkQXBtKjgxg6lIj6MGwSQs
FJTeTsENtN+HYNcPyz5ZV6CN9ueGfwZZZLtgOS6l/bjgW6G3KsLmMfP7oP2m
sOPAFy4z7x6opszvRwLJDN8JVXf0lUfuJ2EbzeuBXg3bAMZF2ET/twNvzpD9
MY2DSL/vhE6eJO/swF9YuG+BX6ODAH9+MudTcPTlbm72+Vn4D6fQUYY=
         "]]}, 
       {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], Opacity[0.5], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQzfzn41b7Fzf22y+uP5nHonsgaIdc6+vAG/tXvXhU
UVOrc2Cd+8MqkXXX92+YMUlA6JX2Ae7riwtsua7vN99/i8coTPtAehoIXNt/
cEHEqX0HtQ4c/qoR03/o6v4M5VmBs3W0DsgDTdshd3X/tY40nbXTNA9Ui4BM
vLI//Lqv373/GgdugI27vF9qyYxZchkaB0yMQeDy/pS7d/6mnlc/MOEQyMBL
+xkUa79sNVU/8CYQ5MCL+w8mKytKz1Y74AFynvvF/U2SL/nW/Vc9sARk3OIL
+29WeWdNTlY9wAAGF/a/WL244fcxlQM7Qd7bcW7/w5xUUUUtlQOFIOUFZ/ez
2TROcO9VPqAFdP1XjTP7H0X/2bPjg9KBRyDjH57av/nUJ9NDIUoHZs0EgZP7
CxNcNm3aqXggGBxeJ/ZfDOH2vi6vCA2f4/v1il+er2hXgIbH0f0qmglxmx7K
H6gB+//I/m9mfbsSd8hB/Xt4/1G97RYRk2Wh/ju4v+FuzoXzRTJQ/xzYr/+u
O/ZOmPQBsHU79u3/y7xpWaK91AEdsHv37J/DWBzHqiN5YA7YfTv37/gW2Ssl
I3GAB+ye7fun/Pj7r5FPHGr/lv1LvPP2ljOKQe3buH/mZS8Xu08iUPPX7f/h
ldzcfkf4wAyweSv3V3cduBO0U+hAA1j/kv3GrK9bWmoEDxwAq5+3P1VYPv03
nwBUfsr+64X8UjcqeKD8lv0KRtO4Xu5jOwAAoZBGJA==
         "]]}}, {}}, {{{}, {}, 
       {GrayLevel[0], Thickness[Large], Opacity[0.5], LineBox[CompressedData["

1:eJwtkHtI01EcxWckmQ9SmmKbzcd0LhsxMuuPGAWGGyaMrYTWWlH4KBhN+6fM
pFyG/RMzHGayTFCp1doyQjesnTvfmuXM3AxTXIUgbajUSmJB3t924HK53Hs/
33NO5gWdsnwLi8USbi66tz2k+oyWl9Hv+pcE5LfwjGEgOIfcDrFLkysgSjvv
zg/FHH6VhYYvanOIVeq7zrZ64cvi1vTbskmct7NKEuvF38KFpYPrfFJZQeXB
UJ3/0aiYTwaDFDiL3ivF8orLWSR9k2bnzcJU64vnPMsktWxK/ISxkHJg41sG
mWNwM4jzyjm5aRnkQD7VDA6rild7unmkaYACP0JtYF9tS9xN/ApqcBoLIZnW
VMMlMmpPOo159fNJtW8X6aK4TjcmVHxboyyVsBi5UbD4lO+xpRAHjWf/AJ9G
J49KTSbV9HnVe6xy9h4bqd9J8mgdwkm4SswJy4Ek8pXifRNoNJXV7NEkknB/
4/BKuTp3RwI5wfQ1Bsua5Ljwfmykn1HkG788ab63LdLHMMaPaGVTrVvJDSb/
EJondhSe7o2K5B3EPtGllabZfwjnc+GcqsFQem0D4TwEMdlFpuTyn2DG2Z0w
O14VWM4HIGL8voG4XPRH7/8OE+PPgaS8lJH1k/OIZ/z04cXy9lJB3RTC819j
5awk+DjaGZnXg/S1lvpAUXeEb4UjVJl2ql2PVoZnhmct5+ahxRLcYv53obrP
qLsdE3QS5n07Hihseu1RjTN8b4SF1n53/9vwuQGsiP4D/QhP6Q==
         "]]}}, {}}, {
      GraphicsComplexBox[{{-0.1, -1.810453111675309}, {-0.1, \
-2.7181005369557116`}, {-0.2, -6.22972173623224}, {-0.1, -5.236281975628584}, \
{-0.2, -7.1691200431165445`}, {-0.3, -11.512925464970229`}, {-0.1, \
-8.145629634983754}, {-0.2, -9.903487552536127}, {-0.1, \
-1.4473615808683413`}, {-0.2, -5.881713683148863}, {-0.3, \
-11.512925464970229`}}, {{{}, {}, {}, 
         {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], Dashing[
          Medium], LineBox[{2, 3}]}, 
         {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Large], Dashing[
          Medium], LineBox[{4, 5, 6}]}, 
         {RGBColor[0.24, 0.6, 0.33692049419863584`], Thickness[Large], 
          Dashing[Medium], LineBox[{7, 8}]}, 
         {GrayLevel[0], Thickness[0.005], Dashing[Medium], 
          LineBox[{9, 10, 11}]}}, {
         {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
          Dashing[Medium], InsetBox[
           GraphicsBox[
            {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Medium], 
             Dashing[None], CircleBox[{0, 0}]},
            ImageSize->10], 1]}, 
         {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], Dashing[
          Medium], InsetBox[
           GraphicsBox[
            {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Medium], 
             Dashing[None], CircleBox[{0, 0}], 
             {RGBColor[0.6, 0.24, 0.4428931686004542]}},
            ImageSize->10], 2], InsetBox[
           GraphicsBox[
            {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Medium], 
             Dashing[None], CircleBox[{0, 0}], 
             {RGBColor[0.6, 0.24, 0.4428931686004542]}},
            ImageSize->10], 3]}, 
         {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Large], Dashing[
          Medium], InsetBox[
           GraphicsBox[
            {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Medium], 
             Dashing[None], CircleBox[{0, 0}], 
             {RGBColor[0.6, 0.5470136627990908, 0.24]}},
            ImageSize->10], 4], InsetBox[
           GraphicsBox[
            {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Medium], 
             Dashing[None], CircleBox[{0, 0}], 
             {RGBColor[0.6, 0.5470136627990908, 0.24]}},
            ImageSize->10], 5], InsetBox[
           GraphicsBox[
            {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Medium], 
             Dashing[None], CircleBox[{0, 0}], 
             {RGBColor[0.6, 0.5470136627990908, 0.24]}},
            ImageSize->10], 6]}, 
         {RGBColor[0.24, 0.6, 0.33692049419863584`], Thickness[Large], 
          Dashing[Medium], InsetBox[
           GraphicsBox[
            {RGBColor[0.24, 0.6, 0.33692049419863584`], Thickness[Medium], 
             Dashing[None], CircleBox[{0, 0}], 
             {RGBColor[0.24, 0.6, 0.33692049419863584`]}},
            ImageSize->10], 7], InsetBox[
           GraphicsBox[
            {RGBColor[0.24, 0.6, 0.33692049419863584`], Thickness[Medium], 
             Dashing[None], CircleBox[{0, 0}], 
             {RGBColor[0.24, 0.6, 0.33692049419863584`]}},
            ImageSize->10], 8]}, 
         {GrayLevel[0], Thickness[0.005], Dashing[Medium], InsetBox[
           GraphicsBox[
            {GrayLevel[0], Thickness[0.005], Dashing[Medium], DiskBox[{0, 0}]},
            ImageSize->8], 9], InsetBox[
           GraphicsBox[
            {GrayLevel[0], Thickness[0.005], Dashing[Medium], DiskBox[{0, 0}]},
            ImageSize->8], 10], InsetBox[
           GraphicsBox[
            {GrayLevel[0], Thickness[0.005], Dashing[Medium], DiskBox[{0, 0}]},
            ImageSize->8], 11]}, {}}}], {}}}, {InsetBox[
      TemplateBox[{
       StyleBox[
        "\"total\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0], 
                    Thickness[Large], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0], 
                    Thickness[Large], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"Directive", "[", 
                RowBox[{
                  RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                  RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                  RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], "}"}], ",", 
            
            RowBox[{"{", #, "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      Scaled[{0.56, 0.22}], ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TemplateBox[{
       StyleBox[
        "\"1-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"2-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"3-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"4-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.5470136627990908`", ",", "0.24`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24`", ",", "0.6`", ",", "0.33692049419863584`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      Scaled[{0.85, 0.22}], ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesOrigin->{-0.4, -14.508657738524219`},
   CoordinatesToolOptions:>{"DisplayFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& ), "CopiedValueFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& )},
   Epilog->{
     InsetBox[
      FormBox[
       StyleBox[
       "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
       TraditionalForm], 
      Scaled[{0.05, 0.95}]], 
     InsetBox[
      FormBox[
       StyleBox[
       "\"platykurtic\"", 14, FontFamily -> "Helvetica", StripOnInput -> 
        False], TraditionalForm], 
      Scaled[{0.25, 0.85}]], {
      Opacity[0.5], {
       Arrowheads[{{0.02, 0, {
           GraphicsBox[
            CircleBox[{1, -1}, 1, 
             
             NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
              3.141592653589793}]]], -1}}, {0.02, 1, {
           GraphicsBox[{
             CircleBox[{-1, 1}, 1, 
              NCache[{Rational[-1, 2] Pi, 0}, {-1.5707963267948966`, 0}]], 
             InsetBox[
              BoxData[
               FormBox[
                StyleBox["\"\"", Larger, StripOnInput -> False], 
                TraditionalForm]], {0, 2}]}], 1}}}], 
       ArrowBox[
        NCache[{{-0.125, -
           Log[1000000]}, {-0.125, -11.310192910916147`}}, {{-0.125, \
-13.815510557964274`}, {-0.125, -11.310192910916147`}}]], 
       Arrowheads[{{0.02, 0, {
           GraphicsBox[
            CircleBox[{1, 1}, 1, 
             
             NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
              4.71238898038469}]]], -1}}, {0.02, 1, {
           GraphicsBox[
            CircleBox[{-1, -1}, 1, 
             NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]], 
           1}}}], 
       ArrowBox[{{-0.125, -11.310192910916147`}, {-0.125, \
-8.804875263868018}}]}}},
   Frame->{True, False, False, True},
   FrameLabel->{{"", 
      FormBox["\"Probability of rescue\"", TraditionalForm]}, {"", ""}},
   FrameTicks->{{None, {{-13.815510557964274`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-11.512925464970229`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-9.210340371976182, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-6.907755278982137, 
        FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
        FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
        FormBox["0.1`", TraditionalForm]}, {0., 
        FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.716898269296165`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.429216196844383`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.206072645530174`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.02375108873622, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.86960040890896, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.736069016284437`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.618285980628055`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.819778284410283`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.414313176302118`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.126631103850338`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.903487552536127, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.721165995742174, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.567015315914915, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.433483923290392, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.315700887634009, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-8.517193191416238, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-8.111728083308073, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.824046010856292, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.600902459542082, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.418580902748127, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.264430222920869, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.1308988302963465`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.013115794639964, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-6.214608098422191, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.298317366548036, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.995732273553991, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.659260036932778, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.407945608651872, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.6931471805599453, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659905, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.35667494393873245`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782616`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {True, False}},
   FrameTicksStyle->{
    FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
   GridLines->{None, None},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.4, 0}, {-14.508657738524219`, 0.}},
   PlotRangeClipping->True,
   PlotRangePadding->0,
   Ticks->{Automatic, {{-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.716898269296165`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.429216196844383`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.02375108873622, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.86960040890896, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.736069016284437`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.618285980628055`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}],
  InterpretTemplate[Legended[
    Graphics[{{{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           Opacity[0.5]], 
          Line[CompressedData["
1:eJwtkF1I01EYxv9pZKhNVzOWoc6PdE7TUOdVrcKLZRTojMASpKlFBWrQRO3z
QgkinUuTirKLCdaFk2W2abXnTdPlSnHOua0LaX2wygSz1AiLdv7bA4fD4Zzz
e5/nSVTXqKpCOI6T+hfb795h8iD956pJPptJK9Iy7fCyGyM1Y2HPDBmkMsc3
zxe7kd8ywZmuy8ig9DaKDC4sVxj1OWfSKcKlr90T7kKW71d//mEpnTrJNIu8
gQLnm9w0GllmQCeWFJ3lf+JSKcFPM8c7cb7eqrFF7KALIkacwZVm4fuCv8nk
5nEO3P/RKa5eSqK8XCYHsha9+UXzidQ2zIDT6PMpfi/6JPS9mBm0Q90X1do7
lUAHmD2lHT0dsf1RnjjqZjj9FB6rNzhFX7cTx2sKC5vUu21cLA2yeOZJVBZa
S/ZKxHSOPa+dQLnePnRNuZVkrA7pW/hqDzZY6kT0geG9Nkw+fWcPN2ymQH/j
mEnZWNWzEE0lfF+voR1XZXjOCoL9WLHr9NFPFkFEsI9R7Ouqb28ZDaOLfP5X
yBq9HKq7uT6YdwRzW6Ty5IZ1wXwvodO0K3aurSGQh9CVI7vRWLQKfpzZgm3a
mDlByBIyeb/PEZ1Wqrt05Bvu8f4GETqkybZPexHJ+zHBkf3l88AtJwLznyCm
QptySDyGwDwjRMqOBzhuDPIN+KeTf2x9qMNtnvcIK0mFkv3CE7jK/+9GpLm0
rKpACOLfd+FYXWV9m6DJErjvQJ7AX3tq9YvAuQlcUP8Bo3NLMw==
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           Opacity[0.5]], 
          Line[CompressedData["
1:eJwtkF9Ik1EYxtcKpC2W01nJUnPZmhFp2rKbNVqExhi0CRERYemqm8pZFKkX
I0wRJ2qWbZGZzBGlzYqB3yj2vk1tFpttU9saBG1+JNjoj5sjaBd5vn0PHA6H
c87vfZ6n+PxVnZ7L4XBka4vsDy1EX2CQjmwueLkbU7IzPe7VMKSs7W3nElLU
UYV3fmjDoLrmUEQOStFeHW0W2UNwu2P0ial5F/JD1kYFLwQJbdzS7CrBixeI
PkNyZtE9xi3ByVUCXIA/3KZgefVOLFqjUYULEJ7P8+WbJNgiIsR5kAsFQmOg
GMMMbg78iesu49ZiPFBJNAfBulNdyrM7sNdNgEGYUlVxp9RFGNcSgwFYCX4/
Jv1agDXEXnUAbgrSpesM23GE4Kx+OKzRWxxZYuQw8sMJm2LIOpyPThKPmoVU
3/1UhXIbGsjzRh9U8YbfeL5twT2kDpkXLtn61e/b8zBG8NGPIBdXnu7bL8JM
fx8gEXMqO6M5WMv0NQPjHXQL/4GQ7ccD5fEb+iZdNtvHNMR6636VygTYyuSf
ghVbja6b4rN5J8EtftpgP7mRzfcOBiSfNCXrs9g8CD4v39Tq2oDMOMoFxw23
6EOdXNzL+H0L6aDd463n4CPGnxPkZZO0fDANmxg/E0DfpZLL/X8hM98BDS9+
HlWPJSEz7xVcHqpVZS/9hgzfDpKJ7iVD1zKYGd4z8ONzns68CEbm/wgcGTXv
G8iNADLvH0NBRa5jvN7L3t+Dfz20P2f1NXtug7JpTXLWcwX+AxnkWJE=
           "]]}, {
          Hue[0.1421359549995791, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           Opacity[0.5]], 
          Line[CompressedData["
1:eJwtkGtI01EYxrdRIqtV6qjZ2tbMXcwCwUV+yKhUNCRCqzWjICxXYjDFGJub
4IeK6kMXZ+h0WeaIWTTK1P23yvdNu9jQpblrtWxGLMz6EK0LRuX5+3/gcDic
c37v8zzSSl15FYfFYinnF9nbrUQRaJWEk7bcysIfyoMXhxJh6HnnuhFdloXl
lPj057IwHIr6q631SnQWxxr4zhC08qd694cVuCTUXZvPDYErT7ONla/AY1qi
IBzvv7zZ3CXH4QQBBmBvjUjRt1iOknkaJQ7AdIXMcaVahiY+IfqBvS+XShnL
xDCNmwQjW/dVnJOJqlyiSfBtdXg9zevw0hABvgJrmy0+8z0DZ8uIwQlIPQOB
R+oMLCH2iifAd3KgpZSSop3gusfBZOVb+tOlyKI1DhV3d2yUm9aim8SjfGB7
bddec0uwjjyvHQONLic52CjG9aQO5ShYVEFHTYEIpwk+5gXO4evGGHcNLvT3
Aq6WaHd5/KtxD93XCDxTP1Dru9KZfp7D25aG6IU6AdPHUzAk4vG6olVopvM/
gaYiG9UoWsnkHYbmjp0f5n7zmXyPwVN/ziJ8k8bkQXBtKjgxg6lIj6MGwSQs
FJTeTsENtN+HYNcPyz5ZV6CN9ueGfwZZZLtgOS6l/bjgW6G3KsLmMfP7oP2m
sOPAFy4z7x6opszvRwLJDN8JVXf0lUfuJ2EbzeuBXg3bAMZF2ET/twNvzpD9
MY2DSL/vhE6eJO/swF9YuG+BX6ODAH9+MudTcPTlbm72+Vn4D6fQUYY=
           "]]}, {
          Hue[0.37820393249936934`, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           Opacity[0.5]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGBQB2IQzfzn41b7Fzf22y+uP5nHonsgaIdc6+vAG/tXvXhU
UVOrc2Cd+8MqkXXX92+YMUlA6JX2Ae7riwtsua7vN99/i8coTPtAehoIXNt/
cEHEqX0HtQ4c/qoR03/o6v4M5VmBs3W0DsgDTdshd3X/tY40nbXTNA9Ui4BM
vLI//Lqv373/GgdugI27vF9qyYxZchkaB0yMQeDy/pS7d/6mnlc/MOEQyMBL
+xkUa79sNVU/8CYQ5MCL+w8mKytKz1Y74AFynvvF/U2SL/nW/Vc9sARk3OIL
+29WeWdNTlY9wAAGF/a/WL244fcxlQM7Qd7bcW7/w5xUUUUtlQOFIOUFZ/ez
2TROcO9VPqAFdP1XjTP7H0X/2bPjg9KBRyDjH57av/nUJ9NDIUoHZs0EgZP7
CxNcNm3aqXggGBxeJ/ZfDOH2vi6vCA2f4/v1il+er2hXgIbH0f0qmglxmx7K
H6gB+//I/m9mfbsSd8hB/Xt4/1G97RYRk2Wh/ju4v+FuzoXzRTJQ/xzYr/+u
O/ZOmPQBsHU79u3/y7xpWaK91AEdsHv37J/DWBzHqiN5YA7YfTv37/gW2Ssl
I3GAB+ye7fun/Pj7r5FPHGr/lv1LvPP2ljOKQe3buH/mZS8Xu08iUPPX7f/h
ldzcfkf4wAyweSv3V3cduBO0U+hAA1j/kv3GrK9bWmoEDxwAq5+3P1VYPv03
nwBUfsr+64X8UjcqeKD8lv0KRtO4Xu5jOwAAoZBGJA==
           
           "]]}}}, {}}, {{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          GrayLevel[0], 
          Thickness[Large], 
          Opacity[0.5], 
          Line[CompressedData["
1:eJwtkHtI01EcxWckmQ9SmmKbzcd0LhsxMuuPGAWGGyaMrYTWWlH4KBhN+6fM
pFyG/RMzHGayTFCp1doyQjesnTvfmuXM3AxTXIUgbajUSmJB3t924HK53Hs/
33NO5gWdsnwLi8USbi66tz2k+oyWl9Hv+pcE5LfwjGEgOIfcDrFLkysgSjvv
zg/FHH6VhYYvanOIVeq7zrZ64cvi1vTbskmct7NKEuvF38KFpYPrfFJZQeXB
UJ3/0aiYTwaDFDiL3ivF8orLWSR9k2bnzcJU64vnPMsktWxK/ISxkHJg41sG
mWNwM4jzyjm5aRnkQD7VDA6rild7unmkaYACP0JtYF9tS9xN/ApqcBoLIZnW
VMMlMmpPOo159fNJtW8X6aK4TjcmVHxboyyVsBi5UbD4lO+xpRAHjWf/AJ9G
J49KTSbV9HnVe6xy9h4bqd9J8mgdwkm4SswJy4Ek8pXifRNoNJXV7NEkknB/
4/BKuTp3RwI5wfQ1Bsua5Ljwfmykn1HkG788ab63LdLHMMaPaGVTrVvJDSb/
EJondhSe7o2K5B3EPtGllabZfwjnc+GcqsFQem0D4TwEMdlFpuTyn2DG2Z0w
O14VWM4HIGL8voG4XPRH7/8OE+PPgaS8lJH1k/OIZ/z04cXy9lJB3RTC819j
5awk+DjaGZnXg/S1lvpAUXeEb4UjVJl2ql2PVoZnhmct5+ahxRLcYv53obrP
qLsdE3QS5n07Hihseu1RjTN8b4SF1n53/9vwuQGsiP4D/QhP6Q==
           "]]}}}, {}}, {
      
       GraphicsComplex[{{-0.1, -1.810453111675309}, {-0.1, \
-2.7181005369557116`}, {-0.2, -6.22972173623224}, {-0.1, -5.236281975628584}, \
{-0.2, -7.1691200431165445`}, {-0.3, -11.512925464970229`}, {-0.1, \
-8.145629634983754}, {-0.2, -9.903487552536127}, {-0.1, \
-1.4473615808683413`}, {-0.2, -5.881713683148863}, {-0.3, \
-11.512925464970229`}}, {{{}, {}, {}, {
           Hue[0.9060679774997897, 0.6, 0.6], 
           Directive[
            RGBColor[0.6, 0.24, 0.4428931686004542], 
            Thickness[Large], 
            Dashing[Medium]], 
           Line[{2, 3}]}, {
           Hue[0.1421359549995791, 0.6, 0.6], 
           Directive[
            RGBColor[0.6, 0.5470136627990908, 0.24], 
            Thickness[Large], 
            Dashing[Medium]], 
           Line[{4, 5, 6}]}, {
           Hue[0.37820393249936934`, 0.6, 0.6], 
           Directive[
            RGBColor[0.24, 0.6, 0.33692049419863584`], 
            Thickness[Large], 
            Dashing[Medium]], 
           Line[{7, 8}]}, {
           Hue[0.6142719099991583, 0.6, 0.6], 
           Directive[
            GrayLevel[0], 
            Thickness[0.005], 
            Dashing[Medium]], 
           Line[{9, 10, 11}]}}, {{
           Hue[0.67, 0.6, 0.6], 
           Directive[
            RGBColor[0.24720000000000014`, 0.24, 0.6], 
            Thickness[Large], 
            Dashing[Medium]], 
           Inset[
            Graphics[{
              Hue[0.67, 0.6, 0.6], 
              Directive[
               RGBColor[0.24720000000000014`, 0.24, 0.6], 
               Thickness[Large], 
               Dashing[Medium]], 
              Dashing[None], 
              Thickness[Medium], 
              RGBColor[0.24720000000000014`, 0.24, 0.6], 
              Circle[{0, 0}]}, ImageSize -> 10], 1]}, {
           Hue[0.9060679774997897, 0.6, 0.6], 
           Directive[
            RGBColor[0.6, 0.24, 0.4428931686004542], 
            Thickness[Large], 
            Dashing[Medium]], 
           Inset[
            Graphics[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.24, 0.4428931686004542], 
               Thickness[Large], 
               Dashing[Medium]], 
              Dashing[None], 
              Thickness[Medium], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.24, 0.4428931686004542]}, ImageSize -> 10], 2], 
           
           Inset[
            Graphics[{
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.24, 0.4428931686004542], 
               Thickness[Large], 
               Dashing[Medium]], 
              Dashing[None], 
              Thickness[Medium], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.24, 0.4428931686004542]}, ImageSize -> 10], 
            3]}, {
           Hue[0.1421359549995791, 0.6, 0.6], 
           Directive[
            RGBColor[0.6, 0.5470136627990908, 0.24], 
            Thickness[Large], 
            Dashing[Medium]], 
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.5470136627990908, 0.24], 
               Thickness[Large], 
               Dashing[Medium]], 
              Dashing[None], 
              Thickness[Medium], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.5470136627990908, 0.24]}, ImageSize -> 10], 4], 
           
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.5470136627990908, 0.24], 
               Thickness[Large], 
               Dashing[Medium]], 
              Dashing[None], 
              Thickness[Medium], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.5470136627990908, 0.24]}, ImageSize -> 10], 5], 
           
           Inset[
            Graphics[{
              Hue[0.1421359549995791, 0.6, 0.6], 
              Directive[
               RGBColor[0.6, 0.5470136627990908, 0.24], 
               Thickness[Large], 
               Dashing[Medium]], 
              Dashing[None], 
              Thickness[Medium], 
              Circle[{0, 0}], 
              RGBColor[0.6, 0.5470136627990908, 0.24]}, ImageSize -> 10], 
            6]}, {
           Hue[0.37820393249936934`, 0.6, 0.6], 
           Directive[
            RGBColor[0.24, 0.6, 0.33692049419863584`], 
            Thickness[Large], 
            Dashing[Medium]], 
           Inset[
            Graphics[{
              Hue[0.37820393249936934`, 0.6, 0.6], 
              Directive[
               RGBColor[0.24, 0.6, 0.33692049419863584`], 
               Thickness[Large], 
               Dashing[Medium]], 
              Dashing[None], 
              Thickness[Medium], 
              Circle[{0, 0}], 
              RGBColor[0.24, 0.6, 0.33692049419863584`]}, ImageSize -> 10], 
            7], 
           Inset[
            Graphics[{
              Hue[0.37820393249936934`, 0.6, 0.6], 
              Directive[
               RGBColor[0.24, 0.6, 0.33692049419863584`], 
               Thickness[Large], 
               Dashing[Medium]], 
              Dashing[None], 
              Thickness[Medium], 
              Circle[{0, 0}], 
              RGBColor[0.24, 0.6, 0.33692049419863584`]}, ImageSize -> 10], 
            8]}, {
           Hue[0.6142719099991583, 0.6, 0.6], 
           Directive[
            GrayLevel[0], 
            Thickness[0.005], 
            Dashing[Medium]], 
           Inset[
            Graphics[{
              Hue[0.6142719099991583, 0.6, 0.6], 
              Directive[
               GrayLevel[0], 
               Thickness[0.005], 
               Dashing[Medium]], 
              GrayLevel[0], 
              Disk[{0, 0}]}, ImageSize -> 8], 9], 
           Inset[
            Graphics[{
              Hue[0.6142719099991583, 0.6, 0.6], 
              Directive[
               GrayLevel[0], 
               Thickness[0.005], 
               Dashing[Medium]], 
              GrayLevel[0], 
              Disk[{0, 0}]}, ImageSize -> 8], 10], 
           Inset[
            Graphics[{
              Hue[0.6142719099991583, 0.6, 0.6], 
              Directive[
               GrayLevel[0], 
               Thickness[0.005], 
               Dashing[Medium]], 
              GrayLevel[0], 
              Disk[{0, 0}]}, ImageSize -> 8], 11]}, {}}}], {}}}, {
     PlotRangePadding -> 0, Epilog -> {
        Text[
         Style["B", 14, Bold, FontFamily -> "Helvetica"], 
         Scaled[{0.05, 0.95}]], 
        Text[
         Style["platykurtic", 14, FontFamily -> "Helvetica"], 
         Scaled[{0.25, 0.85}]], {
         Opacity[0.5], {
          Arrowheads[{{0.02, 0, {
              Graphics[
               Circle[{1, -1}, 1, {Rational[1, 2] Pi, Pi}]], -1}}, {
            0.02, 1, {
              Graphics[{
                Circle[{-1, 1}, 1, {Rational[-1, 2] Pi, 0}], 
                Inset[
                 Style["", Larger], {0, 2}]}], 1}}}], 
          Arrow[{{-0.125, -Log[1000000]}, {-0.125, -11.310192910916147`}}], 
          Arrowheads[{{0.02, 0, {
              Graphics[
               Circle[{1, 1}, 1, {Pi, Rational[3, 2] Pi}]], -1}}, {0.02, 1, {
              Graphics[
               Circle[{-1, -1}, 1, {0, Rational[1, 2] Pi}]], 1}}}], 
          
          Arrow[{{-0.125, -11.310192910916147`}, {-0.125, \
-8.804875263868018}}]}}}, 
      FrameLabel -> {{Null, "Probability of rescue"}, {Null, Null}}, 
      Ticks -> {Automatic, {{-13.815510557964274`, 
          Superscript[10, -6]}, {-11.512925464970229`, 
          Superscript[10, -5]}, {-9.210340371976182, 
          Superscript[10, -4]}, {-6.907755278982137, 
         0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 0.1}, {
         0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 0.}, {
           Thickness[0.001]}}}}, GridLines -> {None, None}, 
      FrameTicks -> {{None, {{-13.815510557964274`, 
           Superscript[10, -6]}, {-11.512925464970229`, 
           Superscript[10, -5]}, {-9.210340371976182, 
           Superscript[10, -4]}, {-6.907755278982137, 
          0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 0.1}, {
          0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 0.}, {
            Thickness[0.001]}}}}, {True, False}}, 
      AxesOrigin -> {-0.4, -14.508657738524219`}, 
      PlotRange -> {{-0.4, 0}, {-14.508657738524219`, 0.}}, AspectRatio -> 
      GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0, 0}, 
      CoordinatesToolOptions -> {"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )}, Frame -> {True, False, False, True}, 
      FrameLabel -> {Null, Null, Null, "Probability of rescue"}, 
      FrameTicks -> {True, False, False, True}, 
      FrameTicksStyle -> {
       FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, 
      LabelStyle -> Directive[12, FontFamily -> "Helvetica"], Method -> {}, 
      PlotRange -> {{-0.4, 0}, {-14.508657738524219`, 0.}}, PlotRangeClipping -> 
      True, PlotRangePadding -> {{None, None}, {None, None}}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          Thickness[Large], 
          Opacity[0.5]], 
         Directive[
          RGBColor[0.6, 0.24, 0.4428931686004542], 
          Thickness[Large], 
          Opacity[0.5]], 
         Directive[
          RGBColor[0.6, 0.5470136627990908, 0.24], 
          Thickness[Large], 
          Opacity[0.5]], 
         Directive[
          RGBColor[0.24, 0.6, 0.33692049419863584`], 
          Thickness[Large], 
          Opacity[0.5]]}, {
         Style["1-step", 12, FontFamily -> "Helvetica"], 
         Style["2-step", 12, FontFamily -> "Helvetica"], 
         Style["3-step", 12, FontFamily -> "Helvetica"], 
         Style["4-step", 12, FontFamily -> "Helvetica"]}, LegendLayout -> 
        "Column"]], 
      Scaled[{0.85, 0.22}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{{3.780061788870672*^9, 3.780061825893939*^9}, {
   3.780061912017297*^9, 3.780061973246648*^9}, {3.780062153063774*^9, 
   3.780062210081258*^9}, 3.780065088769031*^9, {3.7800652065005217`*^9, 
   3.780065211989073*^9}, 3.780065417402557*^9, 3.780065534266232*^9, {
   3.780065568800378*^9, 3.78006560952569*^9}, 3.7800656551350403`*^9, {
   3.780065693906588*^9, 3.7800657163174963`*^9}, {3.780065776778501*^9, 
   3.780065791105357*^9}, 3.780065996820011*^9, {3.780066039760066*^9, 
   3.780066046136739*^9}, {3.7822383788799458`*^9, 3.782238398943215*^9}, {
   3.782238434066427*^9, 3.7822384572768*^9}, 3.782238494349181*^9, {
   3.782238566394252*^9, 3.782238578983485*^9}, {3.782238654603652*^9, 
   3.782238672394351*^9}, 3.782238872995116*^9, 3.7822389208500223`*^9, 
   3.78223900425146*^9, 3.782239069925541*^9, {3.782239138431164*^9, 
   3.782239156234818*^9}, 3.782239229470984*^9, {3.782239270940756*^9, 
   3.7822393701413307`*^9}, 3.7822396817256613`*^9, 3.782239767493195*^9, 
   3.782239841261791*^9, 3.782239963711447*^9, {3.7822409530911083`*^9, 
   3.782240988313508*^9}, 3.782259308412101*^9, 3.782259368984927*^9, 
   3.782262420291787*^9, {3.7849039295156517`*^9, 3.7849039424463263`*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Leptokurtic (Laplace, panel C)", "Subsubsection",
 CellChangeTimes->{{3.7800630046951838`*^9, 3.7800630054175386`*^9}, {
  3.780063965047699*^9, 3.7800639671751432`*^9}, {3.784903967426543*^9, 
  3.784903968747592*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"N0", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwts", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.1"}], ",", 
     RowBox[{"-", "0.2"}], ",", 
     RowBox[{"-", "0.3"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"type", "=", "\"\<lepto\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nreps", "=", "100000"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"file", "=", 
        RowBox[{"StringForm", "[", 
         RowBox[{
          RowBox[{
          "datadir", "<>", 
           "\"\<dfe_``_N``_n``_U``_Es``_mmax``_mwt``_nreps``.csv\>\""}], ",", 
          "type", ",", "N0", ",", "n", ",", 
          RowBox[{"NumberForm", "[", 
           RowBox[{
            RowBox[{"U", "//", "N"}], ",", 
            RowBox[{"{", 
             RowBox[{"6", ",", "5"}], "}"}]}], "]"}], ",", 
          RowBox[{"NumberForm", "[", 
           RowBox[{"Es", ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"NumberForm", "[", 
           RowBox[{"mmax", ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"mwts", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", "nreps"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dat", "=", 
        RowBox[{"Import", "[", 
         RowBox[{"ToString", "[", "file", "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"onestep", "=", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Select", "[", 
           RowBox[{"dat", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], "&"}]}], 
           "]"}], "]"}], "/", "nreps"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"twostep", "=", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Select", "[", 
           RowBox[{"dat", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], 
           "]"}], "]"}], "/", "nreps"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"threestep", "=", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Select", "[", 
           RowBox[{"dat", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "3"}], "&"}]}], 
           "]"}], "]"}], "/", "nreps"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"fourstep", "=", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"Select", "[", 
           RowBox[{"dat", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "4"}], "&"}]}], 
           "]"}], "]"}], "/", "nreps"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"total", "=", 
        RowBox[{
        "onestep", "+", "twostep", "+", "threestep", "+", "fourstep"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "onestep", ",", "twostep", ",", "threestep", ",", "fourstep", ",", 
          "total"}], "}"}], "//", "N"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "mwts", "]"}]}], "}"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"mwts", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "mwts", "]"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"Length", "[", 
       RowBox[{"data", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dataplot", "=", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"%", ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.4"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           SuperscriptBox["10", 
            RowBox[{"-", "6"}]], ",", "1"}], "}"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Frame", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"defaultcolors", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", "Thick", ",", "Dotted"}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"defaultcolors", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", "Thick", ",", "Dotted"}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"defaultcolors", "[", 
            RowBox[{"[", "3", "]"}], "]"}], ",", "Thick", ",", "Dotted"}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"defaultcolors", "[", 
            RowBox[{"[", "4", "]"}], "]"}], ",", "Thick", ",", "Dotted"}], 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Black", ",", 
           RowBox[{"Thickness", "[", "0.005", "]"}], ",", "Dotted"}], "]"}]}],
         "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotMarkers", "\[Rule]", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Dashing", "[", "None", "]"}], ",", 
             RowBox[{"Thickness", "[", "Medium", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", 
             RowBox[{"Circle", "[", "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Dashing", "[", "None", "]"}], ",", 
             RowBox[{"Thickness", "[", "Medium", "]"}], ",", 
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Dashing", "[", "None", "]"}], ",", 
             RowBox[{"Thickness", "[", "Medium", "]"}], ",", 
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Dashing", "[", "None", "]"}], ",", 
             RowBox[{"Thickness", "[", "Medium", "]"}], ",", 
             RowBox[{"Circle", "[", "]"}], ",", 
             RowBox[{"defaultcolors", "[", 
              RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "10"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Black", ",", 
             RowBox[{"Disk", "[", "]"}]}], "}"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "8"}]}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figS3c", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
      RowBox[{"theory", ",", "\[IndentingNewLine]", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", 
          RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"5", "*", 
             SuperscriptBox["10", 
              RowBox[{"-", "7"}]]}], ",", "1"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Wildtype growth rate\>\"", ",", ",", ",", 
          "\"\<Probability of rescue\>\""}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}]}], 
      RowBox[{"(*", 
       RowBox[{",", "\[IndentingNewLine]", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"Placed", "[", 
          RowBox[{
           RowBox[{"LineLegend", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"#", ",", "12", ",", 
                RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
               "]"}], "&"}], "/@", 
             RowBox[{"{", 
              RowBox[{
              "\"\<1-step\>\"", ",", "\"\<2-step\>\"", ",", "\"\<3-step\>\"", 
               ",", "\"\<4-step\>\""}], "}"}]}], "]"}], ",", 
           RowBox[{"Scaled", "@", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"7", "/", "8"}], ",", 
              RowBox[{"1", "/", "4"}]}], "}"}]}]}], "]"}]}]}], "*)"}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ListLogPlot", "[", 
      RowBox[{"alltheory", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick", ",", 
          RowBox[{"Opacity", "[", "0.5", "]"}]}], "}"}]}]}], 
      RowBox[{"(*", 
       RowBox[{",", "\[IndentingNewLine]", 
        RowBox[{"PlotLegends", "\[Rule]", 
         RowBox[{"Placed", "[", 
          RowBox[{
           RowBox[{"LineLegend", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"#", ",", "12", ",", 
                RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
               "]"}], "&"}], "/@", 
             RowBox[{"{", "\"\<1-, 2-, 3-, or 4-step\>\"", "}"}]}], "]"}], 
           ",", 
           RowBox[{"Scaled", "@", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"1", "/", "4"}], ",", 
              RowBox[{"7", "/", "8"}]}], "}"}]}]}], "]"}]}]}], "*)"}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", "dataplot", 
     ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRangePadding", "\[Rule]", "0"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"ImagePadding", "\[Rule]", "probpadding"}], ","}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<C\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<leptokurtic\>\"", ",", "14", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.25", ",", "0.85"}], "}"}]}]}], "]"}]}], 
       "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "N0", ",", "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", 
   "mwts", ",", "type", ",", "nreps"}], "]"}]}], "Input",
 CellChangeTimes->{{3.779482934569633*^9, 3.779483103494062*^9}, {
   3.779483139966634*^9, 3.7794832104291897`*^9}, {3.779483265054079*^9, 
   3.779483561394548*^9}, {3.779483608971405*^9, 3.779483614108574*^9}, {
   3.779483645649742*^9, 3.7794838481810427`*^9}, {3.77948390045612*^9, 
   3.779483904729929*^9}, {3.779484621479521*^9, 3.779484766442582*^9}, 
   3.779484915854886*^9, 3.779484995412224*^9, {3.780059637485427*^9, 
   3.780059637624366*^9}, {3.780059917993656*^9, 3.780059927050202*^9}, {
   3.780059966908615*^9, 3.780059977924687*^9}, {3.780060012342165*^9, 
   3.780060024297332*^9}, {3.7800600606007023`*^9, 3.780060090074156*^9}, {
   3.78006023261409*^9, 3.780060237927293*^9}, {3.7800602729538193`*^9, 
   3.78006027625637*^9}, {3.7800605509619017`*^9, 3.780060563827641*^9}, {
   3.780060597173071*^9, 3.780060665131921*^9}, {3.780060695673909*^9, 
   3.780060700275309*^9}, {3.780060744730639*^9, 3.7800607753668413`*^9}, {
   3.7800608493945847`*^9, 3.780060875336527*^9}, {3.7800609301774817`*^9, 
   3.780061094675621*^9}, {3.780061290389022*^9, 3.7800613346892223`*^9}, {
   3.7800614144410458`*^9, 3.780061472389244*^9}, {3.780061504811533*^9, 
   3.780061570723612*^9}, {3.7800616073277493`*^9, 3.7800616649700737`*^9}, {
   3.7800617801226377`*^9, 3.780061825032199*^9}, {3.780061909278323*^9, 
   3.780061972429881*^9}, {3.780062151922361*^9, 3.7800622372023277`*^9}, {
   3.7800647774730377`*^9, 3.780064781288536*^9}, {3.7800651409638166`*^9, 
   3.7800651494120092`*^9}, {3.78006519401059*^9, 3.780065217286662*^9}, {
   3.780065725785174*^9, 3.780065726215065*^9}, {3.780065827056903*^9, 
   3.7800658365659647`*^9}, {3.7800659207650967`*^9, 
   3.7800659801779003`*^9}, {3.782238944683612*^9, 3.782238991998973*^9}, {
   3.782239715910462*^9, 3.782239753219823*^9}, 3.782239829234295*^9, 
   3.782239976692524*^9, {3.782240085120332*^9, 3.782240106600265*^9}, 
   3.782259386386203*^9, {3.7849039742664623`*^9, 3.784903989175157*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {Hue[0.67, 0.6, 0.6], Thickness[Large], Opacity[0.5], 
      LineBox[CompressedData["
1:eJwtkF1I01EYxv9pZKhNVzOWoc6PdE7TUOdVrcKLZRTojMASpKlFBWrQRO3z
QgkinUuTirKLCdaFk2W2abXnTdPlSnHOua0LaX2wygSz1AiLdv7bA4fD4Zzz
e5/nSVTXqKpCOI6T+hfb795h8iD956pJPptJK9Iy7fCyGyM1Y2HPDBmkMsc3
zxe7kd8ywZmuy8ig9DaKDC4sVxj1OWfSKcKlr90T7kKW71d//mEpnTrJNIu8
gQLnm9w0GllmQCeWFJ3lf+JSKcFPM8c7cb7eqrFF7KALIkacwZVm4fuCv8nk
5nEO3P/RKa5eSqK8XCYHsha9+UXzidQ2zIDT6PMpfi/6JPS9mBm0Q90X1do7
lUAHmD2lHT0dsf1RnjjqZjj9FB6rNzhFX7cTx2sKC5vUu21cLA2yeOZJVBZa
S/ZKxHSOPa+dQLnePnRNuZVkrA7pW/hqDzZY6kT0geG9Nkw+fWcPN2ymQH/j
mEnZWNWzEE0lfF+voR1XZXjOCoL9WLHr9NFPFkFEsI9R7Ouqb28ZDaOLfP5X
yBq9HKq7uT6YdwRzW6Ty5IZ1wXwvodO0K3aurSGQh9CVI7vRWLQKfpzZgm3a
mDlByBIyeb/PEZ1Wqrt05Bvu8f4GETqkybZPexHJ+zHBkf3l88AtJwLznyCm
QptySDyGwDwjRMqOBzhuDPIN+KeTf2x9qMNtnvcIK0mFkv3CE7jK/+9GpLm0
rKpACOLfd+FYXWV9m6DJErjvQJ7AX3tq9YvAuQlcUP8Bo3NLMw==
       "]]}, 
     {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], Opacity[0.5], 
      LineBox[CompressedData["
1:eJwtkF9Ik1EYxtcKpC2W01nJUnPZmhFp2rKbNVqExhi0CRERYemqm8pZFKkX
I0wRJ2qWbZGZzBGlzYqB3yj2vk1tFpttU9saBG1+JNjoj5sjaBd5vn0PHA6H
c87vfZ6n+PxVnZ7L4XBka4vsDy1EX2CQjmwueLkbU7IzPe7VMKSs7W3nElLU
UYV3fmjDoLrmUEQOStFeHW0W2UNwu2P0ial5F/JD1kYFLwQJbdzS7CrBixeI
PkNyZtE9xi3ByVUCXIA/3KZgefVOLFqjUYULEJ7P8+WbJNgiIsR5kAsFQmOg
GMMMbg78iesu49ZiPFBJNAfBulNdyrM7sNdNgEGYUlVxp9RFGNcSgwFYCX4/
Jv1agDXEXnUAbgrSpesM23GE4Kx+OKzRWxxZYuQw8sMJm2LIOpyPThKPmoVU
3/1UhXIbGsjzRh9U8YbfeL5twT2kDpkXLtn61e/b8zBG8NGPIBdXnu7bL8JM
fx8gEXMqO6M5WMv0NQPjHXQL/4GQ7ccD5fEb+iZdNtvHNMR6636VygTYyuSf
ghVbja6b4rN5J8EtftpgP7mRzfcOBiSfNCXrs9g8CD4v39Tq2oDMOMoFxw23
6EOdXNzL+H0L6aDd463n4CPGnxPkZZO0fDANmxg/E0DfpZLL/X8hM98BDS9+
HlWPJSEz7xVcHqpVZS/9hgzfDpKJ7iVD1zKYGd4z8ONzns68CEbm/wgcGTXv
G8iNADLvH0NBRa5jvN7L3t+Dfz20P2f1NXtug7JpTXLWcwX+AxnkWJE=
       "]]}, 
     {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], Opacity[0.5], 
      LineBox[CompressedData["
1:eJwtkGtI01EYxrdRIqtV6qjZ2tbMXcwCwUV+yKhUNCRCqzWjICxXYjDFGJub
4IeK6kMXZ+h0WeaIWTTK1P23yvdNu9jQpblrtWxGLMz6EK0LRuX5+3/gcDic
c37v8zzSSl15FYfFYinnF9nbrUQRaJWEk7bcysIfyoMXhxJh6HnnuhFdloXl
lPj057IwHIr6q631SnQWxxr4zhC08qd694cVuCTUXZvPDYErT7ONla/AY1qi
IBzvv7zZ3CXH4QQBBmBvjUjRt1iOknkaJQ7AdIXMcaVahiY+IfqBvS+XShnL
xDCNmwQjW/dVnJOJqlyiSfBtdXg9zevw0hABvgJrmy0+8z0DZ8uIwQlIPQOB
R+oMLCH2iifAd3KgpZSSop3gusfBZOVb+tOlyKI1DhV3d2yUm9aim8SjfGB7
bddec0uwjjyvHQONLic52CjG9aQO5ShYVEFHTYEIpwk+5gXO4evGGHcNLvT3
Aq6WaHd5/KtxD93XCDxTP1Dru9KZfp7D25aG6IU6AdPHUzAk4vG6olVopvM/
gaYiG9UoWsnkHYbmjp0f5n7zmXyPwVN/ziJ8k8bkQXBtKjgxg6lIj6MGwSQs
FJTeTsENtN+HYNcPyz5ZV6CN9ueGfwZZZLtgOS6l/bjgW6G3KsLmMfP7oP2m
sOPAFy4z7x6opszvRwLJDN8JVXf0lUfuJ2EbzeuBXg3bAMZF2ET/twNvzpD9
MY2DSL/vhE6eJO/swF9YuG+BX6ODAH9+MudTcPTlbm72+Vn4D6fQUYY=
       "]]}, 
     {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], Opacity[0.5], 
      LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQzfzn41b7Fzf22y+uP5nHonsgaIdc6+vAG/tXvXhU
UVOrc2Cd+8MqkXXX92+YMUlA6JX2Ae7riwtsua7vN99/i8coTPtAehoIXNt/
cEHEqX0HtQ4c/qoR03/o6v4M5VmBs3W0DsgDTdshd3X/tY40nbXTNA9Ui4BM
vLI//Lqv373/GgdugI27vF9qyYxZchkaB0yMQeDy/pS7d/6mnlc/MOEQyMBL
+xkUa79sNVU/8CYQ5MCL+w8mKytKz1Y74AFynvvF/U2SL/nW/Vc9sARk3OIL
+29WeWdNTlY9wAAGF/a/WL244fcxlQM7Qd7bcW7/w5xUUUUtlQOFIOUFZ/ez
2TROcO9VPqAFdP1XjTP7H0X/2bPjg9KBRyDjH57av/nUJ9NDIUoHZs0EgZP7
CxNcNm3aqXggGBxeJ/ZfDOH2vi6vCA2f4/v1il+er2hXgIbH0f0qmglxmx7K
H6gB+//I/m9mfbsSd8hB/Xt4/1G97RYRk2Wh/ju4v+FuzoXzRTJQ/xzYr/+u
O/ZOmPQBsHU79u3/y7xpWaK91AEdsHv37J/DWBzHqiN5YA7YfTv37/gW2Ssl
I3GAB+ye7fun/Pj7r5FPHGr/lv1LvPP2ljOKQe3buH/mZS8Xu08iUPPX7f/h
ldzcfkf4wAyweSv3V3cduBO0U+hAA1j/kv3GrK9bWmoEDxwAq5+3P1VYPv03
nwBUfsr+64X8UjcqeKD8lv0KRtO4Xu5jOwAAoZBGJA==
       "]]}}, {}}, {{{}, {}, 
     {GrayLevel[0], Thickness[Large], Opacity[0.5], LineBox[CompressedData["
1:eJwtkHtI01EcxWckmQ9SmmKbzcd0LhsxMuuPGAWGGyaMrYTWWlH4KBhN+6fM
pFyG/RMzHGayTFCp1doyQjesnTvfmuXM3AxTXIUgbajUSmJB3t924HK53Hs/
33NO5gWdsnwLi8USbi66tz2k+oyWl9Hv+pcE5LfwjGEgOIfcDrFLkysgSjvv
zg/FHH6VhYYvanOIVeq7zrZ64cvi1vTbskmct7NKEuvF38KFpYPrfFJZQeXB
UJ3/0aiYTwaDFDiL3ivF8orLWSR9k2bnzcJU64vnPMsktWxK/ISxkHJg41sG
mWNwM4jzyjm5aRnkQD7VDA6rild7unmkaYACP0JtYF9tS9xN/ApqcBoLIZnW
VMMlMmpPOo159fNJtW8X6aK4TjcmVHxboyyVsBi5UbD4lO+xpRAHjWf/AJ9G
J49KTSbV9HnVe6xy9h4bqd9J8mgdwkm4SswJy4Ek8pXifRNoNJXV7NEkknB/
4/BKuTp3RwI5wfQ1Bsua5Ljwfmykn1HkG788ab63LdLHMMaPaGVTrVvJDSb/
EJondhSe7o2K5B3EPtGllabZfwjnc+GcqsFQem0D4TwEMdlFpuTyn2DG2Z0w
O14VWM4HIGL8voG4XPRH7/8OE+PPgaS8lJH1k/OIZ/z04cXy9lJB3RTC819j
5awk+DjaGZnXg/S1lvpAUXeEb4UjVJl2ql2PVoZnhmct5+ahxRLcYv53obrP
qLsdE3QS5n07Hihseu1RjTN8b4SF1n53/9vwuQGsiP4D/QhP6Q==
       "]]}}, {}}, {
    GraphicsComplexBox[{{-0.1, -0.48019943022422984`}, {-0.2, \
-2.5254786755530483`}, {-0.3, -4.656463480375642}, {-0.1, \
-2.8028005376480207`}, {-0.2, -4.46280294470117}, {-0.3, -6.557098407368968}, \
{-0.1, -5.5416636251797655`}, {-0.2, -6.821577582741084}, {-0.3, \
-9.210340371976182}, {-0.1, -8.740336742730447}, {-0.2, -9.903487552536127}, \
{-0.1, -0.38070420516670517`}, {-0.2, -2.378494687094396}, {-0.3, \
-4.508043475257368}}, {{{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
        Dashing[{0, Small}], LineBox[{1, 2, 3}]}, 
       {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
        Dashing[{0, Small}], LineBox[{4, 5, 6}]}, 
       {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Large], 
        Dashing[{0, Small}], LineBox[{7, 8, 9}]}, 
       {RGBColor[0.24, 0.6, 0.33692049419863584`], Thickness[Large], 
        Dashing[{0, Small}], LineBox[{10, 11}]}, 
       {GrayLevel[0], Thickness[0.005], Dashing[{0, Small}], 
        LineBox[{12, 13, 14}]}}, {
       {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
        Dashing[{0, Small}], InsetBox[
         GraphicsBox[
          {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Medium], 
           Dashing[None], CircleBox[{0, 0}]},
          ImageSize->10], 1], InsetBox[
         GraphicsBox[
          {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Medium], 
           Dashing[None], CircleBox[{0, 0}]},
          ImageSize->10], 2], InsetBox[
         GraphicsBox[
          {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Medium], 
           Dashing[None], CircleBox[{0, 0}]},
          ImageSize->10], 3]}, 
       {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
        Dashing[{0, Small}], InsetBox[
         GraphicsBox[
          {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Medium], 
           Dashing[None], CircleBox[{0, 0}], 
           {RGBColor[0.6, 0.24, 0.4428931686004542]}},
          ImageSize->10], 4], InsetBox[
         GraphicsBox[
          {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Medium], 
           Dashing[None], CircleBox[{0, 0}], 
           {RGBColor[0.6, 0.24, 0.4428931686004542]}},
          ImageSize->10], 5], InsetBox[
         GraphicsBox[
          {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Medium], 
           Dashing[None], CircleBox[{0, 0}], 
           {RGBColor[0.6, 0.24, 0.4428931686004542]}},
          ImageSize->10], 6]}, 
       {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Large], 
        Dashing[{0, Small}], InsetBox[
         GraphicsBox[
          {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Medium], 
           Dashing[None], CircleBox[{0, 0}], 
           {RGBColor[0.6, 0.5470136627990908, 0.24]}},
          ImageSize->10], 7], InsetBox[
         GraphicsBox[
          {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Medium], 
           Dashing[None], CircleBox[{0, 0}], 
           {RGBColor[0.6, 0.5470136627990908, 0.24]}},
          ImageSize->10], 8], InsetBox[
         GraphicsBox[
          {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Medium], 
           Dashing[None], CircleBox[{0, 0}], 
           {RGBColor[0.6, 0.5470136627990908, 0.24]}},
          ImageSize->10], 9]}, 
       {RGBColor[0.24, 0.6, 0.33692049419863584`], Thickness[Large], 
        Dashing[{0, Small}], InsetBox[
         GraphicsBox[
          {RGBColor[0.24, 0.6, 0.33692049419863584`], Thickness[Medium], 
           Dashing[None], CircleBox[{0, 0}], 
           {RGBColor[0.24, 0.6, 0.33692049419863584`]}},
          ImageSize->10], 10], InsetBox[
         GraphicsBox[
          {RGBColor[0.24, 0.6, 0.33692049419863584`], Thickness[Medium], 
           Dashing[None], CircleBox[{0, 0}], 
           {RGBColor[0.24, 0.6, 0.33692049419863584`]}},
          ImageSize->10], 11]}, 
       {GrayLevel[0], Thickness[0.005], Dashing[{0, Small}], InsetBox[
         GraphicsBox[
          {GrayLevel[0], Thickness[0.005], Dashing[{0, Small}], 
           DiskBox[{0, 0}]},
          ImageSize->8], 12], InsetBox[
         GraphicsBox[
          {GrayLevel[0], Thickness[0.005], Dashing[{0, Small}], 
           DiskBox[{0, 0}]},
          ImageSize->8], 13], InsetBox[
         GraphicsBox[
          {GrayLevel[0], Thickness[0.005], Dashing[{0, Small}], 
           DiskBox[{0, 0}]},
          ImageSize->8], 14]}, {}}}], {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{-0.4, -14.508657738524219`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"C\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
      TraditionalForm], 
     Scaled[{0.05, 0.95}]], 
    InsetBox[
     FormBox[
      StyleBox[
      "\"leptokurtic\"", 14, FontFamily -> "Helvetica", StripOnInput -> 
       False], TraditionalForm], 
     Scaled[{0.25, 0.85}]]},
  Frame->{True, False, False, True},
  FrameLabel->{{"", 
     FormBox["\"Probability of rescue\"", TraditionalForm]}, {
     FormBox["\"Wildtype growth rate\"", TraditionalForm], ""}},
  FrameTicks->{{None, {{-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.716898269296165`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.429216196844383`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.02375108873622, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.86960040890896, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.736069016284437`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.618285980628055`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {True, False}},
  GridLines->{None, None},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{-0.4, 0}, {-14.508657738524219`, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->0,
  Ticks->{Automatic, {{-13.815510557964274`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-11.512925464970229`, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-9.210340371976182, 
      FormBox[
       TemplateBox[{"10", 
         RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.716898269296165`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.429216196844383`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.206072645530174`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-12.02375108873622, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.86960040890896, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.736069016284437`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-11.618285980628055`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.819778284410283`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.414313176302118`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-10.126631103850338`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.903487552536127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.721165995742174, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.567015315914915, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.433483923290392, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-9.315700887634009, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-8.111728083308073, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.824046010856292, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.418580902748127, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.264430222920869, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.1308988302963465`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-7.013115794639964, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.407945608651872, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{
  3.780062239028949*^9, 3.780065091949088*^9, 3.780065220407436*^9, {
   3.780065728380638*^9, 3.780065771566844*^9}, 3.78006584002836*^9, {
   3.780065956719809*^9, 3.780065982033572*^9}, {3.782238945588705*^9, 
   3.7822389934720592`*^9}, {3.782239719751605*^9, 3.78223975483742*^9}, 
   3.782239831161083*^9, 3.782239982561552*^9, {3.782240093269877*^9, 
   3.7822401081657257`*^9}, 3.782259388088069*^9, {3.784903984745858*^9, 
   3.784903991004249*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure S3", "Subsubsection",
 CellChangeTimes->{{3.784904003638199*^9, 3.784904005187821*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GraphicsColumn", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"figS3a", ",", "figS3b", ",", "figS3c"}], "}"}], ",", 
   RowBox[{"Spacings", "\[Rule]", 
    RowBox[{"-", "70"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "375"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{"supfigdir", "<>", "\"\<FigureS3.eps\>\""}], ",", "%"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.784904026977694*^9, 3.78490408487444*^9}, {
  3.7849055031194277`*^9, 3.784905523645949*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     FormBox[
      TagBox[
       FormBox[
        GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxc3Hc8Vv//P3A7K1zGpZ3SUCpRiZLnSSoNokkkZJZSIQ0lI4RKVijKyIrM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           "], {{{}, 
             {GrayLevel[0], Opacity[0.1], EdgeForm[None], 
              GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl01WQl2UUB+A/KaKCdMMuLIpegDRIl9TuhUuDEotKzdAgIaikktKhMyyx
SkkLGEvMUIrS7YWidKhjYAHjc8aLZ8/vnJ1lXt7zfskZQ9IH50wkEjl4w49f
1dN5EokzbNC/qT+jDuAQ+ThOF3awxe/7qHv4RW6ifkCa/JjanV18qv+bNnIW
A+Xcaof4N3hf/y3PytOpLO/hIWn69UyUN/MzjeNvSJV38xet9WvirPJyLvGM
fhop8gQ28RONzJbTXu7PMi5SxWwqleI++Ji7NDRbRju5H0u5wNNmU6goj2cj
d2hgtpS28mss4TxPmU0mOe6CV1nMOSqbTyIp/i+8wiLOkmL+NhXkF+jLwtgN
lczforw8jg3c5nmzJbSSM1gQu6Vi7JVy8ljWc4v6ZotpGTtlPqdIjrunrDyG
ddykntkiWsi7+DPOpl9Nb3keJ0nST6CMnM0DUvXreF1eyw3q6hfSXN7JPVrp
V9FLzqWms5n39CeokOP/d1tafkJ9Kd4aX8T9qfu5L7dX1zI69q0e5BGO0Znt
fBTnjbOTzXX9V2odFtAsdqEO4gj5OUE3dvJJ3K/al338of867pOV9Iy3ox4g
Jy+yibnmveLM8W3J5dXxlJIfV3uwm8/1/9IuzsooOa/aiW18qL9GbXk+TeUd
/E4LfSYvy3M4Rjn9OErKI8niKrXM5tFE3s5vNNeviPuVZ/MNZfVjKSGPYA1X
qBn7obHcg1lxD5QxG0NxeTir+ZEacQc0krszk6OUjvdBMXkYq/iB6mZzaCh3
Y0bsiVKxX4rG90dX3uVLSsZ9USS+C7rwDkcoYT6SwvEN0JnpHKa4+QgKxXun
E9M4RDHz4TwpD2Ull3nObDZ15Y5M5SBFzYZRUB5CJt9TzWxWvDO5A1M4QBGz
oRSQP+Mf2saeGSznUTuyNXaj/46q8kxqywPVwzxK13if8U7MT6kZ7OU/dcW7
Zw==
                "]]]}, {}, 
             {GrayLevel[0], Opacity[0.1], EdgeForm[None], 
              GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwl1GW4FlUUBtCPRrpbkBZFURrsRLAxCekSle5G6VJBJZRQWlJFKQkFBFFQ
SrpB6ZQu1378sZ6z3z3z3dkzZ+YWbNCyeoukiUQiCfcodis2pEgkNpJBTpU8
kRiVLJG4xf18xCU2OlbCOoDTdJV/Ipe6I3soJ6+nqLoPx6ktf8UV3pSXkV7d
heXklDuwm7LyOoqoP+AYteQvucwb8lLSqTuzjBxye3ZRRv6dwur3OUpNeQKX
eF1eQlp1J5aSXW7HTkrLv1FI3Zsj1JDHc5HX5B9Jo+7IErLJbdkRzyvukXFc
4FW9xdym7sCPZJXbsJ374p4Yy7+8oreI1Or2LCaL3JptlIp74AvOU11vIanU
7VhEZrkVW7k3ZuZzzvGy3gJSqtuykExyS/5K9v/78CpjOMtLevNJoW7DAjLK
LdhCyZiZ0ZzhRb0fSK5uzXwyyO+xmbtjZkZxmhf0vieZuhU/kF5+l03cFTMz
klM8rzePpOqWfE86+Z14PykRM/MZJ3lO7zuSqO+M+fiUEzyr/y0JdfGYhU84
TjX9b+Ib8G3c5AbXucZVisUsjOAYVZ07lyuOFY3rMpyjPKM/h8uOxYc3j7Ry
czZQJGbhY45QRW92fHPxXcbc6v6ciucof0ca9dv8SWF5LQXVvfiHavLd1kGc
jW9Y/oen1bO46G/fZ/0w6vg7ce/WaxSnHydjH+JZWm/EuxHP3f+GIdbz8ewc
Sy4Pj/uOdzyepdzM+geFHE8pj1TfjHcx9lkeav2XXx1PIY9QX+WO2Ce5p/Vv
qsZeWa/He8BAzsTM8aziecZ56qesM7ngnkpZh0UdMzhWzNqXE/GOyCWtgzkX
+yuntjZlPQXlNRRQ9+Awz8jDOMyT8oyY3XWay3NJJTdhXcwvrya/ujuHqCIP
5RBPyF/Hs/P7t+U58XzkxvxOgdgfhnCQx/Wmx6zOzx/3yWAO8Jj+tNhbx85w
mlOc5AS3x7wMYj+POncqxx3LF7MwkH08oj+FY47ljesygL08rD+Zo441k2fH
nsmN+I08MQv92cNDepM44vym8qx4R+SGrCV3zEI/dvOg3sR4Z53fRJ5JMrlB
vB/kivnoyy4e0Psq9t35jeUZJJXrs4acMTN92EllvS9jL53fSP6aJHI9VpMj
ZuYDdlBJb0LsnfMbytNJyHX5hewxM++znYp64zno/AbyNG5RR28V2WJmerON
CnrjOOD8+vJUbvKW3kqyqn/hdnW3+LtUlnuxlfLyWPb7fT15CjeorbeCLOpV
5FN3jetQSe7JX5STv2Cf39eVJ3OdWno/k1m9krzqLnEdKso92EJZ+XP2+n0d
eRLXqKn3E5nUK8ij7hzXoYLcnc2Ukcewx+/fkidylRp6y8mo/pnc6k5xHcrL
3dhEaXk0/wG2CSiK
                "]]]}, {}, 
             {GrayLevel[0], Opacity[0.1], EdgeForm[None], 
              GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwV0mlTTmEAx+HDMINEImRrIku0KFt9CUulfV9sLxjbMEzv7FuytcmeNvkA
VMOgrBWy+wDC+Ayu8+Ka+/z+5839PHPiK/dk7R4fBME4Rnk0MQiGGSFzQhC8
ctYywFqO8Ix/3qU5D/GEbv2XVM8H6WeXbuEncbqGh2ToLv6Qog/Qx07dzA8W
6Wp62KB30MR3FtqqeMB6vZ1GvrHAVhneh3V6Gw18Zb6tgq7wt+garvGFebZy
Olmjq7nKZ2JtZXSQrqu4wifm2kppJ0138ptkvZ/e8D76MqPM0SXcZ7Wu4BIf
mW0rpo1UXU49H4ixFXGPFF3GRd4zy1bIXZJ1KXWMMNNWwB2SdAkXGCbals9t
VulizjPEDFset1ipizjHO6JsudwkURdylrdMt23lBit0AWd4wzRbDq0s1/mc
5jWRtmyus0zncSr8/phqy6KFpTqXk7wkwraFZhJ0B2Mk6X08Du+jTzDIFL2Z
JpboHI4zwGTbJhpZrLM5xgsm2TbSQLxuJ93zYZ7ySx91Pg//SwbZy3/h3meF

                 "]], PolygonBox[CompressedData["
1:eJwV0kVTVXEcx+EDgt3dgq0rZxwLA0RFEZOX4MIC7sVCUaTsbld2rVS6LBR1
xo2+A7tWjordPmfxzPl/vnfzW9zEJdHMSGwQBDE00zouCB7GB8EjMr0f+BZw
n7Hk08Q7v43xzaORLfoerbznc5wEfYm3jNa5NLBYl3KXlnoexxikF1FCE/G2
DI4yUF/kDaN0lHoW6mLuEKfncoQBegFF3KaFLZ3D9NcXeM1IHaEuvFsX0kis
nsMh+unzvGKEzqE2vFtv5hYxejYH6aszKOAmgS2NA/TR53jJcJ1NTXi33sQN
/jHLtp/e3uls5Dp/mWnfRy/vs7xgmM6iOrxb53ONP8yw7aWn9xmeM1SvpCq8
W2+ggd+k2vbQwzuN9dTzi+n23XQPbySPOn6SYt9Ft/BG1lHLD5LtO+ka3sNa
avjONPsOunif5hlD9AoqSdVrqOYbU23b6Rzew2qq+MoU+zY6eZ/iKYP1cipI
0auo5AuTbVvp6H2SJyTqZZSTrHOp4DNJ4X+dDuHdRCnnE5PspbQPbyRCGc1M
tJfQLryRHK7ykQn2YtqG95DNFT4w3l5EG+8TPCZBL6WMJJ3FZd4zzlbIf0Hs
d34=
                 
                 "]]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, \
{{}, {}, 
             {GrayLevel[0], Thickness[Large], Dashing[Medium], 
              LineBox[{1, 365, 272, 193, 129, 80, 51, 2, 3, 4, 5, 6, 7, 8, 9, 
               10, 11, 12, 366, 273, 194, 130, 81, 52, 394, 301, 222, 158, 
               109, 13, 367, 274, 195, 131, 429, 336, 257, 451, 358, 82, 414, 
               321, 459}], LineBox[CompressedData["
1:eJwt01WQlmUYBuAVBEUQRLpZUjyQUjqk0wM6VViQcgYUBRMRJJWwe0bBIFUa
UQxmFBQTsDkAQTAAdezC8bpnPLj2uZ9n//33e+MrLJo2cOoZBQUFN/vxk/qa
WsR+Num3qsMpxR6mcIn5XepFHJKfYKM8mBJM1T+r9uEv+SXKco2+Am/I8xhE
K5aYNeWw/CTTKMe1ZhV5U57PYFqz1KwZX8or8r2cx3SzSuyWFzCENpTnOvPK
WYO8kKG05XyuN6/CW/IihtGOCswwr8rb8mKG056KzDSvxl75TkbQgWVmzTki
r8w6qMQNZtV5J/vHSDqy3KwFR+Wnsg4qc6NZDd7NHjGKTtxt1pKv5KezNqpw
k1lN3sseMTpno+/Kz/JmOnOP/mKOyc9k/VT9/w7U4v2sgctzHvpu/CJv4VLu
zR3geM6ZTfIQSjJDv0rty9/yy7woj6JM9kt/i1qbD+Sd6pUsl59XB1Asd4SJ
XJEzVrtnH/hV/7o6jgNs1W9TR/Ah5+QcuZqP6eL396mtck58rX9FHcM+VmVf
1KFZN2flvjGJmX63Wu3HP/IudTw75R3qaM7NmepvVevkGXI+vCAPpHjWl3ug
9uC3PC9duV/fmm/yf3I/WKPvz+k8JzWYpa+b583ZMSb3RN+T3+XtdOMBfRu+
zffk/lCT28wK807n7BhLdx40a8t38trcH2ox26xe9jd7RxE9eMisHSfkdbkv
1OZ2s/p8lDUxjp7UYY55g5xFno/x9KIuc80b8kmehavoTSF3mDfi0/xfJtCH
h83ac1Jen7tEPeaZNeazfIaJ9OURsw6ckp/LOVGf+WYX8Hk+wyT68ahZR77P
fcze04AFZk34Ip9hct49fS/+yB2nP4/pO/FD7kD2Pnurv4x/5VdpyEL9hRzM
37BBHsSZTMl7qfbmz9y1nLE8ktL5Lv3jamd+zHeqY9mQd1QdlneLs9nN5JwN
s3Nu6n9pprmy
               "]], 
              LineBox[{334, 461, 255, 450, 357, 191, 442, 349, 270, 38, 392, 
               299, 220, 156, 107, 78, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48,
                49, 393, 300, 221, 157, 108, 79, 413, 320, 241, 177, 128, 428,
                335, 256, 192, 443, 350, 271, 457, 364, 470, 50}]}, 
             {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwl1WWYVGUYgOFhaREQBJGWFGmluxGlBFSQDiVUOqS7S7oVlJBSUrqVRhoJ
aaVbur2/yx/3dd7nPWd2ZmfO7KZr3Lp6q2iRSCRbVCRyyjA5eiTyHod0d/Jz
RncmOVt0QjaZP+OJeSb1OO3xU+zycFj3oABndRdS8Jt+jc3m2jw1z6J+eB6P
n2qXlyO6JwU5p7uSkt91IraY6/DMPJsG4Xk8fppdPv7UvSjEed2NVGzVifnN
XJfn5jk0DM/j8d/Z5eeo7k1h/tbdSc02/Tq/m+vxwvwTjcLzePz3dgU4pvtQ
hCRstavPS/NcGoef6/rpdgU5rvtSlKRss2tAhHm6Cf+4foYuxAndj2K8wXa7
hkRjvv6cC67/QRfmL92f4iRjh10joligv+Ci63/URTipB1CCN9lp15joLNRN
ueT6mboop/RASpKcXXZNiMHPuhmXXT9LF+O0HkQpUrDb7nNi8otuzhXXz9bF
OaMHU5qUXHVujn0JzuohlCEV15z7yb4k5/RQypKa687d4Ca3uM0d5rq2FOdd
M4xypOFf5+bZl+ZvPZzypGWP3RfEYpFuwV3Xz9dl+EeP4P3w2ekepGG7fos/
zE2JzWL9Jfc8foEuywU9kgrhs9Q9ScsOnY695mbEYUl4rY7DyM5X4Xd1HEBm
9un7jiPJxX3Ps9CxHBede+Q4mm/Ntx2HkDV8vxjPB+H+cOwV7rEYXn/47jM2
fGZ6Z3jt5hHhHtE5w3eDieH90emd32duHu5pHdfxMWPCPaKXhvfOPDzckzpH
+G4yga+du+E4kLfD3wzGsd/+QXjN5OaB3+lnx/Jccm4Ud8xDycaH4Z517E06
dukM7De34BWW6ZbcNA8iCwf0Qz/7F/P7XNajqUhGDth9STyW61bh/XT9Il2B
K3oMlcjEY+cWh/eUq3oslcnME+ee8oznvOAlS8Lr55prxlGFt4mw1L4i183j
qUoWorHMvhI3zBP4iHc4GO4RXuVX3ZooluvK3DRPpBpZORQ+B+KzQrchOr/q
KtwyT6J61P//Sw7btSQBK3VbYrBCV+W2eTI1yM4Ru1YkZJVuR0xW6o+4Y57C
x+TgT7vWvMZq3Z5YrNLV+Nc8lU/IyVG7NiRije5AbFbr6tw1T+NTcnHMri2J
Was7Eoc1ugb3zN9Rk9wct2vH66zTnYjLWv1x+L6Zv6cW73LCrj1JWK+/4RXW
6U/CvWyezmdc1n1Iz279Hn+ZO5CUDboz8VivP+WheQa1uaL7koE9Og8nzR15
g426C6+yQdfkkfkH6nBV9yMjf+i8nDJ3IhmbdFfis1HXCt9t84/U5ZruTyb2
6nycNn/Dm2zW3bhlHsw7HAzfOcdRvMtLJhHb34YEzv0H+H8m2Q==
               "]]}, 
             {GrayLevel[0], Thickness[Large], Dashing[{0, Small}], 
              LineBox[CompressedData["
1:eJwV0sVyFFEABdAOJLi7k+CwoorC4u5B8gkssCSTYIFAcHdnhdsKdw8EqOIn
cFtRBHc5b3Fq7r0z3VXd85KmVZfH4qIoaqJVfBQtS4iisbyXT1FBMmdt00nk
sb6f1izXx9Ekn6aSFNqwwj6eD/IZqkilLSvtE/gY7k2MNNqxyj6RT/I5qkmn
PavtyXyWz1NDRvidbQZJPNEP0IE1egpf5AvMITNca5vJIJ7qB+nIWj2Vr/JF
5pJFJ9bZ0/gmX2Ie2eG+tlkM5pl+iM6s19P5Ll9mPjl0YYM9gx/yFRaQS1c2
2jP5KV+lljy6scmexS/5GgvJpzub7dn8lq+ziILwHLbZDOG5fpgebNFz+CPf
oI7C8Gy2CobyQj9CT7bqufyVb7KYInqxzZ7HP/kWSygOz22rZBgv9aP0Zrue
T8RtvZ4S+rDDVkAcd/SllIb3pFcxnFf6MfqyUy+kGQ3hDFMW3p0eYwSv9eP0
Y5deRHPuhjPMJPqz21ZMPPfCGWZyeNd6NSN5o59gAHv0EhJoDOeaKQxkr62U
FtwP55qp4b/RaxjFW/0kiezTy2jJg3DWaZBrGc07vdFnHWN4SD2PKPfdf0jO
ddU=
               "]], LineBox[CompressedData["
1:eJwV0tdOVGEYhtFtoom9Ya8BRZQqiO0mVHpvA9gONLZoIJ7ZexdQsIMiegG2
YBA7FlSwXYCK8Rpc/8HKzPNOJnuS+eJjW3O3DIuiqJ8HI6JoGy9I4RmN/Boe
RU+97iGLDh3PRe/XMJJevY88EmiyrWUUz/V+8llAs20do8Oz9AEKeKi3k8pv
fZuFtOgcxvBSH6SQRC7ZchnLK32IIhZx2ZbHOF7rwxSTRKstn/G80UcoYTFt
tgIm8FYfpZQlXLEVMpE+fYwykrlqK2IS7/Rxyknhmq2YybzXJ6ggleu2EuL4
oE9SSRo3bKVM4aM+RRXp3LSVMZV+fZpqMrhlK2can/QZalhKu62C6XzWZ4nx
SO8gjT/6Dpl06Epm8EWfo5as8B/ZqpjJgD5PHcvC923VzGJQX6CebDptNczm
a7gl1rOcu7YYc/gWbokNrKDLVstcvodbYiMruWerYx4/wt2wicd6J+kMhWez
ivu6nvn8DLfEZp7oXWTwN/weur3fTSb/dI/XBrLDfbM33B+rffYf4XVl2A==

               "]]}, 
             {GrayLevel[0], Opacity[0.1], LineBox[{473, 475, 472}], 
              LineBox[{474, 476, 471}], 
              LineBox[{1483, 1484, 1482}]}}, {{}, {}, {}, {}, {}}}], 
          InsetBox[
           
           TemplateBox[{
            StyleBox[
             "\"platykurtic\"", StripOnInput -> False, FontFamily -> 
              "Helvetica", FontSize -> 12],StyleBox[
             "\"normal\"", StripOnInput -> False, FontFamily -> "Helvetica", 
              FontSize -> 12],StyleBox[
             "\"leptokurtic\"", StripOnInput -> False, FontFamily -> 
              "Helvetica", FontSize -> 12]},
            "LineLegend",
            DisplayFunction->(StyleBox[
              StyleBox[
               PaneBox[
                TagBox[
                 GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    Dashing[Medium], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    Dashing[Medium], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    Dashing[{0, Small}], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    Dashing[{0, Small}], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                  False, GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                 "Grid"], Alignment -> Left, AppearanceElements -> None, 
                ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
              FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
              False]& ),
            Editable->True,
            InterpretationFunction:>(RowBox[{"LineLegend", "[", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Medium", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "Small"}], "}"}], "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}]}], "}"}], 
                 ",", 
                 RowBox[{"{", 
                   RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                 RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
               "]"}]& )], Scaled[{0.8, 0.8}], ImageScaled[{0.5, 0.5}],
           BaseStyle->{FontSize -> Larger},
           FormatType->StandardForm]},
         AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
         Axes->True,
         AxesOrigin->{0, 0},
         Epilog->{
           InsetBox[
            FormBox[
             StyleBox[
             "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
              False], TraditionalForm], 
            Scaled[{0.05, 0.95}]]},
         Frame->{True, False, False, False},
         FrameLabel->{{None, None}, {
            FormBox[
            "\"\\!\\(\\*SubscriptBox[\\(\[CapitalDelta]z\\), \\(i\\)]\\)\"", 
             TraditionalForm], None}},
         FrameStyle->Directive[12, FontFamily -> "Helvetica"],
         Method->{"AxesInFront" -> True},
         PlotRange->{{-0.282842712474619, 0.282842712474619}, {0, All}},
         PlotRangeClipping->True,
         PlotRangePadding->None],
        TraditionalForm],
       InterpretTemplate[Legended[
         Graphics[
          GraphicsComplex[CompressedData["
1:eJxc3Hc8Vv//P3A7K1zGpZ3SUCpRiZLnSSoNokkkZJZSIQ0lI4RKVijKyIrM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           "], {{{}, {
              EdgeForm[], 
              Directive[
               GrayLevel[0], 
               Opacity[0.1]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJwl01WQl2UUB+A/KaKCdMMuLIpegDRIl9TuhUuDEotKzdAgIaikktKhMyyx
SkkLGEvMUIrS7YWidKhjYAHjc8aLZ8/vnJ1lXt7zfskZQ9IH50wkEjl4w49f
1dN5EokzbNC/qT+jDuAQ+ThOF3awxe/7qHv4RW6ifkCa/JjanV18qv+bNnIW
A+Xcaof4N3hf/y3PytOpLO/hIWn69UyUN/MzjeNvSJV38xet9WvirPJyLvGM
fhop8gQ28RONzJbTXu7PMi5SxWwqleI++Ji7NDRbRju5H0u5wNNmU6goj2cj
d2hgtpS28mss4TxPmU0mOe6CV1nMOSqbTyIp/i+8wiLOkmL+NhXkF+jLwtgN
lczforw8jg3c5nmzJbSSM1gQu6Vi7JVy8ljWc4v6ZotpGTtlPqdIjrunrDyG
ddykntkiWsi7+DPOpl9Nb3keJ0nST6CMnM0DUvXreF1eyw3q6hfSXN7JPVrp
V9FLzqWms5n39CeokOP/d1tafkJ9Kd4aX8T9qfu5L7dX1zI69q0e5BGO0Znt
fBTnjbOTzXX9V2odFtAsdqEO4gj5OUE3dvJJ3K/al338of867pOV9Iy3ox4g
Jy+yibnmveLM8W3J5dXxlJIfV3uwm8/1/9IuzsooOa/aiW18qL9GbXk+TeUd
/E4LfSYvy3M4Rjn9OErKI8niKrXM5tFE3s5vNNeviPuVZ/MNZfVjKSGPYA1X
qBn7obHcg1lxD5QxG0NxeTir+ZEacQc0krszk6OUjvdBMXkYq/iB6mZzaCh3
Y0bsiVKxX4rG90dX3uVLSsZ9USS+C7rwDkcoYT6SwvEN0JnpHKa4+QgKxXun
E9M4RDHz4TwpD2Ull3nObDZ15Y5M5SBFzYZRUB5CJt9TzWxWvDO5A1M4QBGz
oRSQP+Mf2saeGSznUTuyNXaj/46q8kxqywPVwzxK13if8U7MT6kZ7OU/dcW7
Zw==
                 "]]}]}, {}, {
              EdgeForm[], 
              Directive[
               GrayLevel[0], 
               Opacity[0.1]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJwl1GW4FlUUBtCPRrpbkBZFURrsRLAxCekSle5G6VJBJZRQWlJFKQkFBFFQ
SrpB6ZQu1378sZ6z3z3z3dkzZ+YWbNCyeoukiUQiCfcodis2pEgkNpJBTpU8
kRiVLJG4xf18xCU2OlbCOoDTdJV/Ipe6I3soJ6+nqLoPx6ktf8UV3pSXkV7d
heXklDuwm7LyOoqoP+AYteQvucwb8lLSqTuzjBxye3ZRRv6dwur3OUpNeQKX
eF1eQlp1J5aSXW7HTkrLv1FI3Zsj1JDHc5HX5B9Jo+7IErLJbdkRzyvukXFc
4FW9xdym7sCPZJXbsJ374p4Yy7+8oreI1Or2LCaL3JptlIp74AvOU11vIanU
7VhEZrkVW7k3ZuZzzvGy3gJSqtuykExyS/5K9v/78CpjOMtLevNJoW7DAjLK
LdhCyZiZ0ZzhRb0fSK5uzXwyyO+xmbtjZkZxmhf0vieZuhU/kF5+l03cFTMz
klM8rzePpOqWfE86+Z14PykRM/MZJ3lO7zuSqO+M+fiUEzyr/y0JdfGYhU84
TjX9b+Ib8G3c5AbXucZVisUsjOAYVZ07lyuOFY3rMpyjPKM/h8uOxYc3j7Ry
czZQJGbhY45QRW92fHPxXcbc6v6ciucof0ca9dv8SWF5LQXVvfiHavLd1kGc
jW9Y/oen1bO46G/fZ/0w6vg7ce/WaxSnHydjH+JZWm/EuxHP3f+GIdbz8ewc
Sy4Pj/uOdzyepdzM+geFHE8pj1TfjHcx9lkeav2XXx1PIY9QX+WO2Ce5p/Vv
qsZeWa/He8BAzsTM8aziecZ56qesM7ngnkpZh0UdMzhWzNqXE/GOyCWtgzkX
+yuntjZlPQXlNRRQ9+Awz8jDOMyT8oyY3XWay3NJJTdhXcwvrya/ujuHqCIP
5RBPyF/Hs/P7t+U58XzkxvxOgdgfhnCQx/Wmx6zOzx/3yWAO8Jj+tNhbx85w
mlOc5AS3x7wMYj+POncqxx3LF7MwkH08oj+FY47ljesygL08rD+Zo441k2fH
nsmN+I08MQv92cNDepM44vym8qx4R+SGrCV3zEI/dvOg3sR4Z53fRJ5JMrlB
vB/kivnoyy4e0Psq9t35jeUZJJXrs4acMTN92EllvS9jL53fSP6aJHI9VpMj
ZuYDdlBJb0LsnfMbytNJyHX5hewxM++znYp64zno/AbyNG5RR28V2WJmerON
CnrjOOD8+vJUbvKW3kqyqn/hdnW3+LtUlnuxlfLyWPb7fT15CjeorbeCLOpV
5FN3jetQSe7JX5STv2Cf39eVJ3OdWno/k1m9krzqLnEdKso92EJZ+XP2+n0d
eRLXqKn3E5nUK8ij7hzXoYLcnc2Ukcewx+/fkidylRp6y8mo/pnc6k5xHcrL
3dhEaXk0/wG2CSiK
                 "]]}]}, {}, {
              EdgeForm[], 
              Directive[
               GrayLevel[0], 
               Opacity[0.1]], 
              GraphicsGroup[{
                Polygon[CompressedData["
1:eJwV0mlTTmEAx+HDMINEImRrIku0KFt9CUulfV9sLxjbMEzv7FuytcmeNvkA
VMOgrBWy+wDC+Ayu8+Ka+/z+5839PHPiK/dk7R4fBME4Rnk0MQiGGSFzQhC8
ctYywFqO8Ix/3qU5D/GEbv2XVM8H6WeXbuEncbqGh2ToLv6Qog/Qx07dzA8W
6Wp62KB30MR3FtqqeMB6vZ1GvrHAVhneh3V6Gw18Zb6tgq7wt+garvGFebZy
Olmjq7nKZ2JtZXSQrqu4wifm2kppJ0138ptkvZ/e8D76MqPM0SXcZ7Wu4BIf
mW0rpo1UXU49H4ixFXGPFF3GRd4zy1bIXZJ1KXWMMNNWwB2SdAkXGCbals9t
VulizjPEDFset1ipizjHO6JsudwkURdylrdMt23lBit0AWd4wzRbDq0s1/mc
5jWRtmyus0zncSr8/phqy6KFpTqXk7wkwraFZhJ0B2Mk6X08Du+jTzDIFL2Z
JpboHI4zwGTbJhpZrLM5xgsm2TbSQLxuJ93zYZ7ySx91Pg//SwbZy3/h3meF

                 "]], 
                Polygon[CompressedData["
1:eJwV0kVTVXEcx+EDgt3dgq0rZxwLA0RFEZOX4MIC7sVCUaTsbld2rVS6LBR1
xo2+A7tWjordPmfxzPl/vnfzW9zEJdHMSGwQBDE00zouCB7GB8EjMr0f+BZw
n7Hk08Q7v43xzaORLfoerbznc5wEfYm3jNa5NLBYl3KXlnoexxikF1FCE/G2
DI4yUF/kDaN0lHoW6mLuEKfncoQBegFF3KaFLZ3D9NcXeM1IHaEuvFsX0kis
nsMh+unzvGKEzqE2vFtv5hYxejYH6aszKOAmgS2NA/TR53jJcJ1NTXi33sQN
/jHLtp/e3uls5Dp/mWnfRy/vs7xgmM6iOrxb53ONP8yw7aWn9xmeM1SvpCq8
W2+ggd+k2vbQwzuN9dTzi+n23XQPbySPOn6SYt9Ft/BG1lHLD5LtO+ka3sNa
avjONPsOunif5hlD9AoqSdVrqOYbU23b6Rzew2qq+MoU+zY6eZ/iKYP1cipI
0auo5AuTbVvp6H2SJyTqZZSTrHOp4DNJ4X+dDuHdRCnnE5PspbQPbyRCGc1M
tJfQLryRHK7ykQn2YtqG95DNFT4w3l5EG+8TPCZBL6WMJJ3FZd4zzlbIf0Hs
d34=
                 
                 "]]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, \
{{}, {}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               Thickness[Large], 
               Dashing[Medium], 
               GrayLevel[0]], 
              
              Line[{1, 365, 272, 193, 129, 80, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10,
                11, 12, 366, 273, 194, 130, 81, 52, 394, 301, 222, 158, 109, 
               13, 367, 274, 195, 131, 429, 336, 257, 451, 358, 82, 414, 321, 
               459}], 
              Line[CompressedData["
1:eJwt01WQlmUYBuAVBEUQRLpZUjyQUjqk0wM6VViQcgYUBRMRJJWwe0bBIFUa
UQxmFBQTsDkAQTAAdezC8bpnPLj2uZ9n//33e+MrLJo2cOoZBQUFN/vxk/qa
WsR+Num3qsMpxR6mcIn5XepFHJKfYKM8mBJM1T+r9uEv+SXKco2+Am/I8xhE
K5aYNeWw/CTTKMe1ZhV5U57PYFqz1KwZX8or8r2cx3SzSuyWFzCENpTnOvPK
WYO8kKG05XyuN6/CW/IihtGOCswwr8rb8mKG056KzDSvxl75TkbQgWVmzTki
r8w6qMQNZtV5J/vHSDqy3KwFR+Wnsg4qc6NZDd7NHjGKTtxt1pKv5KezNqpw
k1lN3sseMTpno+/Kz/JmOnOP/mKOyc9k/VT9/w7U4v2sgctzHvpu/CJv4VLu
zR3geM6ZTfIQSjJDv0rty9/yy7woj6JM9kt/i1qbD+Sd6pUsl59XB1Asd4SJ
XJEzVrtnH/hV/7o6jgNs1W9TR/Ah5+QcuZqP6eL396mtck58rX9FHcM+VmVf
1KFZN2flvjGJmX63Wu3HP/IudTw75R3qaM7NmepvVevkGXI+vCAPpHjWl3ug
9uC3PC9duV/fmm/yf3I/WKPvz+k8JzWYpa+b583ZMSb3RN+T3+XtdOMBfRu+
zffk/lCT28wK807n7BhLdx40a8t38trcH2ox26xe9jd7RxE9eMisHSfkdbkv
1OZ2s/p8lDUxjp7UYY55g5xFno/x9KIuc80b8kmehavoTSF3mDfi0/xfJtCH
h83ac1Jen7tEPeaZNeazfIaJ9OURsw6ckp/LOVGf+WYX8Hk+wyT68ahZR77P
fcze04AFZk34Ip9hct49fS/+yB2nP4/pO/FD7kD2Pnurv4x/5VdpyEL9hRzM
37BBHsSZTMl7qfbmz9y1nLE8ktL5Lv3jamd+zHeqY9mQd1QdlneLs9nN5JwN
s3Nu6n9pprmy
               "]], 
              
              Line[{334, 461, 255, 450, 357, 191, 442, 349, 270, 38, 392, 299,
                220, 156, 107, 78, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49,
                393, 300, 221, 157, 108, 79, 413, 320, 241, 177, 128, 428, 
               335, 256, 192, 443, 350, 271, 457, 364, 470, 50}]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               Thickness[Large], 
               GrayLevel[0]], 
              Line[CompressedData["
1:eJwl1WWYVGUYgOFhaREQBJGWFGmluxGlBFSQDiVUOqS7S7oVlJBSUrqVRhoJ
aaVbur2/yx/3dd7nPWd2ZmfO7KZr3Lp6q2iRSCRbVCRyyjA5eiTyHod0d/Jz
RncmOVt0QjaZP+OJeSb1OO3xU+zycFj3oABndRdS8Jt+jc3m2jw1z6J+eB6P
n2qXlyO6JwU5p7uSkt91IraY6/DMPJsG4Xk8fppdPv7UvSjEed2NVGzVifnN
XJfn5jk0DM/j8d/Z5eeo7k1h/tbdSc02/Tq/m+vxwvwTjcLzePz3dgU4pvtQ
hCRstavPS/NcGoef6/rpdgU5rvtSlKRss2tAhHm6Cf+4foYuxAndj2K8wXa7
hkRjvv6cC67/QRfmL92f4iRjh10joligv+Ci63/URTipB1CCN9lp15joLNRN
ueT6mboop/RASpKcXXZNiMHPuhmXXT9LF+O0HkQpUrDb7nNi8otuzhXXz9bF
OaMHU5qUXHVujn0JzuohlCEV15z7yb4k5/RQypKa687d4Ca3uM0d5rq2FOdd
M4xypOFf5+bZl+ZvPZzypGWP3RfEYpFuwV3Xz9dl+EeP4P3w2ekepGG7fos/
zE2JzWL9Jfc8foEuywU9kgrhs9Q9ScsOnY695mbEYUl4rY7DyM5X4Xd1HEBm
9un7jiPJxX3Ps9CxHBede+Q4mm/Ntx2HkDV8vxjPB+H+cOwV7rEYXn/47jM2
fGZ6Z3jt5hHhHtE5w3eDieH90emd32duHu5pHdfxMWPCPaKXhvfOPDzckzpH
+G4yga+du+E4kLfD3wzGsd/+QXjN5OaB3+lnx/Jccm4Ud8xDycaH4Z517E06
dukM7De34BWW6ZbcNA8iCwf0Qz/7F/P7XNajqUhGDth9STyW61bh/XT9Il2B
K3oMlcjEY+cWh/eUq3oslcnME+ee8oznvOAlS8Lr55prxlGFt4mw1L4i183j
qUoWorHMvhI3zBP4iHc4GO4RXuVX3ZooluvK3DRPpBpZORQ+B+KzQrchOr/q
KtwyT6J61P//Sw7btSQBK3VbYrBCV+W2eTI1yM4Ru1YkZJVuR0xW6o+4Y57C
x+TgT7vWvMZq3Z5YrNLV+Nc8lU/IyVG7NiRije5AbFbr6tw1T+NTcnHMri2J
Was7Eoc1ugb3zN9Rk9wct2vH66zTnYjLWv1x+L6Zv6cW73LCrj1JWK+/4RXW
6U/CvWyezmdc1n1Iz279Hn+ZO5CUDboz8VivP+WheQa1uaL7koE9Og8nzR15
g426C6+yQdfkkfkH6nBV9yMjf+i8nDJ3IhmbdFfis1HXCt9t84/U5ZruTyb2
6nycNn/Dm2zW3bhlHsw7HAzfOcdRvMtLJhHb34YEzv0H+H8m2Q==
               "]]}, {
              Hue[0.1421359549995791, 0.6, 0.6], 
              Directive[
               Thickness[Large], 
               Dashing[{0, Small}], 
               GrayLevel[0]], 
              Line[CompressedData["
1:eJwV0sVyFFEABdAOJLi7k+CwoorC4u5B8gkssCSTYIFAcHdnhdsKdw8EqOIn
cFtRBHc5b3Fq7r0z3VXd85KmVZfH4qIoaqJVfBQtS4iisbyXT1FBMmdt00nk
sb6f1izXx9Ekn6aSFNqwwj6eD/IZqkilLSvtE/gY7k2MNNqxyj6RT/I5qkmn
PavtyXyWz1NDRvidbQZJPNEP0IE1egpf5AvMITNca5vJIJ7qB+nIWj2Vr/JF
5pJFJ9bZ0/gmX2Ie2eG+tlkM5pl+iM6s19P5Ll9mPjl0YYM9gx/yFRaQS1c2
2jP5KV+lljy6scmexS/5GgvJpzub7dn8lq+ziILwHLbZDOG5fpgebNFz+CPf
oI7C8Gy2CobyQj9CT7bqufyVb7KYInqxzZ7HP/kWSygOz22rZBgv9aP0Zrue
T8RtvZ4S+rDDVkAcd/SllIb3pFcxnFf6MfqyUy+kGQ3hDFMW3p0eYwSv9eP0
Y5deRHPuhjPMJPqz21ZMPPfCGWZyeNd6NSN5o59gAHv0EhJoDOeaKQxkr62U
FtwP55qp4b/RaxjFW/0kiezTy2jJg3DWaZBrGc07vdFnHWN4SD2PKPfdf0jO
ddU=
               "]], 
              Line[CompressedData["
1:eJwV0tdOVGEYhtFtoom9Ya8BRZQqiO0mVHpvA9gONLZoIJ7ZexdQsIMiegG2
YBA7FlSwXYCK8Rpc/8HKzPNOJnuS+eJjW3O3DIuiqJ8HI6JoGy9I4RmN/Boe
RU+97iGLDh3PRe/XMJJevY88EmiyrWUUz/V+8llAs20do8Oz9AEKeKi3k8pv
fZuFtOgcxvBSH6SQRC7ZchnLK32IIhZx2ZbHOF7rwxSTRKstn/G80UcoYTFt
tgIm8FYfpZQlXLEVMpE+fYwykrlqK2IS7/Rxyknhmq2YybzXJ6ggleu2EuL4
oE9SSRo3bKVM4aM+RRXp3LSVMZV+fZpqMrhlK2can/QZalhKu62C6XzWZ4nx
SO8gjT/6Dpl06Epm8EWfo5as8B/ZqpjJgD5PHcvC923VzGJQX6CebDptNczm
a7gl1rOcu7YYc/gWbokNrKDLVstcvodbYiMruWerYx4/wt2wicd6J+kMhWez
ivu6nvn8DLfEZp7oXWTwN/weur3fTSb/dI/XBrLDfbM33B+rffYf4XVl2A==

               "]]}, {
              Directive[
               GrayLevel[0], 
               Opacity[0.1]], 
              Line[{473, 475, 472}], 
              Line[{474, 476, 471}], 
              Line[{1483, 1484, 1482}]}}, {{}, {}, {}, {}, {}}}], {
          AspectRatio -> GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0, 0},
            Epilog -> {
             Text[
              Style["A", 14, Bold, FontFamily -> "Helvetica"], 
              Scaled[{0.05, 0.95}]]}, Frame -> {True, False, False, False}, 
           FrameLabel -> {{None, None}, {
             "\!\(\*SubscriptBox[\(\[CapitalDelta]z\), \(i\)]\)", None}}, 
           FrameStyle -> Directive[12, FontFamily -> "Helvetica"], 
           Method -> {"AxesInFront" -> True}, 
           PlotRange -> {{-0.282842712474619, 0.282842712474619}, {0, All}}, 
           PlotRangeClipping -> True, PlotRangePadding -> None}], {
          Placed[
           Unevaluated[
            LineLegend[{
              Directive[
               Thickness[Large], 
               Dashing[Medium], 
               GrayLevel[0]], 
              Directive[
               Thickness[Large], 
               GrayLevel[0]], 
              Directive[
               Thickness[Large], 
               Dashing[{0, Small}], 
               GrayLevel[0]]}, {
              Style["platykurtic", 
               Directive[12, FontFamily -> "Helvetica"]], 
              Style["normal", 
               Directive[12, FontFamily -> "Helvetica"]], 
              Style["leptokurtic", 
               Directive[12, FontFamily -> "Helvetica"]]}, LegendLayout -> 
             "Column"]], 
           Scaled[{0.8, 0.8}], Identity]}]& ],
       AutoDelete->True,
       Editable->True,
       SelectWithContents->False,
       Selectable->True],
      TraditionalForm], {189., -122.0820393249937}, {
     Center, Center}, {360., 314.1640786499874}], InsetBox[
     FormBox[
      TagBox[
       FormBox[
        GraphicsBox[{{{{{}, {}, 
             {Hue[0.67, 0.6, 0.6], Thickness[Large], Opacity[0.5], 
              LineBox[CompressedData["
1:eJwtkF1I01EYxv9pZKhNVzOWoc6PdE7TUOdVrcKLZRTojMASpKlFBWrQRO3z
QgkinUuTirKLCdaFk2W2abXnTdPlSnHOua0LaX2wygSz1AiLdv7bA4fD4Zzz
e5/nSVTXqKpCOI6T+hfb795h8iD956pJPptJK9Iy7fCyGyM1Y2HPDBmkMsc3
zxe7kd8ywZmuy8ig9DaKDC4sVxj1OWfSKcKlr90T7kKW71d//mEpnTrJNIu8
gQLnm9w0GllmQCeWFJ3lf+JSKcFPM8c7cb7eqrFF7KALIkacwZVm4fuCv8nk
5nEO3P/RKa5eSqK8XCYHsha9+UXzidQ2zIDT6PMpfi/6JPS9mBm0Q90X1do7
lUAHmD2lHT0dsf1RnjjqZjj9FB6rNzhFX7cTx2sKC5vUu21cLA2yeOZJVBZa
S/ZKxHSOPa+dQLnePnRNuZVkrA7pW/hqDzZY6kT0geG9Nkw+fWcPN2ymQH/j
mEnZWNWzEE0lfF+voR1XZXjOCoL9WLHr9NFPFkFEsI9R7Ouqb28ZDaOLfP5X
yBq9HKq7uT6YdwRzW6Ty5IZ1wXwvodO0K3aurSGQh9CVI7vRWLQKfpzZgm3a
mDlByBIyeb/PEZ1Wqrt05Bvu8f4GETqkybZPexHJ+zHBkf3l88AtJwLznyCm
QptySDyGwDwjRMqOBzhuDPIN+KeTf2x9qMNtnvcIK0mFkv3CE7jK/+9GpLm0
rKpACOLfd+FYXWV9m6DJErjvQJ7AX3tq9YvAuQlcUP8Bo3NLMw==
               "]]}, 
             {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], Opacity[
              0.5], LineBox[CompressedData["
1:eJwtkF9Ik1EYxtcKpC2W01nJUnPZmhFp2rKbNVqExhi0CRERYemqm8pZFKkX
I0wRJ2qWbZGZzBGlzYqB3yj2vk1tFpttU9saBG1+JNjoj5sjaBd5vn0PHA6H
c87vfZ6n+PxVnZ7L4XBka4vsDy1EX2CQjmwueLkbU7IzPe7VMKSs7W3nElLU
UYV3fmjDoLrmUEQOStFeHW0W2UNwu2P0ial5F/JD1kYFLwQJbdzS7CrBixeI
PkNyZtE9xi3ByVUCXIA/3KZgefVOLFqjUYULEJ7P8+WbJNgiIsR5kAsFQmOg
GMMMbg78iesu49ZiPFBJNAfBulNdyrM7sNdNgEGYUlVxp9RFGNcSgwFYCX4/
Jv1agDXEXnUAbgrSpesM23GE4Kx+OKzRWxxZYuQw8sMJm2LIOpyPThKPmoVU
3/1UhXIbGsjzRh9U8YbfeL5twT2kDpkXLtn61e/b8zBG8NGPIBdXnu7bL8JM
fx8gEXMqO6M5WMv0NQPjHXQL/4GQ7ccD5fEb+iZdNtvHNMR6636VygTYyuSf
ghVbja6b4rN5J8EtftpgP7mRzfcOBiSfNCXrs9g8CD4v39Tq2oDMOMoFxw23
6EOdXNzL+H0L6aDd463n4CPGnxPkZZO0fDANmxg/E0DfpZLL/X8hM98BDS9+
HlWPJSEz7xVcHqpVZS/9hgzfDpKJ7iVD1zKYGd4z8ONzns68CEbm/wgcGTXv
G8iNADLvH0NBRa5jvN7L3t+Dfz20P2f1NXtug7JpTXLWcwX+AxnkWJE=
               
               "]]}, 
             {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], Opacity[
              0.5], LineBox[CompressedData["
1:eJwtkGtI01EYxrdRIqtV6qjZ2tbMXcwCwUV+yKhUNCRCqzWjICxXYjDFGJub
4IeK6kMXZ+h0WeaIWTTK1P23yvdNu9jQpblrtWxGLMz6EK0LRuX5+3/gcDic
c37v8zzSSl15FYfFYinnF9nbrUQRaJWEk7bcysIfyoMXhxJh6HnnuhFdloXl
lPj057IwHIr6q631SnQWxxr4zhC08qd694cVuCTUXZvPDYErT7ONla/AY1qi
IBzvv7zZ3CXH4QQBBmBvjUjRt1iOknkaJQ7AdIXMcaVahiY+IfqBvS+XShnL
xDCNmwQjW/dVnJOJqlyiSfBtdXg9zevw0hABvgJrmy0+8z0DZ8uIwQlIPQOB
R+oMLCH2iifAd3KgpZSSop3gusfBZOVb+tOlyKI1DhV3d2yUm9aim8SjfGB7
bddec0uwjjyvHQONLic52CjG9aQO5ShYVEFHTYEIpwk+5gXO4evGGHcNLvT3
Aq6WaHd5/KtxD93XCDxTP1Dru9KZfp7D25aG6IU6AdPHUzAk4vG6olVopvM/
gaYiG9UoWsnkHYbmjp0f5n7zmXyPwVN/ziJ8k8bkQXBtKjgxg6lIj6MGwSQs
FJTeTsENtN+HYNcPyz5ZV6CN9ueGfwZZZLtgOS6l/bjgW6G3KsLmMfP7oP2m
sOPAFy4z7x6opszvRwLJDN8JVXf0lUfuJ2EbzeuBXg3bAMZF2ET/twNvzpD9
MY2DSL/vhE6eJO/swF9YuG+BX6ODAH9+MudTcPTlbm72+Vn4D6fQUYY=
               
               "]]}, 
             {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], Opacity[
              0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQzfzn41b7Fzf22y+uP5nHonsgaIdc6+vAG/tXvXhU
UVOrc2Cd+8MqkXXX92+YMUlA6JX2Ae7riwtsua7vN99/i8coTPtAehoIXNt/
cEHEqX0HtQ4c/qoR03/o6v4M5VmBs3W0DsgDTdshd3X/tY40nbXTNA9Ui4BM
vLI//Lqv373/GgdugI27vF9qyYxZchkaB0yMQeDy/pS7d/6mnlc/MOEQyMBL
+xkUa79sNVU/8CYQ5MCL+w8mKytKz1Y74AFynvvF/U2SL/nW/Vc9sARk3OIL
+29WeWdNTlY9wAAGF/a/WL244fcxlQM7Qd7bcW7/w5xUUUUtlQOFIOUFZ/ez
2TROcO9VPqAFdP1XjTP7H0X/2bPjg9KBRyDjH57av/nUJ9NDIUoHZs0EgZP7
CxNcNm3aqXggGBxeJ/ZfDOH2vi6vCA2f4/v1il+er2hXgIbH0f0qmglxmx7K
H6gB+//I/m9mfbsSd8hB/Xt4/1G97RYRk2Wh/ju4v+FuzoXzRTJQ/xzYr/+u
O/ZOmPQBsHU79u3/y7xpWaK91AEdsHv37J/DWBzHqiN5YA7YfTv37/gW2Ssl
I3GAB+ye7fun/Pj7r5FPHGr/lv1LvPP2ljOKQe3buH/mZS8Xu08iUPPX7f/h
ldzcfkf4wAyweSv3V3cduBO0U+hAA1j/kv3GrK9bWmoEDxwAq5+3P1VYPv03
nwBUfsr+64X8UjcqeKD8lv0KRtO4Xu5jOwAAoZBGJA==
               
               "]]}}, {}}, {{{}, {}, 
             {GrayLevel[0], Thickness[Large], Opacity[0.5], 
              LineBox[CompressedData["
1:eJwtkHtI01EcxWckmQ9SmmKbzcd0LhsxMuuPGAWGGyaMrYTWWlH4KBhN+6fM
pFyG/RMzHGayTFCp1doyQjesnTvfmuXM3AxTXIUgbajUSmJB3t924HK53Hs/
33NO5gWdsnwLi8USbi66tz2k+oyWl9Hv+pcE5LfwjGEgOIfcDrFLkysgSjvv
zg/FHH6VhYYvanOIVeq7zrZ64cvi1vTbskmct7NKEuvF38KFpYPrfFJZQeXB
UJ3/0aiYTwaDFDiL3ivF8orLWSR9k2bnzcJU64vnPMsktWxK/ISxkHJg41sG
mWNwM4jzyjm5aRnkQD7VDA6rild7unmkaYACP0JtYF9tS9xN/ApqcBoLIZnW
VMMlMmpPOo159fNJtW8X6aK4TjcmVHxboyyVsBi5UbD4lO+xpRAHjWf/AJ9G
J49KTSbV9HnVe6xy9h4bqd9J8mgdwkm4SswJy4Ek8pXifRNoNJXV7NEkknB/
4/BKuTp3RwI5wfQ1Bsua5Ljwfmykn1HkG788ab63LdLHMMaPaGVTrVvJDSb/
EJondhSe7o2K5B3EPtGllabZfwjnc+GcqsFQem0D4TwEMdlFpuTyn2DG2Z0w
O14VWM4HIGL8voG4XPRH7/8OE+PPgaS8lJH1k/OIZ/z04cXy9lJB3RTC819j
5awk+DjaGZnXg/S1lvpAUXeEb4UjVJl2ql2PVoZnhmct5+ahxRLcYv53obrP
qLsdE3QS5n07Hihseu1RjTN8b4SF1n53/9vwuQGsiP4D/QhP6Q==
               
               "]]}}, {}}, {
            GraphicsComplexBox[{{-0.1, -1.810453111675309}, {-0.1, \
-2.7181005369557116`}, {-0.2, -6.22972173623224}, {-0.1, -5.236281975628584}, \
{-0.2, -7.1691200431165445`}, {-0.3, -11.512925464970229`}, {-0.1, \
-8.145629634983754}, {-0.2, -9.903487552536127}, {-0.1, \
-1.4473615808683413`}, {-0.2, -5.881713683148863}, {-0.3, \
-11.512925464970229`}}, {{{}, {}, {}, 
               {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
                Dashing[Medium], LineBox[{2, 3}]}, 
               {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Large], 
                Dashing[Medium], LineBox[{4, 5, 6}]}, 
               {RGBColor[0.24, 0.6, 0.33692049419863584`], Thickness[Large], 
                Dashing[Medium], LineBox[{7, 8}]}, 
               {GrayLevel[0], Thickness[0.005], Dashing[Medium], 
                LineBox[{9, 10, 11}]}}, {
               {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
                Dashing[Medium], InsetBox[
                 GraphicsBox[
                  {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[
                   Medium], Dashing[None], CircleBox[{0, 0}]},
                  ImageSize->10], 1]}, 
               {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
                Dashing[Medium], InsetBox[
                 GraphicsBox[
                  {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Medium],
                    Dashing[None], CircleBox[{0, 0}], 
                   {RGBColor[0.6, 0.24, 0.4428931686004542]}},
                  ImageSize->10], 2], InsetBox[
                 GraphicsBox[
                  {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Medium],
                    Dashing[None], CircleBox[{0, 0}], 
                   {RGBColor[0.6, 0.24, 0.4428931686004542]}},
                  ImageSize->10], 3]}, 
               {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Large], 
                Dashing[Medium], InsetBox[
                 GraphicsBox[
                  {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Medium],
                    Dashing[None], CircleBox[{0, 0}], 
                   {RGBColor[0.6, 0.5470136627990908, 0.24]}},
                  ImageSize->10], 4], InsetBox[
                 GraphicsBox[
                  {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Medium],
                    Dashing[None], CircleBox[{0, 0}], 
                   {RGBColor[0.6, 0.5470136627990908, 0.24]}},
                  ImageSize->10], 5], InsetBox[
                 GraphicsBox[
                  {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Medium],
                    Dashing[None], CircleBox[{0, 0}], 
                   {RGBColor[0.6, 0.5470136627990908, 0.24]}},
                  ImageSize->10], 6]}, 
               {RGBColor[0.24, 0.6, 0.33692049419863584`], Thickness[Large], 
                Dashing[Medium], InsetBox[
                 GraphicsBox[
                  {RGBColor[0.24, 0.6, 0.33692049419863584`], Thickness[
                   Medium], Dashing[None], CircleBox[{0, 0}], 
                   {RGBColor[0.24, 0.6, 0.33692049419863584`]}},
                  ImageSize->10], 7], InsetBox[
                 GraphicsBox[
                  {RGBColor[0.24, 0.6, 0.33692049419863584`], Thickness[
                   Medium], Dashing[None], CircleBox[{0, 0}], 
                   {RGBColor[0.24, 0.6, 0.33692049419863584`]}},
                  ImageSize->10], 8]}, 
               {GrayLevel[0], Thickness[0.005], Dashing[Medium], InsetBox[
                 GraphicsBox[
                  {GrayLevel[0], Thickness[0.005], Dashing[Medium], 
                   DiskBox[{0, 0}]},
                  ImageSize->8], 9], InsetBox[
                 GraphicsBox[
                  {GrayLevel[0], Thickness[0.005], Dashing[Medium], 
                   DiskBox[{0, 0}]},
                  ImageSize->8], 10], InsetBox[
                 GraphicsBox[
                  {GrayLevel[0], Thickness[0.005], Dashing[Medium], 
                   DiskBox[{0, 0}]},
                  ImageSize->8], 11]}, {}}}], {}}}, {InsetBox[
            
            TemplateBox[{
             StyleBox[
              "\"total\"", StripOnInput -> False, FontFamily -> "Helvetica", 
               FontSize -> 12]},
             "LineLegend",
             DisplayFunction->(StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0], 
                    Thickness[Large], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0], 
                    Thickness[Large], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
               False]& ),
             Editable->True,
             InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], "}"}], 
                  ",", 
                  RowBox[{"{", #, "}"}], ",", 
                  RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                "]"}]& )], Scaled[{0.56, 0.22}], ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm], InsetBox[
            
            TemplateBox[{
             StyleBox[
              "\"1-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
               FontSize -> 12],StyleBox[
              "\"2-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
               FontSize -> 12],StyleBox[
              "\"3-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
               FontSize -> 12],StyleBox[
              "\"4-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
               FontSize -> 12]},
             "LineLegend",
             DisplayFunction->(StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
               False]& ),
             Editable->True,
             InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.24720000000000014`", ",", "0.24`", ",", 
                    "0.6`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.6`", ",", "0.24`", ",", 
                    "0.4428931686004542`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.6`", ",", "0.5470136627990908`", ",", 
                    "0.24`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.24`", ",", "0.6`", ",", 
                    "0.33692049419863584`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}]}], "}"}], 
                  ",", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                  RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                "]"}]& )], Scaled[{0.85, 0.22}], ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm]}},
         AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
         Axes->True,
         AxesOrigin->{-0.4, -14.508657738524219`},
         CoordinatesToolOptions:>{"DisplayFunction" -> ({
             Part[#, 1], 
             Exp[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             Part[#, 1], 
             Exp[
              Part[#, 2]]}& )},
         Epilog->{
           InsetBox[
            FormBox[
             StyleBox[
             "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
              False], TraditionalForm], 
            Scaled[{0.05, 0.95}]], 
           InsetBox[
            FormBox[
             StyleBox[
             "\"platykurtic\"", 14, FontFamily -> "Helvetica", StripOnInput -> 
              False], TraditionalForm], 
            Scaled[{0.25, 0.85}]], {
            Opacity[0.5], {
             Arrowheads[{{0.02, 0, {
                 GraphicsBox[
                  CircleBox[{1, -1}, 1, 
                   
                   NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
                    3.141592653589793}]]], -1}}, {0.02, 1, {
                 GraphicsBox[{
                   CircleBox[{-1, 1}, 1, 
                    
                    NCache[{
                    Rational[-1, 2] Pi, 0}, {-1.5707963267948966`, 0}]], 
                   InsetBox[
                    BoxData[
                    FormBox[
                    StyleBox["\"\"", Larger, StripOnInput -> False], 
                    TraditionalForm]], {0, 2}]}], 1}}}], 
             ArrowBox[
              
              NCache[{{-0.125, -
                 Log[1000000]}, {-0.125, -11.310192910916147`}}, {{-0.125, \
-13.815510557964274`}, {-0.125, -11.310192910916147`}}]], 
             Arrowheads[{{0.02, 0, {
                 GraphicsBox[
                  CircleBox[{1, 1}, 1, 
                   
                   NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
                    4.71238898038469}]]], -1}}, {0.02, 1, {
                 GraphicsBox[
                  CircleBox[{-1, -1}, 1, 
                   NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]],
                  1}}}], 
             
             ArrowBox[{{-0.125, -11.310192910916147`}, {-0.125, \
-8.804875263868018}}]}}},
         Frame->{True, False, False, True},
         FrameLabel->{{"", 
            FormBox["\"Probability of rescue\"", TraditionalForm]}, {"", ""}},
         
         FrameTicks->{{None, {{-13.815510557964274`, 
              FormBox[
               TemplateBox[{"10", 
                 RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
                SuperscriptBox], TraditionalForm]}, {-11.512925464970229`, 
              FormBox[
               TemplateBox[{"10", 
                 RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
                SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
              FormBox[
               TemplateBox[{"10", 
                 RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
                SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
              FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
              FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
              FormBox["0.1`", TraditionalForm]}, {0., 
              FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-12.716898269296165`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-12.429216196844383`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-12.206072645530174`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-12.02375108873622, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-11.86960040890896, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-11.736069016284437`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-11.618285980628055`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-10.819778284410283`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-10.414313176302118`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-10.126631103850338`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.903487552536127, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.721165995742174, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.567015315914915, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.433483923290392, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.315700887634009, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-8.517193191416238, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-8.111728083308073, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.824046010856292, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.600902459542082, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.418580902748127, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.264430222920869, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.1308988302963465`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.013115794639964, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-6.214608098422191, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-5.809142990314028, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-5.521460917862246, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-5.298317366548036, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-5.115995809754082, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-4.961845129926823, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-4.8283137373023015`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-4.710530701645918, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-3.912023005428146, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-3.506557897319982, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-3.2188758248682006`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.995732273553991, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.8134107167600364`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.659260036932778, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.5257286443082556`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.407945608651872, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-1.6094379124341003`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-1.203972804325936, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.916290731874155, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.6931471805599453, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.5108256237659905, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.35667494393873245`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.2231435513142097, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.10536051565782616`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}}}, {True, False}},
         FrameTicksStyle->{
          FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
         GridLines->{None, None},
         LabelStyle->Directive[12, FontFamily -> "Helvetica"],
         Method->{},
         PlotRange->{{-0.4, 0}, {-14.508657738524219`, 0.}},
         PlotRangeClipping->True,
         PlotRangePadding->0,
         Ticks->{Automatic, {{-13.815510557964274`, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm]}, {-11.512925464970229`, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
             FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
             FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
             FormBox["0.1`", TraditionalForm]}, {0., 
             FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-12.716898269296165`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-12.429216196844383`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-12.206072645530174`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-12.02375108873622, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-11.86960040890896, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-11.736069016284437`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-11.618285980628055`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-10.819778284410283`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-10.414313176302118`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-10.126631103850338`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.903487552536127, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.721165995742174, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.567015315914915, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.433483923290392, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.315700887634009, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-8.517193191416238, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-8.111728083308073, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.824046010856292, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.600902459542082, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.418580902748127, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.264430222920869, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.1308988302963465`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.013115794639964, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-6.214608098422191, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-5.809142990314028, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-5.521460917862246, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-5.298317366548036, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-5.115995809754082, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-4.961845129926823, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-4.8283137373023015`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-4.710530701645918, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-3.912023005428146, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-3.506557897319982, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-3.2188758248682006`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.995732273553991, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.8134107167600364`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.659260036932778, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.5257286443082556`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.407945608651872, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-1.6094379124341003`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-1.203972804325936, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.916290731874155, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.6931471805599453, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.5108256237659905, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.35667494393873245`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.2231435513142097, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.10536051565782616`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}}}],
        TraditionalForm],
       InterpretTemplate[Legended[
         Graphics[{{{{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                Thickness[Large], 
                Opacity[0.5]], 
               Line[CompressedData["
1:eJwtkF1I01EYxv9pZKhNVzOWoc6PdE7TUOdVrcKLZRTojMASpKlFBWrQRO3z
QgkinUuTirKLCdaFk2W2abXnTdPlSnHOua0LaX2wygSz1AiLdv7bA4fD4Zzz
e5/nSVTXqKpCOI6T+hfb795h8iD956pJPptJK9Iy7fCyGyM1Y2HPDBmkMsc3
zxe7kd8ywZmuy8ig9DaKDC4sVxj1OWfSKcKlr90T7kKW71d//mEpnTrJNIu8
gQLnm9w0GllmQCeWFJ3lf+JSKcFPM8c7cb7eqrFF7KALIkacwZVm4fuCv8nk
5nEO3P/RKa5eSqK8XCYHsha9+UXzidQ2zIDT6PMpfi/6JPS9mBm0Q90X1do7
lUAHmD2lHT0dsf1RnjjqZjj9FB6rNzhFX7cTx2sKC5vUu21cLA2yeOZJVBZa
S/ZKxHSOPa+dQLnePnRNuZVkrA7pW/hqDzZY6kT0geG9Nkw+fWcPN2ymQH/j
mEnZWNWzEE0lfF+voR1XZXjOCoL9WLHr9NFPFkFEsI9R7Ouqb28ZDaOLfP5X
yBq9HKq7uT6YdwRzW6Ty5IZ1wXwvodO0K3aurSGQh9CVI7vRWLQKfpzZgm3a
mDlByBIyeb/PEZ1Wqrt05Bvu8f4GETqkybZPexHJ+zHBkf3l88AtJwLznyCm
QptySDyGwDwjRMqOBzhuDPIN+KeTf2x9qMNtnvcIK0mFkv3CE7jK/+9GpLm0
rKpACOLfd+FYXWV9m6DJErjvQJ7AX3tq9YvAuQlcUP8Bo3NLMw==
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                Thickness[Large], 
                Opacity[0.5]], 
               Line[CompressedData["
1:eJwtkF9Ik1EYxtcKpC2W01nJUnPZmhFp2rKbNVqExhi0CRERYemqm8pZFKkX
I0wRJ2qWbZGZzBGlzYqB3yj2vk1tFpttU9saBG1+JNjoj5sjaBd5vn0PHA6H
c87vfZ6n+PxVnZ7L4XBka4vsDy1EX2CQjmwueLkbU7IzPe7VMKSs7W3nElLU
UYV3fmjDoLrmUEQOStFeHW0W2UNwu2P0ial5F/JD1kYFLwQJbdzS7CrBixeI
PkNyZtE9xi3ByVUCXIA/3KZgefVOLFqjUYULEJ7P8+WbJNgiIsR5kAsFQmOg
GMMMbg78iesu49ZiPFBJNAfBulNdyrM7sNdNgEGYUlVxp9RFGNcSgwFYCX4/
Jv1agDXEXnUAbgrSpesM23GE4Kx+OKzRWxxZYuQw8sMJm2LIOpyPThKPmoVU
3/1UhXIbGsjzRh9U8YbfeL5twT2kDpkXLtn61e/b8zBG8NGPIBdXnu7bL8JM
fx8gEXMqO6M5WMv0NQPjHXQL/4GQ7ccD5fEb+iZdNtvHNMR6636VygTYyuSf
ghVbja6b4rN5J8EtftpgP7mRzfcOBiSfNCXrs9g8CD4v39Tq2oDMOMoFxw23
6EOdXNzL+H0L6aDd463n4CPGnxPkZZO0fDANmxg/E0DfpZLL/X8hM98BDS9+
HlWPJSEz7xVcHqpVZS/9hgzfDpKJ7iVD1zKYGd4z8ONzns68CEbm/wgcGTXv
G8iNADLvH0NBRa5jvN7L3t+Dfz20P2f1NXtug7JpTXLWcwX+AxnkWJE=
                
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                Thickness[Large], 
                Opacity[0.5]], 
               Line[CompressedData["
1:eJwtkGtI01EYxrdRIqtV6qjZ2tbMXcwCwUV+yKhUNCRCqzWjICxXYjDFGJub
4IeK6kMXZ+h0WeaIWTTK1P23yvdNu9jQpblrtWxGLMz6EK0LRuX5+3/gcDic
c37v8zzSSl15FYfFYinnF9nbrUQRaJWEk7bcysIfyoMXhxJh6HnnuhFdloXl
lPj057IwHIr6q631SnQWxxr4zhC08qd694cVuCTUXZvPDYErT7ONla/AY1qi
IBzvv7zZ3CXH4QQBBmBvjUjRt1iOknkaJQ7AdIXMcaVahiY+IfqBvS+XShnL
xDCNmwQjW/dVnJOJqlyiSfBtdXg9zevw0hABvgJrmy0+8z0DZ8uIwQlIPQOB
R+oMLCH2iifAd3KgpZSSop3gusfBZOVb+tOlyKI1DhV3d2yUm9aim8SjfGB7
bddec0uwjjyvHQONLic52CjG9aQO5ShYVEFHTYEIpwk+5gXO4evGGHcNLvT3
Aq6WaHd5/KtxD93XCDxTP1Dru9KZfp7D25aG6IU6AdPHUzAk4vG6olVopvM/
gaYiG9UoWsnkHYbmjp0f5n7zmXyPwVN/ziJ8k8bkQXBtKjgxg6lIj6MGwSQs
FJTeTsENtN+HYNcPyz5ZV6CN9ueGfwZZZLtgOS6l/bjgW6G3KsLmMfP7oP2m
sOPAFy4z7x6opszvRwLJDN8JVXf0lUfuJ2EbzeuBXg3bAMZF2ET/twNvzpD9
MY2DSL/vhE6eJO/swF9YuG+BX6ODAH9+MudTcPTlbm72+Vn4D6fQUYY=
                
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                Thickness[Large], 
                Opacity[0.5]], 
               Line[CompressedData["
1:eJxTTMoPSmViYGBQB2IQzfzn41b7Fzf22y+uP5nHonsgaIdc6+vAG/tXvXhU
UVOrc2Cd+8MqkXXX92+YMUlA6JX2Ae7riwtsua7vN99/i8coTPtAehoIXNt/
cEHEqX0HtQ4c/qoR03/o6v4M5VmBs3W0DsgDTdshd3X/tY40nbXTNA9Ui4BM
vLI//Lqv373/GgdugI27vF9qyYxZchkaB0yMQeDy/pS7d/6mnlc/MOEQyMBL
+xkUa79sNVU/8CYQ5MCL+w8mKytKz1Y74AFynvvF/U2SL/nW/Vc9sARk3OIL
+29WeWdNTlY9wAAGF/a/WL244fcxlQM7Qd7bcW7/w5xUUUUtlQOFIOUFZ/ez
2TROcO9VPqAFdP1XjTP7H0X/2bPjg9KBRyDjH57av/nUJ9NDIUoHZs0EgZP7
CxNcNm3aqXggGBxeJ/ZfDOH2vi6vCA2f4/v1il+er2hXgIbH0f0qmglxmx7K
H6gB+//I/m9mfbsSd8hB/Xt4/1G97RYRk2Wh/ju4v+FuzoXzRTJQ/xzYr/+u
O/ZOmPQBsHU79u3/y7xpWaK91AEdsHv37J/DWBzHqiN5YA7YfTv37/gW2Ssl
I3GAB+ye7fun/Pj7r5FPHGr/lv1LvPP2ljOKQe3buH/mZS8Xu08iUPPX7f/h
ldzcfkf4wAyweSv3V3cduBO0U+hAA1j/kv3GrK9bWmoEDxwAq5+3P1VYPv03
nwBUfsr+64X8UjcqeKD8lv0KRtO4Xu5jOwAAoZBGJA==
                
                "]]}}}, {}}, {{{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               GrayLevel[0], 
               Thickness[Large], 
               Opacity[0.5], 
               Line[CompressedData["
1:eJwtkHtI01EcxWckmQ9SmmKbzcd0LhsxMuuPGAWGGyaMrYTWWlH4KBhN+6fM
pFyG/RMzHGayTFCp1doyQjesnTvfmuXM3AxTXIUgbajUSmJB3t924HK53Hs/
33NO5gWdsnwLi8USbi66tz2k+oyWl9Hv+pcE5LfwjGEgOIfcDrFLkysgSjvv
zg/FHH6VhYYvanOIVeq7zrZ64cvi1vTbskmct7NKEuvF38KFpYPrfFJZQeXB
UJ3/0aiYTwaDFDiL3ivF8orLWSR9k2bnzcJU64vnPMsktWxK/ISxkHJg41sG
mWNwM4jzyjm5aRnkQD7VDA6rild7unmkaYACP0JtYF9tS9xN/ApqcBoLIZnW
VMMlMmpPOo159fNJtW8X6aK4TjcmVHxboyyVsBi5UbD4lO+xpRAHjWf/AJ9G
J49KTSbV9HnVe6xy9h4bqd9J8mgdwkm4SswJy4Ek8pXifRNoNJXV7NEkknB/
4/BKuTp3RwI5wfQ1Bsua5Ljwfmykn1HkG788ab63LdLHMMaPaGVTrVvJDSb/
EJondhSe7o2K5B3EPtGllabZfwjnc+GcqsFQem0D4TwEMdlFpuTyn2DG2Z0w
O14VWM4HIGL8voG4XPRH7/8OE+PPgaS8lJH1k/OIZ/z04cXy9lJB3RTC819j
5awk+DjaGZnXg/S1lvpAUXeEb4UjVJl2ql2PVoZnhmct5+ahxRLcYv53obrP
qLsdE3QS5n07Hihseu1RjTN8b4SF1n53/9vwuQGsiP4D/QhP6Q==
                
                "]]}}}, {}}, {
            
            GraphicsComplex[{{-0.1, -1.810453111675309}, {-0.1, \
-2.7181005369557116`}, {-0.2, -6.22972173623224}, {-0.1, -5.236281975628584}, \
{-0.2, -7.1691200431165445`}, {-0.3, -11.512925464970229`}, {-0.1, \
-8.145629634983754}, {-0.2, -9.903487552536127}, {-0.1, \
-1.4473615808683413`}, {-0.2, -5.881713683148863}, {-0.3, \
-11.512925464970229`}}, {{{}, {}, {}, {
                Hue[0.9060679774997897, 0.6, 0.6], 
                Directive[
                 RGBColor[0.6, 0.24, 0.4428931686004542], 
                 Thickness[Large], 
                 Dashing[Medium]], 
                Line[{2, 3}]}, {
                Hue[0.1421359549995791, 0.6, 0.6], 
                Directive[
                 RGBColor[0.6, 0.5470136627990908, 0.24], 
                 Thickness[Large], 
                 Dashing[Medium]], 
                Line[{4, 5, 6}]}, {
                Hue[0.37820393249936934`, 0.6, 0.6], 
                Directive[
                 RGBColor[0.24, 0.6, 0.33692049419863584`], 
                 Thickness[Large], 
                 Dashing[Medium]], 
                Line[{7, 8}]}, {
                Hue[0.6142719099991583, 0.6, 0.6], 
                Directive[
                 GrayLevel[0], 
                 Thickness[0.005], 
                 Dashing[Medium]], 
                Line[{9, 10, 11}]}}, {{
                Hue[0.67, 0.6, 0.6], 
                Directive[
                 RGBColor[0.24720000000000014`, 0.24, 0.6], 
                 Thickness[Large], 
                 Dashing[Medium]], 
                Inset[
                 Graphics[{
                   Hue[0.67, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large], 
                    Dashing[Medium]], 
                   Dashing[None], 
                   Thickness[Medium], 
                   RGBColor[0.24720000000000014`, 0.24, 0.6], 
                   Circle[{0, 0}]}, ImageSize -> 10], 1]}, {
                Hue[0.9060679774997897, 0.6, 0.6], 
                Directive[
                 RGBColor[0.6, 0.24, 0.4428931686004542], 
                 Thickness[Large], 
                 Dashing[Medium]], 
                Inset[
                 Graphics[{
                   Hue[0.9060679774997897, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large], 
                    Dashing[Medium]], 
                   Dashing[None], 
                   Thickness[Medium], 
                   Circle[{0, 0}], 
                   RGBColor[0.6, 0.24, 0.4428931686004542]}, ImageSize -> 10],
                  2], 
                Inset[
                 Graphics[{
                   Hue[0.9060679774997897, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large], 
                    Dashing[Medium]], 
                   Dashing[None], 
                   Thickness[Medium], 
                   Circle[{0, 0}], 
                   RGBColor[0.6, 0.24, 0.4428931686004542]}, ImageSize -> 10],
                  3]}, {
                Hue[0.1421359549995791, 0.6, 0.6], 
                Directive[
                 RGBColor[0.6, 0.5470136627990908, 0.24], 
                 Thickness[Large], 
                 Dashing[Medium]], 
                Inset[
                 Graphics[{
                   Hue[0.1421359549995791, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large], 
                    Dashing[Medium]], 
                   Dashing[None], 
                   Thickness[Medium], 
                   Circle[{0, 0}], 
                   RGBColor[0.6, 0.5470136627990908, 0.24]}, ImageSize -> 10],
                  4], 
                Inset[
                 Graphics[{
                   Hue[0.1421359549995791, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large], 
                    Dashing[Medium]], 
                   Dashing[None], 
                   Thickness[Medium], 
                   Circle[{0, 0}], 
                   RGBColor[0.6, 0.5470136627990908, 0.24]}, ImageSize -> 10],
                  5], 
                Inset[
                 Graphics[{
                   Hue[0.1421359549995791, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large], 
                    Dashing[Medium]], 
                   Dashing[None], 
                   Thickness[Medium], 
                   Circle[{0, 0}], 
                   RGBColor[0.6, 0.5470136627990908, 0.24]}, ImageSize -> 10],
                  6]}, {
                Hue[0.37820393249936934`, 0.6, 0.6], 
                Directive[
                 RGBColor[0.24, 0.6, 0.33692049419863584`], 
                 Thickness[Large], 
                 Dashing[Medium]], 
                Inset[
                 Graphics[{
                   Hue[0.37820393249936934`, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large], 
                    Dashing[Medium]], 
                   Dashing[None], 
                   Thickness[Medium], 
                   Circle[{0, 0}], 
                   RGBColor[0.24, 0.6, 0.33692049419863584`]}, ImageSize -> 
                  10], 7], 
                Inset[
                 Graphics[{
                   Hue[0.37820393249936934`, 0.6, 0.6], 
                   Directive[
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large], 
                    Dashing[Medium]], 
                   Dashing[None], 
                   Thickness[Medium], 
                   Circle[{0, 0}], 
                   RGBColor[0.24, 0.6, 0.33692049419863584`]}, ImageSize -> 
                  10], 8]}, {
                Hue[0.6142719099991583, 0.6, 0.6], 
                Directive[
                 GrayLevel[0], 
                 Thickness[0.005], 
                 Dashing[Medium]], 
                Inset[
                 Graphics[{
                   Hue[0.6142719099991583, 0.6, 0.6], 
                   Directive[
                    GrayLevel[0], 
                    Thickness[0.005], 
                    Dashing[Medium]], 
                   GrayLevel[0], 
                   Disk[{0, 0}]}, ImageSize -> 8], 9], 
                Inset[
                 Graphics[{
                   Hue[0.6142719099991583, 0.6, 0.6], 
                   Directive[
                    GrayLevel[0], 
                    Thickness[0.005], 
                    Dashing[Medium]], 
                   GrayLevel[0], 
                   Disk[{0, 0}]}, ImageSize -> 8], 10], 
                Inset[
                 Graphics[{
                   Hue[0.6142719099991583, 0.6, 0.6], 
                   Directive[
                    GrayLevel[0], 
                    Thickness[0.005], 
                    Dashing[Medium]], 
                   GrayLevel[0], 
                   Disk[{0, 0}]}, ImageSize -> 8], 11]}, {}}}], {}}}, {
          PlotRangePadding -> 0, Epilog -> {
             Text[
              Style["B", 14, Bold, FontFamily -> "Helvetica"], 
              Scaled[{0.05, 0.95}]], 
             Text[
              Style["platykurtic", 14, FontFamily -> "Helvetica"], 
              Scaled[{0.25, 0.85}]], {
              Opacity[0.5], {
               Arrowheads[{{0.02, 0, {
                   Graphics[
                    Circle[{1, -1}, 1, {Rational[1, 2] Pi, Pi}]], -1}}, {
                 0.02, 1, {
                   Graphics[{
                    Circle[{-1, 1}, 1, {Rational[-1, 2] Pi, 0}], 
                    Inset[
                    Style["", Larger], {0, 2}]}], 1}}}], 
               
               Arrow[{{-0.125, -
                  Log[1000000]}, {-0.125, -11.310192910916147`}}], 
               Arrowheads[{{0.02, 0, {
                   Graphics[
                    Circle[{1, 1}, 1, {Pi, Rational[3, 2] Pi}]], -1}}, {
                 0.02, 1, {
                   Graphics[
                    Circle[{-1, -1}, 1, {0, Rational[1, 2] Pi}]], 1}}}], 
               
               Arrow[{{-0.125, -11.310192910916147`}, {-0.125, \
-8.804875263868018}}]}}}, 
           FrameLabel -> {{Null, "Probability of rescue"}, {Null, Null}}, 
           Ticks -> {Automatic, {{-13.815510557964274`, 
               Superscript[10, -6]}, {-11.512925464970229`, 
               Superscript[10, -5]}, {-9.210340371976182, 
               Superscript[10, -4]}, {-6.907755278982137, 
              0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 
              0.1}, {0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
               
                Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
               
                Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 
               0.}, {
                Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
               
                Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 
               0.}, {
                Thickness[0.001]}}}}, GridLines -> {None, None}, 
           FrameTicks -> {{None, {{-13.815510557964274`, 
                Superscript[10, -6]}, {-11.512925464970229`, 
                Superscript[10, -5]}, {-9.210340371976182, 
                Superscript[10, -4]}, {-6.907755278982137, 
               0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 
               0.1}, {0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
                 Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
                 Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
                 Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
                 Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}}}, {True, False}}, 
           AxesOrigin -> {-0.4, -14.508657738524219`}, 
           PlotRange -> {{-0.4, 0}, {-14.508657738524219`, 0.}}, AspectRatio -> 
           GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0, 0}, 
           CoordinatesToolOptions -> {"DisplayFunction" -> ({
               Part[#, 1], 
               Exp[
                Part[#, 2]]}& ), "CopiedValueFunction" -> ({
               Part[#, 1], 
               Exp[
                Part[#, 2]]}& )}, Frame -> {True, False, False, True}, 
           FrameLabel -> {Null, Null, Null, "Probability of rescue"}, 
           FrameTicks -> {True, False, False, True}, 
           FrameTicksStyle -> {
            FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, 
           LabelStyle -> Directive[12, FontFamily -> "Helvetica"], 
           Method -> {}, PlotRange -> {{-0.4, 0}, {-14.508657738524219`, 0.}},
            PlotRangeClipping -> True, 
           PlotRangePadding -> {{None, None}, {None, None}}}], {
          Placed[
           Unevaluated[
            LineLegend[{
              Directive[
               RGBColor[0.24720000000000014`, 0.24, 0.6], 
               Thickness[Large], 
               Opacity[0.5]], 
              Directive[
               RGBColor[0.6, 0.24, 0.4428931686004542], 
               Thickness[Large], 
               Opacity[0.5]], 
              Directive[
               RGBColor[0.6, 0.5470136627990908, 0.24], 
               Thickness[Large], 
               Opacity[0.5]], 
              Directive[
               RGBColor[0.24, 0.6, 0.33692049419863584`], 
               Thickness[Large], 
               Opacity[0.5]]}, {
              Style["1-step", 12, FontFamily -> "Helvetica"], 
              Style["2-step", 12, FontFamily -> "Helvetica"], 
              Style["3-step", 12, FontFamily -> "Helvetica"], 
              Style["4-step", 12, FontFamily -> "Helvetica"]}, LegendLayout -> 
             "Column"]], 
           Scaled[{0.85, 0.22}], Identity]}]& ],
       AutoDelete->True,
       Editable->True,
       SelectWithContents->False,
       Selectable->True],
      TraditionalForm], {189., -366.2461179749811}, {
     Center, Center}, {360., 314.1640786499874}], InsetBox[
     GraphicsBox[{{{{}, {}, 
         {Hue[0.67, 0.6, 0.6], Thickness[Large], Opacity[0.5], 
          LineBox[CompressedData["
1:eJwtkF1I01EYxv9pZKhNVzOWoc6PdE7TUOdVrcKLZRTojMASpKlFBWrQRO3z
QgkinUuTirKLCdaFk2W2abXnTdPlSnHOua0LaX2wygSz1AiLdv7bA4fD4Zzz
e5/nSVTXqKpCOI6T+hfb795h8iD956pJPptJK9Iy7fCyGyM1Y2HPDBmkMsc3
zxe7kd8ywZmuy8ig9DaKDC4sVxj1OWfSKcKlr90T7kKW71d//mEpnTrJNIu8
gQLnm9w0GllmQCeWFJ3lf+JSKcFPM8c7cb7eqrFF7KALIkacwZVm4fuCv8nk
5nEO3P/RKa5eSqK8XCYHsha9+UXzidQ2zIDT6PMpfi/6JPS9mBm0Q90X1do7
lUAHmD2lHT0dsf1RnjjqZjj9FB6rNzhFX7cTx2sKC5vUu21cLA2yeOZJVBZa
S/ZKxHSOPa+dQLnePnRNuZVkrA7pW/hqDzZY6kT0geG9Nkw+fWcPN2ymQH/j
mEnZWNWzEE0lfF+voR1XZXjOCoL9WLHr9NFPFkFEsI9R7Ouqb28ZDaOLfP5X
yBq9HKq7uT6YdwRzW6Ty5IZ1wXwvodO0K3aurSGQh9CVI7vRWLQKfpzZgm3a
mDlByBIyeb/PEZ1Wqrt05Bvu8f4GETqkybZPexHJ+zHBkf3l88AtJwLznyCm
QptySDyGwDwjRMqOBzhuDPIN+KeTf2x9qMNtnvcIK0mFkv3CE7jK/+9GpLm0
rKpACOLfd+FYXWV9m6DJErjvQJ7AX3tq9YvAuQlcUP8Bo3NLMw==
           "]]}, 
         {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], Opacity[0.5], 
          LineBox[CompressedData["
1:eJwtkF9Ik1EYxtcKpC2W01nJUnPZmhFp2rKbNVqExhi0CRERYemqm8pZFKkX
I0wRJ2qWbZGZzBGlzYqB3yj2vk1tFpttU9saBG1+JNjoj5sjaBd5vn0PHA6H
c87vfZ6n+PxVnZ7L4XBka4vsDy1EX2CQjmwueLkbU7IzPe7VMKSs7W3nElLU
UYV3fmjDoLrmUEQOStFeHW0W2UNwu2P0ial5F/JD1kYFLwQJbdzS7CrBixeI
PkNyZtE9xi3ByVUCXIA/3KZgefVOLFqjUYULEJ7P8+WbJNgiIsR5kAsFQmOg
GMMMbg78iesu49ZiPFBJNAfBulNdyrM7sNdNgEGYUlVxp9RFGNcSgwFYCX4/
Jv1agDXEXnUAbgrSpesM23GE4Kx+OKzRWxxZYuQw8sMJm2LIOpyPThKPmoVU
3/1UhXIbGsjzRh9U8YbfeL5twT2kDpkXLtn61e/b8zBG8NGPIBdXnu7bL8JM
fx8gEXMqO6M5WMv0NQPjHXQL/4GQ7ccD5fEb+iZdNtvHNMR6636VygTYyuSf
ghVbja6b4rN5J8EtftpgP7mRzfcOBiSfNCXrs9g8CD4v39Tq2oDMOMoFxw23
6EOdXNzL+H0L6aDd463n4CPGnxPkZZO0fDANmxg/E0DfpZLL/X8hM98BDS9+
HlWPJSEz7xVcHqpVZS/9hgzfDpKJ7iVD1zKYGd4z8ONzns68CEbm/wgcGTXv
G8iNADLvH0NBRa5jvN7L3t+Dfz20P2f1NXtug7JpTXLWcwX+AxnkWJE=
           "]]}, 
         {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], Opacity[0.5], 
          LineBox[CompressedData["
1:eJwtkGtI01EYxrdRIqtV6qjZ2tbMXcwCwUV+yKhUNCRCqzWjICxXYjDFGJub
4IeK6kMXZ+h0WeaIWTTK1P23yvdNu9jQpblrtWxGLMz6EK0LRuX5+3/gcDic
c37v8zzSSl15FYfFYinnF9nbrUQRaJWEk7bcysIfyoMXhxJh6HnnuhFdloXl
lPj057IwHIr6q631SnQWxxr4zhC08qd694cVuCTUXZvPDYErT7ONla/AY1qi
IBzvv7zZ3CXH4QQBBmBvjUjRt1iOknkaJQ7AdIXMcaVahiY+IfqBvS+XShnL
xDCNmwQjW/dVnJOJqlyiSfBtdXg9zevw0hABvgJrmy0+8z0DZ8uIwQlIPQOB
R+oMLCH2iifAd3KgpZSSop3gusfBZOVb+tOlyKI1DhV3d2yUm9aim8SjfGB7
bddec0uwjjyvHQONLic52CjG9aQO5ShYVEFHTYEIpwk+5gXO4evGGHcNLvT3
Aq6WaHd5/KtxD93XCDxTP1Dru9KZfp7D25aG6IU6AdPHUzAk4vG6olVopvM/
gaYiG9UoWsnkHYbmjp0f5n7zmXyPwVN/ziJ8k8bkQXBtKjgxg6lIj6MGwSQs
FJTeTsENtN+HYNcPyz5ZV6CN9ueGfwZZZLtgOS6l/bjgW6G3KsLmMfP7oP2m
sOPAFy4z7x6opszvRwLJDN8JVXf0lUfuJ2EbzeuBXg3bAMZF2ET/twNvzpD9
MY2DSL/vhE6eJO/swF9YuG+BX6ODAH9+MudTcPTlbm72+Vn4D6fQUYY=
           "]]}, 
         {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], Opacity[0.5],
           LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQzfzn41b7Fzf22y+uP5nHonsgaIdc6+vAG/tXvXhU
UVOrc2Cd+8MqkXXX92+YMUlA6JX2Ae7riwtsua7vN99/i8coTPtAehoIXNt/
cEHEqX0HtQ4c/qoR03/o6v4M5VmBs3W0DsgDTdshd3X/tY40nbXTNA9Ui4BM
vLI//Lqv373/GgdugI27vF9qyYxZchkaB0yMQeDy/pS7d/6mnlc/MOEQyMBL
+xkUa79sNVU/8CYQ5MCL+w8mKytKz1Y74AFynvvF/U2SL/nW/Vc9sARk3OIL
+29WeWdNTlY9wAAGF/a/WL244fcxlQM7Qd7bcW7/w5xUUUUtlQOFIOUFZ/ez
2TROcO9VPqAFdP1XjTP7H0X/2bPjg9KBRyDjH57av/nUJ9NDIUoHZs0EgZP7
CxNcNm3aqXggGBxeJ/ZfDOH2vi6vCA2f4/v1il+er2hXgIbH0f0qmglxmx7K
H6gB+//I/m9mfbsSd8hB/Xt4/1G97RYRk2Wh/ju4v+FuzoXzRTJQ/xzYr/+u
O/ZOmPQBsHU79u3/y7xpWaK91AEdsHv37J/DWBzHqiN5YA7YfTv37/gW2Ssl
I3GAB+ye7fun/Pj7r5FPHGr/lv1LvPP2ljOKQe3buH/mZS8Xu08iUPPX7f/h
ldzcfkf4wAyweSv3V3cduBO0U+hAA1j/kv3GrK9bWmoEDxwAq5+3P1VYPv03
nwBUfsr+64X8UjcqeKD8lv0KRtO4Xu5jOwAAoZBGJA==
           
           "]]}}, {}}, {{{}, {}, 
         {GrayLevel[0], Thickness[Large], Opacity[0.5], 
          LineBox[CompressedData["
1:eJwtkHtI01EcxWckmQ9SmmKbzcd0LhsxMuuPGAWGGyaMrYTWWlH4KBhN+6fM
pFyG/RMzHGayTFCp1doyQjesnTvfmuXM3AxTXIUgbajUSmJB3t924HK53Hs/
33NO5gWdsnwLi8USbi66tz2k+oyWl9Hv+pcE5LfwjGEgOIfcDrFLkysgSjvv
zg/FHH6VhYYvanOIVeq7zrZ64cvi1vTbskmct7NKEuvF38KFpYPrfFJZQeXB
UJ3/0aiYTwaDFDiL3ivF8orLWSR9k2bnzcJU64vnPMsktWxK/ISxkHJg41sG
mWNwM4jzyjm5aRnkQD7VDA6rild7unmkaYACP0JtYF9tS9xN/ApqcBoLIZnW
VMMlMmpPOo159fNJtW8X6aK4TjcmVHxboyyVsBi5UbD4lO+xpRAHjWf/AJ9G
J49KTSbV9HnVe6xy9h4bqd9J8mgdwkm4SswJy4Ek8pXifRNoNJXV7NEkknB/
4/BKuTp3RwI5wfQ1Bsua5Ljwfmykn1HkG788ab63LdLHMMaPaGVTrVvJDSb/
EJondhSe7o2K5B3EPtGllabZfwjnc+GcqsFQem0D4TwEMdlFpuTyn2DG2Z0w
O14VWM4HIGL8voG4XPRH7/8OE+PPgaS8lJH1k/OIZ/z04cXy9lJB3RTC819j
5awk+DjaGZnXg/S1lvpAUXeEb4UjVJl2ql2PVoZnhmct5+ahxRLcYv53obrP
qLsdE3QS5n07Hihseu1RjTN8b4SF1n53/9vwuQGsiP4D/QhP6Q==
           "]]}}, {}}, {
        GraphicsComplexBox[{{-0.1, -0.48019943022422984`}, {-0.2, \
-2.5254786755530483`}, {-0.3, -4.656463480375642}, {-0.1, \
-2.8028005376480207`}, {-0.2, -4.46280294470117}, {-0.3, -6.557098407368968}, \
{-0.1, -5.5416636251797655`}, {-0.2, -6.821577582741084}, {-0.3, \
-9.210340371976182}, {-0.1, -8.740336742730447}, {-0.2, -9.903487552536127}, \
{-0.1, -0.38070420516670517`}, {-0.2, -2.378494687094396}, {-0.3, \
-4.508043475257368}}, {{{}, {}, 
           {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
            Dashing[{0, Small}], LineBox[{1, 2, 3}]}, 
           {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
            Dashing[{0, Small}], LineBox[{4, 5, 6}]}, 
           {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Large], 
            Dashing[{0, Small}], LineBox[{7, 8, 9}]}, 
           {RGBColor[0.24, 0.6, 0.33692049419863584`], Thickness[Large], 
            Dashing[{0, Small}], LineBox[{10, 11}]}, 
           {GrayLevel[0], Thickness[0.005], Dashing[{0, Small}], 
            LineBox[{12, 13, 14}]}}, {
           {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
            Dashing[{0, Small}], InsetBox[
             GraphicsBox[
              {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Medium], 
               Dashing[None], CircleBox[{0, 0}]},
              ImageSize->10], 1], InsetBox[
             GraphicsBox[
              {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Medium], 
               Dashing[None], CircleBox[{0, 0}]},
              ImageSize->10], 2], InsetBox[
             GraphicsBox[
              {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Medium], 
               Dashing[None], CircleBox[{0, 0}]},
              ImageSize->10], 3]}, 
           {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
            Dashing[{0, Small}], InsetBox[
             GraphicsBox[
              {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Medium], 
               Dashing[None], CircleBox[{0, 0}], 
               {RGBColor[0.6, 0.24, 0.4428931686004542]}},
              ImageSize->10], 4], InsetBox[
             GraphicsBox[
              {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Medium], 
               Dashing[None], CircleBox[{0, 0}], 
               {RGBColor[0.6, 0.24, 0.4428931686004542]}},
              ImageSize->10], 5], InsetBox[
             GraphicsBox[
              {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Medium], 
               Dashing[None], CircleBox[{0, 0}], 
               {RGBColor[0.6, 0.24, 0.4428931686004542]}},
              ImageSize->10], 6]}, 
           {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Large], 
            Dashing[{0, Small}], InsetBox[
             GraphicsBox[
              {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Medium], 
               Dashing[None], CircleBox[{0, 0}], 
               {RGBColor[0.6, 0.5470136627990908, 0.24]}},
              ImageSize->10], 7], InsetBox[
             GraphicsBox[
              {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Medium], 
               Dashing[None], CircleBox[{0, 0}], 
               {RGBColor[0.6, 0.5470136627990908, 0.24]}},
              ImageSize->10], 8], InsetBox[
             GraphicsBox[
              {RGBColor[0.6, 0.5470136627990908, 0.24], Thickness[Medium], 
               Dashing[None], CircleBox[{0, 0}], 
               {RGBColor[0.6, 0.5470136627990908, 0.24]}},
              ImageSize->10], 9]}, 
           {RGBColor[0.24, 0.6, 0.33692049419863584`], Thickness[Large], 
            Dashing[{0, Small}], InsetBox[
             GraphicsBox[
              {RGBColor[0.24, 0.6, 0.33692049419863584`], Thickness[Medium], 
               Dashing[None], CircleBox[{0, 0}], 
               {RGBColor[0.24, 0.6, 0.33692049419863584`]}},
              ImageSize->10], 10], InsetBox[
             GraphicsBox[
              {RGBColor[0.24, 0.6, 0.33692049419863584`], Thickness[Medium], 
               Dashing[None], CircleBox[{0, 0}], 
               {RGBColor[0.24, 0.6, 0.33692049419863584`]}},
              ImageSize->10], 11]}, 
           {GrayLevel[0], Thickness[0.005], Dashing[{0, Small}], InsetBox[
             GraphicsBox[
              {GrayLevel[0], Thickness[0.005], Dashing[{0, Small}], 
               DiskBox[{0, 0}]},
              ImageSize->8], 12], InsetBox[
             GraphicsBox[
              {GrayLevel[0], Thickness[0.005], Dashing[{0, Small}], 
               DiskBox[{0, 0}]},
              ImageSize->8], 13], InsetBox[
             GraphicsBox[
              {GrayLevel[0], Thickness[0.005], Dashing[{0, Small}], 
               DiskBox[{0, 0}]},
              ImageSize->8], 14]}, {}}}], {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-0.4, -14.508657738524219`},
      CoordinatesToolOptions:>{"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )},
      Epilog->{
        InsetBox[
         FormBox[
          StyleBox[
          "\"C\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
           False], TraditionalForm], 
         Scaled[{0.05, 0.95}]], 
        InsetBox[
         FormBox[
          StyleBox[
          "\"leptokurtic\"", 14, FontFamily -> "Helvetica", StripOnInput -> 
           False], TraditionalForm], 
         Scaled[{0.25, 0.85}]]},
      Frame->{True, False, False, True},
      FrameLabel->{{"", 
         FormBox["\"Probability of rescue\"", TraditionalForm]}, {
         FormBox["\"Wildtype growth rate\"", TraditionalForm], ""}},
      FrameTicks->{{None, {{-13.815510557964274`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0., 
           FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.716898269296165`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.429216196844383`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.206072645530174`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.02375108873622, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.86960040890896, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.736069016284437`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.618285980628055`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.819778284410283`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.407945608651872, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782616`, 
           FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {True, False}},
      GridLines->{None, None},
      LabelStyle->Directive[12, FontFamily -> "Helvetica"],
      Method->{},
      PlotRange->{{-0.4, 0}, {-14.508657738524219`, 0.}},
      PlotRangeClipping->True,
      PlotRangePadding->0,
      Ticks->{Automatic, {{-13.815510557964274`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-11.512925464970229`, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
          FormBox[
           TemplateBox[{"10", 
             RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0., 
          FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.716898269296165`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.429216196844383`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.206072645530174`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.02375108873622, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.86960040890896, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.736069016284437`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.618285980628055`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.819778284410283`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.414313176302118`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.126631103850338`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.903487552536127, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.721165995742174, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.567015315914915, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.433483923290392, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.315700887634009, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.517193191416238, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.111728083308073, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.824046010856292, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.600902459542082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.418580902748127, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.264430222920869, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.1308988302963465`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.013115794639964, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-6.214608098422191, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.407945608651872, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782616`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}}], {189., -610.4101966249684}, 
     ImageScaled[{0.5, 0.5}], {360., 314.16407864998735`}]}, {}},
  ContentSelectable->True,
  ImageSize->375,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.784904043732194*^9, 3.784904085293172*^9}, {
  3.784905504263558*^9, 3.784905524284833*^9}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Rescue genotype growth rate (figure S4)", "Subsection",
 CellChangeTimes->{{3.7794704634668283`*^9, 3.779470474057392*^9}, {
  3.7794710306220827`*^9, 3.779471034112606*^9}, {3.779482842010936*^9, 
  3.7794828429873037`*^9}, {3.7800683415343847`*^9, 3.7800683444466963`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Platykurtic (semicircle, panel A)\
\>", "Subsubsection",
 CellChangeTimes->{
  3.779471039584958*^9, {3.784904140699018*^9, 3.7849041427050323`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"-", "0.3"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"xmax", "=", "0.25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ymax", "=", "40"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"N0", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", 
   RowBox[{"-", "0.1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xint", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"type", "=", "\"\<platy\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", "random", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        RowBox[{"fm", "[", 
         RowBox[{"m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "xmin", ",", "xmax", ",", "xint"}], "}"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"(*", "established", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"fm", "[", 
           RowBox[{
           "m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], "]"}], 
          RowBox[{"pest", "[", 
           RowBox[{"m2", "-", "mwt"}], "]"}]}], 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"fm", "[", 
             RowBox[{
             "m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
             "]"}], 
            RowBox[{"pest", "[", 
             RowBox[{"m2", "-", "mwt"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"m2", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "mwt", ",", "xmax", ",", "xint"}], "}"}]}], "]"}]}],
    "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Gray", ",", "Dashed"}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Gray"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{"\"\<random\>\"", ",", "\"\<established\>\""}], "}"}]}], 
          "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1.5", "/", "8"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"1", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        RowBox[{"g1m", "/.", 
         RowBox[{"m", "\[Rule]", "m2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "0", ",", "xmax", ",", "xint"}], "}"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"2", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"total", "=", 
      RowBox[{"Re", "[", 
       RowBox[{"g2denominator", "[", "mwt", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"m2", ",", 
         RowBox[{
          FractionBox["1", "total"], 
          RowBox[{"g2numerator", "[", 
           RowBox[{"mwt", ",", "m2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "xmax", ",", "xint"}], "}"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", 
         RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{"\"\<1-step\>\"", ",", "\"\<2-step\>\""}], "}"}]}], "]"}],
          ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1.5", "/", "8"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StringForm", "[", 
   RowBox[{
    RowBox[{
    "datadir", "<>", 
     "\"\<dfe_``_N``_n``_U``_Es``_mmax``_mwt``_nreps100000.csv\>\""}], ",", 
    "type", ",", "N0", ",", "n", ",", 
    RowBox[{"NumberForm", "[", 
     RowBox[{
      RowBox[{"U", "//", "N"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "5"}], "}"}]}], "]"}], ",", 
    RowBox[{"NumberForm", "[", 
     RowBox[{"Es", ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}]}], "]"}], ",", 
    RowBox[{"NumberForm", "[", 
     RowBox[{"mmax", ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}]}], "]"}], ",", "mwt"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"ToString", "[", "%", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"onestep", "=", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"dat", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], "&"}]}], "]"}], 
    "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"twostep", "=", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"dat", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
    "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Histogram", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"onestep", ",", "twostep"}], "}"}], ",", "Automatic", ",", 
      "\"\<PDF\>\"", ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figS4a", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"oldtheory", ",", "data", ",", "theory"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontColor", "\[Rule]", "White"}], ",", "Automatic", ",", 
        "Automatic", ",", "Automatic"}], "}"}]}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<\!\(\*
StyleBox[SubscriptBox[\"m\", \"0\"],
FontSlant->\"Italic\"]\)=\>\"", "<>", 
             RowBox[{"ToString", "[", "mwt", "]"}]}], ",", "12", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"7", "/", "8"}], ",", 
             RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<A\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<platykurtic\>\"", ",", "14", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"7", "/", "8"}], ",", 
             RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}], 
       "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.751575679958344*^9, 3.751575707856783*^9}, {
   3.751575756450697*^9, 3.7515757716167583`*^9}, {3.751575806118587*^9, 
   3.751575998358532*^9}, {3.7515761122033863`*^9, 3.751576131258815*^9}, {
   3.751576172283361*^9, 3.751576174879533*^9}, {3.7515762580970592`*^9, 
   3.751576326479478*^9}, {3.7515763695777597`*^9, 3.751576370332637*^9}, {
   3.7515764174224873`*^9, 3.751576419272636*^9}, {3.751577234452231*^9, 
   3.751577234571393*^9}, {3.751598119440303*^9, 3.7515981249463587`*^9}, 
   3.751650792683756*^9, {3.751650847039688*^9, 3.751650935724555*^9}, {
   3.751651020576578*^9, 3.751651024456732*^9}, {3.7516511744217253`*^9, 
   3.751651271292901*^9}, {3.7516514431359167`*^9, 3.751651596903675*^9}, {
   3.75165167006041*^9, 3.7516517016743317`*^9}, {3.751651837998188*^9, 
   3.751651848660565*^9}, {3.751651901804051*^9, 3.751651938743773*^9}, {
   3.75165209054011*^9, 3.751652092941709*^9}, {3.751654667780588*^9, 
   3.751654726734174*^9}, {3.751654761368635*^9, 3.751654832140562*^9}, {
   3.751654888268785*^9, 3.7516548919393587`*^9}, 3.751656018745837*^9, {
   3.751656381036447*^9, 3.7516563882551813`*^9}, {3.7565000581145897`*^9, 
   3.7565001021945477`*^9}, {3.756500617190415*^9, 3.75650065699045*^9}, 
   3.75650069938904*^9, {3.756500741026494*^9, 3.756500755155011*^9}, {
   3.756501221346011*^9, 3.75650122389799*^9}, 3.756502363067445*^9, 
   3.756502628112669*^9, 3.7565026817972727`*^9, {3.756503286102932*^9, 
   3.756503290049591*^9}, 3.756503323237875*^9, {3.756503496903769*^9, 
   3.75650353646167*^9}, {3.7565038167736483`*^9, 3.756503833330291*^9}, {
   3.7565038702319183`*^9, 3.7565038987244377`*^9}, {3.7565039623685904`*^9, 
   3.7565039995283422`*^9}, 3.756511754548572*^9, 3.756511866105935*^9, {
   3.756511901000861*^9, 3.756511903883478*^9}, {3.7565119526094627`*^9, 
   3.756511957815688*^9}, {3.756512664854374*^9, 3.756512670495578*^9}, {
   3.7565186714828672`*^9, 3.756518674830636*^9}, {3.756518724785604*^9, 
   3.7565187318397303`*^9}, {3.756518775324299*^9, 3.75651877705446*^9}, {
   3.756518831207197*^9, 3.756518836010257*^9}, {3.7565191876130047`*^9, 
   3.7565192273750753`*^9}, 3.756557317943141*^9, 3.756565191609994*^9, {
   3.756565226853438*^9, 3.756565227347921*^9}, {3.756565372407086*^9, 
   3.756565372554656*^9}, {3.7642581275023746`*^9, 3.764258130547591*^9}, {
   3.764258191591094*^9, 3.7642582094474382`*^9}, 3.769438935312201*^9, {
   3.769440382123701*^9, 3.769440472454721*^9}, 3.769440550032837*^9, {
   3.769440597811926*^9, 3.76944060297188*^9}, {3.769440831103504*^9, 
   3.769440912756571*^9}, {3.769440959415164*^9, 3.769440994826437*^9}, {
   3.769441059064315*^9, 3.769441091058297*^9}, {3.769441130350876*^9, 
   3.76944116439666*^9}, {3.7694411991785088`*^9, 3.7694412021516743`*^9}, 
   3.76996874883585*^9, 3.769968810893046*^9, {3.771262388292754*^9, 
   3.771262479562519*^9}, {3.771262525425778*^9, 3.771262540854212*^9}, {
   3.771262571282227*^9, 3.771262676392552*^9}, 3.771262708817911*^9, {
   3.771262787550537*^9, 3.77126278925319*^9}, {3.771262848265294*^9, 
   3.7712628699284153`*^9}, {3.771263092625225*^9, 3.771263094812828*^9}, 
   3.771263271500595*^9, {3.771523030703679*^9, 3.7715230467362022`*^9}, {
   3.771523079011808*^9, 3.771523152186151*^9}, {3.77152320543019*^9, 
   3.771523315803763*^9}, {3.7715233464449253`*^9, 3.771523576781527*^9}, {
   3.771523631873809*^9, 3.7715236430826683`*^9}, {3.7715241526920757`*^9, 
   3.771524155896125*^9}, {3.7715242229465923`*^9, 3.771524257316955*^9}, {
   3.771524320220757*^9, 3.771524423589848*^9}, {3.771524462952353*^9, 
   3.771524468371491*^9}, 3.771524519796175*^9, {3.771524560722151*^9, 
   3.77152458745588*^9}, {3.7715456914503183`*^9, 3.771545693694459*^9}, 
   3.7715458002283154`*^9, {3.771545911589119*^9, 3.771545926111433*^9}, {
   3.77160975420442*^9, 3.7716097651557693`*^9}, {3.7716099182331963`*^9, 
   3.77160992062647*^9}, {3.771609967213895*^9, 3.771610003678589*^9}, {
   3.771610042996176*^9, 3.771610061906077*^9}, {3.771610106603993*^9, 
   3.771610114408716*^9}, {3.771610201107335*^9, 3.771610202727501*^9}, 
   3.771610248378283*^9, {3.7794686898536158`*^9, 3.7794688301324673`*^9}, {
   3.77946886396563*^9, 3.77946888729186*^9}, {3.779468925902836*^9, 
   3.7794689413547277`*^9}, {3.779469011076345*^9, 3.779469071332287*^9}, {
   3.779469527005124*^9, 3.779469555307827*^9}, {3.779469593442951*^9, 
   3.77946961429259*^9}, {3.779469796805294*^9, 3.779469866620295*^9}, {
   3.779469901788733*^9, 3.779470016571252*^9}, {3.779470051010948*^9, 
   3.779470158052433*^9}, {3.779470201565462*^9, 3.779470241549526*^9}, 
   3.780062293224526*^9, {3.780062341271126*^9, 3.7800623697424707`*^9}, {
   3.780062860795129*^9, 3.780062861799574*^9}, {3.7800666511707067`*^9, 
   3.7800666553558607`*^9}, {3.780066708471122*^9, 3.780066726219557*^9}, 
   3.780067723259276*^9, {3.782262502504594*^9, 3.782262505156313*^9}, {
   3.782262648809627*^9, 3.782262649281292*^9}, {3.784855676748372*^9, 
   3.784855702181672*^9}, {3.7849044057780733`*^9, 3.7849044497486134`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "izero"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Integral and error estimates are 0 on all integration \
subregions. Try increasing the value of the MinRecursion option. If value of \
integral may be 0, specify a finite value for the AccuracyGoal option. \\!\\(\
\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/NIntegrate\\\", ButtonNote -> \
\\\"NIntegrate::izero\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.784904424146611*^9, 3.784904463632641*^9}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {{}, {}, 
       {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
        LineBox[CompressedData["
1:eJwtU3tI01EUntN8v/aAUlIyrUaalbYSxJ0bRCqZNQVJ85GS+Uema0E5k7Qw
UyIt0TLfopUW2srhi+lVp2ibE1/zEY2cY+YrTNJMi0x/93fgcjmce7/vO+d+
1yUuOSSeyWAwfLbXzu5NxSjWVuiGqkzGIK97jReZN4LTytr3r69MwaKwxfnh
4jDucwpNn6mchgBdKrfBfxgzHS+uB3EMUCPys5yoHsKBjsyD3xMWgEHFEJY3
nfUWh/+AndvClkFcaeI2yDdaBeq4SI0znrs7O3n+hm2ybcYB/FljiL6u/QsU
vE6J/Qpch7uZRuglFZ/wfPAN1U2lMQqhAPuxyONN2/sWU7SD5mfZh7eytE5m
cgtEye/uxQINDprpsEYUXGoPDpbk7D5ea4dIvwoc9Gc/w9eThUh/XXjy8r6A
4hg2qqYEduI1JXspLIKDiP4OfFU2NmFgcRHRK8fXpkxDzdO4qIjS14pnWWtf
6p9xaT3NODFQ0vf6Apfml+HMSJkJq5mDFii+D9jdlvs0Sc2m8RtwWaxGGlXK
ovHqsJVawPx1zB6lUPdr8PwhlxQp3wZJqfPleMCofsl+3AKJqHoB5tt2/YuL
N0UZVJ6J74wIwGBsjBh0LDBrj0SVbAFdB8Wy996Ajxt0XgDuhblSXuIqdBJ8
OH8yJ9asaZmu14DKs2+Rbz4HlUQfPBLu+Zqt0NHv2wDRvq1htS+mYIn0B+IV
7yn/n8OQRvqH2cHpb1X3+sGazAeWmeOqdr9OKCXzg81wtrV4TgYeZL5wNCv3
br7DWxq/A8yyVVfO5FbQfuuEV+/u71Lcyqf5uqCZ06t9MJkJJ8j7gjKbN+vV
fJvm74FsjXxofDwBeog/IFnSZaW3uQS0f0Btnet46pw/0P4CN1V6fUwJH4qJ
/8CnvDfKn+cKM8SfsPGkMWPUyx4OE/9CUWGS5LTdpkBM/A1tvWmqA3q9oI34
H/RakVDSNCAwIv8DNA51EezHjYL/hVay3A==
         "]]}, 
       {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQPWsmCOzczwAF3NcXF9hybd8vWXAltPwgg0O1yDr3
h1Vb9k91DQ6KkxJweBO4Q6719cb9NVoSe2TPiznsBPICd6zbzzTDVT7CRMYB
Yt7K/RP/FH734lFwqAHrX7L/RJFpa7WxosMOsPp5+x+GTI28NFkRKj9l/zcT
ppoldooODWB+y/7dk+u1f/krOMDcZfLK0NvwmqxDBUTeXshnR6lNrhSUP8X+
0ak35mkbxWDm2x/dkcfX/lwIZr/9wjtznydP4HOYAXGf/RxJv58/f7JD1a+z
31WuseagPRPMf/YrLRO8+z/+sq+C+N/eh2OZnrPHZ3suSPjY2y3y9ZLc+8oe
Gn72/QleC3Z+emivEdN/6KvGHnvTpHjLeX7X7SHm77PPbLFKa7c/a78EqPv6
4gP2D/c/XK+//aD9a7B9B+1fzVu2U3vjFntjMDhsb3GQ58Zt1+X2kPA/Ys//
yOhvuvZM+8NfQTYctZ/l/fith1KXPSS+jtv/dE+I+MJYZQ82LvCEvelkO82t
hzLswc6bedJ+2tSmypWNYfYPwR46Zb9kq7+KYq2zvSbYvWfsGfolZ6zlNLAv
BDmv4Ky98Xp1yUcskvaQ+D1nH75D5Xl3IZM9JDYu2B9Je/ZDbN5LOwAJBgl/

         "]]}}, {}}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[Opacity[0.469]], {{}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], Opacity[0.5], EdgeForm[
        Opacity[0.469]], 
        RectangleBox[{0., 0.}, 
         NCache[{0.005, Rational[114000, 8179]}, {0.005, 13.938134246240372`}],
         RoundingRadius->0], 
        RectangleBox[{0.005, 0.}, 
         NCache[{0.01, Rational[164400, 8179]}, {0.01, 20.100256755104535`}],
         RoundingRadius->0], 
        RectangleBox[{0.01, 0.}, 
         NCache[{0.015, Rational[205200, 8179]}, {0.015, 25.08864164323267}],
         RoundingRadius->0], 
        RectangleBox[{0.015, 0.}, 
         NCache[{0.02, Rational[246500, 8179]}, {0.02, 30.13815869910747}],
         RoundingRadius->0], 
        RectangleBox[{0.02, 0.}, 
         NCache[{0.025, Rational[272500, 8179]}, {0.025, 33.317031421934225`}],
         RoundingRadius->0], 
        RectangleBox[{0.025, 0.}, 
         NCache[{0.03, Rational[270100, 8179]}, {0.03, 33.023597016750216`}],
         RoundingRadius->0], 
        RectangleBox[{0.03, 0.}, 
         NCache[{0.035, Rational[223600, 8179]}, {0.035, 27.338305416310064`}],
         RoundingRadius->0], 
        RectangleBox[{0.035, 0.}, 
         NCache[{0.04, Rational[118300, 8179]}, {0.04, 14.463870888861718`}],
         RoundingRadius->0], 
        RectangleBox[{0.04, 0.}, 
         NCache[{0.045, Rational[21200, 8179]}, {0.045, 2.5920039124587357`}],
         
         RoundingRadius->0], RectangleBox[{0.045, 0.}, {0.05, 0},
         RoundingRadius->0], RectangleBox[{0.05, 0.}, {0.055, 0},
         RoundingRadius->0], RectangleBox[{0.055, 0.}, {0.06, 0},
         RoundingRadius->0], RectangleBox[{0.06, 0.}, {0.065, 0},
         RoundingRadius->0], RectangleBox[{0.065, 0.}, {0.07, 0},
         RoundingRadius->0], RectangleBox[{0.07, 0.}, {0.075, 0},
         RoundingRadius->0], RectangleBox[{0.075, 0.}, {0.08, 0},
         RoundingRadius->0], RectangleBox[{0.08, 0.}, {0.085, 0},
         RoundingRadius->0], RectangleBox[{0.085, 0.}, {0.09, 0},
         RoundingRadius->0], RectangleBox[{0.09, 0.}, {0.095, 0},
         RoundingRadius->0], RectangleBox[{0.095, 0.}, {0.1, 0},
         RoundingRadius->0], RectangleBox[{0.1, 0.}, {0.105, 0},
         RoundingRadius->0], RectangleBox[{0.105, 0.}, {0.11, 0},
         RoundingRadius->0], RectangleBox[{0.11, 0.}, {0.115, 0},
         RoundingRadius->0], RectangleBox[{0.115, 0.}, {0.12, 0},
         RoundingRadius->0], RectangleBox[{0.12, 0.}, {0.125, 0},
         RoundingRadius->0], RectangleBox[{0.125, 0.}, {0.13, 0},
         RoundingRadius->0], RectangleBox[{0.13, 0.}, {0.135, 0},
         RoundingRadius->0], RectangleBox[{0.135, 0.}, {0.14, 0},
         RoundingRadius->0], RectangleBox[{0.14, 0.}, {0.145, 0},
         RoundingRadius->0], RectangleBox[{0.145, 0.}, {0.15, 0},
         RoundingRadius->0], RectangleBox[{0.15, 0.}, {0.155, 0},
         RoundingRadius->0], RectangleBox[{0.155, 0.}, {0.16, 0},
         RoundingRadius->0], RectangleBox[{0.16, 0.}, {0.165, 0},
         RoundingRadius->0]}, {}, {}}, {{}, 
       {RGBColor[0.6, 0.24, 0.4428931686004542], Opacity[0.5], EdgeForm[
        Opacity[0.469]], 
        RectangleBox[{0., 0.}, 
         NCache[{0.005, Rational[43, 33]}, {0.005, 1.303030303030303}],
         RoundingRadius->0], 
        RectangleBox[{0.005, 0.}, 
         NCache[{0.01, Rational[26, 11]}, {0.01, 2.3636363636363638`}],
         RoundingRadius->0], 
        RectangleBox[{0.01, 0.}, 
         NCache[{0.015, Rational[89, 33]}, {0.015, 2.696969696969697}],
         RoundingRadius->0], 
        RectangleBox[{0.015, 0.}, 
         NCache[{0.02, Rational[131, 33]}, {0.02, 3.9696969696969697`}],
         RoundingRadius->0], 
        RectangleBox[{0.02, 0.}, 
         NCache[{0.025, Rational[119, 33]}, {0.025, 3.606060606060606}],
         RoundingRadius->0], 
        RectangleBox[{0.025, 0.}, 
         NCache[{0.03, Rational[181, 33]}, {0.03, 5.484848484848484}],
         RoundingRadius->0], 
        RectangleBox[{0.03, 0.}, 
         NCache[{0.035, Rational[197, 33]}, {0.035, 5.96969696969697}],
         RoundingRadius->0], 
        RectangleBox[{0.035, 0.}, 
         NCache[{0.04, Rational[233, 33]}, {0.04, 7.0606060606060606`}],
         RoundingRadius->0], 
        RectangleBox[{0.04, 0.}, 
         NCache[{0.045, Rational[90, 11]}, {0.045, 8.181818181818182}],
         RoundingRadius->0], 
        RectangleBox[{0.045, 0.}, 
         NCache[{0.05, Rational[254, 33]}, {0.05, 7.696969696969697}],
         RoundingRadius->0], 
        RectangleBox[{0.05, 0.}, 
         NCache[{0.055, Rational[28, 3]}, {0.055, 9.333333333333334}],
         RoundingRadius->0], 
        RectangleBox[{0.055, 0.}, 
         NCache[{0.06, Rational[108, 11]}, {0.06, 9.818181818181818}],
         RoundingRadius->0], 
        RectangleBox[{0.06, 0.}, 
         NCache[{0.065, Rational[119, 11]}, {0.065, 10.818181818181818`}],
         RoundingRadius->0], 
        RectangleBox[{0.065, 0.}, 
         NCache[{0.07, Rational[361, 33]}, {0.07, 10.93939393939394}],
         RoundingRadius->0], 
        RectangleBox[{0.07, 0.}, 
         NCache[{0.075, Rational[32, 3]}, {0.075, 10.666666666666666`}],
         RoundingRadius->0], 
        RectangleBox[{0.075, 0.}, 
         NCache[{0.08, Rational[368, 33]}, {0.08, 11.151515151515152`}],
         RoundingRadius->0], 
        RectangleBox[{0.08, 0.}, 
         NCache[{0.085, Rational[373, 33]}, {0.085, 11.303030303030303`}],
         RoundingRadius->0], 
        RectangleBox[{0.085, 0.}, 
         NCache[{0.09, Rational[349, 33]}, {0.09, 10.575757575757576`}],
         RoundingRadius->0], 
        RectangleBox[{0.09, 0.}, 
         NCache[{0.095, Rational[111, 11]}, {0.095, 10.090909090909092`}],
         RoundingRadius->0], 
        RectangleBox[{0.095, 0.}, 
         NCache[{0.1, Rational[109, 11]}, {0.1, 9.909090909090908}],
         RoundingRadius->0], 
        RectangleBox[{0.1, 0.}, 
         NCache[{0.105, Rational[305, 33]}, {0.105, 9.242424242424242}],
         RoundingRadius->0], 
        RectangleBox[{0.105, 0.}, 
         NCache[{0.11, Rational[233, 33]}, {0.11, 7.0606060606060606`}],
         RoundingRadius->0], 
        RectangleBox[{0.11, 0.}, 
         NCache[{0.115, Rational[73, 11]}, {0.115, 6.636363636363637}],
         RoundingRadius->0], 
        RectangleBox[{0.115, 0.}, 
         NCache[{0.12, Rational[200, 33]}, {0.12, 6.0606060606060606`}],
         RoundingRadius->0], 
        RectangleBox[{0.12, 0.}, 
         NCache[{0.125, Rational[59, 11]}, {0.125, 5.363636363636363}],
         RoundingRadius->0], 
        RectangleBox[{0.125, 0.}, 
         NCache[{0.13, Rational[155, 33]}, {0.13, 4.696969696969697}],
         RoundingRadius->0], 
        RectangleBox[{0.13, 0.}, 
         NCache[{0.135, Rational[112, 33]}, {0.135, 3.393939393939394}],
         RoundingRadius->0], 
        RectangleBox[{0.135, 0.}, 
         NCache[{0.14, Rational[46, 33]}, {0.14, 1.393939393939394}],
         RoundingRadius->0], 
        RectangleBox[{0.14, 0.}, 
         NCache[{0.145, Rational[59, 33]}, {0.145, 1.7878787878787878`}],
         RoundingRadius->0], 
        RectangleBox[{0.145, 0.}, 
         NCache[{0.15, Rational[26, 33]}, {0.15, 0.7878787878787878}],
         RoundingRadius->0], 
        RectangleBox[{0.15, 0.}, 
         NCache[{0.155, Rational[1, 3]}, {0.155, 0.3333333333333333}],
         RoundingRadius->0], 
        RectangleBox[{0.155, 0.}, 
         NCache[{0.16, Rational[3, 11]}, {0.16, 0.2727272727272727}],
         RoundingRadius->0], 
        RectangleBox[{0.16, 0.}, 
         NCache[{0.165, Rational[1, 33]}, {0.165, 0.030303030303030304`}],
         RoundingRadius->0]}, {}, {}}}, {{}, {{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], Opacity[
        0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsT8Vtu3JyseyDhD+FHu2qm0uHK3q
DjvkWl8H7phnn7vQdto6OW2o/BL7w7LiggFK2g6zZoLASvv7ha+MrS9rQNWv
s0/6cG7LR3tVhzeBIJGN9p8jnxnJWShC9W+xX8+u/+DmdCkHruuLC2y5tttL
858WFF0qDDVvp72Q7ocdBle4HTRj+g991dhjv9VhAlvIGyao+fvsK5lOBbju
+GG/BKj7+uID9lJMvod1WN/bQ+w7aF/964bv0Q2P7I3B4LD9/S+qflVzr9pD
7D9iv+/yjX23vx+3P/xVA2jDUXvvwl0v3Ep22kPcc9z+QFze/Gu3VtoHgS08
Yc/7eFetoMhMe4j7TtrnxLo4chm02z+sAhl4yv6yxO2IgNQSe4h7z9j7bn0V
7MieaF8Icl7BWfuAMLXg+6+97CHuP2efairVelncxB4SCxfsV02fsMbfWsYe
ALe+ueE=
         "]]}, 
       {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], Opacity[
        0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsY8qNFU578LjAOFPsXeW6Zk24ZSY
ww651teBO+bZz8xzdrvQJwOVX2L/7VtW+hReBYdZM0Fgpf28pFjTd28VoOrX
2Vf9SwmZJKzo8CYQJLLRXnK5b7zGEgWo/i32Ng0dje7N8g5c1xcX2HJtty9R
s7jbIioLNW+nPeujj8sMzaQcNGP6D33V2GOv/vq99ndRcaj5++wva9ukX74n
7LAEqPv64gP2F23CSzi3CEDtO2hvs8tGPT2F28EYDA7bP3j7KvnuPVao/Ufs
ZRz3xCl+Z3A4/FUDaMNR+62VXuxFjT/tIe45bv+pPkvnStsn+yCwhSfs/e/N
9nN8/9Ie4r6T9ie3MKuJFT20f1gFMvCU/e1js7RONF6zh7j3jL3P9wsbbp0+
bV8Icl7BWfslpppSOpkH7CHuP2f//WC2nFrzJntILFywdzXdf1Ti42J7ALp0
unI=
         "]]}}, {}}}, InsetBox[
     TagBox[GridBox[{
        {
         TemplateBox[{
          StyleBox[
           "\"random\"", StripOnInput -> False, FontFamily -> "Helvetica", 
            FontSize -> 12],StyleBox[
           "\"established\"", StripOnInput -> False, FontFamily -> 
            "Helvetica", FontSize -> 12]},
          "LineLegend",
          DisplayFunction->(StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
            False]& ),
          Editable->True,
          InterpretationFunction:>(RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                   ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}]}], "]"}]}], "}"}],
                ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]},
        {
         TemplateBox[{
          StyleBox[
           "\"1-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
            FontSize -> 12],StyleBox[
           "\"2-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
            FontSize -> 12]},
          "LineLegend",
          DisplayFunction->(StyleBox[
            StyleBox[
             PaneBox[
              TagBox[
               GridBox[{{
                  TagBox[
                   GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
               "Grid"], Alignment -> Left, AppearanceElements -> None, 
              ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
              "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
            FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
            False]& ),
          Editable->True,
          InterpretationFunction:>(RowBox[{"LineLegend", "[", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}]}], "}"}], 
               ",", 
               RowBox[{"{", 
                 RowBox[{#, ",", #2}], "}"}], ",", 
               RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
               RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {{0}}}],
      "Grid"], NCache[
     Scaled[{0.1875, Rational[1, 2]}], Scaled[{0.1875, 0.5}]], ImageScaled[{0.5, 0.5}],
     BaseStyle->{FontSize -> Larger},
     FormatType->StandardForm]},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesLabel->{None, None},
   AxesOrigin->{0., 0.},
   Epilog->{
     InsetBox[
      FormBox[
       StyleBox[
       "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=-0.1\"", 12, FontFamily -> 
        "Helvetica", StripOnInput -> False], TraditionalForm], 
      NCache[
       Scaled[{
         Rational[7, 8], 
         Rational[3, 4]}], 
       Scaled[{0.875, 0.75}]]], 
     InsetBox[
      FormBox[
       StyleBox[
       "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
       TraditionalForm], 
      Scaled[{0.05, 0.95}]], 
     InsetBox[
      FormBox[
       StyleBox[
       "\"platykurtic\"", 14, FontFamily -> "Helvetica", StripOnInput -> 
        False], TraditionalForm], 
      NCache[
       Scaled[{
         Rational[7, 8], 
         Rational[1, 2]}], 
       Scaled[{0.875, 0.5}]]]},
   Frame->{True, False, False, False},
   FrameTicksStyle->{
    FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.3, 0.25}, {0, 40}},
   PlotRangeClipping->True,
   PlotRangePadding->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           GrayLevel[0.5], 
           Dashing[{Small, Small}]], 
          Line[CompressedData["
1:eJwtU3tI01EUntN8v/aAUlIyrUaalbYSxJ0bRCqZNQVJ85GS+Uema0E5k7Qw
UyIt0TLfopUW2srhi+lVp2ibE1/zEY2cY+YrTNJMi0x/93fgcjmce7/vO+d+
1yUuOSSeyWAwfLbXzu5NxSjWVuiGqkzGIK97jReZN4LTytr3r69MwaKwxfnh
4jDucwpNn6mchgBdKrfBfxgzHS+uB3EMUCPys5yoHsKBjsyD3xMWgEHFEJY3
nfUWh/+AndvClkFcaeI2yDdaBeq4SI0znrs7O3n+hm2ybcYB/FljiL6u/QsU
vE6J/Qpch7uZRuglFZ/wfPAN1U2lMQqhAPuxyONN2/sWU7SD5mfZh7eytE5m
cgtEye/uxQINDprpsEYUXGoPDpbk7D5ea4dIvwoc9Gc/w9eThUh/XXjy8r6A
4hg2qqYEduI1JXspLIKDiP4OfFU2NmFgcRHRK8fXpkxDzdO4qIjS14pnWWtf
6p9xaT3NODFQ0vf6Apfml+HMSJkJq5mDFii+D9jdlvs0Sc2m8RtwWaxGGlXK
ovHqsJVawPx1zB6lUPdr8PwhlxQp3wZJqfPleMCofsl+3AKJqHoB5tt2/YuL
N0UZVJ6J74wIwGBsjBh0LDBrj0SVbAFdB8Wy996Ajxt0XgDuhblSXuIqdBJ8
OH8yJ9asaZmu14DKs2+Rbz4HlUQfPBLu+Zqt0NHv2wDRvq1htS+mYIn0B+IV
7yn/n8OQRvqH2cHpb1X3+sGazAeWmeOqdr9OKCXzg81wtrV4TgYeZL5wNCv3
br7DWxq/A8yyVVfO5FbQfuuEV+/u71Lcyqf5uqCZ06t9MJkJJ8j7gjKbN+vV
fJvm74FsjXxofDwBeog/IFnSZaW3uQS0f0Btnet46pw/0P4CN1V6fUwJH4qJ
/8CnvDfKn+cKM8SfsPGkMWPUyx4OE/9CUWGS5LTdpkBM/A1tvWmqA3q9oI34
H/RakVDSNCAwIv8DNA51EezHjYL/hVay3A==
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           GrayLevel[0.5]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGBQAWIQPWsmCOzczwAF3NcXF9hybd8vWXAltPwgg0O1yDr3
h1Vb9k91DQ6KkxJweBO4Q6719cb9NVoSe2TPiznsBPICd6zbzzTDVT7CRMYB
Yt7K/RP/FH734lFwqAHrX7L/RJFpa7WxosMOsPp5+x+GTI28NFkRKj9l/zcT
ppoldooODWB+y/7dk+u1f/krOMDcZfLK0NvwmqxDBUTeXshnR6lNrhSUP8X+
0ak35mkbxWDm2x/dkcfX/lwIZr/9wjtznydP4HOYAXGf/RxJv58/f7JD1a+z
31WuseagPRPMf/YrLRO8+z/+sq+C+N/eh2OZnrPHZ3suSPjY2y3y9ZLc+8oe
Gn72/QleC3Z+emivEdN/6KvGHnvTpHjLeX7X7SHm77PPbLFKa7c/a78EqPv6
4gP2D/c/XK+//aD9a7B9B+1fzVu2U3vjFntjMDhsb3GQ58Zt1+X2kPA/Ys//
yOhvuvZM+8NfQTYctZ/l/fith1KXPSS+jtv/dE+I+MJYZQ82LvCEvelkO82t
hzLswc6bedJ+2tSmypWNYfYPwR46Zb9kq7+KYq2zvSbYvWfsGfolZ6zlNLAv
BDmv4Ky98Xp1yUcskvaQ+D1nH75D5Xl3IZM9JDYu2B9Je/ZDbN5LOwAJBgl/

           "]]}}}, {}}, {
       Directive[
        EdgeForm[
         Opacity[0.469]], 
        RGBColor[
        0.798413061722744, 0.824719615472648, 0.968322270542458]], {{{{}, {
           Directive[
            Opacity[0.5], 
            Directive[
             EdgeForm[
              Opacity[0.469]], 
             RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458]], 
            Directive[
             RGBColor[0.24720000000000014`, 0.24, 0.6]]], {{{
              Rectangle[{0., 0.}, {0.005, 
                Rational[114000, 8179]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.005, 0.}, {0.01, 
                Rational[164400, 8179]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.01, 0.}, {0.015, 
                Rational[205200, 8179]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.015, 0.}, {0.02, 
                Rational[246500, 8179]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.02, 0.}, {0.025, 
                Rational[272500, 8179]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.025, 0.}, {0.03, 
                Rational[270100, 8179]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.03, 0.}, {0.035, 
                Rational[223600, 8179]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.035, 0.}, {0.04, 
                Rational[118300, 8179]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.04, 0.}, {0.045, 
                Rational[21200, 8179]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.045, 0.}, {0.05, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.05, 0.}, {0.055, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.055, 0.}, {0.06, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.06, 0.}, {0.065, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.065, 0.}, {0.07, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.07, 0.}, {0.075, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.075, 0.}, {0.08, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.08, 0.}, {0.085, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.085, 0.}, {0.09, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.09, 0.}, {0.095, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.095, 0.}, {0.1, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.1, 0.}, {0.105, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.105, 0.}, {0.11, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.11, 0.}, {0.115, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.115, 0.}, {0.12, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.12, 0.}, {0.125, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.125, 0.}, {0.13, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.13, 0.}, {0.135, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.135, 0.}, {0.14, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.14, 0.}, {0.145, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.145, 0.}, {0.15, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.15, 0.}, {0.155, 0}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.155, 0.}, {0.16, 0}, "RoundingRadius" -> 0]}}, {{
              
              Rectangle[{0.16, 0.}, {0.165, 0}, "RoundingRadius" -> 
               0]}}}}, {}, {}}}, {{{}, {
           Directive[
            Opacity[0.5], 
            Directive[
             EdgeForm[
              Opacity[0.469]], 
             RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458]], 
            Directive[
             RGBColor[0.6, 0.24, 0.4428931686004542]]], {{{
              Rectangle[{0., 0.}, {0.005, 
                Rational[43, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.005, 0.}, {0.01, 
                Rational[26, 11]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.01, 0.}, {0.015, 
                Rational[89, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.015, 0.}, {0.02, 
                Rational[131, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.02, 0.}, {0.025, 
                Rational[119, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.025, 0.}, {0.03, 
                Rational[181, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.03, 0.}, {0.035, 
                Rational[197, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.035, 0.}, {0.04, 
                Rational[233, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.04, 0.}, {0.045, 
                Rational[90, 11]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.045, 0.}, {0.05, 
                Rational[254, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.05, 0.}, {0.055, 
                Rational[28, 3]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.055, 0.}, {0.06, 
                Rational[108, 11]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.06, 0.}, {0.065, 
                Rational[119, 11]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.065, 0.}, {0.07, 
                Rational[361, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.07, 0.}, {0.075, 
                Rational[32, 3]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.075, 0.}, {0.08, 
                Rational[368, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.08, 0.}, {0.085, 
                Rational[373, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.085, 0.}, {0.09, 
                Rational[349, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.09, 0.}, {0.095, 
                Rational[111, 11]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.095, 0.}, {0.1, 
                Rational[109, 11]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.1, 0.}, {0.105, 
                Rational[305, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.105, 0.}, {0.11, 
                Rational[233, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.11, 0.}, {0.115, 
                Rational[73, 11]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.115, 0.}, {0.12, 
                Rational[200, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.12, 0.}, {0.125, 
                Rational[59, 11]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.125, 0.}, {0.13, 
                Rational[155, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.13, 0.}, {0.135, 
                Rational[112, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.135, 0.}, {0.14, 
                Rational[46, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.14, 0.}, {0.145, 
                Rational[59, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.145, 0.}, {0.15, 
                Rational[26, 33]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.15, 0.}, {0.155, 
                Rational[1, 3]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.155, 0.}, {0.16, 
                Rational[3, 11]}, "RoundingRadius" -> 0]}}, {{
              Rectangle[{0.16, 0.}, {0.165, 
                Rational[1, 33]}, "RoundingRadius" -> 
               0]}}}}, {}, {}}}}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           Thickness[Large], 
           Opacity[0.5]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsT8Vtu3JyseyDhD+FHu2qm0uHK3q
DjvkWl8H7phnn7vQdto6OW2o/BL7w7LiggFK2g6zZoLASvv7ha+MrS9rQNWv
s0/6cG7LR3tVhzeBIJGN9p8jnxnJWShC9W+xX8+u/+DmdCkHruuLC2y5tttL
858WFF0qDDVvp72Q7ocdBle4HTRj+g991dhjv9VhAlvIGyao+fvsK5lOBbju
+GG/BKj7+uID9lJMvod1WN/bQ+w7aF/964bv0Q2P7I3B4LD9/S+qflVzr9pD
7D9iv+/yjX23vx+3P/xVA2jDUXvvwl0v3Ep22kPcc9z+QFze/Gu3VtoHgS08
Yc/7eFetoMhMe4j7TtrnxLo4chm02z+sAhl4yv6yxO2IgNQSe4h7z9j7bn0V
7MieaF8Icl7BWfuAMLXg+6+97CHuP2efairVelncxB4SCxfsV02fsMbfWsYe
ALe+ueE=
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Directive[
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           Thickness[Large], 
           Opacity[0.5]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsY8qNFU578LjAOFPsXeW6Zk24ZSY
ww651teBO+bZz8xzdrvQJwOVX2L/7VtW+hReBYdZM0Fgpf28pFjTd28VoOrX
2Vf9SwmZJKzo8CYQJLLRXnK5b7zGEgWo/i32Ng0dje7N8g5c1xcX2HJtty9R
s7jbIioLNW+nPeujj8sMzaQcNGP6D33V2GOv/vq99ndRcaj5++wva9ukX74n
7LAEqPv64gP2F23CSzi3CEDtO2hvs8tGPT2F28EYDA7bP3j7KvnuPVao/Ufs
ZRz3xCl+Z3A4/FUDaMNR+62VXuxFjT/tIe45bv+pPkvnStsn+yCwhSfs/e/N
9nN8/9Ie4r6T9ie3MKuJFT20f1gFMvCU/e1js7RONF6zh7j3jL3P9wsbbp0+
bV8Icl7BWfslpppSOpkH7CHuP2f//WC2nFrzJntILFywdzXdf1Ti42J7ALp0
unI=
           "]]}}}, {}}}, {
     PlotRange -> {{-0.3, 0.25}, {0, 40}}, 
      Frame -> {True, False, False, False}, LabelStyle -> 
      Directive[12, FontFamily -> "Helvetica"], 
      FrameTicksStyle -> {
       FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, Epilog -> {
        Text[
         Style[
         "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=-0.1", 12, FontFamily -> "Helvetica"], 
         Scaled[{
           Rational[7, 8], 
           Rational[3, 4]}]], 
        Text[
         Style["A", 14, Bold, FontFamily -> "Helvetica"], 
         Scaled[{0.05, 0.95}]], 
        Text[
         Style["platykurtic", 14, FontFamily -> "Helvetica"], 
         Scaled[{
           Rational[7, 8], 
           Rational[1, 2]}]]}, AxesLabel -> {None, None}, AspectRatio -> 
      GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0., 0.}, Method -> {}, 
      PlotRange -> {All, All}, PlotRangeClipping -> True, 
      PlotRangePadding -> {Automatic, Automatic}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          RGBColor[0.24720000000000014`, 0.24, 0.6], 
          Thickness[Large], 
          Opacity[0.5]], 
         Directive[
          RGBColor[0.6, 0.24, 0.4428931686004542], 
          Thickness[Large], 
          Opacity[0.5]]}, {
         Style["1-step", 12, FontFamily -> "Helvetica"], 
         Style["2-step", 12, FontFamily -> "Helvetica"]}, LegendLayout -> 
        "Column", LegendMarkers -> False]], 
      Scaled[{0.1875, 
        Rational[1, 2]}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{3.7849044325029488`*^9, 3.784904471749628*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Leptokurtic (Laplace, panel B)", "Subsubsection",
 CellChangeTimes->{
  3.779471050457033*^9, 3.780063971413493*^9, {3.784904145488882*^9, 
   3.7849041464008293`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"-", "0.3"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"xmax", "=", "0.25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ymax", "=", "40"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"N0", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", 
   RowBox[{"-", "0.1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xint", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"type", "=", "\"\<lepto\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", "random", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        RowBox[{"fm", "[", 
         RowBox[{"m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "xmin", ",", "xmax", ",", "xint"}], "}"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"(*", "established", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        FractionBox[
         RowBox[{
          RowBox[{"fm", "[", 
           RowBox[{
           "m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], "]"}], 
          RowBox[{"pest", "[", 
           RowBox[{"m2", "-", "mwt"}], "]"}]}], 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"fm", "[", 
             RowBox[{
             "m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
             "]"}], 
            RowBox[{"pest", "[", 
             RowBox[{"m2", "-", "mwt"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"m2", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], "}"}],
       ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "mwt", ",", "xmax", ",", "xint"}], "}"}]}], "]"}]}],
    "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Gray", ",", "Dashed"}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Gray"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], 
     RowBox[{"(*", 
      RowBox[{",", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"LineLegend", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{"\"\<random\>\"", ",", "\"\<established\>\""}], "}"}]}], 
           "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"1.5", "/", "8"}], ",", 
             RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}]}], "*)"}], "]"}]}],
    ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"1", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        RowBox[{"g1m", "/.", 
         RowBox[{"m", "\[Rule]", "m2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "0", ",", "xmax", ",", "xint"}], "}"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"2", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"total", "=", 
      RowBox[{"Re", "[", 
       RowBox[{"g2denominator", "[", "mwt", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"m2", ",", 
         RowBox[{
          FractionBox["1", "total"], 
          RowBox[{"g2numerator", "[", 
           RowBox[{"mwt", ",", "m2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "xmax", ",", "xint"}], "}"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", 
         RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], 
     RowBox[{"(*", 
      RowBox[{",", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"LineLegend", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{"\"\<1-step\>\"", ",", "\"\<2-step\>\""}], "}"}]}], 
           "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"1.5", "/", "8"}], ",", 
             RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}]}], "*)"}], "]"}]}],
    ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StringForm", "[", 
   RowBox[{
    RowBox[{
    "datadir", "<>", 
     "\"\<dfe_``_N``_n``_U``_Es``_mmax``_mwt``_nreps100000.csv\>\""}], ",", 
    "type", ",", "N0", ",", "n", ",", 
    RowBox[{"NumberForm", "[", 
     RowBox[{
      RowBox[{"U", "//", "N"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "5"}], "}"}]}], "]"}], ",", 
    RowBox[{"NumberForm", "[", 
     RowBox[{"Es", ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}]}], "]"}], ",", 
    RowBox[{"NumberForm", "[", 
     RowBox[{"mmax", ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}]}], "]"}], ",", "mwt"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"ToString", "[", "%", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"onestep", "=", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"dat", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], "&"}]}], "]"}], 
    "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"twostep", "=", 
   RowBox[{
    RowBox[{"Select", "[", 
     RowBox[{"dat", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
    "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Histogram", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"onestep", ",", "twostep"}], "}"}], ",", "Automatic", ",", 
      "\"\<PDF\>\"", ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figS4b", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"oldtheory", ",", "data", ",", "theory"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "Automatic", ",", "Automatic", ",", "Automatic", ",", "Automatic"}], 
       "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", "\"\<Growth rate\>\"", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{
             RowBox[{"\"\<\!\(\*
StyleBox[SubscriptBox[\"m\", \"0\"],
FontSlant->\"Italic\"]\)=\>\"", "<>", 
              RowBox[{"ToString", "[", "mwt", "]"}]}], ",", "12", ",", 
             RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
           ",", 
           RowBox[{"Scaled", "@", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"7", "/", "8"}], ",", 
              RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ","}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<B\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<leptokurtic\>\"", ",", "14", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"7", "/", "8"}], ",", 
             RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}], 
       "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.751575679958344*^9, 3.751575707856783*^9}, {
   3.751575756450697*^9, 3.7515757716167583`*^9}, {3.751575806118587*^9, 
   3.751575998358532*^9}, {3.7515761122033863`*^9, 3.751576131258815*^9}, {
   3.751576172283361*^9, 3.751576174879533*^9}, {3.7515762580970592`*^9, 
   3.751576326479478*^9}, {3.7515763695777597`*^9, 3.751576370332637*^9}, {
   3.7515764174224873`*^9, 3.751576419272636*^9}, {3.751577234452231*^9, 
   3.751577234571393*^9}, {3.751598119440303*^9, 3.7515981249463587`*^9}, 
   3.751650792683756*^9, {3.751650847039688*^9, 3.751650935724555*^9}, {
   3.751651020576578*^9, 3.751651024456732*^9}, {3.7516511744217253`*^9, 
   3.751651271292901*^9}, {3.7516514431359167`*^9, 3.751651596903675*^9}, {
   3.75165167006041*^9, 3.7516517016743317`*^9}, {3.751651837998188*^9, 
   3.751651848660565*^9}, {3.751651901804051*^9, 3.751651938743773*^9}, {
   3.75165209054011*^9, 3.751652092941709*^9}, {3.751654667780588*^9, 
   3.751654726734174*^9}, {3.751654761368635*^9, 3.751654832140562*^9}, {
   3.751654888268785*^9, 3.7516548919393587`*^9}, 3.751656018745837*^9, {
   3.751656381036447*^9, 3.7516563882551813`*^9}, {3.7565000581145897`*^9, 
   3.7565001021945477`*^9}, {3.756500617190415*^9, 3.75650065699045*^9}, 
   3.75650069938904*^9, {3.756500741026494*^9, 3.756500755155011*^9}, {
   3.756501221346011*^9, 3.75650122389799*^9}, 3.756502363067445*^9, 
   3.756502628112669*^9, 3.7565026817972727`*^9, {3.756503286102932*^9, 
   3.756503290049591*^9}, 3.756503323237875*^9, {3.756503496903769*^9, 
   3.75650353646167*^9}, {3.7565038167736483`*^9, 3.756503833330291*^9}, {
   3.7565038702319183`*^9, 3.7565038987244377`*^9}, {3.7565039623685904`*^9, 
   3.7565039995283422`*^9}, 3.756511754548572*^9, 3.756511866105935*^9, {
   3.756511901000861*^9, 3.756511903883478*^9}, {3.7565119526094627`*^9, 
   3.756511957815688*^9}, {3.756512664854374*^9, 3.756512670495578*^9}, {
   3.7565186714828672`*^9, 3.756518674830636*^9}, {3.756518724785604*^9, 
   3.7565187318397303`*^9}, {3.756518775324299*^9, 3.75651877705446*^9}, {
   3.756518831207197*^9, 3.756518836010257*^9}, {3.7565191876130047`*^9, 
   3.7565192273750753`*^9}, 3.756557317943141*^9, 3.756565191609994*^9, {
   3.756565226853438*^9, 3.756565227347921*^9}, {3.756565372407086*^9, 
   3.756565372554656*^9}, {3.7642581275023746`*^9, 3.764258130547591*^9}, {
   3.764258191591094*^9, 3.7642582094474382`*^9}, 3.769438935312201*^9, {
   3.769440382123701*^9, 3.769440472454721*^9}, 3.769440550032837*^9, {
   3.769440597811926*^9, 3.76944060297188*^9}, {3.769440831103504*^9, 
   3.769440912756571*^9}, {3.769440959415164*^9, 3.769440994826437*^9}, {
   3.769441059064315*^9, 3.769441091058297*^9}, {3.769441130350876*^9, 
   3.76944116439666*^9}, {3.7694411991785088`*^9, 3.7694412021516743`*^9}, 
   3.76996874883585*^9, 3.769968810893046*^9, {3.771262388292754*^9, 
   3.771262479562519*^9}, {3.771262525425778*^9, 3.771262540854212*^9}, {
   3.771262571282227*^9, 3.771262676392552*^9}, 3.771262708817911*^9, {
   3.771262787550537*^9, 3.77126278925319*^9}, {3.771262848265294*^9, 
   3.7712628699284153`*^9}, {3.771263092625225*^9, 3.771263094812828*^9}, 
   3.771263271500595*^9, {3.771523030703679*^9, 3.7715230467362022`*^9}, {
   3.771523079011808*^9, 3.771523152186151*^9}, {3.77152320543019*^9, 
   3.771523315803763*^9}, {3.7715233464449253`*^9, 3.771523576781527*^9}, {
   3.771523631873809*^9, 3.7715236430826683`*^9}, {3.7715241526920757`*^9, 
   3.771524155896125*^9}, {3.7715242229465923`*^9, 3.771524257316955*^9}, {
   3.771524320220757*^9, 3.771524423589848*^9}, {3.771524462952353*^9, 
   3.771524468371491*^9}, 3.771524519796175*^9, {3.771524560722151*^9, 
   3.77152458745588*^9}, {3.7715456914503183`*^9, 3.771545693694459*^9}, 
   3.7715458002283154`*^9, {3.771545911589119*^9, 3.771545926111433*^9}, {
   3.77160975420442*^9, 3.7716097651557693`*^9}, {3.7716099182331963`*^9, 
   3.77160992062647*^9}, {3.771609967213895*^9, 3.771610003678589*^9}, {
   3.771610042996176*^9, 3.771610061906077*^9}, {3.771610106603993*^9, 
   3.771610114408716*^9}, {3.771610201107335*^9, 3.771610202727501*^9}, 
   3.771610248378283*^9, {3.7794686898536158`*^9, 3.7794688301324673`*^9}, {
   3.77946886396563*^9, 3.77946888729186*^9}, {3.779468925902836*^9, 
   3.7794689413547277`*^9}, {3.779469011076345*^9, 3.779469071332287*^9}, {
   3.779469527005124*^9, 3.779469555307827*^9}, {3.779469593442951*^9, 
   3.77946961429259*^9}, {3.779469796805294*^9, 3.779469866620295*^9}, {
   3.779469901788733*^9, 3.779470016571252*^9}, {3.779470051010948*^9, 
   3.779470158052433*^9}, {3.779470201565462*^9, 3.779470241549526*^9}, {
   3.7794705231999197`*^9, 3.779470523756588*^9}, {3.780062496794438*^9, 
   3.7800625066167603`*^9}, {3.780062909403524*^9, 3.780062912695772*^9}, {
   3.78006682464965*^9, 3.7800669013742*^9}, 3.7800669511491013`*^9, {
   3.7800677085607452`*^9, 3.780067712552669*^9}, 3.780068221807846*^9, {
   3.7822625629567738`*^9, 3.782262569292008*^9}, {3.782262640214355*^9, 
   3.782262640372933*^9}, {3.784904420528934*^9, 3.7849044266584167`*^9}, {
   3.784904456696473*^9, 3.784904463223031*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "izero"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Integral and error estimates are 0 on all integration \
subregions. Try increasing the value of the MinRecursion option. If value of \
integral may be 0, specify a finite value for the AccuracyGoal option. \\!\\(\
\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/NIntegrate\\\", ButtonNote -> \
\\\"NIntegrate::izero\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.779470161635611*^9, 3.779470252570225*^9, 3.779470536241621*^9, 
   3.7800629229816113`*^9, {3.780066866886881*^9, 3.780066911485097*^9}, 
   3.780066966276246*^9, 3.78006781916588*^9, 3.780068240689426*^9, 
   3.782262582275881*^9, 3.782262653314526*^9, 3.784904442919694*^9, 
   3.7849044820508413`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
      LineBox[CompressedData["
1:eJwtU3tI01EUntN8v/aAUlIyrUaalbYSxJ0bRCqZNQVJ85GS+Uema0E5k7Qw
UyIt0TLfopUW2srhi+lVp2ibE1/zEY2cY+YrTNJMi0x/93fgcjmce7/vO+d+
1yUuOSSeyWAwfLbXzu5NxSjWVuiGqkzGIK97jReZN4LTytr3r69MwaKwxfnh
4jDucwpNn6mchgBdKrfBfxgzHS+uB3EMUCPys5yoHsKBjsyD3xMWgEHFEJY3
nfUWh/+AndvClkFcaeI2yDdaBeq4SI0znrs7O3n+hm2ybcYB/FljiL6u/QsU
vE6J/Qpch7uZRuglFZ/wfPAN1U2lMQqhAPuxyONN2/sWU7SD5mfZh7eytE5m
cgtEye/uxQINDprpsEYUXGoPDpbk7D5ea4dIvwoc9Gc/w9eThUh/XXjy8r6A
4hg2qqYEduI1JXspLIKDiP4OfFU2NmFgcRHRK8fXpkxDzdO4qIjS14pnWWtf
6p9xaT3NODFQ0vf6Apfml+HMSJkJq5mDFii+D9jdlvs0Sc2m8RtwWaxGGlXK
ovHqsJVawPx1zB6lUPdr8PwhlxQp3wZJqfPleMCofsl+3AKJqHoB5tt2/YuL
N0UZVJ6J74wIwGBsjBh0LDBrj0SVbAFdB8Wy996Ajxt0XgDuhblSXuIqdBJ8
OH8yJ9asaZmu14DKs2+Rbz4HlUQfPBLu+Zqt0NHv2wDRvq1htS+mYIn0B+IV
7yn/n8OQRvqH2cHpb1X3+sGazAeWmeOqdr9OKCXzg81wtrV4TgYeZL5wNCv3
br7DWxq/A8yyVVfO5FbQfuuEV+/u71Lcyqf5uqCZ06t9MJkJJ8j7gjKbN+vV
fJvm74FsjXxofDwBeog/IFnSZaW3uQS0f0Btnet46pw/0P4CN1V6fUwJH4qJ
/8CnvDfKn+cKM8SfsPGkMWPUyx4OE/9CUWGS5LTdpkBM/A1tvWmqA3q9oI34
H/RakVDSNCAwIv8DNA51EezHjYL/hVay3A==
       "]]}, 
     {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQPWsmCOzczwAF3NcXF9hybd8vWXAltPwgg0O1yDr3
h1Vb9k91DQ6KkxJweBO4Q6719cb9NVoSe2TPiznsBPICd6zbzzTDVT7CRMYB
Yt7K/RP/FH734lFwqAHrX7L/RJFpa7WxosMOsPp5+x+GTI28NFkRKj9l/zcT
ppoldooODWB+y/7dk+u1f/krOMDcZfLK0NvwmqxDBUTeXshnR6lNrhSUP8X+
0ak35mkbxWDm2x/dkcfX/lwIZr/9wjtznydP4HOYAXGf/RxJv58/f7JD1a+z
31WuseagPRPMf/YrLRO8+z/+sq+C+N/eh2OZnrPHZ3suSPjY2y3y9ZLc+8oe
Gn72/QleC3Z+emivEdN/6KvGHnvTpHjLeX7X7SHm77PPbLFKa7c/a78EqPv6
4gP2D/c/XK+//aD9a7B9B+1fzVu2U3vjFntjMDhsb3GQ58Zt1+X2kPA/Ys//
yOhvuvZM+8NfQTYctZ/l/fith1KXPSS+jtv/dE+I+MJYZQ82LvCEvelkO82t
hzLswc6bedJ+2tSmypWNYfYPwR46Zb9kq7+KYq2zvSbYvWfsGfolZ6zlNLAv
BDmv4Ky98Xp1yUcskvaQ+D1nH75D5Xl3IZM9JDYu2B9Je/ZDbN5LOwAJBgl/

       "]]}}, {}}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.06999999999999999]], {{}, 
     {RGBColor[0.24720000000000014`, 0.24, 0.6], Opacity[0.5], EdgeForm[
      Opacity[0.06999999999999999]], 
      RectangleBox[{0., 0.}, 
       NCache[{0.005, Rational[65300, 30933]}, {0.005, 2.1110141273074063`}],
       RoundingRadius->0], 
      RectangleBox[{0.005, 0.}, 
       NCache[{0.01, Rational[84200, 30933]}, {0.01, 2.7220120906475285`}],
       RoundingRadius->0], 
      RectangleBox[{0.01, 0.}, 
       NCache[{0.015, Rational[34600, 10311]}, {0.015, 3.355639608185433}],
       RoundingRadius->0], 
      RectangleBox[{0.015, 0.}, 
       NCache[{0.02, Rational[19000, 4419]}, {0.02, 4.2996152975786375`}],
       RoundingRadius->0], 
      RectangleBox[{0.02, 0.}, 
       NCache[{0.025, Rational[151000, 30933]}, {0.025, 4.881518119807326}],
       RoundingRadius->0], 
      RectangleBox[{0.025, 0.}, 
       NCache[{0.03, Rational[25100, 4419]}, {0.03, 5.680018103643358}],
       RoundingRadius->0], 
      RectangleBox[{0.03, 0.}, 
       NCache[{0.035, Rational[191900, 30933]}, {0.035, 6.203730643649177}],
       RoundingRadius->0], 
      RectangleBox[{0.035, 0.}, 
       NCache[{0.04, Rational[21500, 3437]}, {0.04, 6.255455338958394}],
       RoundingRadius->0], 
      RectangleBox[{0.04, 0.}, 
       NCache[{0.045, Rational[205600, 30933]}, {0.045, 6.646623347234345}],
       RoundingRadius->0], 
      RectangleBox[{0.045, 0.}, 
       NCache[{0.05, Rational[213700, 30933]}, {0.05, 6.908479617237255}],
       RoundingRadius->0], 
      RectangleBox[{0.05, 0.}, 
       NCache[{0.055, Rational[221600, 30933]}, {0.055, 7.163870300326512}],
       RoundingRadius->0], 
      RectangleBox[{0.055, 0.}, 
       NCache[{0.06, Rational[231400, 30933]}, {0.06, 7.480684059095465}],
       RoundingRadius->0], 
      RectangleBox[{0.06, 0.}, 
       NCache[{0.065, Rational[75100, 10311]}, {0.065, 7.283483658229076}],
       RoundingRadius->0], 
      RectangleBox[{0.065, 0.}, 
       NCache[{0.07, Rational[10600, 1473]}, {0.07, 7.196198234894773}],
       RoundingRadius->0], 
      RectangleBox[{0.07, 0.}, 
       NCache[{0.075, Rational[73100, 10311]}, {0.075, 7.089516050819513}],
       RoundingRadius->0], 
      RectangleBox[{0.075, 0.}, 
       NCache[{0.08, Rational[208700, 30933]}, {0.08, 6.746839944395952}],
       RoundingRadius->0], 
      RectangleBox[{0.08, 0.}, 
       NCache[{0.085, Rational[209000, 30933]}, {0.085, 6.756538324766431}],
       RoundingRadius->0], 
      RectangleBox[{0.085, 0.}, 
       NCache[{0.09, Rational[204500, 30933]}, {0.09, 6.6110626192092585`}],
       RoundingRadius->0], 
      RectangleBox[{0.09, 0.}, 
       NCache[{0.095, Rational[64000, 10311]}, {0.095, 6.206963437106003}],
       RoundingRadius->0], 
      RectangleBox[{0.095, 0.}, 
       NCache[{0.1, Rational[198200, 30933]}, {0.1, 6.407396631429218}],
       RoundingRadius->0], 
      RectangleBox[{0.1, 0.}, 
       NCache[{0.105, Rational[180800, 30933]}, {0.105, 5.844890569941486}],
       RoundingRadius->0], 
      RectangleBox[{0.105, 0.}, 
       NCache[{0.11, Rational[179300, 30933]}, {0.11, 5.796398668089096}],
       RoundingRadius->0], 
      RectangleBox[{0.11, 0.}, 
       NCache[{0.115, Rational[53000, 10311]}, {0.115, 5.140141596353409}],
       RoundingRadius->0], 
      RectangleBox[{0.115, 0.}, 
       NCache[{0.12, Rational[155900, 30933]}, {0.12, 5.039924999191801}],
       RoundingRadius->0], 
      RectangleBox[{0.12, 0.}, 
       NCache[{0.125, Rational[49900, 10311]}, {0.125, 4.839491804868587}],
       RoundingRadius->0], 
      RectangleBox[{0.125, 0.}, 
       NCache[{0.13, Rational[48500, 10311]}, {0.13, 4.703714479681893}],
       RoundingRadius->0], 
      RectangleBox[{0.13, 0.}, 
       NCache[{0.135, Rational[125900, 30933]}, {0.135, 4.070086962143988}],
       RoundingRadius->0], 
      RectangleBox[{0.135, 0.}, 
       NCache[{0.14, Rational[40000, 10311]}, {0.14, 3.879352148191252}],
       RoundingRadius->0], 
      RectangleBox[{0.14, 0.}, 
       NCache[{0.145, Rational[110800, 30933]}, {0.145, 3.581935150163256}],
       RoundingRadius->0], 
      RectangleBox[{0.145, 0.}, 
       NCache[{0.15, Rational[106100, 30933]}, {0.15, 3.429993857692432}],
       RoundingRadius->0], 
      RectangleBox[{0.15, 0.}, 
       NCache[{0.155, Rational[32300, 10311]}, {0.155, 3.132576859664436}],
       RoundingRadius->0], 
      RectangleBox[{0.155, 0.}, 
       NCache[{0.16, Rational[89900, 30933]}, {0.16, 2.906281317686613}],
       RoundingRadius->0], 
      RectangleBox[{0.16, 0.}, 
       NCache[{0.165, Rational[9400, 3437]}, {0.165, 2.7349432644748326`}],
       RoundingRadius->0], 
      RectangleBox[{0.165, 0.}, 
       NCache[{0.17, Rational[11300, 4419]}, {0.17, 2.5571396243494005`}],
       RoundingRadius->0], 
      RectangleBox[{0.17, 0.}, 
       NCache[{0.175, Rational[22900, 10311]}, {0.175, 2.2209291048394917`}],
       RoundingRadius->0], 
      RectangleBox[{0.175, 0.}, 
       NCache[{0.18, Rational[66100, 30933]}, {0.18, 2.1368764749620146`}],
       RoundingRadius->0], 
      RectangleBox[{0.18, 0.}, 
       NCache[{0.185, Rational[60400, 30933]}, {0.185, 1.9526072479229302`}],
       RoundingRadius->0], 
      RectangleBox[{0.185, 0.}, 
       NCache[{0.19, Rational[56800, 30933]}, {0.19, 1.8362266834771925`}],
       RoundingRadius->0], 
      RectangleBox[{0.19, 0.}, 
       NCache[{0.195, Rational[50600, 30933]}, {0.195, 1.635793489153978}],
       RoundingRadius->0], 
      RectangleBox[{0.195, 0.}, 
       NCache[{0.2, Rational[15200, 10311]}, {0.2, 1.4741538163126757`}],
       RoundingRadius->0], 
      RectangleBox[{0.2, 0.}, 
       NCache[{0.205, Rational[2000, 1473]}, {0.205, 1.3577732518669383`}],
       RoundingRadius->0], 
      RectangleBox[{0.205, 0.}, 
       NCache[{0.21, Rational[5500, 4419]}, {0.21, 1.2446254808780266`}],
       RoundingRadius->0], 
      RectangleBox[{0.21, 0.}, 
       NCache[{0.215, Rational[37300, 30933]}, {0.215, 1.2058319593961142`}],
       RoundingRadius->0], 
      RectangleBox[{0.215, 0.}, 
       NCache[{0.22, Rational[31400, 30933]}, {0.22, 1.0150971454433777`}],
       RoundingRadius->0], 
      RectangleBox[{0.22, 0.}, 
       NCache[{0.225, Rational[31100, 30933]}, {0.225, 1.0053987650728995`}],
       RoundingRadius->0], 
      RectangleBox[{0.225, 0.}, 
       NCache[{0.23, Rational[8300, 10311]}, {0.23, 0.8049655707496848}],
       RoundingRadius->0], 
      RectangleBox[{0.23, 0.}, 
       NCache[{0.235, Rational[1100, 1473]}, {0.235, 0.7467752885268161}],
       RoundingRadius->0], 
      RectangleBox[{0.235, 0.}, 
       NCache[{0.24, Rational[20600, 30933]}, {0.24, 0.6659554521061649}],
       RoundingRadius->0], 
      RectangleBox[{0.24, 0.}, 
       NCache[{0.245, Rational[17300, 30933]}, {0.245, 0.5592732680309055}],
       RoundingRadius->0], 
      RectangleBox[{0.245, 0.}, 
       NCache[{0.25, Rational[17000, 30933]}, {0.25, 0.5495748876604274}],
       RoundingRadius->0], 
      RectangleBox[{0.25, 0.}, 
       NCache[{0.255, Rational[14800, 30933]}, {0.255, 0.47845343161025444`}],
       
       RoundingRadius->0], 
      RectangleBox[{0.255, 0.}, 
       NCache[{0.26, Rational[13100, 30933]}, {0.26, 0.42349594284421166`}],
       RoundingRadius->0], 
      RectangleBox[{0.26, 0.}, 
       NCache[{0.265, Rational[4100, 10311]}, {0.265, 0.39763359518960334`}],
       RoundingRadius->0], 
      RectangleBox[{0.265, 0.}, 
       NCache[{0.27, Rational[3700, 10311]}, {0.27, 0.35884007370769083`}],
       RoundingRadius->0], 
      RectangleBox[{0.27, 0.}, 
       NCache[{0.275, Rational[8800, 30933]}, {0.275, 0.2844858242006918}],
       RoundingRadius->0], 
      RectangleBox[{0.275, 0.}, 
       NCache[{0.28, Rational[2300, 10311]}, {0.28, 0.223062748520997}],
       RoundingRadius->0], 
      RectangleBox[{0.28, 0.}, 
       NCache[{0.285, Rational[900, 3437]}, {0.285, 0.2618562700029095}],
       RoundingRadius->0], 
      RectangleBox[{0.285, 0.}, 
       NCache[{0.29, Rational[2200, 10311]}, {0.29, 0.21336436815051887`}],
       RoundingRadius->0], 
      RectangleBox[{0.29, 0.}, 
       NCache[{0.295, Rational[5500, 30933]}, {0.295, 0.1778036401254324}],
       RoundingRadius->0], 
      RectangleBox[{0.295, 0.}, 
       NCache[{0.3, Rational[3400, 30933]}, {0.3, 0.10991497753208547`}],
       RoundingRadius->0], 
      RectangleBox[{0.3, 0.}, 
       NCache[{0.305, Rational[4400, 30933]}, {0.305, 0.1422429121003459}],
       RoundingRadius->0], 
      RectangleBox[{0.305, 0.}, 
       NCache[{0.31, Rational[1100, 10311]}, {0.31, 0.10668218407525944`}],
       RoundingRadius->0], 
      RectangleBox[{0.31, 0.}, 
       NCache[{0.315, Rational[1300, 10311]}, {0.315, 0.1260789448162157}],
       RoundingRadius->0], 
      RectangleBox[{0.315, 0.}, 
       NCache[{0.32, Rational[3400, 30933]}, {0.32, 0.10991497753208547`}],
       RoundingRadius->0], 
      RectangleBox[{0.32, 0.}, 
       NCache[{0.325, Rational[300, 3437]}, {0.325, 0.08728542333430317}],
       RoundingRadius->0], 
      RectangleBox[{0.325, 0.}, 
       NCache[{0.33, Rational[100, 1473]}, {0.33, 0.06788866259334692}],
       RoundingRadius->0], 
      RectangleBox[{0.33, 0.}, 
       NCache[{0.335, Rational[400, 10311]}, {0.335, 0.03879352148191252}],
       RoundingRadius->0], 
      RectangleBox[{0.335, 0.}, 
       NCache[{0.34, Rational[1000, 30933]}, {0.34, 0.032327934568260434`}],
       RoundingRadius->0], 
      RectangleBox[{0.34, 0.}, 
       NCache[{0.345, Rational[200, 4419]}, {0.345, 0.04525910839556461}],
       RoundingRadius->0], 
      RectangleBox[{0.345, 0.}, 
       NCache[{0.35, Rational[400, 10311]}, {0.35, 0.03879352148191252}],
       RoundingRadius->0], 
      RectangleBox[{0.35, 0.}, 
       NCache[{0.355, Rational[100, 4419]}, {0.355, 0.022629554197782304`}],
       RoundingRadius->0], 
      RectangleBox[{0.355, 0.}, 
       NCache[{0.36, Rational[200, 4419]}, {0.36, 0.04525910839556461}],
       RoundingRadius->0], 
      RectangleBox[{0.36, 0.}, 
       NCache[{0.365, Rational[400, 10311]}, {0.365, 0.03879352148191252}],
       RoundingRadius->0], 
      RectangleBox[{0.365, 0.}, 
       NCache[{0.37, Rational[100, 4419]}, {0.37, 0.022629554197782304`}],
       RoundingRadius->0], 
      RectangleBox[{0.37, 0.}, 
       NCache[{0.375, Rational[200, 10311]}, {0.375, 0.01939676074095626}],
       RoundingRadius->0], 
      RectangleBox[{0.375, 0.}, 
       NCache[{0.38, Rational[200, 30933]}, {0.38, 0.006465586913652087}],
       RoundingRadius->0], 
      RectangleBox[{0.38, 0.}, 
       NCache[{0.385, Rational[100, 30933]}, {0.385, 0.0032327934568260434`}],
       
       RoundingRadius->0], 
      RectangleBox[{0.385, 0.}, 
       NCache[{0.39, Rational[400, 30933]}, {0.39, 0.012931173827304174`}],
       RoundingRadius->0], 
      RectangleBox[{0.39, 0.}, 
       NCache[{0.395, Rational[200, 30933]}, {0.395, 0.006465586913652087}],
       RoundingRadius->0], 
      RectangleBox[{0.395, 0.}, 
       NCache[{0.4, Rational[200, 30933]}, {0.4, 0.006465586913652087}],
       RoundingRadius->0], 
      RectangleBox[{0.4, 0.}, 
       NCache[{0.405, Rational[200, 30933]}, {0.405, 0.006465586913652087}],
       RoundingRadius->0], 
      RectangleBox[{0.405, 0.}, 
       NCache[{0.41, Rational[100, 30933]}, {0.41, 0.0032327934568260434`}],
       RoundingRadius->0], 
      RectangleBox[{0.41, 0.}, 
       NCache[{0.415, Rational[200, 30933]}, {0.415, 0.006465586913652087}],
       RoundingRadius->0], RectangleBox[{0.415, 0.}, {0.42, 0},
       RoundingRadius->0], RectangleBox[{0.42, 0.}, {0.425, 0},
       RoundingRadius->0], RectangleBox[{0.425, 0.}, {0.43, 0},
       RoundingRadius->0], RectangleBox[{0.43, 0.}, {0.435, 0},
       RoundingRadius->0], RectangleBox[{0.435, 0.}, {0.44, 0},
       RoundingRadius->0], RectangleBox[{0.44, 0.}, {0.445, 0},
       RoundingRadius->0], RectangleBox[{0.445, 0.}, {0.45, 0},
       RoundingRadius->0]}, {}, {}}, {{}, 
     {RGBColor[0.6, 0.24, 0.4428931686004542], Opacity[0.5], EdgeForm[Opacity[
      0.06999999999999999]], 
      RectangleBox[{0., 0.}, 
       NCache[{0.005, Rational[975, 758]}, {0.005, 1.2862796833773087`}],
       RoundingRadius->0], 
      RectangleBox[{0.005, 0.}, 
       NCache[{0.01, Rational[725, 379]}, {0.01, 1.912928759894459}],
       RoundingRadius->0], 
      RectangleBox[{0.01, 0.}, 
       NCache[{0.015, Rational[1725, 758]}, {0.015, 2.2757255936675462`}],
       RoundingRadius->0], 
      RectangleBox[{0.015, 0.}, 
       NCache[{0.02, Rational[2025, 758]}, {0.02, 2.6715039577836412`}],
       RoundingRadius->0], 
      RectangleBox[{0.02, 0.}, 
       NCache[{0.025, Rational[2925, 758]}, {0.025, 3.8588390501319263`}],
       RoundingRadius->0], 
      RectangleBox[{0.025, 0.}, 
       NCache[{0.03, Rational[1475, 379]}, {0.03, 3.891820580474934}],
       RoundingRadius->0], 
      RectangleBox[{0.03, 0.}, 
       NCache[{0.035, Rational[2000, 379]}, {0.035, 5.277044854881266}],
       RoundingRadius->0], 
      RectangleBox[{0.035, 0.}, 
       NCache[{0.04, Rational[3975, 758]}, {0.04, 5.244063324538258}],
       RoundingRadius->0], 
      RectangleBox[{0.04, 0.}, 
       NCache[{0.045, Rational[2300, 379]}, {0.045, 6.068601583113456}],
       RoundingRadius->0], 
      RectangleBox[{0.045, 0.}, 
       NCache[{0.05, Rational[2400, 379]}, {0.05, 6.332453825857519}],
       RoundingRadius->0], 
      RectangleBox[{0.05, 0.}, 
       NCache[{0.055, Rational[2375, 379]}, {0.055, 6.266490765171504}],
       RoundingRadius->0], 
      RectangleBox[{0.055, 0.}, 
       NCache[{0.06, Rational[2550, 379]}, {0.06, 6.728232189973615}],
       RoundingRadius->0], 
      RectangleBox[{0.06, 0.}, 
       NCache[{0.065, Rational[2475, 379]}, {0.065, 6.530343007915567}],
       RoundingRadius->0], 
      RectangleBox[{0.065, 0.}, 
       NCache[{0.07, Rational[4875, 758]}, {0.07, 6.431398416886544}],
       RoundingRadius->0], 
      RectangleBox[{0.07, 0.}, 
       NCache[{0.075, Rational[2750, 379]}, {0.075, 7.255936675461742}],
       RoundingRadius->0], 
      RectangleBox[{0.075, 0.}, 
       NCache[{0.08, Rational[5625, 758]}, {0.08, 7.420844327176781}],
       RoundingRadius->0], 
      RectangleBox[{0.08, 0.}, 
       NCache[{0.085, Rational[2375, 379]}, {0.085, 6.266490765171504}],
       RoundingRadius->0], 
      RectangleBox[{0.085, 0.}, 
       NCache[{0.09, Rational[4825, 758]}, {0.09, 6.3654353562005275`}],
       RoundingRadius->0], 
      RectangleBox[{0.09, 0.}, 
       NCache[{0.095, Rational[4675, 758]}, {0.095, 6.167546174142481}],
       RoundingRadius->0], 
      RectangleBox[{0.095, 0.}, 
       NCache[{0.1, Rational[4675, 758]}, {0.1, 6.167546174142481}],
       RoundingRadius->0], 
      RectangleBox[{0.1, 0.}, 
       NCache[{0.105, Rational[4625, 758]}, {0.105, 6.101583113456464}],
       RoundingRadius->0], 
      RectangleBox[{0.105, 0.}, 
       NCache[{0.11, Rational[1875, 379]}, {0.11, 4.947229551451187}],
       RoundingRadius->0], 
      RectangleBox[{0.11, 0.}, 
       NCache[{0.115, Rational[3925, 758]}, {0.115, 5.178100263852243}],
       RoundingRadius->0], 
      RectangleBox[{0.115, 0.}, 
       NCache[{0.12, Rational[1850, 379]}, {0.12, 4.881266490765172}],
       RoundingRadius->0], 
      RectangleBox[{0.12, 0.}, 
       NCache[{0.125, Rational[4075, 758]}, {0.125, 5.375989445910291}],
       RoundingRadius->0], 
      RectangleBox[{0.125, 0.}, 
       NCache[{0.13, Rational[3725, 758]}, {0.13, 4.91424802110818}],
       RoundingRadius->0], 
      RectangleBox[{0.13, 0.}, 
       NCache[{0.135, Rational[3525, 758]}, {0.135, 4.650395778364116}],
       RoundingRadius->0], 
      RectangleBox[{0.135, 0.}, 
       NCache[{0.14, Rational[3175, 758]}, {0.14, 4.188654353562005}],
       RoundingRadius->0], 
      RectangleBox[{0.14, 0.}, 
       NCache[{0.145, Rational[1625, 379]}, {0.145, 4.287598944591029}],
       RoundingRadius->0], 
      RectangleBox[{0.145, 0.}, 
       NCache[{0.15, Rational[3375, 758]}, {0.15, 4.452506596306069}],
       RoundingRadius->0], 
      RectangleBox[{0.15, 0.}, 
       NCache[{0.155, Rational[1475, 379]}, {0.155, 3.891820580474934}],
       RoundingRadius->0], 
      RectangleBox[{0.155, 0.}, 
       NCache[{0.16, Rational[2375, 758]}, {0.16, 3.133245382585752}],
       RoundingRadius->0], 
      RectangleBox[{0.16, 0.}, 
       NCache[{0.165, Rational[1075, 379]}, {0.165, 2.836411609498681}],
       RoundingRadius->0], 
      RectangleBox[{0.165, 0.}, 
       NCache[{0.17, Rational[825, 379]}, {0.17, 2.1767810026385224`}],
       RoundingRadius->0], 
      RectangleBox[{0.17, 0.}, 
       NCache[{0.175, Rational[925, 379]}, {0.175, 2.440633245382586}],
       RoundingRadius->0], 
      RectangleBox[{0.175, 0.}, 
       NCache[{0.18, Rational[2425, 758]}, {0.18, 3.199208443271768}],
       RoundingRadius->0], 
      RectangleBox[{0.18, 0.}, 
       NCache[{0.185, Rational[1575, 758]}, {0.185, 2.0778364116094985`}],
       RoundingRadius->0], 
      RectangleBox[{0.185, 0.}, 
       NCache[{0.19, Rational[1875, 758]}, {0.19, 2.4736147757255935`}],
       RoundingRadius->0], 
      RectangleBox[{0.19, 0.}, 
       NCache[{0.195, Rational[1125, 379]}, {0.195, 2.9683377308707124`}],
       RoundingRadius->0], 
      RectangleBox[{0.195, 0.}, 
       NCache[{0.2, Rational[800, 379]}, {0.2, 2.1108179419525066`}],
       RoundingRadius->0], 
      RectangleBox[{0.2, 0.}, 
       NCache[{0.205, Rational[750, 379]}, {0.205, 1.9788918205804749`}],
       RoundingRadius->0], 
      RectangleBox[{0.205, 0.}, 
       NCache[{0.21, Rational[700, 379]}, {0.21, 1.8469656992084433`}],
       RoundingRadius->0], 
      RectangleBox[{0.21, 0.}, 
       NCache[{0.215, Rational[525, 379]}, {0.215, 1.3852242744063326`}],
       RoundingRadius->0], 
      RectangleBox[{0.215, 0.}, 
       NCache[{0.22, Rational[775, 758]}, {0.22, 1.0224274406332454`}],
       RoundingRadius->0], 
      RectangleBox[{0.22, 0.}, 
       NCache[{0.225, Rational[1225, 758]}, {0.225, 1.616094986807388}],
       RoundingRadius->0], 
      RectangleBox[{0.225, 0.}, 
       NCache[{0.23, Rational[1225, 758]}, {0.23, 1.616094986807388}],
       RoundingRadius->0], 
      RectangleBox[{0.23, 0.}, 
       NCache[{0.235, Rational[275, 379]}, {0.235, 0.7255936675461742}],
       RoundingRadius->0], 
      RectangleBox[{0.235, 0.}, 
       NCache[{0.24, Rational[525, 758]}, {0.24, 0.6926121372031663}],
       RoundingRadius->0], 
      RectangleBox[{0.24, 0.}, 
       NCache[{0.245, Rational[400, 379]}, {0.245, 1.0554089709762533`}],
       RoundingRadius->0], 
      RectangleBox[{0.245, 0.}, 
       NCache[{0.25, Rational[275, 379]}, {0.25, 0.7255936675461742}],
       RoundingRadius->0], 
      RectangleBox[{0.25, 0.}, 
       NCache[{0.255, Rational[300, 379]}, {0.255, 0.7915567282321899}],
       RoundingRadius->0], 
      RectangleBox[{0.255, 0.}, 
       NCache[{0.26, Rational[175, 379]}, {0.26, 0.46174142480211083`}],
       RoundingRadius->0], 
      RectangleBox[{0.26, 0.}, 
       NCache[{0.265, Rational[300, 379]}, {0.265, 0.7915567282321899}],
       RoundingRadius->0], 
      RectangleBox[{0.265, 0.}, 
       NCache[{0.27, Rational[225, 379]}, {0.27, 0.5936675461741425}],
       RoundingRadius->0], 
      RectangleBox[{0.27, 0.}, 
       NCache[{0.275, Rational[175, 379]}, {0.275, 0.46174142480211083`}],
       RoundingRadius->0], 
      RectangleBox[{0.275, 0.}, 
       NCache[{0.28, Rational[225, 758]}, {0.28, 0.29683377308707126`}],
       RoundingRadius->0], 
      RectangleBox[{0.28, 0.}, 
       NCache[{0.285, Rational[150, 379]}, {0.285, 0.39577836411609496`}],
       RoundingRadius->0], 
      RectangleBox[{0.285, 0.}, 
       NCache[{0.29, Rational[125, 379]}, {0.29, 0.32981530343007914`}],
       RoundingRadius->0], 
      RectangleBox[{0.29, 0.}, 
       NCache[{0.295, Rational[325, 758]}, {0.295, 0.4287598944591029}],
       RoundingRadius->0], 
      RectangleBox[{0.295, 0.}, 
       NCache[{0.3, Rational[125, 758]}, {0.3, 0.16490765171503957`}],
       RoundingRadius->0], 
      RectangleBox[{0.3, 0.}, 
       NCache[{0.305, Rational[225, 758]}, {0.305, 0.29683377308707126`}],
       RoundingRadius->0], 
      RectangleBox[{0.305, 0.}, 
       NCache[{0.31, Rational[175, 758]}, {0.31, 0.23087071240105542`}],
       RoundingRadius->0], 
      RectangleBox[{0.31, 0.}, 
       NCache[{0.315, Rational[75, 379]}, {0.315, 0.19788918205804748`}],
       RoundingRadius->0], 
      RectangleBox[{0.315, 0.}, 
       NCache[{0.32, Rational[125, 758]}, {0.32, 0.16490765171503957`}],
       RoundingRadius->0], 
      RectangleBox[{0.32, 0.}, 
       NCache[{0.325, Rational[75, 379]}, {0.325, 0.19788918205804748`}],
       RoundingRadius->0], 
      RectangleBox[{0.325, 0.}, 
       NCache[{0.33, Rational[50, 379]}, {0.33, 0.13192612137203166`}],
       RoundingRadius->0], 
      RectangleBox[{0.33, 0.}, 
       NCache[{0.335, Rational[75, 758]}, {0.335, 0.09894459102902374}],
       RoundingRadius->0], 
      RectangleBox[{0.335, 0.}, 
       NCache[{0.34, Rational[75, 758]}, {0.34, 0.09894459102902374}],
       RoundingRadius->0], 
      RectangleBox[{0.34, 0.}, 
       NCache[{0.345, Rational[25, 758]}, {0.345, 0.032981530343007916`}],
       RoundingRadius->0], 
      RectangleBox[{0.345, 0.}, 
       NCache[{0.35, Rational[75, 758]}, {0.35, 0.09894459102902374}],
       RoundingRadius->0], 
      RectangleBox[{0.35, 0.}, 
       NCache[{0.355, Rational[25, 379]}, {0.355, 0.06596306068601583}],
       RoundingRadius->0], RectangleBox[{0.355, 0.}, {0.36, 0},
       RoundingRadius->0], 
      RectangleBox[{0.36, 0.}, 
       NCache[{0.365, Rational[25, 758]}, {0.365, 0.032981530343007916`}],
       RoundingRadius->0], RectangleBox[{0.365, 0.}, {0.37, 0},
       RoundingRadius->0], 
      RectangleBox[{0.37, 0.}, 
       NCache[{0.375, Rational[25, 758]}, {0.375, 0.032981530343007916`}],
       RoundingRadius->0], 
      RectangleBox[{0.375, 0.}, 
       NCache[{0.38, Rational[25, 379]}, {0.38, 0.06596306068601583}],
       RoundingRadius->0], 
      RectangleBox[{0.38, 0.}, 
       NCache[{0.385, Rational[25, 379]}, {0.385, 0.06596306068601583}],
       RoundingRadius->0], RectangleBox[{0.385, 0.}, {0.39, 0},
       RoundingRadius->0], 
      RectangleBox[{0.39, 0.}, 
       NCache[{0.395, Rational[25, 379]}, {0.395, 0.06596306068601583}],
       RoundingRadius->0], RectangleBox[{0.395, 0.}, {0.4, 0},
       RoundingRadius->0], RectangleBox[{0.4, 0.}, {0.405, 0},
       RoundingRadius->0], RectangleBox[{0.405, 0.}, {0.41, 0},
       RoundingRadius->0], RectangleBox[{0.41, 0.}, {0.415, 0},
       RoundingRadius->0], RectangleBox[{0.415, 0.}, {0.42, 0},
       RoundingRadius->0], RectangleBox[{0.42, 0.}, {0.425, 0},
       RoundingRadius->0], RectangleBox[{0.425, 0.}, {0.43, 0},
       RoundingRadius->0], RectangleBox[{0.43, 0.}, {0.435, 0},
       RoundingRadius->0], RectangleBox[{0.435, 0.}, {0.44, 0},
       RoundingRadius->0], RectangleBox[{0.44, 0.}, {0.445, 0},
       RoundingRadius->0], 
      RectangleBox[{0.445, 0.}, 
       NCache[{0.45, Rational[25, 758]}, {0.45, 0.032981530343007916`}],
       RoundingRadius->0]}, {}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], Opacity[
      0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsT8Vtu3JyseyDhD+FHu2qm0uHK3q
DjvkWl8H7phnn7vQdto6OW2o/BL7w7LiggFK2g6zZoLASvv7ha+MrS9rQNWv
s0/6cG7LR3tVhzeBIJGN9p8jnxnJWShC9W+xX8+u/+DmdCkHruuLC2y5tttL
858WFF0qDDVvp72Q7ocdBle4HTRj+g991dhjv9VhAlvIGyao+fvsK5lOBbju
+GG/BKj7+uID9lJMvod1WN/bQ+w7aF/964bv0Q2P7I3B4LD9/S+qflVzr9pD
7D9iv+/yjX23vx+3P/xVA2jDUXvvwl0v3Ep22kPcc9z+QFze/Gu3VtoHgS08
Yc/7eFetoMhMe4j7TtrnxLo4chm02z+sAhl4yv6yxO2IgNQSe4h7z9j7bn0V
7MieaF8Icl7BWfuAMLXg+6+97CHuP2efairVelncxB4SCxfsV02fsMbfWsYe
ALe+ueE=
       "]]}, 
     {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], Opacity[0.5],
       LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsY8qNFU578LjAOFPsXeW6Zk24ZSY
ww651teBO+bZz8xzdrvQJwOVX2L/7VtW+hReBYdZM0Fgpf28pFjTd28VoOrX
2Vf9SwmZJKzo8CYQJLLRXnK5b7zGEgWo/i32Ng0dje7N8g5c1xcX2HJtty9R
s7jbIioLNW+nPeujj8sMzaQcNGP6D33V2GOv/vq99ndRcaj5++wva9ukX74n
7LAEqPv64gP2F23CSzi3CEDtO2hvs8tGPT2F28EYDA7bP3j7KvnuPVao/Ufs
ZRz3xCl+Z3A4/FUDaMNR+62VXuxFjT/tIe45bv+pPkvnStsn+yCwhSfs/e/N
9nN8/9Ie4r6T9ie3MKuJFT20f1gFMvCU/e1js7RONF6zh7j3jL3P9wsbbp0+
bV8Icl7BWfslpppSOpkH7CHuP2f//WC2nFrzJntILFywdzXdf1Ti42J7ALp0
unI=
       "]]}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
      TraditionalForm], 
     Scaled[{0.05, 0.95}]], 
    InsetBox[
     FormBox[
      StyleBox[
      "\"leptokurtic\"", 14, FontFamily -> "Helvetica", StripOnInput -> 
       False], TraditionalForm], 
     NCache[
      Scaled[{
        Rational[7, 8], 
        Rational[1, 2]}], 
      Scaled[{0.875, 0.5}]]]},
  Frame->{True, False, False, False},
  FrameLabel->{
    FormBox["\"Growth rate\"", TraditionalForm]},
  FrameTicksStyle->{Automatic, Automatic, Automatic, Automatic},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{-0.3, 0.25}, {0, 40}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.779468795408979*^9, 3.779468830949634*^9}, 
   3.779468917873926*^9, {3.779469011820323*^9, 3.779469047660637*^9}, {
   3.779469821103179*^9, 3.779469830115543*^9}, {3.779470013240581*^9, 
   3.77947001697924*^9}, {3.779470060618907*^9, 3.779470094444737*^9}, 
   3.779470124926302*^9, 3.7794701689603777`*^9, 3.7794702603696213`*^9, 
   3.7794705446442757`*^9, 3.780062933136012*^9, {3.780066873452311*^9, 
   3.780066921157032*^9}, 3.7800669760990868`*^9, 3.7800678292900887`*^9, 
   3.780068250329835*^9, 3.7822625937450733`*^9, 3.7822626646239643`*^9, 
   3.784904452840802*^9, 3.784904492075498*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure S4", "Subsubsection",
 CellChangeTimes->{{3.7849041512723722`*^9, 3.784904153474444*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GraphicsColumn", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"figS4a", ",", "figS4b"}], "}"}], ",", 
   RowBox[{"Spacings", "\[Rule]", 
    RowBox[{"-", "50"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{"supfigdir", "<>", "\"\<FigureS4.pdf\>\""}], ",", "%"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.784904507256456*^9, 3.78490452851932*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     FormBox[
      TagBox[
       FormBox[
        GraphicsBox[{{{{}, {{}, {}, 
             {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
              LineBox[CompressedData["
1:eJwtU3tI01EUntN8v/aAUlIyrUaalbYSxJ0bRCqZNQVJ85GS+Uema0E5k7Qw
UyIt0TLfopUW2srhi+lVp2ibE1/zEY2cY+YrTNJMi0x/93fgcjmce7/vO+d+
1yUuOSSeyWAwfLbXzu5NxSjWVuiGqkzGIK97jReZN4LTytr3r69MwaKwxfnh
4jDucwpNn6mchgBdKrfBfxgzHS+uB3EMUCPys5yoHsKBjsyD3xMWgEHFEJY3
nfUWh/+AndvClkFcaeI2yDdaBeq4SI0znrs7O3n+hm2ybcYB/FljiL6u/QsU
vE6J/Qpch7uZRuglFZ/wfPAN1U2lMQqhAPuxyONN2/sWU7SD5mfZh7eytE5m
cgtEye/uxQINDprpsEYUXGoPDpbk7D5ea4dIvwoc9Gc/w9eThUh/XXjy8r6A
4hg2qqYEduI1JXspLIKDiP4OfFU2NmFgcRHRK8fXpkxDzdO4qIjS14pnWWtf
6p9xaT3NODFQ0vf6Apfml+HMSJkJq5mDFii+D9jdlvs0Sc2m8RtwWaxGGlXK
ovHqsJVawPx1zB6lUPdr8PwhlxQp3wZJqfPleMCofsl+3AKJqHoB5tt2/YuL
N0UZVJ6J74wIwGBsjBh0LDBrj0SVbAFdB8Wy996Ajxt0XgDuhblSXuIqdBJ8
OH8yJ9asaZmu14DKs2+Rbz4HlUQfPBLu+Zqt0NHv2wDRvq1htS+mYIn0B+IV
7yn/n8OQRvqH2cHpb1X3+sGazAeWmeOqdr9OKCXzg81wtrV4TgYeZL5wNCv3
br7DWxq/A8yyVVfO5FbQfuuEV+/u71Lcyqf5uqCZ06t9MJkJJ8j7gjKbN+vV
fJvm74FsjXxofDwBeog/IFnSZaW3uQS0f0Btnet46pw/0P4CN1V6fUwJH4qJ
/8CnvDfKn+cKM8SfsPGkMWPUyx4OE/9CUWGS5LTdpkBM/A1tvWmqA3q9oI34
H/RakVDSNCAwIv8DNA51EezHjYL/hVay3A==
               "]]}, 
             {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQPWsmCOzczwAF3NcXF9hybd8vWXAltPwgg0O1yDr3
h1Vb9k91DQ6KkxJweBO4Q6719cb9NVoSe2TPiznsBPICd6zbzzTDVT7CRMYB
Yt7K/RP/FH734lFwqAHrX7L/RJFpa7WxosMOsPp5+x+GTI28NFkRKj9l/zcT
ppoldooODWB+y/7dk+u1f/krOMDcZfLK0NvwmqxDBUTeXshnR6lNrhSUP8X+
0ak35mkbxWDm2x/dkcfX/lwIZr/9wjtznydP4HOYAXGf/RxJv58/f7JD1a+z
31WuseagPRPMf/YrLRO8+z/+sq+C+N/eh2OZnrPHZ3suSPjY2y3y9ZLc+8oe
Gn72/QleC3Z+emivEdN/6KvGHnvTpHjLeX7X7SHm77PPbLFKa7c/a78EqPv6
4gP2D/c/XK+//aD9a7B9B+1fzVu2U3vjFntjMDhsb3GQ58Zt1+X2kPA/Ys//
yOhvuvZM+8NfQTYctZ/l/fith1KXPSS+jtv/dE+I+MJYZQ82LvCEvelkO82t
hzLswc6bedJ+2tSmypWNYfYPwR46Zb9kq7+KYq2zvSbYvWfsGfolZ6zlNLAv
BDmv4Ky98Xp1yUcskvaQ+D1nH75D5Xl3IZM9JDYu2B9Je/ZDbN5LOwAJBgl/

               "]]}}, {}}, 
           {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458],
             EdgeForm[Opacity[0.469]], {{}, 
             {RGBColor[0.24720000000000014`, 0.24, 0.6], Opacity[0.5], 
              EdgeForm[Opacity[0.469]], 
              RectangleBox[{0., 0.}, 
               NCache[{0.005, Rational[114000, 8179]}, {0.005, 
                13.938134246240372`}],
               RoundingRadius->0], 
              RectangleBox[{0.005, 0.}, 
               NCache[{0.01, Rational[164400, 8179]}, {0.01, 
                20.100256755104535`}],
               RoundingRadius->0], 
              RectangleBox[{0.01, 0.}, 
               NCache[{0.015, Rational[205200, 8179]}, {0.015, 
                25.08864164323267}],
               RoundingRadius->0], 
              RectangleBox[{0.015, 0.}, 
               NCache[{0.02, Rational[246500, 8179]}, {0.02, 
                30.13815869910747}],
               RoundingRadius->0], 
              RectangleBox[{0.02, 0.}, 
               NCache[{0.025, Rational[272500, 8179]}, {0.025, 
                33.317031421934225`}],
               RoundingRadius->0], 
              RectangleBox[{0.025, 0.}, 
               NCache[{0.03, Rational[270100, 8179]}, {0.03, 
                33.023597016750216`}],
               RoundingRadius->0], 
              RectangleBox[{0.03, 0.}, 
               NCache[{0.035, Rational[223600, 8179]}, {0.035, 
                27.338305416310064`}],
               RoundingRadius->0], 
              RectangleBox[{0.035, 0.}, 
               NCache[{0.04, Rational[118300, 8179]}, {0.04, 
                14.463870888861718`}],
               RoundingRadius->0], 
              RectangleBox[{0.04, 0.}, 
               NCache[{0.045, Rational[21200, 8179]}, {0.045, 
                2.5920039124587357`}],
               RoundingRadius->0], RectangleBox[{0.045, 0.}, {0.05, 0},
               RoundingRadius->0], RectangleBox[{0.05, 0.}, {0.055, 0},
               RoundingRadius->0], RectangleBox[{0.055, 0.}, {0.06, 0},
               RoundingRadius->0], RectangleBox[{0.06, 0.}, {0.065, 0},
               RoundingRadius->0], RectangleBox[{0.065, 0.}, {0.07, 0},
               RoundingRadius->0], RectangleBox[{0.07, 0.}, {0.075, 0},
               RoundingRadius->0], RectangleBox[{0.075, 0.}, {0.08, 0},
               RoundingRadius->0], RectangleBox[{0.08, 0.}, {0.085, 0},
               RoundingRadius->0], RectangleBox[{0.085, 0.}, {0.09, 0},
               RoundingRadius->0], RectangleBox[{0.09, 0.}, {0.095, 0},
               RoundingRadius->0], RectangleBox[{0.095, 0.}, {0.1, 0},
               RoundingRadius->0], RectangleBox[{0.1, 0.}, {0.105, 0},
               RoundingRadius->0], RectangleBox[{0.105, 0.}, {0.11, 0},
               RoundingRadius->0], RectangleBox[{0.11, 0.}, {0.115, 0},
               RoundingRadius->0], RectangleBox[{0.115, 0.}, {0.12, 0},
               RoundingRadius->0], RectangleBox[{0.12, 0.}, {0.125, 0},
               RoundingRadius->0], RectangleBox[{0.125, 0.}, {0.13, 0},
               RoundingRadius->0], RectangleBox[{0.13, 0.}, {0.135, 0},
               RoundingRadius->0], RectangleBox[{0.135, 0.}, {0.14, 0},
               RoundingRadius->0], RectangleBox[{0.14, 0.}, {0.145, 0},
               RoundingRadius->0], RectangleBox[{0.145, 0.}, {0.15, 0},
               RoundingRadius->0], RectangleBox[{0.15, 0.}, {0.155, 0},
               RoundingRadius->0], RectangleBox[{0.155, 0.}, {0.16, 0},
               RoundingRadius->0], RectangleBox[{0.16, 0.}, {0.165, 0},
               RoundingRadius->0]}, {}, {}}, {{}, 
             {RGBColor[0.6, 0.24, 0.4428931686004542], Opacity[0.5], EdgeForm[
              Opacity[0.469]], 
              RectangleBox[{0., 0.}, 
               NCache[{0.005, Rational[43, 33]}, {0.005, 1.303030303030303}],
               RoundingRadius->0], 
              RectangleBox[{0.005, 0.}, 
               NCache[{0.01, Rational[26, 11]}, {0.01, 2.3636363636363638`}],
               RoundingRadius->0], 
              RectangleBox[{0.01, 0.}, 
               NCache[{0.015, Rational[89, 33]}, {0.015, 2.696969696969697}],
               RoundingRadius->0], 
              RectangleBox[{0.015, 0.}, 
               NCache[{0.02, Rational[131, 33]}, {0.02, 3.9696969696969697`}],
               
               RoundingRadius->0], 
              RectangleBox[{0.02, 0.}, 
               NCache[{0.025, Rational[119, 33]}, {0.025, 3.606060606060606}],
               
               RoundingRadius->0], 
              RectangleBox[{0.025, 0.}, 
               NCache[{0.03, Rational[181, 33]}, {0.03, 5.484848484848484}],
               RoundingRadius->0], 
              RectangleBox[{0.03, 0.}, 
               NCache[{0.035, Rational[197, 33]}, {0.035, 5.96969696969697}],
               RoundingRadius->0], 
              RectangleBox[{0.035, 0.}, 
               NCache[{0.04, Rational[233, 33]}, {0.04, 7.0606060606060606`}],
               
               RoundingRadius->0], 
              RectangleBox[{0.04, 0.}, 
               NCache[{0.045, Rational[90, 11]}, {0.045, 8.181818181818182}],
               RoundingRadius->0], 
              RectangleBox[{0.045, 0.}, 
               NCache[{0.05, Rational[254, 33]}, {0.05, 7.696969696969697}],
               RoundingRadius->0], 
              RectangleBox[{0.05, 0.}, 
               NCache[{0.055, Rational[28, 3]}, {0.055, 9.333333333333334}],
               RoundingRadius->0], 
              RectangleBox[{0.055, 0.}, 
               NCache[{0.06, Rational[108, 11]}, {0.06, 9.818181818181818}],
               RoundingRadius->0], 
              RectangleBox[{0.06, 0.}, 
               NCache[{0.065, Rational[119, 11]}, {0.065, 
                10.818181818181818`}],
               RoundingRadius->0], 
              RectangleBox[{0.065, 0.}, 
               NCache[{0.07, Rational[361, 33]}, {0.07, 10.93939393939394}],
               RoundingRadius->0], 
              RectangleBox[{0.07, 0.}, 
               NCache[{0.075, Rational[32, 3]}, {0.075, 10.666666666666666`}],
               
               RoundingRadius->0], 
              RectangleBox[{0.075, 0.}, 
               NCache[{0.08, Rational[368, 33]}, {0.08, 11.151515151515152`}],
               
               RoundingRadius->0], 
              RectangleBox[{0.08, 0.}, 
               NCache[{0.085, Rational[373, 33]}, {0.085, 
                11.303030303030303`}],
               RoundingRadius->0], 
              RectangleBox[{0.085, 0.}, 
               NCache[{0.09, Rational[349, 33]}, {0.09, 10.575757575757576`}],
               
               RoundingRadius->0], 
              RectangleBox[{0.09, 0.}, 
               NCache[{0.095, Rational[111, 11]}, {0.095, 
                10.090909090909092`}],
               RoundingRadius->0], 
              RectangleBox[{0.095, 0.}, 
               NCache[{0.1, Rational[109, 11]}, {0.1, 9.909090909090908}],
               RoundingRadius->0], 
              RectangleBox[{0.1, 0.}, 
               NCache[{0.105, Rational[305, 33]}, {0.105, 9.242424242424242}],
               
               RoundingRadius->0], 
              RectangleBox[{0.105, 0.}, 
               NCache[{0.11, Rational[233, 33]}, {0.11, 7.0606060606060606`}],
               
               RoundingRadius->0], 
              RectangleBox[{0.11, 0.}, 
               NCache[{0.115, Rational[73, 11]}, {0.115, 6.636363636363637}],
               RoundingRadius->0], 
              RectangleBox[{0.115, 0.}, 
               NCache[{0.12, Rational[200, 33]}, {0.12, 6.0606060606060606`}],
               
               RoundingRadius->0], 
              RectangleBox[{0.12, 0.}, 
               NCache[{0.125, Rational[59, 11]}, {0.125, 5.363636363636363}],
               RoundingRadius->0], 
              RectangleBox[{0.125, 0.}, 
               NCache[{0.13, Rational[155, 33]}, {0.13, 4.696969696969697}],
               RoundingRadius->0], 
              RectangleBox[{0.13, 0.}, 
               NCache[{0.135, Rational[112, 33]}, {0.135, 3.393939393939394}],
               
               RoundingRadius->0], 
              RectangleBox[{0.135, 0.}, 
               NCache[{0.14, Rational[46, 33]}, {0.14, 1.393939393939394}],
               RoundingRadius->0], 
              RectangleBox[{0.14, 0.}, 
               NCache[{0.145, Rational[59, 33]}, {0.145, 1.7878787878787878`}],
               RoundingRadius->0], 
              RectangleBox[{0.145, 0.}, 
               NCache[{0.15, Rational[26, 33]}, {0.15, 0.7878787878787878}],
               RoundingRadius->0], 
              RectangleBox[{0.15, 0.}, 
               NCache[{0.155, Rational[1, 3]}, {0.155, 0.3333333333333333}],
               RoundingRadius->0], 
              RectangleBox[{0.155, 0.}, 
               NCache[{0.16, Rational[3, 11]}, {0.16, 0.2727272727272727}],
               RoundingRadius->0], 
              RectangleBox[{0.16, 0.}, 
               NCache[{0.165, Rational[1, 33]}, {0.165, 
                0.030303030303030304`}],
               RoundingRadius->0]}, {}, {}}}, {{}, {{}, {}, 
             {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
              Opacity[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsT8Vtu3JyseyDhD+FHu2qm0uHK3q
DjvkWl8H7phnn7vQdto6OW2o/BL7w7LiggFK2g6zZoLASvv7ha+MrS9rQNWv
s0/6cG7LR3tVhzeBIJGN9p8jnxnJWShC9W+xX8+u/+DmdCkHruuLC2y5tttL
858WFF0qDDVvp72Q7ocdBle4HTRj+g991dhjv9VhAlvIGyao+fvsK5lOBbju
+GG/BKj7+uID9lJMvod1WN/bQ+w7aF/964bv0Q2P7I3B4LD9/S+qflVzr9pD
7D9iv+/yjX23vx+3P/xVA2jDUXvvwl0v3Ep22kPcc9z+QFze/Gu3VtoHgS08
Yc/7eFetoMhMe4j7TtrnxLo4chm02z+sAhl4yv6yxO2IgNQSe4h7z9j7bn0V
7MieaF8Icl7BWfuAMLXg+6+97CHuP2efairVelncxB4SCxfsV02fsMbfWsYe
ALe+ueE=
               "]]}, 
             {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
              Opacity[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsY8qNFU578LjAOFPsXeW6Zk24ZSY
ww651teBO+bZz8xzdrvQJwOVX2L/7VtW+hReBYdZM0Fgpf28pFjTd28VoOrX
2Vf9SwmZJKzo8CYQJLLRXnK5b7zGEgWo/i32Ng0dje7N8g5c1xcX2HJtty9R
s7jbIioLNW+nPeujj8sMzaQcNGP6D33V2GOv/vq99ndRcaj5++wva9ukX74n
7LAEqPv64gP2F23CSzi3CEDtO2hvs8tGPT2F28EYDA7bP3j7KvnuPVao/Ufs
ZRz3xCl+Z3A4/FUDaMNR+62VXuxFjT/tIe45bv+pPkvnStsn+yCwhSfs/e/N
9nN8/9Ie4r6T9ie3MKuJFT20f1gFMvCU/e1js7RONF6zh7j3jL3P9wsbbp0+
bV8Icl7BWfslpppSOpkH7CHuP2f//WC2nFrzJntILFywdzXdf1Ti42J7ALp0
unI=
               "]]}}, {}}}, InsetBox[
           TagBox[GridBox[{
              {
               
               TemplateBox[{
                StyleBox[
                 "\"random\"", StripOnInput -> False, FontFamily -> 
                  "Helvetica", FontSize -> 12],StyleBox[
                 "\"established\"", StripOnInput -> False, FontFamily -> 
                  "Helvetica", FontSize -> 12]},
                "LineLegend",
                DisplayFunction->(StyleBox[
                  StyleBox[
                   PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                  FontFamily -> "Times"}, Background -> Automatic, 
                  StripOnInput -> False]& ),
                Editable->True,
                InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}]}], "]"}]}], "}"}],
                     ",", 
                    RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                    RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], 
                   "]"}]& )]},
              {
               
               TemplateBox[{
                StyleBox[
                 "\"1-step\"", StripOnInput -> False, FontFamily -> 
                  "Helvetica", FontSize -> 12],StyleBox[
                 "\"2-step\"", StripOnInput -> False, FontFamily -> 
                  "Helvetica", FontSize -> 12]},
                "LineLegend",
                DisplayFunction->(StyleBox[
                  StyleBox[
                   PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                  FontFamily -> "Times"}, Background -> Automatic, 
                  StripOnInput -> False]& ),
                Editable->True,
                InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.24720000000000014`", ",", "0.24`", ",", 
                    "0.6`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.6`", ",", "0.24`", ",", 
                    "0.4428931686004542`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}]}], "}"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                    RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]}
             },
             AutoDelete->False,
             GridBoxAlignment->{"Columns" -> {{Left}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
             GridBoxSpacings->{"Columns" -> {{0}}}],
            "Grid"], NCache[
           Scaled[{0.1875, Rational[1, 2]}], Scaled[{0.1875, 0.5}]], 
           ImageScaled[{0.5, 0.5}],
           BaseStyle->{FontSize -> Larger},
           FormatType->StandardForm]},
         AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
         Axes->True,
         AxesLabel->{None, None},
         AxesOrigin->{0., 0.},
         Epilog->{
           InsetBox[
            FormBox[
             StyleBox[
             "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=-0.1\"", 12, FontFamily -> 
              "Helvetica", StripOnInput -> False], TraditionalForm], 
            NCache[
             Scaled[{
               Rational[7, 8], 
               Rational[3, 4]}], 
             Scaled[{0.875, 0.75}]]], 
           InsetBox[
            FormBox[
             StyleBox[
             "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
              False], TraditionalForm], 
            Scaled[{0.05, 0.95}]], 
           InsetBox[
            FormBox[
             StyleBox[
             "\"platykurtic\"", 14, FontFamily -> "Helvetica", StripOnInput -> 
              False], TraditionalForm], 
            NCache[
             Scaled[{
               Rational[7, 8], 
               Rational[1, 2]}], 
             Scaled[{0.875, 0.5}]]]},
         Frame->{True, False, False, False},
         FrameTicksStyle->{
          FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
         LabelStyle->Directive[12, FontFamily -> "Helvetica"],
         Method->{},
         PlotRange->{{-0.3, 0.25}, {0, 40}},
         PlotRangeClipping->True,
         PlotRangePadding->{Automatic, Automatic}],
        TraditionalForm],
       InterpretTemplate[Legended[
         Graphics[{{{}, {{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                Thickness[Large], 
                GrayLevel[0.5], 
                Dashing[{Small, Small}]], 
               Line[CompressedData["
1:eJwtU3tI01EUntN8v/aAUlIyrUaalbYSxJ0bRCqZNQVJ85GS+Uema0E5k7Qw
UyIt0TLfopUW2srhi+lVp2ibE1/zEY2cY+YrTNJMi0x/93fgcjmce7/vO+d+
1yUuOSSeyWAwfLbXzu5NxSjWVuiGqkzGIK97jReZN4LTytr3r69MwaKwxfnh
4jDucwpNn6mchgBdKrfBfxgzHS+uB3EMUCPys5yoHsKBjsyD3xMWgEHFEJY3
nfUWh/+AndvClkFcaeI2yDdaBeq4SI0znrs7O3n+hm2ybcYB/FljiL6u/QsU
vE6J/Qpch7uZRuglFZ/wfPAN1U2lMQqhAPuxyONN2/sWU7SD5mfZh7eytE5m
cgtEye/uxQINDprpsEYUXGoPDpbk7D5ea4dIvwoc9Gc/w9eThUh/XXjy8r6A
4hg2qqYEduI1JXspLIKDiP4OfFU2NmFgcRHRK8fXpkxDzdO4qIjS14pnWWtf
6p9xaT3NODFQ0vf6Apfml+HMSJkJq5mDFii+D9jdlvs0Sc2m8RtwWaxGGlXK
ovHqsJVawPx1zB6lUPdr8PwhlxQp3wZJqfPleMCofsl+3AKJqHoB5tt2/YuL
N0UZVJ6J74wIwGBsjBh0LDBrj0SVbAFdB8Wy996Ajxt0XgDuhblSXuIqdBJ8
OH8yJ9asaZmu14DKs2+Rbz4HlUQfPBLu+Zqt0NHv2wDRvq1htS+mYIn0B+IV
7yn/n8OQRvqH2cHpb1X3+sGazAeWmeOqdr9OKCXzg81wtrV4TgYeZL5wNCv3
br7DWxq/A8yyVVfO5FbQfuuEV+/u71Lcyqf5uqCZ06t9MJkJJ8j7gjKbN+vV
fJvm74FsjXxofDwBeog/IFnSZaW3uQS0f0Btnet46pw/0P4CN1V6fUwJH4qJ
/8CnvDfKn+cKM8SfsPGkMWPUyx4OE/9CUWGS5LTdpkBM/A1tvWmqA3q9oI34
H/RakVDSNCAwIv8DNA51EezHjYL/hVay3A==
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                Thickness[Large], 
                GrayLevel[0.5]], 
               Line[CompressedData["
1:eJxTTMoPSmViYGBQAWIQPWsmCOzczwAF3NcXF9hybd8vWXAltPwgg0O1yDr3
h1Vb9k91DQ6KkxJweBO4Q6719cb9NVoSe2TPiznsBPICd6zbzzTDVT7CRMYB
Yt7K/RP/FH734lFwqAHrX7L/RJFpa7WxosMOsPp5+x+GTI28NFkRKj9l/zcT
ppoldooODWB+y/7dk+u1f/krOMDcZfLK0NvwmqxDBUTeXshnR6lNrhSUP8X+
0ak35mkbxWDm2x/dkcfX/lwIZr/9wjtznydP4HOYAXGf/RxJv58/f7JD1a+z
31WuseagPRPMf/YrLRO8+z/+sq+C+N/eh2OZnrPHZ3suSPjY2y3y9ZLc+8oe
Gn72/QleC3Z+emivEdN/6KvGHnvTpHjLeX7X7SHm77PPbLFKa7c/a78EqPv6
4gP2D/c/XK+//aD9a7B9B+1fzVu2U3vjFntjMDhsb3GQ58Zt1+X2kPA/Ys//
yOhvuvZM+8NfQTYctZ/l/fith1KXPSS+jtv/dE+I+MJYZQ82LvCEvelkO82t
hzLswc6bedJ+2tSmypWNYfYPwR46Zb9kq7+KYq2zvSbYvWfsGfolZ6zlNLAv
BDmv4Ky98Xp1yUcskvaQ+D1nH75D5Xl3IZM9JDYu2B9Je/ZDbN5LOwAJBgl/

                "]]}}}, {}}, {
            Directive[
             EdgeForm[
              Opacity[0.469]], 
             RGBColor[
             0.798413061722744, 0.824719615472648, 
              0.968322270542458]], {{{{}, {
                Directive[
                 Opacity[0.5], 
                 Directive[
                  EdgeForm[
                   Opacity[0.469]], 
                  RGBColor[
                  0.798413061722744, 0.824719615472648, 0.968322270542458]], 
                 Directive[
                  RGBColor[0.24720000000000014`, 0.24, 0.6]]], {{{
                   Rectangle[{0., 0.}, {0.005, 
                    Rational[114000, 8179]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.005, 0.}, {0.01, 
                    Rational[164400, 8179]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.01, 0.}, {0.015, 
                    Rational[205200, 8179]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.015, 0.}, {0.02, 
                    Rational[246500, 8179]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.02, 0.}, {0.025, 
                    Rational[272500, 8179]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.025, 0.}, {0.03, 
                    Rational[270100, 8179]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.03, 0.}, {0.035, 
                    Rational[223600, 8179]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.035, 0.}, {0.04, 
                    Rational[118300, 8179]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.04, 0.}, {0.045, 
                    Rational[21200, 8179]}, "RoundingRadius" -> 0]}}, {{
                   
                   Rectangle[{0.045, 0.}, {0.05, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.05, 0.}, {0.055, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.055, 0.}, {0.06, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.06, 0.}, {0.065, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.065, 0.}, {0.07, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   Rectangle[{0.07, 0.}, {0.075, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.075, 0.}, {0.08, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.08, 0.}, {0.085, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.085, 0.}, {0.09, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.09, 0.}, {0.095, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.095, 0.}, {0.1, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.1, 0.}, {0.105, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.105, 0.}, {0.11, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.11, 0.}, {0.115, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.115, 0.}, {0.12, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.12, 0.}, {0.125, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.125, 0.}, {0.13, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.13, 0.}, {0.135, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.135, 0.}, {0.14, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.14, 0.}, {0.145, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.145, 0.}, {0.15, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.15, 0.}, {0.155, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.155, 0.}, {0.16, 0}, "RoundingRadius" -> 
                    0]}}, {{
                   
                   Rectangle[{0.16, 0.}, {0.165, 0}, "RoundingRadius" -> 
                    0]}}}}, {}, {}}}, {{{}, {
                Directive[
                 Opacity[0.5], 
                 Directive[
                  EdgeForm[
                   Opacity[0.469]], 
                  RGBColor[
                  0.798413061722744, 0.824719615472648, 0.968322270542458]], 
                 Directive[
                  RGBColor[0.6, 0.24, 0.4428931686004542]]], {{{
                   Rectangle[{0., 0.}, {0.005, 
                    Rational[43, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.005, 0.}, {0.01, 
                    Rational[26, 11]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.01, 0.}, {0.015, 
                    Rational[89, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.015, 0.}, {0.02, 
                    Rational[131, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.02, 0.}, {0.025, 
                    Rational[119, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.025, 0.}, {0.03, 
                    Rational[181, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.03, 0.}, {0.035, 
                    Rational[197, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.035, 0.}, {0.04, 
                    Rational[233, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.04, 0.}, {0.045, 
                    Rational[90, 11]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.045, 0.}, {0.05, 
                    Rational[254, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.05, 0.}, {0.055, 
                    Rational[28, 3]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.055, 0.}, {0.06, 
                    Rational[108, 11]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.06, 0.}, {0.065, 
                    Rational[119, 11]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.065, 0.}, {0.07, 
                    Rational[361, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.07, 0.}, {0.075, 
                    Rational[32, 3]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.075, 0.}, {0.08, 
                    Rational[368, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.08, 0.}, {0.085, 
                    Rational[373, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.085, 0.}, {0.09, 
                    Rational[349, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.09, 0.}, {0.095, 
                    Rational[111, 11]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.095, 0.}, {0.1, 
                    Rational[109, 11]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.1, 0.}, {0.105, 
                    Rational[305, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.105, 0.}, {0.11, 
                    Rational[233, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.11, 0.}, {0.115, 
                    Rational[73, 11]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.115, 0.}, {0.12, 
                    Rational[200, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.12, 0.}, {0.125, 
                    Rational[59, 11]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.125, 0.}, {0.13, 
                    Rational[155, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.13, 0.}, {0.135, 
                    Rational[112, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.135, 0.}, {0.14, 
                    Rational[46, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.14, 0.}, {0.145, 
                    Rational[59, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.145, 0.}, {0.15, 
                    Rational[26, 33]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.15, 0.}, {0.155, 
                    Rational[1, 3]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.155, 0.}, {0.16, 
                    Rational[3, 11]}, "RoundingRadius" -> 0]}}, {{
                   Rectangle[{0.16, 0.}, {0.165, 
                    Rational[1, 33]}, "RoundingRadius" -> 
                    0]}}}}, {}, {}}}}}, {{}, {{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                RGBColor[0.24720000000000014`, 0.24, 0.6], 
                Thickness[Large], 
                Opacity[0.5]], 
               Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsT8Vtu3JyseyDhD+FHu2qm0uHK3q
DjvkWl8H7phnn7vQdto6OW2o/BL7w7LiggFK2g6zZoLASvv7ha+MrS9rQNWv
s0/6cG7LR3tVhzeBIJGN9p8jnxnJWShC9W+xX8+u/+DmdCkHruuLC2y5tttL
858WFF0qDDVvp72Q7ocdBle4HTRj+g991dhjv9VhAlvIGyao+fvsK5lOBbju
+GG/BKj7+uID9lJMvod1WN/bQ+w7aF/964bv0Q2P7I3B4LD9/S+qflVzr9pD
7D9iv+/yjX23vx+3P/xVA2jDUXvvwl0v3Ep22kPcc9z+QFze/Gu3VtoHgS08
Yc/7eFetoMhMe4j7TtrnxLo4chm02z+sAhl4yv6yxO2IgNQSe4h7z9j7bn0V
7MieaF8Icl7BWfuAMLXg+6+97CHuP2efairVelncxB4SCxfsV02fsMbfWsYe
ALe+ueE=
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                RGBColor[0.6, 0.24, 0.4428931686004542], 
                Thickness[Large], 
                Opacity[0.5]], 
               Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsY8qNFU578LjAOFPsXeW6Zk24ZSY
ww651teBO+bZz8xzdrvQJwOVX2L/7VtW+hReBYdZM0Fgpf28pFjTd28VoOrX
2Vf9SwmZJKzo8CYQJLLRXnK5b7zGEgWo/i32Ng0dje7N8g5c1xcX2HJtty9R
s7jbIioLNW+nPeujj8sMzaQcNGP6D33V2GOv/vq99ndRcaj5++wva9ukX74n
7LAEqPv64gP2F23CSzi3CEDtO2hvs8tGPT2F28EYDA7bP3j7KvnuPVao/Ufs
ZRz3xCl+Z3A4/FUDaMNR+62VXuxFjT/tIe45bv+pPkvnStsn+yCwhSfs/e/N
9nN8/9Ie4r6T9ie3MKuJFT20f1gFMvCU/e1js7RONF6zh7j3jL3P9wsbbp0+
bV8Icl7BWfslpppSOpkH7CHuP2f//WC2nFrzJntILFywdzXdf1Ti42J7ALp0
unI=
                "]]}}}, {}}}, {
          PlotRange -> {{-0.3, 0.25}, {0, 40}}, 
           Frame -> {True, False, False, False}, LabelStyle -> 
           Directive[12, FontFamily -> "Helvetica"], 
           FrameTicksStyle -> {
            FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, 
           Epilog -> {
             Text[
              Style[
              "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=-0.1", 12, FontFamily -> "Helvetica"], 
              Scaled[{
                Rational[7, 8], 
                Rational[3, 4]}]], 
             Text[
              Style["A", 14, Bold, FontFamily -> "Helvetica"], 
              Scaled[{0.05, 0.95}]], 
             Text[
              Style["platykurtic", 14, FontFamily -> "Helvetica"], 
              Scaled[{
                Rational[7, 8], 
                Rational[1, 2]}]]}, AxesLabel -> {None, None}, AspectRatio -> 
           GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0., 0.}, 
           Method -> {}, PlotRange -> {All, All}, PlotRangeClipping -> True, 
           PlotRangePadding -> {Automatic, Automatic}}], {
          Placed[
           Unevaluated[
            LineLegend[{
              Directive[
               RGBColor[0.24720000000000014`, 0.24, 0.6], 
               Thickness[Large], 
               Opacity[0.5]], 
              Directive[
               RGBColor[0.6, 0.24, 0.4428931686004542], 
               Thickness[Large], 
               Opacity[0.5]]}, {
              Style["1-step", 12, FontFamily -> "Helvetica"], 
              Style["2-step", 12, FontFamily -> "Helvetica"]}, LegendLayout -> 
             "Column", LegendMarkers -> False]], 
           Scaled[{0.1875, 
             Rational[1, 2]}], Identity]}]& ],
       AutoDelete->True,
       Editable->True,
       SelectWithContents->False,
       Selectable->True],
      TraditionalForm], {189., -120.62305898749054`}, {
     Center, Center}, {360., 291.2461179749811}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
          LineBox[CompressedData["
1:eJwtU3tI01EUntN8v/aAUlIyrUaalbYSxJ0bRCqZNQVJ85GS+Uema0E5k7Qw
UyIt0TLfopUW2srhi+lVp2ibE1/zEY2cY+YrTNJMi0x/93fgcjmce7/vO+d+
1yUuOSSeyWAwfLbXzu5NxSjWVuiGqkzGIK97jReZN4LTytr3r69MwaKwxfnh
4jDucwpNn6mchgBdKrfBfxgzHS+uB3EMUCPys5yoHsKBjsyD3xMWgEHFEJY3
nfUWh/+AndvClkFcaeI2yDdaBeq4SI0znrs7O3n+hm2ybcYB/FljiL6u/QsU
vE6J/Qpch7uZRuglFZ/wfPAN1U2lMQqhAPuxyONN2/sWU7SD5mfZh7eytE5m
cgtEye/uxQINDprpsEYUXGoPDpbk7D5ea4dIvwoc9Gc/w9eThUh/XXjy8r6A
4hg2qqYEduI1JXspLIKDiP4OfFU2NmFgcRHRK8fXpkxDzdO4qIjS14pnWWtf
6p9xaT3NODFQ0vf6Apfml+HMSJkJq5mDFii+D9jdlvs0Sc2m8RtwWaxGGlXK
ovHqsJVawPx1zB6lUPdr8PwhlxQp3wZJqfPleMCofsl+3AKJqHoB5tt2/YuL
N0UZVJ6J74wIwGBsjBh0LDBrj0SVbAFdB8Wy996Ajxt0XgDuhblSXuIqdBJ8
OH8yJ9asaZmu14DKs2+Rbz4HlUQfPBLu+Zqt0NHv2wDRvq1htS+mYIn0B+IV
7yn/n8OQRvqH2cHpb1X3+sGazAeWmeOqdr9OKCXzg81wtrV4TgYeZL5wNCv3
br7DWxq/A8yyVVfO5FbQfuuEV+/u71Lcyqf5uqCZ06t9MJkJJ8j7gjKbN+vV
fJvm74FsjXxofDwBeog/IFnSZaW3uQS0f0Btnet46pw/0P4CN1V6fUwJH4qJ
/8CnvDfKn+cKM8SfsPGkMWPUyx4OE/9CUWGS5LTdpkBM/A1tvWmqA3q9oI34
H/RakVDSNCAwIv8DNA51EezHjYL/hVay3A==
           "]]}, 
         {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQAWIQPWsmCOzczwAF3NcXF9hybd8vWXAltPwgg0O1yDr3
h1Vb9k91DQ6KkxJweBO4Q6719cb9NVoSe2TPiznsBPICd6zbzzTDVT7CRMYB
Yt7K/RP/FH734lFwqAHrX7L/RJFpa7WxosMOsPp5+x+GTI28NFkRKj9l/zcT
ppoldooODWB+y/7dk+u1f/krOMDcZfLK0NvwmqxDBUTeXshnR6lNrhSUP8X+
0ak35mkbxWDm2x/dkcfX/lwIZr/9wjtznydP4HOYAXGf/RxJv58/f7JD1a+z
31WuseagPRPMf/YrLRO8+z/+sq+C+N/eh2OZnrPHZ3suSPjY2y3y9ZLc+8oe
Gn72/QleC3Z+emivEdN/6KvGHnvTpHjLeX7X7SHm77PPbLFKa7c/a78EqPv6
4gP2D/c/XK+//aD9a7B9B+1fzVu2U3vjFntjMDhsb3GQ58Zt1+X2kPA/Ys//
yOhvuvZM+8NfQTYctZ/l/fith1KXPSS+jtv/dE+I+MJYZQ82LvCEvelkO82t
hzLswc6bedJ+2tSmypWNYfYPwR46Zb9kq7+KYq2zvSbYvWfsGfolZ6zlNLAv
BDmv4Ky98Xp1yUcskvaQ+D1nH75D5Xl3IZM9JDYu2B9Je/ZDbN5LOwAJBgl/

           "]]}}, {}}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        EdgeForm[Opacity[0.06999999999999999]], {{}, 
         {RGBColor[0.24720000000000014`, 0.24, 0.6], Opacity[0.5], EdgeForm[
          Opacity[0.06999999999999999]], 
          RectangleBox[{0., 0.}, 
           NCache[{0.005, Rational[65300, 30933]}, {0.005, 
            2.1110141273074063`}],
           RoundingRadius->0], 
          RectangleBox[{0.005, 0.}, 
           NCache[{0.01, Rational[84200, 30933]}, {0.01, 2.7220120906475285`}],
           RoundingRadius->0], 
          RectangleBox[{0.01, 0.}, 
           NCache[{0.015, Rational[34600, 10311]}, {0.015, 3.355639608185433}],
           RoundingRadius->0], 
          RectangleBox[{0.015, 0.}, 
           NCache[{0.02, Rational[19000, 4419]}, {0.02, 4.2996152975786375`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.02, 0.}, 
           NCache[{0.025, Rational[151000, 30933]}, {0.025, 
            4.881518119807326}],
           RoundingRadius->0], 
          RectangleBox[{0.025, 0.}, 
           NCache[{0.03, Rational[25100, 4419]}, {0.03, 5.680018103643358}],
           RoundingRadius->0], 
          RectangleBox[{0.03, 0.}, 
           NCache[{0.035, Rational[191900, 30933]}, {0.035, 
            6.203730643649177}],
           RoundingRadius->0], 
          RectangleBox[{0.035, 0.}, 
           NCache[{0.04, Rational[21500, 3437]}, {0.04, 6.255455338958394}],
           RoundingRadius->0], 
          RectangleBox[{0.04, 0.}, 
           NCache[{0.045, Rational[205600, 30933]}, {0.045, 
            6.646623347234345}],
           RoundingRadius->0], 
          RectangleBox[{0.045, 0.}, 
           NCache[{0.05, Rational[213700, 30933]}, {0.05, 6.908479617237255}],
           
           RoundingRadius->0], 
          RectangleBox[{0.05, 0.}, 
           NCache[{0.055, Rational[221600, 30933]}, {0.055, 
            7.163870300326512}],
           RoundingRadius->0], 
          RectangleBox[{0.055, 0.}, 
           NCache[{0.06, Rational[231400, 30933]}, {0.06, 7.480684059095465}],
           
           RoundingRadius->0], 
          RectangleBox[{0.06, 0.}, 
           NCache[{0.065, Rational[75100, 10311]}, {0.065, 7.283483658229076}],
           RoundingRadius->0], 
          RectangleBox[{0.065, 0.}, 
           NCache[{0.07, Rational[10600, 1473]}, {0.07, 7.196198234894773}],
           RoundingRadius->0], 
          RectangleBox[{0.07, 0.}, 
           NCache[{0.075, Rational[73100, 10311]}, {0.075, 7.089516050819513}],
           RoundingRadius->0], 
          RectangleBox[{0.075, 0.}, 
           NCache[{0.08, Rational[208700, 30933]}, {0.08, 6.746839944395952}],
           
           RoundingRadius->0], 
          RectangleBox[{0.08, 0.}, 
           NCache[{0.085, Rational[209000, 30933]}, {0.085, 
            6.756538324766431}],
           RoundingRadius->0], 
          RectangleBox[{0.085, 0.}, 
           NCache[{0.09, Rational[204500, 30933]}, {0.09, 
            6.6110626192092585`}],
           RoundingRadius->0], 
          RectangleBox[{0.09, 0.}, 
           NCache[{0.095, Rational[64000, 10311]}, {0.095, 6.206963437106003}],
           RoundingRadius->0], 
          RectangleBox[{0.095, 0.}, 
           NCache[{0.1, Rational[198200, 30933]}, {0.1, 6.407396631429218}],
           RoundingRadius->0], 
          RectangleBox[{0.1, 0.}, 
           NCache[{0.105, Rational[180800, 30933]}, {0.105, 
            5.844890569941486}],
           RoundingRadius->0], 
          RectangleBox[{0.105, 0.}, 
           NCache[{0.11, Rational[179300, 30933]}, {0.11, 5.796398668089096}],
           
           RoundingRadius->0], 
          RectangleBox[{0.11, 0.}, 
           NCache[{0.115, Rational[53000, 10311]}, {0.115, 5.140141596353409}],
           RoundingRadius->0], 
          RectangleBox[{0.115, 0.}, 
           NCache[{0.12, Rational[155900, 30933]}, {0.12, 5.039924999191801}],
           
           RoundingRadius->0], 
          RectangleBox[{0.12, 0.}, 
           NCache[{0.125, Rational[49900, 10311]}, {0.125, 4.839491804868587}],
           RoundingRadius->0], 
          RectangleBox[{0.125, 0.}, 
           NCache[{0.13, Rational[48500, 10311]}, {0.13, 4.703714479681893}],
           RoundingRadius->0], 
          RectangleBox[{0.13, 0.}, 
           NCache[{0.135, Rational[125900, 30933]}, {0.135, 
            4.070086962143988}],
           RoundingRadius->0], 
          RectangleBox[{0.135, 0.}, 
           NCache[{0.14, Rational[40000, 10311]}, {0.14, 3.879352148191252}],
           RoundingRadius->0], 
          RectangleBox[{0.14, 0.}, 
           NCache[{0.145, Rational[110800, 30933]}, {0.145, 
            3.581935150163256}],
           RoundingRadius->0], 
          RectangleBox[{0.145, 0.}, 
           NCache[{0.15, Rational[106100, 30933]}, {0.15, 3.429993857692432}],
           
           RoundingRadius->0], 
          RectangleBox[{0.15, 0.}, 
           NCache[{0.155, Rational[32300, 10311]}, {0.155, 3.132576859664436}],
           RoundingRadius->0], 
          RectangleBox[{0.155, 0.}, 
           NCache[{0.16, Rational[89900, 30933]}, {0.16, 2.906281317686613}],
           RoundingRadius->0], 
          RectangleBox[{0.16, 0.}, 
           NCache[{0.165, Rational[9400, 3437]}, {0.165, 2.7349432644748326`}],
           RoundingRadius->0], 
          RectangleBox[{0.165, 0.}, 
           NCache[{0.17, Rational[11300, 4419]}, {0.17, 2.5571396243494005`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.17, 0.}, 
           NCache[{0.175, Rational[22900, 10311]}, {0.175, 
            2.2209291048394917`}],
           RoundingRadius->0], 
          RectangleBox[{0.175, 0.}, 
           NCache[{0.18, Rational[66100, 30933]}, {0.18, 2.1368764749620146`}],
           RoundingRadius->0], 
          RectangleBox[{0.18, 0.}, 
           NCache[{0.185, Rational[60400, 30933]}, {0.185, 
            1.9526072479229302`}],
           RoundingRadius->0], 
          RectangleBox[{0.185, 0.}, 
           NCache[{0.19, Rational[56800, 30933]}, {0.19, 1.8362266834771925`}],
           RoundingRadius->0], 
          RectangleBox[{0.19, 0.}, 
           NCache[{0.195, Rational[50600, 30933]}, {0.195, 1.635793489153978}],
           RoundingRadius->0], 
          RectangleBox[{0.195, 0.}, 
           NCache[{0.2, Rational[15200, 10311]}, {0.2, 1.4741538163126757`}],
           RoundingRadius->0], 
          RectangleBox[{0.2, 0.}, 
           NCache[{0.205, Rational[2000, 1473]}, {0.205, 1.3577732518669383`}],
           RoundingRadius->0], 
          RectangleBox[{0.205, 0.}, 
           NCache[{0.21, Rational[5500, 4419]}, {0.21, 1.2446254808780266`}],
           RoundingRadius->0], 
          RectangleBox[{0.21, 0.}, 
           NCache[{0.215, Rational[37300, 30933]}, {0.215, 
            1.2058319593961142`}],
           RoundingRadius->0], 
          RectangleBox[{0.215, 0.}, 
           NCache[{0.22, Rational[31400, 30933]}, {0.22, 1.0150971454433777`}],
           RoundingRadius->0], 
          RectangleBox[{0.22, 0.}, 
           NCache[{0.225, Rational[31100, 30933]}, {0.225, 
            1.0053987650728995`}],
           RoundingRadius->0], 
          RectangleBox[{0.225, 0.}, 
           NCache[{0.23, Rational[8300, 10311]}, {0.23, 0.8049655707496848}],
           RoundingRadius->0], 
          RectangleBox[{0.23, 0.}, 
           NCache[{0.235, Rational[1100, 1473]}, {0.235, 0.7467752885268161}],
           
           RoundingRadius->0], 
          RectangleBox[{0.235, 0.}, 
           NCache[{0.24, Rational[20600, 30933]}, {0.24, 0.6659554521061649}],
           
           RoundingRadius->0], 
          RectangleBox[{0.24, 0.}, 
           NCache[{0.245, Rational[17300, 30933]}, {0.245, 
            0.5592732680309055}],
           RoundingRadius->0], 
          RectangleBox[{0.245, 0.}, 
           NCache[{0.25, Rational[17000, 30933]}, {0.25, 0.5495748876604274}],
           
           RoundingRadius->0], 
          RectangleBox[{0.25, 0.}, 
           NCache[{0.255, Rational[14800, 30933]}, {0.255, 
            0.47845343161025444`}],
           RoundingRadius->0], 
          RectangleBox[{0.255, 0.}, 
           NCache[{0.26, Rational[13100, 30933]}, {0.26, 
            0.42349594284421166`}],
           RoundingRadius->0], 
          RectangleBox[{0.26, 0.}, 
           NCache[{0.265, Rational[4100, 10311]}, {0.265, 
            0.39763359518960334`}],
           RoundingRadius->0], 
          RectangleBox[{0.265, 0.}, 
           NCache[{0.27, Rational[3700, 10311]}, {0.27, 0.35884007370769083`}],
           RoundingRadius->0], 
          RectangleBox[{0.27, 0.}, 
           NCache[{0.275, Rational[8800, 30933]}, {0.275, 0.2844858242006918}],
           RoundingRadius->0], 
          RectangleBox[{0.275, 0.}, 
           NCache[{0.28, Rational[2300, 10311]}, {0.28, 0.223062748520997}],
           RoundingRadius->0], 
          RectangleBox[{0.28, 0.}, 
           NCache[{0.285, Rational[900, 3437]}, {0.285, 0.2618562700029095}],
           RoundingRadius->0], 
          RectangleBox[{0.285, 0.}, 
           NCache[{0.29, Rational[2200, 10311]}, {0.29, 0.21336436815051887`}],
           RoundingRadius->0], 
          RectangleBox[{0.29, 0.}, 
           NCache[{0.295, Rational[5500, 30933]}, {0.295, 0.1778036401254324}],
           RoundingRadius->0], 
          RectangleBox[{0.295, 0.}, 
           NCache[{0.3, Rational[3400, 30933]}, {0.3, 0.10991497753208547`}],
           RoundingRadius->0], 
          RectangleBox[{0.3, 0.}, 
           NCache[{0.305, Rational[4400, 30933]}, {0.305, 0.1422429121003459}],
           RoundingRadius->0], 
          RectangleBox[{0.305, 0.}, 
           NCache[{0.31, Rational[1100, 10311]}, {0.31, 0.10668218407525944`}],
           RoundingRadius->0], 
          RectangleBox[{0.31, 0.}, 
           NCache[{0.315, Rational[1300, 10311]}, {0.315, 0.1260789448162157}],
           RoundingRadius->0], 
          RectangleBox[{0.315, 0.}, 
           NCache[{0.32, Rational[3400, 30933]}, {0.32, 0.10991497753208547`}],
           RoundingRadius->0], 
          RectangleBox[{0.32, 0.}, 
           NCache[{0.325, Rational[300, 3437]}, {0.325, 0.08728542333430317}],
           
           RoundingRadius->0], 
          RectangleBox[{0.325, 0.}, 
           NCache[{0.33, Rational[100, 1473]}, {0.33, 0.06788866259334692}],
           RoundingRadius->0], 
          RectangleBox[{0.33, 0.}, 
           NCache[{0.335, Rational[400, 10311]}, {0.335, 0.03879352148191252}],
           RoundingRadius->0], 
          RectangleBox[{0.335, 0.}, 
           NCache[{0.34, Rational[1000, 30933]}, {0.34, 
            0.032327934568260434`}],
           RoundingRadius->0], 
          RectangleBox[{0.34, 0.}, 
           NCache[{0.345, Rational[200, 4419]}, {0.345, 0.04525910839556461}],
           
           RoundingRadius->0], 
          RectangleBox[{0.345, 0.}, 
           NCache[{0.35, Rational[400, 10311]}, {0.35, 0.03879352148191252}],
           RoundingRadius->0], 
          RectangleBox[{0.35, 0.}, 
           NCache[{0.355, Rational[100, 4419]}, {0.355, 
            0.022629554197782304`}],
           RoundingRadius->0], 
          RectangleBox[{0.355, 0.}, 
           NCache[{0.36, Rational[200, 4419]}, {0.36, 0.04525910839556461}],
           RoundingRadius->0], 
          RectangleBox[{0.36, 0.}, 
           NCache[{0.365, Rational[400, 10311]}, {0.365, 0.03879352148191252}],
           RoundingRadius->0], 
          RectangleBox[{0.365, 0.}, 
           NCache[{0.37, Rational[100, 4419]}, {0.37, 0.022629554197782304`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.37, 0.}, 
           NCache[{0.375, Rational[200, 10311]}, {0.375, 0.01939676074095626}],
           RoundingRadius->0], 
          RectangleBox[{0.375, 0.}, 
           NCache[{0.38, Rational[200, 30933]}, {0.38, 0.006465586913652087}],
           
           RoundingRadius->0], 
          RectangleBox[{0.38, 0.}, 
           NCache[{0.385, Rational[100, 30933]}, {0.385, 
            0.0032327934568260434`}],
           RoundingRadius->0], 
          RectangleBox[{0.385, 0.}, 
           NCache[{0.39, Rational[400, 30933]}, {0.39, 0.012931173827304174`}],
           RoundingRadius->0], 
          RectangleBox[{0.39, 0.}, 
           NCache[{0.395, Rational[200, 30933]}, {0.395, 
            0.006465586913652087}],
           RoundingRadius->0], 
          RectangleBox[{0.395, 0.}, 
           NCache[{0.4, Rational[200, 30933]}, {0.4, 0.006465586913652087}],
           RoundingRadius->0], 
          RectangleBox[{0.4, 0.}, 
           NCache[{0.405, Rational[200, 30933]}, {0.405, 
            0.006465586913652087}],
           RoundingRadius->0], 
          RectangleBox[{0.405, 0.}, 
           NCache[{0.41, Rational[100, 30933]}, {0.41, 
            0.0032327934568260434`}],
           RoundingRadius->0], 
          RectangleBox[{0.41, 0.}, 
           NCache[{0.415, Rational[200, 30933]}, {0.415, 
            0.006465586913652087}],
           RoundingRadius->0], RectangleBox[{0.415, 0.}, {0.42, 0},
           RoundingRadius->0], RectangleBox[{0.42, 0.}, {0.425, 0},
           RoundingRadius->0], RectangleBox[{0.425, 0.}, {0.43, 0},
           RoundingRadius->0], RectangleBox[{0.43, 0.}, {0.435, 0},
           RoundingRadius->0], RectangleBox[{0.435, 0.}, {0.44, 0},
           RoundingRadius->0], RectangleBox[{0.44, 0.}, {0.445, 0},
           RoundingRadius->0], RectangleBox[{0.445, 0.}, {0.45, 0},
           RoundingRadius->0]}, {}, {}}, {{}, 
         {RGBColor[0.6, 0.24, 0.4428931686004542], Opacity[0.5], EdgeForm[
          Opacity[0.06999999999999999]], 
          RectangleBox[{0., 0.}, 
           NCache[{0.005, Rational[975, 758]}, {0.005, 1.2862796833773087`}],
           RoundingRadius->0], 
          RectangleBox[{0.005, 0.}, 
           NCache[{0.01, Rational[725, 379]}, {0.01, 1.912928759894459}],
           RoundingRadius->0], 
          RectangleBox[{0.01, 0.}, 
           NCache[{0.015, Rational[1725, 758]}, {0.015, 2.2757255936675462`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.015, 0.}, 
           NCache[{0.02, Rational[2025, 758]}, {0.02, 2.6715039577836412`}],
           RoundingRadius->0], 
          RectangleBox[{0.02, 0.}, 
           NCache[{0.025, Rational[2925, 758]}, {0.025, 3.8588390501319263`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.025, 0.}, 
           NCache[{0.03, Rational[1475, 379]}, {0.03, 3.891820580474934}],
           RoundingRadius->0], 
          RectangleBox[{0.03, 0.}, 
           NCache[{0.035, Rational[2000, 379]}, {0.035, 5.277044854881266}],
           RoundingRadius->0], 
          RectangleBox[{0.035, 0.}, 
           NCache[{0.04, Rational[3975, 758]}, {0.04, 5.244063324538258}],
           RoundingRadius->0], 
          RectangleBox[{0.04, 0.}, 
           NCache[{0.045, Rational[2300, 379]}, {0.045, 6.068601583113456}],
           RoundingRadius->0], 
          RectangleBox[{0.045, 0.}, 
           NCache[{0.05, Rational[2400, 379]}, {0.05, 6.332453825857519}],
           RoundingRadius->0], 
          RectangleBox[{0.05, 0.}, 
           NCache[{0.055, Rational[2375, 379]}, {0.055, 6.266490765171504}],
           RoundingRadius->0], 
          RectangleBox[{0.055, 0.}, 
           NCache[{0.06, Rational[2550, 379]}, {0.06, 6.728232189973615}],
           RoundingRadius->0], 
          RectangleBox[{0.06, 0.}, 
           NCache[{0.065, Rational[2475, 379]}, {0.065, 6.530343007915567}],
           RoundingRadius->0], 
          RectangleBox[{0.065, 0.}, 
           NCache[{0.07, Rational[4875, 758]}, {0.07, 6.431398416886544}],
           RoundingRadius->0], 
          RectangleBox[{0.07, 0.}, 
           NCache[{0.075, Rational[2750, 379]}, {0.075, 7.255936675461742}],
           RoundingRadius->0], 
          RectangleBox[{0.075, 0.}, 
           NCache[{0.08, Rational[5625, 758]}, {0.08, 7.420844327176781}],
           RoundingRadius->0], 
          RectangleBox[{0.08, 0.}, 
           NCache[{0.085, Rational[2375, 379]}, {0.085, 6.266490765171504}],
           RoundingRadius->0], 
          RectangleBox[{0.085, 0.}, 
           NCache[{0.09, Rational[4825, 758]}, {0.09, 6.3654353562005275`}],
           RoundingRadius->0], 
          RectangleBox[{0.09, 0.}, 
           NCache[{0.095, Rational[4675, 758]}, {0.095, 6.167546174142481}],
           RoundingRadius->0], 
          RectangleBox[{0.095, 0.}, 
           NCache[{0.1, Rational[4675, 758]}, {0.1, 6.167546174142481}],
           RoundingRadius->0], 
          RectangleBox[{0.1, 0.}, 
           NCache[{0.105, Rational[4625, 758]}, {0.105, 6.101583113456464}],
           RoundingRadius->0], 
          RectangleBox[{0.105, 0.}, 
           NCache[{0.11, Rational[1875, 379]}, {0.11, 4.947229551451187}],
           RoundingRadius->0], 
          RectangleBox[{0.11, 0.}, 
           NCache[{0.115, Rational[3925, 758]}, {0.115, 5.178100263852243}],
           RoundingRadius->0], 
          RectangleBox[{0.115, 0.}, 
           NCache[{0.12, Rational[1850, 379]}, {0.12, 4.881266490765172}],
           RoundingRadius->0], 
          RectangleBox[{0.12, 0.}, 
           NCache[{0.125, Rational[4075, 758]}, {0.125, 5.375989445910291}],
           RoundingRadius->0], 
          RectangleBox[{0.125, 0.}, 
           NCache[{0.13, Rational[3725, 758]}, {0.13, 4.91424802110818}],
           RoundingRadius->0], 
          RectangleBox[{0.13, 0.}, 
           NCache[{0.135, Rational[3525, 758]}, {0.135, 4.650395778364116}],
           RoundingRadius->0], 
          RectangleBox[{0.135, 0.}, 
           NCache[{0.14, Rational[3175, 758]}, {0.14, 4.188654353562005}],
           RoundingRadius->0], 
          RectangleBox[{0.14, 0.}, 
           NCache[{0.145, Rational[1625, 379]}, {0.145, 4.287598944591029}],
           RoundingRadius->0], 
          RectangleBox[{0.145, 0.}, 
           NCache[{0.15, Rational[3375, 758]}, {0.15, 4.452506596306069}],
           RoundingRadius->0], 
          RectangleBox[{0.15, 0.}, 
           NCache[{0.155, Rational[1475, 379]}, {0.155, 3.891820580474934}],
           RoundingRadius->0], 
          RectangleBox[{0.155, 0.}, 
           NCache[{0.16, Rational[2375, 758]}, {0.16, 3.133245382585752}],
           RoundingRadius->0], 
          RectangleBox[{0.16, 0.}, 
           NCache[{0.165, Rational[1075, 379]}, {0.165, 2.836411609498681}],
           RoundingRadius->0], 
          RectangleBox[{0.165, 0.}, 
           NCache[{0.17, Rational[825, 379]}, {0.17, 2.1767810026385224`}],
           RoundingRadius->0], 
          RectangleBox[{0.17, 0.}, 
           NCache[{0.175, Rational[925, 379]}, {0.175, 2.440633245382586}],
           RoundingRadius->0], 
          RectangleBox[{0.175, 0.}, 
           NCache[{0.18, Rational[2425, 758]}, {0.18, 3.199208443271768}],
           RoundingRadius->0], 
          RectangleBox[{0.18, 0.}, 
           NCache[{0.185, Rational[1575, 758]}, {0.185, 2.0778364116094985`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.185, 0.}, 
           NCache[{0.19, Rational[1875, 758]}, {0.19, 2.4736147757255935`}],
           RoundingRadius->0], 
          RectangleBox[{0.19, 0.}, 
           NCache[{0.195, Rational[1125, 379]}, {0.195, 2.9683377308707124`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.195, 0.}, 
           NCache[{0.2, Rational[800, 379]}, {0.2, 2.1108179419525066`}],
           RoundingRadius->0], 
          RectangleBox[{0.2, 0.}, 
           NCache[{0.205, Rational[750, 379]}, {0.205, 1.9788918205804749`}],
           RoundingRadius->0], 
          RectangleBox[{0.205, 0.}, 
           NCache[{0.21, Rational[700, 379]}, {0.21, 1.8469656992084433`}],
           RoundingRadius->0], 
          RectangleBox[{0.21, 0.}, 
           NCache[{0.215, Rational[525, 379]}, {0.215, 1.3852242744063326`}],
           RoundingRadius->0], 
          RectangleBox[{0.215, 0.}, 
           NCache[{0.22, Rational[775, 758]}, {0.22, 1.0224274406332454`}],
           RoundingRadius->0], 
          RectangleBox[{0.22, 0.}, 
           NCache[{0.225, Rational[1225, 758]}, {0.225, 1.616094986807388}],
           RoundingRadius->0], 
          RectangleBox[{0.225, 0.}, 
           NCache[{0.23, Rational[1225, 758]}, {0.23, 1.616094986807388}],
           RoundingRadius->0], 
          RectangleBox[{0.23, 0.}, 
           NCache[{0.235, Rational[275, 379]}, {0.235, 0.7255936675461742}],
           RoundingRadius->0], 
          RectangleBox[{0.235, 0.}, 
           NCache[{0.24, Rational[525, 758]}, {0.24, 0.6926121372031663}],
           RoundingRadius->0], 
          RectangleBox[{0.24, 0.}, 
           NCache[{0.245, Rational[400, 379]}, {0.245, 1.0554089709762533`}],
           RoundingRadius->0], 
          RectangleBox[{0.245, 0.}, 
           NCache[{0.25, Rational[275, 379]}, {0.25, 0.7255936675461742}],
           RoundingRadius->0], 
          RectangleBox[{0.25, 0.}, 
           NCache[{0.255, Rational[300, 379]}, {0.255, 0.7915567282321899}],
           RoundingRadius->0], 
          RectangleBox[{0.255, 0.}, 
           NCache[{0.26, Rational[175, 379]}, {0.26, 0.46174142480211083`}],
           RoundingRadius->0], 
          RectangleBox[{0.26, 0.}, 
           NCache[{0.265, Rational[300, 379]}, {0.265, 0.7915567282321899}],
           RoundingRadius->0], 
          RectangleBox[{0.265, 0.}, 
           NCache[{0.27, Rational[225, 379]}, {0.27, 0.5936675461741425}],
           RoundingRadius->0], 
          RectangleBox[{0.27, 0.}, 
           NCache[{0.275, Rational[175, 379]}, {0.275, 0.46174142480211083`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.275, 0.}, 
           NCache[{0.28, Rational[225, 758]}, {0.28, 0.29683377308707126`}],
           RoundingRadius->0], 
          RectangleBox[{0.28, 0.}, 
           NCache[{0.285, Rational[150, 379]}, {0.285, 0.39577836411609496`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.285, 0.}, 
           NCache[{0.29, Rational[125, 379]}, {0.29, 0.32981530343007914`}],
           RoundingRadius->0], 
          RectangleBox[{0.29, 0.}, 
           NCache[{0.295, Rational[325, 758]}, {0.295, 0.4287598944591029}],
           RoundingRadius->0], 
          RectangleBox[{0.295, 0.}, 
           NCache[{0.3, Rational[125, 758]}, {0.3, 0.16490765171503957`}],
           RoundingRadius->0], 
          RectangleBox[{0.3, 0.}, 
           NCache[{0.305, Rational[225, 758]}, {0.305, 0.29683377308707126`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.305, 0.}, 
           NCache[{0.31, Rational[175, 758]}, {0.31, 0.23087071240105542`}],
           RoundingRadius->0], 
          RectangleBox[{0.31, 0.}, 
           NCache[{0.315, Rational[75, 379]}, {0.315, 0.19788918205804748`}],
           RoundingRadius->0], 
          RectangleBox[{0.315, 0.}, 
           NCache[{0.32, Rational[125, 758]}, {0.32, 0.16490765171503957`}],
           RoundingRadius->0], 
          RectangleBox[{0.32, 0.}, 
           NCache[{0.325, Rational[75, 379]}, {0.325, 0.19788918205804748`}],
           RoundingRadius->0], 
          RectangleBox[{0.325, 0.}, 
           NCache[{0.33, Rational[50, 379]}, {0.33, 0.13192612137203166`}],
           RoundingRadius->0], 
          RectangleBox[{0.33, 0.}, 
           NCache[{0.335, Rational[75, 758]}, {0.335, 0.09894459102902374}],
           RoundingRadius->0], 
          RectangleBox[{0.335, 0.}, 
           NCache[{0.34, Rational[75, 758]}, {0.34, 0.09894459102902374}],
           RoundingRadius->0], 
          RectangleBox[{0.34, 0.}, 
           NCache[{0.345, Rational[25, 758]}, {0.345, 0.032981530343007916`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.345, 0.}, 
           NCache[{0.35, Rational[75, 758]}, {0.35, 0.09894459102902374}],
           RoundingRadius->0], 
          RectangleBox[{0.35, 0.}, 
           NCache[{0.355, Rational[25, 379]}, {0.355, 0.06596306068601583}],
           RoundingRadius->0], RectangleBox[{0.355, 0.}, {0.36, 0},
           RoundingRadius->0], 
          RectangleBox[{0.36, 0.}, 
           NCache[{0.365, Rational[25, 758]}, {0.365, 0.032981530343007916`}],
           
           RoundingRadius->0], RectangleBox[{0.365, 0.}, {0.37, 0},
           RoundingRadius->0], 
          RectangleBox[{0.37, 0.}, 
           NCache[{0.375, Rational[25, 758]}, {0.375, 0.032981530343007916`}],
           
           RoundingRadius->0], 
          RectangleBox[{0.375, 0.}, 
           NCache[{0.38, Rational[25, 379]}, {0.38, 0.06596306068601583}],
           RoundingRadius->0], 
          RectangleBox[{0.38, 0.}, 
           NCache[{0.385, Rational[25, 379]}, {0.385, 0.06596306068601583}],
           RoundingRadius->0], RectangleBox[{0.385, 0.}, {0.39, 0},
           RoundingRadius->0], 
          RectangleBox[{0.39, 0.}, 
           NCache[{0.395, Rational[25, 379]}, {0.395, 0.06596306068601583}],
           RoundingRadius->0], RectangleBox[{0.395, 0.}, {0.4, 0},
           RoundingRadius->0], RectangleBox[{0.4, 0.}, {0.405, 0},
           RoundingRadius->0], RectangleBox[{0.405, 0.}, {0.41, 0},
           RoundingRadius->0], RectangleBox[{0.41, 0.}, {0.415, 0},
           RoundingRadius->0], RectangleBox[{0.415, 0.}, {0.42, 0},
           RoundingRadius->0], RectangleBox[{0.42, 0.}, {0.425, 0},
           RoundingRadius->0], RectangleBox[{0.425, 0.}, {0.43, 0},
           RoundingRadius->0], RectangleBox[{0.43, 0.}, {0.435, 0},
           RoundingRadius->0], RectangleBox[{0.435, 0.}, {0.44, 0},
           RoundingRadius->0], RectangleBox[{0.44, 0.}, {0.445, 0},
           RoundingRadius->0], 
          RectangleBox[{0.445, 0.}, 
           NCache[{0.45, Rational[25, 758]}, {0.45, 0.032981530343007916`}],
           RoundingRadius->0]}, {}, {}}}, {{}, {{}, {}, 
         {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
          Opacity[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsT8Vtu3JyseyDhD+FHu2qm0uHK3q
DjvkWl8H7phnn7vQdto6OW2o/BL7w7LiggFK2g6zZoLASvv7ha+MrS9rQNWv
s0/6cG7LR3tVhzeBIJGN9p8jnxnJWShC9W+xX8+u/+DmdCkHruuLC2y5tttL
858WFF0qDDVvp72Q7ocdBle4HTRj+g991dhjv9VhAlvIGyao+fvsK5lOBbju
+GG/BKj7+uID9lJMvod1WN/bQ+w7aF/964bv0Q2P7I3B4LD9/S+qflVzr9pD
7D9iv+/yjX23vx+3P/xVA2jDUXvvwl0v3Ep22kPcc9z+QFze/Gu3VtoHgS08
Yc/7eFetoMhMe4j7TtrnxLo4chm02z+sAhl4yv6yxO2IgNQSe4h7z9j7bn0V
7MieaF8Icl7BWfuAMLXg+6+97CHuP2efairVelncxB4SCxfsV02fsMbfWsYe
ALe+ueE=
           "]]}, 
         {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], Opacity[
          0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsY8qNFU578LjAOFPsXeW6Zk24ZSY
ww651teBO+bZz8xzdrvQJwOVX2L/7VtW+hReBYdZM0Fgpf28pFjTd28VoOrX
2Vf9SwmZJKzo8CYQJLLRXnK5b7zGEgWo/i32Ng0dje7N8g5c1xcX2HJtty9R
s7jbIioLNW+nPeujj8sMzaQcNGP6D33V2GOv/vq99ndRcaj5++wva9ukX74n
7LAEqPv64gP2F23CSzi3CEDtO2hvs8tGPT2F28EYDA7bP3j7KvnuPVao/Ufs
ZRz3xCl+Z3A4/FUDaMNR+62VXuxFjT/tIe45bv+pPkvnStsn+yCwhSfs/e/N
9nN8/9Ie4r6T9ie3MKuJFT20f1gFMvCU/e1js7RONF6zh7j3jL3P9wsbbp0+
bV8Icl7BWfslpppSOpkH7CHuP2f//WC2nFrzJntILFywdzXdf1Ti42J7ALp0
unI=
           "]]}}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesLabel->{None, None},
      AxesOrigin->{0., 0.},
      Epilog->{
        InsetBox[
         FormBox[
          StyleBox[
          "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
           False], TraditionalForm], 
         Scaled[{0.05, 0.95}]], 
        InsetBox[
         FormBox[
          StyleBox[
          "\"leptokurtic\"", 14, FontFamily -> "Helvetica", StripOnInput -> 
           False], TraditionalForm], 
         NCache[
          Scaled[{
            Rational[7, 8], 
            Rational[1, 2]}], 
          Scaled[{0.875, 0.5}]]]},
      Frame->{True, False, False, False},
      FrameLabel->{
        FormBox["\"Growth rate\"", TraditionalForm]},
      FrameTicksStyle->{Automatic, Automatic, Automatic, Automatic},
      LabelStyle->Directive[12, FontFamily -> "Helvetica"],
      Method->{},
      PlotRange->{{-0.3, 0.25}, {0, 40}},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {189., -361.8691769624716}, 
     ImageScaled[{0.5, 0.5}], {360., 291.2461179749811}]}, {}},
  ContentSelectable->True,
  ImageSize->350,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.784904518122554*^9, 3.784904529012877*^9}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2-step intermediate growth rate (figure S5)", "Subsection",
 CellChangeTimes->{{3.779477356570382*^9, 3.779477361850051*^9}, {
  3.779482848762312*^9, 3.779482851539497*^9}, {3.780068347007688*^9, 
  3.780068352358201*^9}}],

Cell[CellGroupData[{

Cell["\<\
Platykurtic (semicircle, panel A)\
\>", "Subsubsection",
 CellChangeTimes->{{3.7566733855717278`*^9, 3.7566733875576344`*^9}, {
  3.756673727633417*^9, 3.756673728609564*^9}, {3.760637625474948*^9, 
  3.76063762745905*^9}, {3.769433508402923*^9, 3.769433509874899*^9}, {
  3.769439032936616*^9, 3.76943903839826*^9}, {3.7794773798356237`*^9, 
  3.7794773862977257`*^9}, {3.784904157153232*^9, 3.784904158033132*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"-", "0.3"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmax", "=", "0.15"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymax", "=", "30"}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"N0", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", 
   RowBox[{"-", "0.2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"type", "=", "\"\<platy\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exact", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
     RowBox[{"prescuem", "[", 
      RowBox[{"m1", ",", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"critical", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"0", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     SqrtBox[
      RowBox[{"2", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}]], 
     RowBox[{"HeavisideTheta", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m1", "+", "pr0"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"pr0", "-", "m1"}], ")"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"subcritical", "=", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], 
     RowBox[{"Abs", "[", "m1", "]"}]], 
    RowBox[{"HeavisideTheta", "[", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "m1"}], "-", "pr0"}], ")"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"supercritical", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
     FractionBox[
      RowBox[{" ", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], 
      RowBox[{"Abs", "[", "m1", "]"}]], 
     RowBox[{"HeavisideTheta", "[", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "pr0"}], ")"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"allexact", "=", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{"exact", ",", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "mwt", ",", "0.1"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], ",", "\[IndentingNewLine]", 
    FractionBox[
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"pest", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}]}], 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fm", "[", 
         RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"pest", "[", 
         RowBox[{"m1", "-", "mwt"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], 
   "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory", "=", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{"%", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Filling", "\[Rule]", "Bottom"}], ","}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{"Gray", ",", "Thick", ",", "Dashed"}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Gray", ",", "Thick"}], "]"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{"\"\<random\>\"", ",", "\"\<established\>\""}], "}"}]}], 
          "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "8"}], ",", 
            RowBox[{"1.25", "/", "2"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    FractionBox["subcritical", "allexact"], ",", 
    FractionBox["critical", "allexact"], ",", 
    FractionBox["supercritical", "allexact"]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory", "=", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{"%", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"SwatchLegend", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Directive", "[", 
              RowBox[{
               RowBox[{"defaultcolors", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}], ",", 
             RowBox[{"Directive", "[", 
              RowBox[{
               RowBox[{"defaultcolors", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", 
               RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}], ",", 
             RowBox[{"Directive", "[", 
              RowBox[{
               RowBox[{"defaultcolors", "[", 
                RowBox[{"[", "3", "]"}], "]"}], ",", 
               RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}]}], "}"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{
             "\"\<subcritical\>\"", ",", "\"\<critical\>\"", ",", 
              "\"\<supercritical\>\""}], "}"}]}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "8"}], ",", 
            RowBox[{"0.65", "/", "2"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exactplot", "=", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"exact", "/", "allexact"}], ",", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", "Black", ",", 
         RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", "\"\<first-step\>\"", "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "8"}], ",", 
            RowBox[{"1.25", "/", "2"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StringForm", "[", 
   RowBox[{
    RowBox[{
    "datadir", "<>", 
     "\"\<dfe_``_N``_n``_U``_Es``_mmax``_mwt``_nreps100000.csv\>\""}], ",", 
    "type", ",", "N0", ",", "n", ",", 
    RowBox[{"NumberForm", "[", 
     RowBox[{
      RowBox[{"U", "//", "N"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "5"}], "}"}]}], "]"}], ",", 
    RowBox[{"NumberForm", "[", 
     RowBox[{"Es", ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}]}], "]"}], ",", 
    RowBox[{"NumberForm", "[", 
     RowBox[{"mmax", ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}]}], "]"}], ",", "mwt"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"ToString", "[", "%", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Select", "[", 
    RowBox[{"dat", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
   "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Histogram", "[", 
     RowBox[{"%", ",", "Automatic", ",", "\"\<PDF\>\"", ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], ",", 
      RowBox[{"ChartStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Gray", ",", 
         RowBox[{"Opacity", "[", "0.25", "]"}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figS5a", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
    "oldtheory", ",", "data", ",", "theory", ",", "exactplot", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontColor", "\[Rule]", "White"}], ",", "Automatic", ",", 
        "Automatic", ",", "Automatic"}], "}"}]}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<\!\(\*
StyleBox[SubscriptBox[\"m\", \"0\"],
FontSlant->\"Italic\"]\)=\>\"", "<>", 
             RowBox[{"ToString", "[", "mwt", "]"}]}], ",", "12", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"7", "/", "8"}], ",", 
             RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<A\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<platykurtic\>\"", ",", "14", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"7", "/", "8"}], ",", 
             RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}], 
       "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.780067993000177*^9, 3.780067997314149*^9}, {
  3.7822627696074963`*^9, 3.782262779670377*^9}, {3.784904547272605*^9, 
  3.784904559940302*^9}}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
       LineBox[CompressedData["
1:eJwVink41HsfQCm7yIw1ugqpUJmaklK/z89aSElxlUu2UJbKkiVkRCVrCFki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        "]]}, 
      {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxFyQk01XkfBnBi7CFClhBlzZalkP/3b6kREVFMJttMblkrW6RCsmS7lhAK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        "]]}}, 
     {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
      EdgeForm[Opacity[0.63]], {}, 
      {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
       EdgeForm[Opacity[0.63]], 
       TagBox[
        TooltipBox[
         TagBox[
          {GrayLevel[0.5], Opacity[0.25], 
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{-0.14, 0}, 
              NCache[{-0.13, 
                Rational[200, 197]}, {-0.13, 1.015228426395939}], 
              "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{138.73232838589976`, 147.6921614100185}, {
             115.56257574319521`, 123.74128865317425`}}]},
          StatusArea[#, 1.015228426395939]& ,
          TagBoxNote->"1.015228426395939"],
         StyleBox["1.015228426395939`", {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[1.015228426395939, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          {GrayLevel[0.5], Opacity[0.25], 
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{-0.13, 0}, 
              NCache[{-0.12, 
                Rational[300, 197]}, {-0.12, 1.5228426395939085`}], 
              "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{146.4421614100185, 155.40199443413726`}, {
             112.09821928820568`, 123.74128865317425`}}]},
          StatusArea[#, 1.5228426395939085`]& ,
          TagBoxNote->"1.5228426395939085"],
         StyleBox["1.5228426395939085`", {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[1.5228426395939085`, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          {GrayLevel[0.5], Opacity[0.25], 
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{-0.12, 0}, 
              NCache[{-0.11, 
                Rational[600, 197]}, {-0.11, 3.045685279187817}], 
              "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{154.15199443413726`, 163.11182745825602`}, {
             101.70514992323713`, 123.74128865317425`}}]},
          StatusArea[#, 3.045685279187817]& ,
          TagBoxNote->"3.045685279187817"],
         StyleBox["3.045685279187817`", {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[3.045685279187817, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          {GrayLevel[0.5], Opacity[0.25], 
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{-0.11, 0}, 
              NCache[{-0.1, 
                Rational[1100, 197]}, {-0.1, 5.583756345177665}], 
              "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{161.86182745825602`, 170.82166048237474`}, {
             84.38336764828952, 123.74128865317425`}}]},
          StatusArea[#, 5.583756345177665]& ,
          TagBoxNote->"5.583756345177665"],
         StyleBox["5.583756345177665`", {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[5.583756345177665, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          {GrayLevel[0.5], Opacity[0.25], 
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{-0.1, 0}, 
              NCache[{-0.09, 
                Rational[2100, 197]}, {-0.09, 10.65989847715736}], 
              "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{169.57166048237474`, 178.53149350649346`}, {
             49.739803098394304`, 123.74128865317425`}}]},
          StatusArea[#, 10.65989847715736]& ,
          TagBoxNote->"10.65989847715736"],
         StyleBox["10.65989847715736`", {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[10.65989847715736, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          {GrayLevel[0.5], Opacity[0.25], 
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{-0.09, 0}, 
              NCache[{-0.08, 
                Rational[2800, 197]}, {-0.08, 14.213197969543147`}], 
              "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{177.28149350649346`, 186.2413265306122}, {
             25.48930791346767, 123.74128865317425`}}]},
          StatusArea[#, 14.213197969543147`]& ,
          TagBoxNote->"14.213197969543147"],
         StyleBox["14.213197969543147`", {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[14.213197969543147`, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          {GrayLevel[0.5], Opacity[0.25], 
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{-0.08, 0}, 
              NCache[{-0.07, 
                Rational[3000, 197]}, {-0.07, 15.228426395939087`}], 
              "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{184.9913265306122, 193.95115955473096`}, {
             18.56059500348863, 123.74128865317425`}}]},
          StatusArea[#, 15.228426395939087`]& ,
          TagBoxNote->"15.228426395939087"],
         StyleBox["15.228426395939087`", {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[15.228426395939087`, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          {GrayLevel[0.5], Opacity[0.25], 
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{-0.07, 0}, 
              NCache[{-0.06, 
                Rational[4600, 197]}, {-0.06, 23.3502538071066}], 
              "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{192.70115955473096`, 
             201.6609925788497}, {-36.869108276343724`, 
             123.74128865317425`}}]},
          StatusArea[#, 23.3502538071066]& ,
          TagBoxNote->"23.3502538071066"],
         StyleBox["23.3502538071066`", {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[23.3502538071066, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          {GrayLevel[0.5], Opacity[0.25], 
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{-0.06, 0}, 
              NCache[{-0.05, 
                Rational[4700, 197]}, {-0.05, 23.85786802030457}], 
              "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{200.4109925788497, 
             209.37082560296844`}, {-40.33346473133324, 
             123.74128865317425`}}]},
          StatusArea[#, 23.85786802030457]& ,
          TagBoxNote->"23.85786802030457"],
         StyleBox["23.85786802030457`", {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[23.85786802030457, {
           GrayLevel[0]}], "Tooltip"]& ], 
       TagBox[
        TooltipBox[
         TagBox[
          {GrayLevel[0.5], Opacity[0.25], 
           DynamicBox[{
             FEPrivate`If[
              CurrentValue["MouseOver"], 
              EdgeForm[{
                GrayLevel[0.5], 
                AbsoluteThickness[1.5], 
                Opacity[0.66]}], {}, {}], 
             RectangleBox[{-0.05, 0}, 
              NCache[{-0.04, 
                Rational[300, 197]}, {-0.04, 1.5228426395939085`}], 
              "RoundingRadius" -> 0]},
            
            ImageSizeCache->{{208.12082560296844`, 217.0806586270872}, {
             112.09821928820568`, 123.74128865317425`}}]},
          StatusArea[#, 1.5228426395939085`]& ,
          TagBoxNote->"1.5228426395939085"],
         StyleBox["1.5228426395939085`", {
           GrayLevel[0]}, StripOnInput -> False]],
        Annotation[#, 
         Style[1.5228426395939085`, {
           GrayLevel[0]}], "Tooltip"]& ]}, {}, {}}, 
     GraphicsComplexBox[CompressedData["
1:eJzllnkw1fv/xw/JHmUNLbJTJCrazutjjWtJctHVLUudo5BCtiSkhJRUsoTI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      "], {{{}, 
        {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
         GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwt0EdOQgEABNCvYNcL2FExsRcgsSGgxoqNRERFEBs2QLz/wkfC4s3sZjGR
50au3hkEQQfldg+LP31AhVm+SZBjiCb7PBHlizjXDLLX3pshxhUDZCgxzTqX
9JPmkSnWuKCPFEUirHJOL7s8MMknK2TpIck9E3ywzBnd/LLDHeNUWeKULhps
U2CMdxY5IUydLW4Z5Y0FjglRY5M8I7wyzxGtn3/Y4Kb1My/Mccg/LzgY1w==

           "]]]}, {}, 
        {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
         GraphicsGroupBox[
          PolygonBox[{{154, 144, 168, 150, 160, 129, 169}}]]}, {}, 
        {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
         GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwlzMk2wmEcx+F/JUPKPGTplmzsXUCuz1ThHCTRwlwdSZQFojiG0ONYPOfz
+y7ed35peSEVDoIgxCIRxxzb7qTea1iLmtCKvrHFrN38e6tHGteyvrLJjN0I
/j8/lGEtaYcs0/ad/lIgZl9qmwxT9q3+cMCQfaEvpJm06/pNnkH7XJ/ZYMK+
0S77DNhn2mKdcbumX+Tot0/1iTXG7Gv9ZI+ofaKPrDJqV/WDXfrsY31ghRH7
St/ZoQfBLjfb
           
           "]]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
        {Hue[0.67, 0.6, 0.6], 
         LineBox[{1, 70, 41, 99, 26, 85, 56, 108, 2, 71, 42, 100, 27, 86, 57, 
          109, 3, 72, 43, 101, 28, 87, 58, 110, 4, 73, 44, 102, 29, 88, 59, 
          111, 5, 74, 45, 103, 30, 89, 60, 112, 6, 75, 46, 104, 31, 90, 61, 7,
           76, 47, 105, 32, 91, 62, 8, 77, 48, 33, 92, 63, 9, 78, 49, 34, 93, 
          64, 10, 79, 50, 35, 94, 65, 11, 80, 51, 36, 95, 66, 12, 81, 52, 106,
           37, 96, 67, 113, 13, 82, 53, 107, 38, 97, 68, 114, 14, 83, 54, 39, 
          15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 84, 55, 40, 98, 69, 115, 
          25}]}, 
        {Hue[0.9060679774997897, 0.6, 0.6], 
         LineBox[{116, 157, 147, 141, 117, 118, 119, 120, 121, 122, 123, 124, 
          125, 126, 127, 158, 148, 142, 163, 153, 128, 159, 149, 167, 143, 
          164, 154, 169, 129, 160, 150, 168, 144, 165, 155, 130, 161, 151, 
          145, 131, 132, 133, 134, 135, 136, 137, 138, 139, 162, 152, 146, 
          166, 156, 170, 140}]}, 
        {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzUVSQwEURcGPOyT4lC2xBBYQFkaA4O4OIQR3d3fXZtB16tYbvKqa2upI
ShAEEeq4YJ5RotTTQCMxmmimhVbaaKeDSxYY45UdOrlikTSPxvWNXQrtLr1m
iXR7Qt/Zo8ju1huWybAn9YN9QnaP3rJCpj2lnxwQtnv1jlWy7Gn94pBiu0/v
WSPbntFvjiix+/WBdXLsuP5wTKk9oI9skGvP6i8nlNmD+sQmeXZCAz2Vch3S
Z7bIt+f+z3qmFTqsL2xTYCc1Vc+1Ukf0D0T7SiA=
          "]]}}}], {{}, {}, 
      {GrayLevel[0], Thickness[Large], Opacity[0.5], LineBox[CompressedData["
1:eJwVlPc/1X0fgCkZUZmV0bD3KEnC9/0lUvaIuEVROYlKKCNZiWSG7JEc1CmS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        "]]}}}, {InsetBox[
      TemplateBox[{
       StyleBox[
        "\"subcritical\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"critical\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"supercritical\"", StripOnInput -> False, FontFamily -> "Helvetica",
          FontSize -> 12]},
       "SwatchLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"SwatchLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.5470136627990908`", ",", "0.24`"}], "]"}],
                     ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      NCache[Scaled[{Rational[1, 8], 0.325}], Scaled[{0.125, 0.325}]], 
      ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TagBox[GridBox[{
         {
          
          TemplateBox[{
           StyleBox[
            "\"random\"", StripOnInput -> False, FontFamily -> "Helvetica", 
             FontSize -> 12],StyleBox[
            "\"established\"", StripOnInput -> False, FontFamily -> 
             "Helvetica", FontSize -> 12]},
           "LineLegend",
           DisplayFunction->(StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
             False]& ),
           Editable->True,
           InterpretationFunction:>(RowBox[{"LineLegend", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
                  "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{#, ",", #2}], "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
              "]"}]& )]},
         {
          
          TemplateBox[{
           StyleBox[
            "\"first-step\"", StripOnInput -> False, FontFamily -> 
             "Helvetica", FontSize -> 12]},
           "LineLegend",
           DisplayFunction->(StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
             False]& ),
           Editable->True,
           InterpretationFunction:>(RowBox[{"LineLegend", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], "}"}], 
                ",", 
                RowBox[{"{", #, "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{0}}}],
       "Grid"], NCache[
      Scaled[{Rational[1, 8], 0.625}], Scaled[{0.125, 0.625}]], ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesLabel->{None, None},
   AxesOrigin->{0, 0},
   Epilog->{
     InsetBox[
      FormBox[
       StyleBox[
       "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=-0.2\"", 12, FontFamily -> 
        "Helvetica", StripOnInput -> False], TraditionalForm], 
      NCache[
       Scaled[{
         Rational[7, 8], 
         Rational[3, 4]}], 
       Scaled[{0.875, 0.75}]]], 
     InsetBox[
      FormBox[
       StyleBox[
       "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
       TraditionalForm], 
      Scaled[{0.05, 0.95}]], 
     InsetBox[
      FormBox[
       StyleBox[
       "\"platykurtic\"", 14, FontFamily -> "Helvetica", StripOnInput -> 
        False], TraditionalForm], 
      NCache[
       Scaled[{
         Rational[7, 8], 
         Rational[1, 2]}], 
       Scaled[{0.875, 0.5}]]]},
   Frame->{True, False, False, False},
   FrameTicksStyle->{
    FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.3, 0.25}, {0, 40}},
   PlotRangeClipping->True,
   PlotRangePadding->{
     Scaled[0.02], Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          GrayLevel[0.5], 
          Thickness[Large], 
          Dashing[{Small, Small}]], 
         Line[CompressedData["
1:eJwVink41HsfQCm7yIw1ugqpUJmaklK/z89aSElxlUu2UJbKkiVkRCVrCFki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          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          GrayLevel[0.5], 
          Thickness[Large]], 
         Line[CompressedData["
1:eJxFyQk01XkfBnBi7CFClhBlzZalkP/3b6kREVFMJttMblkrW6RCsmS7lhAK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          "]]}}}, {
       Directive[
        EdgeForm[
         Opacity[0.63]], 
        RGBColor[
        0.798413061722744, 0.824719615472648, 0.968322270542458]], {{}, {
         Directive[
          EdgeForm[
           Opacity[0.63]], 
          RGBColor[
          0.798413061722744, 0.824719615472648, 0.968322270542458]], {{
           Tooltip[
            StatusArea[{
              Directive[
               GrayLevel[0.5], 
               Opacity[0.25]], 
              RawBoxes[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.14, 0}, 
                  NCache[{-0.13, 
                    Rational[200, 197]}, {-0.13, 1.015228426395939}], 
                  "RoundingRadius" -> 0]}]]}, 1.015228426395939], 
            Style[1.015228426395939, {
              GrayLevel[0]}]]}, {
           Tooltip[
            StatusArea[{
              Directive[
               GrayLevel[0.5], 
               Opacity[0.25]], 
              RawBoxes[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.13, 0}, 
                  NCache[{-0.12, 
                    Rational[300, 197]}, {-0.12, 1.5228426395939085`}], 
                  "RoundingRadius" -> 0]}]]}, 1.5228426395939085`], 
            Style[1.5228426395939085`, {
              GrayLevel[0]}]]}, {
           Tooltip[
            StatusArea[{
              Directive[
               GrayLevel[0.5], 
               Opacity[0.25]], 
              RawBoxes[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.12, 0}, 
                  NCache[{-0.11, 
                    Rational[600, 197]}, {-0.11, 3.045685279187817}], 
                  "RoundingRadius" -> 0]}]]}, 3.045685279187817], 
            Style[3.045685279187817, {
              GrayLevel[0]}]]}, {
           Tooltip[
            StatusArea[{
              Directive[
               GrayLevel[0.5], 
               Opacity[0.25]], 
              RawBoxes[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.11, 0}, 
                  NCache[{-0.1, 
                    Rational[1100, 197]}, {-0.1, 5.583756345177665}], 
                  "RoundingRadius" -> 0]}]]}, 5.583756345177665], 
            Style[5.583756345177665, {
              GrayLevel[0]}]]}, {
           Tooltip[
            StatusArea[{
              Directive[
               GrayLevel[0.5], 
               Opacity[0.25]], 
              RawBoxes[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.1, 0}, 
                  NCache[{-0.09, 
                    Rational[2100, 197]}, {-0.09, 10.65989847715736}], 
                  "RoundingRadius" -> 0]}]]}, 10.65989847715736], 
            Style[10.65989847715736, {
              GrayLevel[0]}]]}, {
           Tooltip[
            StatusArea[{
              Directive[
               GrayLevel[0.5], 
               Opacity[0.25]], 
              RawBoxes[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.09, 0}, 
                  NCache[{-0.08, 
                    Rational[2800, 197]}, {-0.08, 14.213197969543147`}], 
                  "RoundingRadius" -> 0]}]]}, 14.213197969543147`], 
            Style[14.213197969543147`, {
              GrayLevel[0]}]]}, {
           Tooltip[
            StatusArea[{
              Directive[
               GrayLevel[0.5], 
               Opacity[0.25]], 
              RawBoxes[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.08, 0}, 
                  NCache[{-0.07, 
                    Rational[3000, 197]}, {-0.07, 15.228426395939087`}], 
                  "RoundingRadius" -> 0]}]]}, 15.228426395939087`], 
            Style[15.228426395939087`, {
              GrayLevel[0]}]]}, {
           Tooltip[
            StatusArea[{
              Directive[
               GrayLevel[0.5], 
               Opacity[0.25]], 
              RawBoxes[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.07, 0}, 
                  NCache[{-0.06, 
                    Rational[4600, 197]}, {-0.06, 23.3502538071066}], 
                  "RoundingRadius" -> 0]}]]}, 23.3502538071066], 
            Style[23.3502538071066, {
              GrayLevel[0]}]]}, {
           Tooltip[
            StatusArea[{
              Directive[
               GrayLevel[0.5], 
               Opacity[0.25]], 
              RawBoxes[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.06, 0}, 
                  NCache[{-0.05, 
                    Rational[4700, 197]}, {-0.05, 23.85786802030457}], 
                  "RoundingRadius" -> 0]}]]}, 23.85786802030457], 
            Style[23.85786802030457, {
              GrayLevel[0]}]]}, {
           Tooltip[
            StatusArea[{
              Directive[
               GrayLevel[0.5], 
               Opacity[0.25]], 
              RawBoxes[
               DynamicBox[{
                 FEPrivate`If[
                  CurrentValue["MouseOver"], 
                  EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                 RectangleBox[{-0.05, 0}, 
                  NCache[{-0.04, 
                    Rational[300, 197]}, {-0.04, 1.5228426395939085`}], 
                  "RoundingRadius" -> 0]}]]}, 1.5228426395939085`], 
            Style[1.5228426395939085`, {
              GrayLevel[0]}]]}}}, {}, {}}}, 
      GraphicsComplex[CompressedData["
1:eJzllnkw1fv/xw/JHmUNLbJTJCrazutjjWtJctHVLUudo5BCtiSkhJRUsoTI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       "], {{{}, {
          EdgeForm[], 
          Directive[{
            Opacity[0.2], 
            Hue[0.67, 0.6, 0.6]}], 
          GraphicsGroup[{
            Polygon[CompressedData["
1:eJwt0EdOQgEABNCvYNcL2FExsRcgsSGgxoqNRERFEBs2QLz/wkfC4s3sZjGR
50au3hkEQQfldg+LP31AhVm+SZBjiCb7PBHlizjXDLLX3pshxhUDZCgxzTqX
9JPmkSnWuKCPFEUirHJOL7s8MMknK2TpIck9E3ywzBnd/LLDHeNUWeKULhps
U2CMdxY5IUydLW4Z5Y0FjglRY5M8I7wyzxGtn3/Y4Kb1My/Mccg/LzgY1w==

             "]]}]}, {}, {
          EdgeForm[], 
          Directive[{
            Opacity[0.2], 
            Hue[0.9060679774997897, 0.6, 0.6]}], 
          GraphicsGroup[{
            Polygon[{{154, 144, 168, 150, 160, 129, 169}}]}]}, {}, {
          EdgeForm[], 
          Directive[{
            Opacity[0.2], 
            Hue[0.1421359549995791, 0.6, 0.6]}], 
          GraphicsGroup[{
            Polygon[CompressedData["
1:eJwlzMk2wmEcx+F/JUPKPGTplmzsXUCuz1ThHCTRwlwdSZQFojiG0ONYPOfz
+y7ed35peSEVDoIgxCIRxxzb7qTea1iLmtCKvrHFrN38e6tHGteyvrLJjN0I
/j8/lGEtaYcs0/ad/lIgZl9qmwxT9q3+cMCQfaEvpJm06/pNnkH7XJ/ZYMK+
0S77DNhn2mKdcbumX+Tot0/1iTXG7Gv9ZI+ofaKPrDJqV/WDXfrsY31ghRH7
St/ZoQfBLjfb
             
             "]]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, \
{}, {
          Hue[0.67, 0.6, 0.6], 
          
          Line[{1, 70, 41, 99, 26, 85, 56, 108, 2, 71, 42, 100, 27, 86, 57, 
           109, 3, 72, 43, 101, 28, 87, 58, 110, 4, 73, 44, 102, 29, 88, 59, 
           111, 5, 74, 45, 103, 30, 89, 60, 112, 6, 75, 46, 104, 31, 90, 61, 
           7, 76, 47, 105, 32, 91, 62, 8, 77, 48, 33, 92, 63, 9, 78, 49, 34, 
           93, 64, 10, 79, 50, 35, 94, 65, 11, 80, 51, 36, 95, 66, 12, 81, 52,
            106, 37, 96, 67, 113, 13, 82, 53, 107, 38, 97, 68, 114, 14, 83, 
           54, 39, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 84, 55, 40, 98, 69,
            115, 25}]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          
          Line[{116, 157, 147, 141, 117, 118, 119, 120, 121, 122, 123, 124, 
           125, 126, 127, 158, 148, 142, 163, 153, 128, 159, 149, 167, 143, 
           164, 154, 169, 129, 160, 150, 168, 144, 165, 155, 130, 161, 151, 
           145, 131, 132, 133, 134, 135, 136, 137, 138, 139, 162, 152, 146, 
           166, 156, 170, 140}]}, {
          Hue[0.1421359549995791, 0.6, 0.6], 
          Line[CompressedData["
1:eJwVzUVSQwEURcGPOyT4lC2xBBYQFkaA4O4OIQR3d3fXZtB16tYbvKqa2upI
ShAEEeq4YJ5RotTTQCMxmmimhVbaaKeDSxYY45UdOrlikTSPxvWNXQrtLr1m
iXR7Qt/Zo8ju1huWybAn9YN9QnaP3rJCpj2lnxwQtnv1jlWy7Gn94pBiu0/v
WSPbntFvjiix+/WBdXLsuP5wTKk9oI9skGvP6i8nlNmD+sQmeXZCAz2Vch3S
Z7bIt+f+z3qmFTqsL2xTYCc1Vc+1Ukf0D0T7SiA=
           "]]}}}], {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          Thickness[Large], 
          GrayLevel[0], 
          Opacity[0.5]], 
         Line[CompressedData["
1:eJwVlPc/1X0fgCkZUZmV0bD3KEnC9/0lUvaIuEVROYlKKCNZiWSG7JEc1CmS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          "]]}}}}, {
     Frame -> {True, False, False, False}, 
      FrameTicksStyle -> {
       FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, 
      PlotRange -> {{-0.3, 0.25}, {0, 40}}, LabelStyle -> 
      Directive[12, FontFamily -> "Helvetica"], Epilog -> {
        Text[
         Style[
         "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=-0.2", 12, FontFamily -> "Helvetica"], 
         Scaled[{
           Rational[7, 8], 
           Rational[3, 4]}]], 
        Text[
         Style["A", 14, Bold, FontFamily -> "Helvetica"], 
         Scaled[{0.05, 0.95}]], 
        Text[
         Style["platykurtic", 14, FontFamily -> "Helvetica"], 
         Scaled[{
           Rational[7, 8], 
           Rational[1, 2]}]]}, AspectRatio -> GoldenRatio^(-1), Axes -> True, 
      AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
      PlotRange -> {{-0.3, 0.25}, {0, All}}, PlotRangeClipping -> True, 
      PlotRangePadding -> {
        Scaled[0.02], Automatic}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          Thickness[Large], 
          GrayLevel[0], 
          Opacity[0.5]]}, {
         Style["first-step", 12, FontFamily -> "Helvetica"]}, LegendLayout -> 
        "Column"]], 
      Scaled[{
        Rational[1, 8], 0.625}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.780068017612506*^9, {3.782262776154358*^9, 3.7822628022060137`*^9}, 
   3.784904583678905*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Leptokurtic (Laplace, panel B)", "Subsubsection",
 CellChangeTimes->{{3.7566733855717278`*^9, 3.7566733875576344`*^9}, {
  3.756673727633417*^9, 3.756673728609564*^9}, {3.760637625474948*^9, 
  3.76063762745905*^9}, {3.769433508402923*^9, 3.769433509874899*^9}, {
  3.769439032936616*^9, 3.76943903839826*^9}, {3.7794773798356237`*^9, 
  3.7794773862977257`*^9}, {3.780063479096868*^9, 3.780063485574933*^9}, {
  3.784904159889151*^9, 3.784904162872971*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"N0", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", 
   RowBox[{"-", "0.2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"type", "=", "\"\<lepto\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"mneg", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", 
         RowBox[{"-", "0.1"}]}], "}"}]}], "]"}]}], ",", 
    RowBox[{"mpos", "=", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", 
         SuperscriptBox["m1", "2"]}], "-", 
        RowBox[{"\[CapitalLambda]1", "[", 
         RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "0.1"}], "}"}]}], "]"}]}]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pr0", "=", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}], "/", "2"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exact", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
     RowBox[{"prescuem", "[", 
      RowBox[{"m1", ",", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"critical", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"0", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     SqrtBox[
      RowBox[{"2", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}]], 
     RowBox[{"HeavisideTheta", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"m1", "+", "pr0"}], ")"}], 
       RowBox[{"(", 
        RowBox[{"pr0", "-", "m1"}], ")"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"subcritical", "=", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], 
    FractionBox[
     RowBox[{" ", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], 
     RowBox[{"Abs", "[", "m1", "]"}]], 
    RowBox[{"HeavisideTheta", "[", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "m1"}], "-", "pr0"}], ")"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"supercritical", "=", 
    RowBox[{
     RowBox[{"fm", "[", 
      RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
      "]"}], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
     FractionBox[
      RowBox[{" ", 
       RowBox[{"\[CapitalLambda]1", "[", 
        RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], 
      RowBox[{"Abs", "[", "m1", "]"}]], 
     RowBox[{"HeavisideTheta", "[", 
      RowBox[{"(", 
       RowBox[{"m1", "-", "pr0"}], ")"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"allexact", "=", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{"exact", ",", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "mwt", ",", "0.1"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], ",", "\[IndentingNewLine]", 
    FractionBox[
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"pest", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}]}], 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fm", "[", 
         RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"pest", "[", 
         RowBox[{"m1", "-", "mwt"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], 
   "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory", "=", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{"%", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Filling", "\[Rule]", "Bottom"}], ","}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{"Gray", ",", "Thick", ",", "Dashed"}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Gray", ",", "Thick"}], "]"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], 
     RowBox[{"(*", 
      RowBox[{",", "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"LineLegend", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{"\"\<random\>\"", ",", "\"\<established\>\""}], "}"}]}], 
           "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"1", "/", "8"}], ",", 
             RowBox[{"1.25", "/", "2"}]}], "}"}]}]}], "]"}]}]}], "*)"}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    FractionBox["subcritical", "allexact"], ",", 
    FractionBox["critical", "allexact"], ",", 
    FractionBox["supercritical", "allexact"]}], "}"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory", "=", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{"%", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"Filling", "\[Rule]", "Bottom"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], 
     RowBox[{"(*", 
      RowBox[{",", "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"SwatchLegend", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Directive", "[", 
               RowBox[{
                RowBox[{"defaultcolors", "[", 
                 RowBox[{"[", "1", "]"}], "]"}], ",", 
                RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}], ",", 
              RowBox[{"Directive", "[", 
               RowBox[{
                RowBox[{"defaultcolors", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], ",", 
                RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}], ",", 
              RowBox[{"Directive", "[", 
               RowBox[{
                RowBox[{"defaultcolors", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], ",", 
                RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}]}], "}"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"#", ",", "12", ",", 
                RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
               "]"}], "&"}], "/@", 
             RowBox[{"{", 
              RowBox[{
              "\"\<subcritical\>\"", ",", "\"\<critical\>\"", ",", 
               "\"\<supercritical\>\""}], "}"}]}]}], "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"1", "/", "8"}], ",", 
             RowBox[{"0.65", "/", "2"}]}], "}"}]}]}], "]"}]}]}], "*)"}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"exactplot", "=", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"exact", "/", "allexact"}], ",", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", "Black", ",", 
         RowBox[{"Opacity", "[", "0.5", "]"}]}], "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], 
     RowBox[{"(*", 
      RowBox[{",", "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"LineLegend", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", "\"\<first-step\>\"", "}"}]}], "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"1", "/", "8"}], ",", 
             RowBox[{"1.25", "/", "2"}]}], "}"}]}]}], "]"}]}]}], "*)"}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StringForm", "[", 
   RowBox[{
    RowBox[{
    "datadir", "<>", 
     "\"\<dfe_``_N``_n``_U``_Es``_mmax``_mwt``_nreps100000.csv\>\""}], ",", 
    "type", ",", "N0", ",", "n", ",", 
    RowBox[{"NumberForm", "[", 
     RowBox[{
      RowBox[{"U", "//", "N"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "5"}], "}"}]}], "]"}], ",", 
    RowBox[{"NumberForm", "[", 
     RowBox[{"Es", ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}]}], "]"}], ",", 
    RowBox[{"NumberForm", "[", 
     RowBox[{"mmax", ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}]}], "]"}], ",", "mwt"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dat", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"ToString", "[", "%", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Select", "[", 
    RowBox[{"dat", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "2"}], "&"}]}], "]"}], 
   "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "3"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"data", "=", 
    RowBox[{"Histogram", "[", 
     RowBox[{"%", ",", "Automatic", ",", "\"\<PDF\>\"", ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], ",", 
      RowBox[{"ChartStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Gray", ",", 
         RowBox[{"Opacity", "[", "0.25", "]"}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figS5b", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
    "oldtheory", ",", "data", ",", "theory", ",", "exactplot", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "Automatic", ",", "Automatic", ",", "Automatic", ",", "Automatic"}], 
       "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", "\"\<Growth rate\>\"", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{
             RowBox[{"\"\<\!\(\*
StyleBox[SubscriptBox[\"m\", \"0\"],
FontSlant->\"Italic\"]\)=\>\"", "<>", 
              RowBox[{"ToString", "[", "mwt", "]"}]}], ",", "12", ",", 
             RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
           ",", 
           RowBox[{"Scaled", "@", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"7", "/", "8"}], ",", 
              RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ","}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<B\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<leptokurtic\>\"", ",", "14", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"7", "/", "8"}], ",", 
             RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}], 
       "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.771259863315041*^9, 3.771259875817935*^9}, {
   3.77125993618959*^9, 3.7712599967791033`*^9}, {3.7712600806108303`*^9, 
   3.771260101998229*^9}, {3.7712601420091887`*^9, 3.771260164023238*^9}, {
   3.7712604866075153`*^9, 3.7712604916540623`*^9}, {3.771260596998*^9, 
   3.7712606779327497`*^9}, {3.771260742113587*^9, 3.77126078863237*^9}, {
   3.7712608356681213`*^9, 3.771260853796445*^9}, 3.77126088730492*^9, {
   3.771260950376927*^9, 3.771260951994858*^9}, {3.771260988204628*^9, 
   3.771261046264202*^9}, {3.771261095976034*^9, 3.771261100349186*^9}, {
   3.771261221602476*^9, 3.771261223165237*^9}, {3.7712612596219587`*^9, 
   3.771261376814014*^9}, {3.7712614254017878`*^9, 3.771261458422593*^9}, {
   3.771261523796259*^9, 3.771261558803645*^9}, {3.771525291980131*^9, 
   3.771525296404852*^9}, {3.771525340514213*^9, 3.771525362538801*^9}, {
   3.771525476715866*^9, 3.771525481529388*^9}, {3.771525527353706*^9, 
   3.771525572057776*^9}, {3.771525611182823*^9, 3.77152571017303*^9}, {
   3.771525850691698*^9, 3.771525923002439*^9}, {3.771525956576083*^9, 
   3.771525983790447*^9}, {3.771526019222022*^9, 3.7715260269883137`*^9}, {
   3.771526062519966*^9, 3.77152607841735*^9}, {3.771526152732314*^9, 
   3.771526160701219*^9}, {3.771526280292366*^9, 3.771526400673423*^9}, 
   3.771526440426137*^9, {3.7794773959510937`*^9, 3.7794774153789377`*^9}, 
   3.779479818451282*^9, {3.779482804081335*^9, 3.779482804522912*^9}, {
   3.780063051430872*^9, 3.78006305162116*^9}, {3.780063286850298*^9, 
   3.780063305483961*^9}, {3.780063489828211*^9, 3.780063490633092*^9}, {
   3.7800676370282516`*^9, 3.7800676950403423`*^9}, 3.780067730901782*^9, {
   3.780068053927796*^9, 3.780068057366358*^9}, {3.780068149395151*^9, 
   3.78006820057061*^9}, {3.782262800755519*^9, 3.7822628077352257`*^9}, {
   3.784904571694641*^9, 3.784904577940155*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
     LineBox[CompressedData["
1:eJwVink41HsfQCm7yIw1ugqpUJmaklK/z89aSElxlUu2UJbKkiVkRCVrCFki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      "]]}, 
    {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxFyQk01XkfBnBi7CFClhBlzZalkP/3b6kREVFMJttMblkrW6RCsmS7lhAK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      "]]}}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.504]], {}, 
    {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
     EdgeForm[Opacity[0.504]], 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.3, 0}, 
       NCache[{-0.28, Rational[100, 1153]}, {-0.28, 0.08673026886383348}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.24, 0}, 
       NCache[{-0.22, Rational[200, 1153]}, {-0.22, 0.17346053772766695`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.22, 0}, 
       NCache[{-0.2, Rational[150, 1153]}, {-0.2, 0.13009540329575023`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.2, 0}, 
       NCache[{-0.18, Rational[700, 1153]}, {-0.18, 0.6071118820468343}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.18, 0}, 
       NCache[{-0.16, Rational[900, 1153]}, {-0.16, 0.7805724197745013}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.16, 0}, 
       NCache[{-0.14, Rational[650, 1153]}, {-0.14, 0.5637467476149176}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.14, 0}, 
       NCache[{-0.12, Rational[750, 1153]}, {-0.12, 0.6504770164787511}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.12, 0}, 
       NCache[{-0.1, Rational[1050, 1153]}, {-0.1, 0.9106678230702515}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.1, 0}, 
       NCache[{-0.08, Rational[1350, 1153]}, {-0.08, 1.170858629661752}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.08, 0}, 
       NCache[{-0.06, Rational[1900, 1153]}, {-0.06, 1.647875108412836}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.06, 0}, 
       NCache[{-0.04, Rational[2350, 1153]}, {-0.04, 2.038161318300087}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.04, 0}, 
       NCache[{-0.02, Rational[4100, 1153]}, {-0.02, 3.5559410234171724`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{-0.02, 0}, 
       NCache[{0., Rational[11200, 1153]}, {0., 9.713790112749349}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0., 0}, 
       NCache[{0.02, Rational[9450, 1153]}, {0.02, 8.196010407632263}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.02, 0}, 
       NCache[{0.04, Rational[7850, 1153]}, {0.04, 6.808326105810928}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.04, 0}, 
       NCache[{0.06, Rational[5400, 1153]}, {0.06, 4.683434518647008}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.06, 0}, 
       NCache[{0.08, Rational[3300, 1153]}, {0.08, 2.862098872506505}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.08, 0}, 
       NCache[{0.1, Rational[2200, 1153]}, {0.1, 1.9080659150043364`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.1, 0}, 
       NCache[{0.12, Rational[1700, 1153]}, {0.12, 1.4744145706851692`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.12, 0}, 
       NCache[{0.14, Rational[1050, 1153]}, {0.14, 0.9106678230702515}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.14, 0}, 
       NCache[{0.16, Rational[600, 1153]}, {0.16, 0.5203816131830009}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.16, 0}, 
       NCache[{0.18, Rational[350, 1153]}, {0.18, 0.30355594102341715`}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.18, 0}, 
       NCache[{0.2, Rational[50, 1153]}, {0.2, 0.04336513443191674}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.2, 0}, 
       NCache[{0.22, Rational[50, 1153]}, {0.22, 0.04336513443191674}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.22, 0}, 
       NCache[{0.24, Rational[100, 1153]}, {0.24, 0.08673026886383348}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.24, 0}, 
       NCache[{0.26, Rational[50, 1153]}, {0.26, 0.04336513443191674}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.26, 0}, 
       NCache[{0.28, Rational[50, 1153]}, {0.28, 0.04336513443191674}],
       RoundingRadius->0]}, 
     {GrayLevel[0.5], Opacity[0.25], 
      RectangleBox[{0.3, 0}, 
       NCache[{0.32, Rational[50, 1153]}, {0.32, 0.04336513443191674}],
       RoundingRadius->0]}}, {}, {}}, GraphicsComplexBox[CompressedData["
1:eJzllnkw1fv/xw/JHmUNLbJTJCrazutjjWtJctHVLUudo5BCtiSkhJRUsoTI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    "], {{{}, 
      {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwt0EdOQgEABNCvYNcL2FExsRcgsSGgxoqNRERFEBs2QLz/wkfC4s3sZjGR
50au3hkEQQfldg+LP31AhVm+SZBjiCb7PBHlizjXDLLX3pshxhUDZCgxzTqX
9JPmkSnWuKCPFEUirHJOL7s8MMknK2TpIck9E3ywzBnd/LLDHeNUWeKULhps
U2CMdxY5IUydLW4Z5Y0FjglRY5M8I7wyzxGtn3/Y4Kb1My/Mccg/LzgY1w==

         "]]]}, {}, 
      {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{154, 144, 168, 150, 160, 129, 169}}]]}, {}, 
      {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwlzMk2wmEcx+F/JUPKPGTplmzsXUCuz1ThHCTRwlwdSZQFojiG0ONYPOfz
+y7ed35peSEVDoIgxCIRxxzb7qTea1iLmtCKvrHFrN38e6tHGteyvrLJjN0I
/j8/lGEtaYcs0/ad/lIgZl9qmwxT9q3+cMCQfaEvpJm06/pNnkH7XJ/ZYMK+
0S77DNhn2mKdcbumX+Tot0/1iTXG7Gv9ZI+ofaKPrDJqV/WDXfrsY31ghRH7
St/ZoQfBLjfb
         
         "]]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, 
      {Hue[0.67, 0.6, 0.6], 
       LineBox[{1, 70, 41, 99, 26, 85, 56, 108, 2, 71, 42, 100, 27, 86, 57, 
        109, 3, 72, 43, 101, 28, 87, 58, 110, 4, 73, 44, 102, 29, 88, 59, 111,
         5, 74, 45, 103, 30, 89, 60, 112, 6, 75, 46, 104, 31, 90, 61, 7, 76, 
        47, 105, 32, 91, 62, 8, 77, 48, 33, 92, 63, 9, 78, 49, 34, 93, 64, 10,
         79, 50, 35, 94, 65, 11, 80, 51, 36, 95, 66, 12, 81, 52, 106, 37, 96, 
        67, 113, 13, 82, 53, 107, 38, 97, 68, 114, 14, 83, 54, 39, 15, 16, 17,
         18, 19, 20, 21, 22, 23, 24, 84, 55, 40, 98, 69, 115, 25}]}, 
      {Hue[0.9060679774997897, 0.6, 0.6], 
       LineBox[{116, 157, 147, 141, 117, 118, 119, 120, 121, 122, 123, 124, 
        125, 126, 127, 158, 148, 142, 163, 153, 128, 159, 149, 167, 143, 164, 
        154, 169, 129, 160, 150, 168, 144, 165, 155, 130, 161, 151, 145, 131, 
        132, 133, 134, 135, 136, 137, 138, 139, 162, 152, 146, 166, 156, 170, 
        140}]}, 
      {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzUVSQwEURcGPOyT4lC2xBBYQFkaA4O4OIQR3d3fXZtB16tYbvKqa2upI
ShAEEeq4YJ5RotTTQCMxmmimhVbaaKeDSxYY45UdOrlikTSPxvWNXQrtLr1m
iXR7Qt/Zo8ju1huWybAn9YN9QnaP3rJCpj2lnxwQtnv1jlWy7Gn94pBiu0/v
WSPbntFvjiix+/WBdXLsuP5wTKk9oI9skGvP6i8nlNmD+sQmeXZCAz2Vch3S
Z7bIt+f+z3qmFTqsL2xTYCc1Vc+1Ukf0D0T7SiA=
        "]]}}}], {{}, {}, 
    {GrayLevel[0], Thickness[Large], Opacity[0.5], LineBox[CompressedData["
1:eJwVlPc/1X0fgCkZUZmV0bD3KEnC9/0lUvaIuEVROYlKKCNZiWSG7JEc1CmS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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  Epilog->{
    InsetBox[
     FormBox[
      StyleBox[
      "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
      TraditionalForm], 
     Scaled[{0.05, 0.95}]], 
    InsetBox[
     FormBox[
      StyleBox[
      "\"leptokurtic\"", 14, FontFamily -> "Helvetica", StripOnInput -> 
       False], TraditionalForm], 
     NCache[
      Scaled[{
        Rational[7, 8], 
        Rational[1, 2]}], 
      Scaled[{0.875, 0.5}]]]},
  Frame->{True, False, False, False},
  FrameLabel->{
    FormBox["\"Growth rate\"", TraditionalForm]},
  FrameTicksStyle->{Automatic, Automatic, Automatic, Automatic},
  LabelStyle->Directive[12, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{-0.3, 0.25}, {0, 40}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{
  3.771525510234125*^9, 3.7715256009094276`*^9, 3.771525757082961*^9, 
   3.771525945477487*^9, 3.771526012114366*^9, 3.771526049084855*^9, 
   3.7715261034426117`*^9, 3.771526184585018*^9, 3.771526357338108*^9, 
   3.771526389498026*^9, 3.771526423875675*^9, 3.7794798589403677`*^9, 
   3.780063098246232*^9, 3.7800633399036427`*^9, 3.7800635102016077`*^9, 
   3.7800677160872507`*^9, 3.78006774942317*^9, 3.780068076339994*^9, {
   3.7800681985787277`*^9, 3.7800682241585627`*^9}, 3.7822628300633*^9, 
   3.784904603257433*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure S5", "Subsubsection",
 CellChangeTimes->{{3.784904168849897*^9, 3.784904171353175*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GraphicsColumn", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"figS5a", ",", "figS5b"}], "}"}], ",", 
   RowBox[{"Spacings", "\[Rule]", 
    RowBox[{"-", "50"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{"supfigdir", "<>", "\"\<FigureS5.pdf\>\""}], ",", "%"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.784904601175037*^9, 3.784904605082445*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     FormBox[
      TagBox[
       FormBox[
        GraphicsBox[{{{{}, {}, 
            {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
             LineBox[CompressedData["
1:eJwVink41HsfQCm7yIw1ugqpUJmaklK/z89aSElxlUu2UJbKkiVkRCVrCFki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              "]]}, 
            {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxFyQk01XkfBnBi7CFClhBlzZalkP/3b6kREVFMJttMblkrW6RCsmS7lhAK
RZYpXZHd/V3bvbZru5N1Sta8KEokinfec97Dc85znvM5zwFXn7OXdjExMT3+
t//bQ3PpYpqaDMT0/3w6nS/Kx7bj6pekffND/ds2828Xfnp7x1eZNgQEO/q2
7f/4S2+yUe+237ayh3KU0LddcZnW7mO14/vcUYKDq13bPmbNVlhgvGPer61L
PHOd255Ou6fnR9xx8j+s3UZvO7Ztn6fIKRCy4/1ulibjYjueUPK9Q6pp33bR
YnrtHft2pDLlbCmrMAjeFfUrlt/akGd+umBWxQJoBo2rS6a1ocz9+yPZOleB
vEu5sJ5BQ4WX/zq8K50Fl9ZIs+QIoiFxESpiO8mO33ViXrWRpKESpO6gMsKF
m9YPmsxfpqLRLM7e3xn8eMmc0YIOLxUZdP+QWvUUwHlES1PCy1tRTdjzXz4v
C+J9/hETopstaID7lkx/qzAuQ7W9Sc9qQTLcI9oExX24n/ChvWG6LahjcuoM
6boo3uq28lxrsBllJ2yRR3LFcOGq1hOzfs1IZk6b63i5OE5gT3uXJdCM6vac
zjxbLIFX27kFniE1oTteBbup4ftxriIdfhbLJuRErtEhgCTusMZWXDnfiJi9
q1rVxiTxPzP71bRjG5GZpoGUlLMU7n38cWW5UiPSrtBSedYqhd94d8XgSAcF
WUXoxAhzSONhodotpCsUxDTRMy0pLY3fl2E2V+OkoPLvyUaGytK4QszDpw7W
CBn+nBsdV5TG9ejqZfZEMvInaXP6SkjjFnvayOd6GhDjS5GYH4s0nqmwkG8u
3oBKo23uubZI4TPAH2tIqEdnbq6jPB8pXNNO69rR8jrkaJ+q+oxTCg/1trdT
2apFB8Y+a4SkSOL0eyEGsua1KD/4jKUeryQu9ihXVjS9Bg1ObxzZCt6Pl3fO
LrKqVaO3xH/EtdUk8Hdyg9UdHlWocObWguIVcZwjvDWMWFSJYt54vTTJEMMv
HnsiKCHzGv3RxKsyNLoPZy9wOKop9ArFMy3tdpEWwj0ZA0OfHcvQvZYg+Xr9
vXgv89lgUhEJOcKLCR47QVy9gRjscKMUXR18uSmbtAe3UXePtKIWIRcGd+aS
NQ/+g2ER9t25EN10ltEn1HPhzwI1Qp5sFKCSUQP7eA1O/Dt57dpX9adI6JzC
XSZgw5+4/uP5qDMP+flSxpOHWPHTbBTCSbdcJFOdvex8hwWHLN469aNZSHEf
2wOhVSac88umfpNaBvKX54lLvrAFDNPFehuFB2h9aoJqO/cDHuWMGUxLJ6OS
ZrNC/6x16F7IufXxSALyOJuk1uK1Bq6ZoXf4D0ajR6/6DMecV2H1V5cwTaFw
JOJg/Lue31fwi7u/d+YtAZ1/3y/ftLYESznBI/37DqKn6cE+YqyLEHBMv6bz
wiX4+TLBbNB0AQJ281klb/jD17Cv0XMN/wF7oLiM5YfCkSqnM+4uH2D1242s
FfNIyDDvG7HXmIYUksYb7uVYOLls1VGsPAkZWv7se+hEWF6v5P/Vchw+EK0P
ZuemgPnSvKCy6hiQ37JWfiClgVYo1Y9AG4U0pepfNRsfgtfkt/sipCHwDvQY
vt2XDYqC43arE2/gZIukR8d4DmxwXTYcucCARI4rm1xBefCl+MH7eoE+2Cg1
oqkzP4WeRAmTu9zdQDgnQTwfkw/sWpvRAY4dwNhYsQ/Z8wzMIsyinIVo4Ogw
cSUguRBSp+dZn2u1wFxtd/BVwWKg3jCI989vBH+xulj31BLoy+DP56sjA1Nw
YfafQs9BLjl6r96rWogdTnnhmPYC3offvUY+UAXCuqFke5GX8FM8q6j7ZzlY
na4kKJ4mQeKD93MB+mUgHHL46jOeMpjx5ahQz3sBT4aEcpUoZfAno54o/LwY
VLS3ekp9X0GqAXsUh8YzqE6a3ToiXw4jrt7TuOxTMPnUp1Y1Ug5y6os6PIG5
0GtW56SfUAFWLE6OAcbZ8HthfiIyfA05pd3HFTQzYJYlARmvvAavKbpx9F+p
4OscuEgrqgTNwI+hudlJcCAo7XiIRxXEPGS2iY6Mh56k1zHqqtWgfv02y+EX
0XCr5O+BqaVqEJXLVGclRoBy87Lsw/IacKlnpp8SCoPhUYFrFgG1QCnNjU48
HQJRXzXIzLp1MFDaLiftGAjau625KzfqIPEC0cL9uC9MHrpq706uB8/nun9L
JvvAeY9d9EN+DXBN4IWttIo7dJBSDccVycDjsqn6V/4lwFblKrPHyOBmGsVn
PeQCr/RrlOwfILC2UI0ZtbsIKZSCnphDFDi0myRny2sPFpOfYgihFPgyr+so
WGID7GzHTE6MUuCcjWQOO7sVNCqEbcroNIKjuat1Oo8ZxCleomVkNMKxVrdh
/noTsFc6ReTdaAQNfk6a1HUcZJVVfou42ATt/ZGU9E1d+KS8R2YdNQHR2NZV
4IYW1BxemfORaYYN0YNKu/nUIUJluHw6ohlmabpAFFMEK9WGEIcPzTDA/yZO
M04WxNXyTvSdaoEy1VjVOBtJUH0XIx1S0gJOSrJDTrEiYBh/fUOOuxUcVx+9
7dEWANvjDgN9Hq0wnaWwXMnHA4R547KQrlZw9/2tOirmFwjOPBwnr0IF0Zs0
HYFAJog/JUToj6eCFN44dFTwO5a79tPw1icqeD25oGzFuoyVF85IKJyhQfuP
+yv7axcwxY/RseeLacAFVuki7DNYzhHl9QiWNgj3Ns8z+fs9JnSDfrn8YhuY
1hgEkB8PY7ENPoPjVW3g/FmurdaLgTGzCJzkF2gH9oquyc8X6FigaUUF5tkO
Cb/Zpt4UoWIf48/LelHbYUKk6T/ERAr2B2MtKUu6AyadO8r06qqxuVVtPtfw
DthychupWyzDrov5xilM/fsfDrVImyrGvhuQOBdPdMJ7GeFQu4dPsFCXj5Gv
CzuhSPNjf1paJsZ+T4k1hLMLlIKqyhZmk7GEIkKYkUcXnExqurzadB8T7srf
5KB3gffUksnoQDj2aHH8Zo8qHfjebextdQ3G3MawyJVoOvRapYyXzl7HVHuy
iOKTdFg8NXFXft0d+0ZeyzQ06Ib6KT1alPwfGKX0XAEhvRtcJuljVgIOWMzj
Vy/jP3fDPn2NozOcNtjZBL7acvMemPUMspwrMMPEb3u2DBf0QAqj1/RhghE2
5dXevbXVA7H+2CxvlS72X5kdkLk=
              "]]}}, 
           {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458],
             EdgeForm[Opacity[0.63]], {}, 
            {RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458], 
             EdgeForm[Opacity[0.63]], 
             TagBox[
              TooltipBox[
               TagBox[
                {GrayLevel[0.5], Opacity[0.25], 
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{-0.14, 0}, 
                    NCache[{-0.13, 
                    Rational[200, 197]}, {-0.13, 1.015228426395939}], 
                    "RoundingRadius" -> 0]},
                  
                  ImageSizeCache->{{125.31671542742964`, 
                   133.438072641644}, {-57.97569288832259, \
-50.550505787607584`}}]},
                StatusArea[#, 1.015228426395939]& ,
                TagBoxNote->"1.015228426395939"],
               StyleBox["1.015228426395939`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[1.015228426395939, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                {GrayLevel[0.5], Opacity[0.25], 
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{-0.13, 0}, 
                    NCache[{-0.12, 
                    Rational[300, 197]}, {-0.12, 1.5228426395939085`}], 
                    "RoundingRadius" -> 0]},
                  
                  ImageSizeCache->{{132.188072641644, 
                   140.30942985585835`}, {-61.063286438680095`, \
-50.550505787607584`}}]},
                StatusArea[#, 1.5228426395939085`]& ,
                TagBoxNote->"1.5228426395939085"],
               StyleBox["1.5228426395939085`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[1.5228426395939085`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                {GrayLevel[0.5], Opacity[0.25], 
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{-0.12, 0}, 
                    NCache[{-0.11, 
                    Rational[600, 197]}, {-0.11, 3.045685279187817}], 
                    "RoundingRadius" -> 0]},
                  
                  ImageSizeCache->{{139.05942985585835`, 
                   147.1807870700727}, {-70.32606708975261, \
-50.550505787607584`}}]},
                StatusArea[#, 3.045685279187817]& ,
                TagBoxNote->"3.045685279187817"],
               StyleBox["3.045685279187817`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[3.045685279187817, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                {GrayLevel[0.5], Opacity[0.25], 
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{-0.11, 0}, 
                    NCache[{-0.1, 
                    Rational[1100, 197]}, {-0.1, 5.583756345177665}], 
                    "RoundingRadius" -> 0]},
                  
                  ImageSizeCache->{{145.9307870700727, 
                   154.05214428428707`}, {-85.76403484154014, \
-50.550505787607584`}}]},
                StatusArea[#, 5.583756345177665]& ,
                TagBoxNote->"5.583756345177665"],
               StyleBox["5.583756345177665`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[5.583756345177665, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                {GrayLevel[0.5], Opacity[0.25], 
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{-0.1, 0}, 
                    NCache[{-0.09, 
                    Rational[2100, 197]}, {-0.09, 10.65989847715736}], 
                    "RoundingRadius" -> 0]},
                  
                  ImageSizeCache->{{152.80214428428707`, 
                   160.92350149850142`}, {-116.63997034511519`, \
-50.55050578760759}}]},
                StatusArea[#, 10.65989847715736]& ,
                TagBoxNote->"10.65989847715736"],
               StyleBox["10.65989847715736`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[10.65989847715736, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                {GrayLevel[0.5], Opacity[0.25], 
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{-0.09, 0}, 
                    NCache[{-0.08, 
                    Rational[2800, 197]}, {-0.08, 14.213197969543147`}], 
                    "RoundingRadius" -> 0]},
                  
                  ImageSizeCache->{{159.67350149850142`, 
                   167.79485871271578`}, {-138.25312519761772`, \
-50.55050578760759}}]},
                StatusArea[#, 14.213197969543147`]& ,
                TagBoxNote->"14.213197969543147"],
               StyleBox["14.213197969543147`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[14.213197969543147`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                {GrayLevel[0.5], Opacity[0.25], 
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{-0.08, 0}, 
                    NCache[{-0.07, 
                    Rational[3000, 197]}, {-0.07, 15.228426395939087`}], 
                    "RoundingRadius" -> 0]},
                  
                  ImageSizeCache->{{166.54485871271578`, 
                   174.66621592693014`}, {-144.42831229833274`, \
-50.55050578760759}}]},
                StatusArea[#, 15.228426395939087`]& ,
                TagBoxNote->"15.228426395939087"],
               StyleBox["15.228426395939087`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[15.228426395939087`, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                {GrayLevel[0.5], Opacity[0.25], 
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{-0.07, 0}, 
                    NCache[{-0.06, 
                    Rational[4600, 197]}, {-0.06, 23.3502538071066}], 
                    "RoundingRadius" -> 0]},
                  
                  ImageSizeCache->{{173.41621592693014`, 
                   181.5375731411445}, {-193.82980910405283`, \
-50.55050578760759}}]},
                StatusArea[#, 23.3502538071066]& ,
                TagBoxNote->"23.3502538071066"],
               StyleBox["23.3502538071066`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[23.3502538071066, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                {GrayLevel[0.5], Opacity[0.25], 
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{-0.06, 0}, 
                    NCache[{-0.05, 
                    Rational[4700, 197]}, {-0.05, 23.85786802030457}], 
                    "RoundingRadius" -> 0]},
                  
                  ImageSizeCache->{{180.2875731411445, 
                   188.40893035535885`}, {-196.91740265441032`, \
-50.55050578760759}}]},
                StatusArea[#, 23.85786802030457]& ,
                TagBoxNote->"23.85786802030457"],
               StyleBox["23.85786802030457`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[23.85786802030457, {
                 GrayLevel[0]}], "Tooltip"]& ], 
             TagBox[
              TooltipBox[
               TagBox[
                {GrayLevel[0.5], Opacity[0.25], 
                 DynamicBox[{
                   FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                   RectangleBox[{-0.05, 0}, 
                    NCache[{-0.04, 
                    Rational[300, 197]}, {-0.04, 1.5228426395939085`}], 
                    "RoundingRadius" -> 0]},
                  
                  ImageSizeCache->{{187.15893035535885`, 
                   195.2802875695732}, {-61.063286438680095`, \
-50.550505787607584`}}]},
                StatusArea[#, 1.5228426395939085`]& ,
                TagBoxNote->"1.5228426395939085"],
               StyleBox["1.5228426395939085`", {
                 GrayLevel[0]}, StripOnInput -> False]],
              Annotation[#, 
               Style[1.5228426395939085`, {
                 GrayLevel[0]}], "Tooltip"]& ]}, {}, {}}, 
           GraphicsComplexBox[CompressedData["
1:eJzllnkw1fv/xw/JHmUNLbJTJCrazutjjWtJctHVLUudo5BCtiSkhJRUsoTI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            "], {{{}, 
              {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
               GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwt0EdOQgEABNCvYNcL2FExsRcgsSGgxoqNRERFEBs2QLz/wkfC4s3sZjGR
50au3hkEQQfldg+LP31AhVm+SZBjiCb7PBHlizjXDLLX3pshxhUDZCgxzTqX
9JPmkSnWuKCPFEUirHJOL7s8MMknK2TpIck9E3ywzBnd/LLDHeNUWeKULhps
U2CMdxY5IUydLW4Z5Y0FjglRY5M8I7wyzxGtn3/Y4Kb1My/Mccg/LzgY1w==

                 "]]]}, {}, 
              {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[
               None], GraphicsGroupBox[
                PolygonBox[{{154, 144, 168, 150, 160, 129, 169}}]]}, {}, 
              {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[
               None], GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwlzMk2wmEcx+F/JUPKPGTplmzsXUCuz1ThHCTRwlwdSZQFojiG0ONYPOfz
+y7ed35peSEVDoIgxCIRxxzb7qTea1iLmtCKvrHFrN38e6tHGteyvrLJjN0I
/j8/lGEtaYcs0/ad/lIgZl9qmwxT9q3+cMCQfaEvpJm06/pNnkH7XJ/ZYMK+
0S77DNhn2mKdcbumX+Tot0/1iTXG7Gv9ZI+ofaKPrDJqV/WDXfrsY31ghRH7
St/ZoQfBLjfb
                 
                 "]]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, \
{}, 
              {Hue[0.67, 0.6, 0.6], 
               LineBox[{1, 70, 41, 99, 26, 85, 56, 108, 2, 71, 42, 100, 27, 
                86, 57, 109, 3, 72, 43, 101, 28, 87, 58, 110, 4, 73, 44, 102, 
                29, 88, 59, 111, 5, 74, 45, 103, 30, 89, 60, 112, 6, 75, 46, 
                104, 31, 90, 61, 7, 76, 47, 105, 32, 91, 62, 8, 77, 48, 33, 
                92, 63, 9, 78, 49, 34, 93, 64, 10, 79, 50, 35, 94, 65, 11, 80,
                 51, 36, 95, 66, 12, 81, 52, 106, 37, 96, 67, 113, 13, 82, 53,
                 107, 38, 97, 68, 114, 14, 83, 54, 39, 15, 16, 17, 18, 19, 20,
                 21, 22, 23, 24, 84, 55, 40, 98, 69, 115, 25}]}, 
              {Hue[0.9060679774997897, 0.6, 0.6], 
               LineBox[{116, 157, 147, 141, 117, 118, 119, 120, 121, 122, 123,
                 124, 125, 126, 127, 158, 148, 142, 163, 153, 128, 159, 149, 
                167, 143, 164, 154, 169, 129, 160, 150, 168, 144, 165, 155, 
                130, 161, 151, 145, 131, 132, 133, 134, 135, 136, 137, 138, 
                139, 162, 152, 146, 166, 156, 170, 140}]}, 
              {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzUVSQwEURcGPOyT4lC2xBBYQFkaA4O4OIQR3d3fXZtB16tYbvKqa2upI
ShAEEeq4YJ5RotTTQCMxmmimhVbaaKeDSxYY45UdOrlikTSPxvWNXQrtLr1m
iXR7Qt/Zo8ju1huWybAn9YN9QnaP3rJCpj2lnxwQtnv1jlWy7Gn94pBiu0/v
WSPbntFvjiix+/WBdXLsuP5wTKk9oI9skGvP6i8nlNmD+sQmeXZCAz2Vch3S
Z7bIt+f+z3qmFTqsL2xTYCc1Vc+1Ukf0D0T7SiA=
                "]]}}}], {{}, {}, 
            {GrayLevel[0], Thickness[Large], Opacity[0.5], 
             LineBox[CompressedData["
1:eJwVlPc/1X0fgCkZUZmV0bD3KEnC9/0lUvaIuEVROYlKKCNZiWSG7JEc1CmS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              "]]}}}, {InsetBox[
            
            TemplateBox[{
             StyleBox[
              "\"subcritical\"", StripOnInput -> False, FontFamily -> 
               "Helvetica", FontSize -> 12],StyleBox[
              "\"critical\"", StripOnInput -> False, FontFamily -> 
               "Helvetica", FontSize -> 12],StyleBox[
              "\"supercritical\"", StripOnInput -> False, FontFamily -> 
               "Helvetica", FontSize -> 12]},
             "SwatchLegend",
             DisplayFunction->(StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Opacity[0.5]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
               False]& ),
             Editable->True,
             InterpretationFunction:>(RowBox[{"SwatchLegend", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.24720000000000014`", ",", "0.24`", ",", 
                    "0.6`"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.6`", ",", "0.24`", ",", 
                    "0.4428931686004542`"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.6`", ",", "0.5470136627990908`", ",", 
                    "0.24`"}], "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}]}], "}"}], 
                  ",", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
                  RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                "]"}]& )], NCache[
            Scaled[{Rational[1, 8], 0.325}], Scaled[{0.125, 0.325}]], 
            ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm], InsetBox[
            TagBox[GridBox[{
               {
                
                TemplateBox[{
                 StyleBox[
                  "\"random\"", StripOnInput -> False, FontFamily -> 
                   "Helvetica", FontSize -> 12],StyleBox[
                  "\"established\"", StripOnInput -> False, FontFamily -> 
                   "Helvetica", FontSize -> 12]},
                 "LineLegend",
                 DisplayFunction->(StyleBox[
                   StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                   FontFamily -> "Times"}, Background -> Automatic, 
                   StripOnInput -> False]& ),
                 Editable->True,
                 InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                    ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
                    "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                    "]"}]& )]},
               {
                
                TemplateBox[{
                 StyleBox[
                  "\"first-step\"", StripOnInput -> False, FontFamily -> 
                   "Helvetica", FontSize -> 12]},
                 "LineLegend",
                 DisplayFunction->(StyleBox[
                   StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Opacity[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Opacity[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, 
                    GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                   FontFamily -> "Times"}, Background -> Automatic, 
                   StripOnInput -> False]& ),
                 Editable->True,
                 InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}]}], "]"}], "}"}], 
                    ",", 
                    RowBox[{"{", #, "}"}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                    "]"}]& )]}
              },
              AutoDelete->False,
              GridBoxAlignment->{"Columns" -> {{Left}}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
              GridBoxSpacings->{"Columns" -> {{0}}}],
             "Grid"], NCache[
            Scaled[{Rational[1, 8], 0.625}], Scaled[{0.125, 0.625}]], 
            ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm]}},
         AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
         Axes->True,
         AxesLabel->{None, None},
         AxesOrigin->{0, 0},
         Epilog->{
           InsetBox[
            FormBox[
             StyleBox[
             "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=-0.2\"", 12, FontFamily -> 
              "Helvetica", StripOnInput -> False], TraditionalForm], 
            NCache[
             Scaled[{
               Rational[7, 8], 
               Rational[3, 4]}], 
             Scaled[{0.875, 0.75}]]], 
           InsetBox[
            FormBox[
             StyleBox[
             "\"A\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
              False], TraditionalForm], 
            Scaled[{0.05, 0.95}]], 
           InsetBox[
            FormBox[
             StyleBox[
             "\"platykurtic\"", 14, FontFamily -> "Helvetica", StripOnInput -> 
              False], TraditionalForm], 
            NCache[
             Scaled[{
               Rational[7, 8], 
               Rational[1, 2]}], 
             Scaled[{0.875, 0.5}]]]},
         Frame->{True, False, False, False},
         FrameTicksStyle->{
          FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
         LabelStyle->Directive[12, FontFamily -> "Helvetica"],
         Method->{},
         PlotRange->{{-0.3, 0.25}, {0, 40}},
         PlotRangeClipping->True,
         PlotRangePadding->{
           Scaled[0.02], Automatic}],
        TraditionalForm],
       InterpretTemplate[Legended[
         Graphics[{{{{}, {}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               GrayLevel[0.5], 
               Thickness[Large], 
               Dashing[{Small, Small}]], 
              Line[CompressedData["
1:eJwVink41HsfQCm7yIw1ugqpUJmaklK/z89aSElxlUu2UJbKkiVkRCVrCFki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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               GrayLevel[0.5], 
               Thickness[Large]], 
              Line[CompressedData["
1:eJxFyQk01XkfBnBi7CFClhBlzZalkP/3b6kREVFMJttMblkrW6RCsmS7lhAK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               "]]}}}, {
            Directive[
             EdgeForm[
              Opacity[0.63]], 
             RGBColor[
             0.798413061722744, 0.824719615472648, 0.968322270542458]], {{}, {
             
              Directive[
               EdgeForm[
                Opacity[0.63]], 
               RGBColor[
               0.798413061722744, 0.824719615472648, 0.968322270542458]], {{
                Tooltip[
                 StatusArea[{
                   Directive[
                    GrayLevel[0.5], 
                    Opacity[0.25]], 
                   RawBoxes[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    RectangleBox[{-0.14, 0}, 
                    NCache[{-0.13, 
                    Rational[200, 197]}, {-0.13, 1.015228426395939}], 
                    "RoundingRadius" -> 0]}]]}, 1.015228426395939], 
                 Style[1.015228426395939, {
                   GrayLevel[0]}]]}, {
                Tooltip[
                 StatusArea[{
                   Directive[
                    GrayLevel[0.5], 
                    Opacity[0.25]], 
                   RawBoxes[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    RectangleBox[{-0.13, 0}, 
                    NCache[{-0.12, 
                    Rational[300, 197]}, {-0.12, 1.5228426395939085`}], 
                    "RoundingRadius" -> 0]}]]}, 1.5228426395939085`], 
                 Style[1.5228426395939085`, {
                   GrayLevel[0]}]]}, {
                Tooltip[
                 StatusArea[{
                   Directive[
                    GrayLevel[0.5], 
                    Opacity[0.25]], 
                   RawBoxes[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    RectangleBox[{-0.12, 0}, 
                    NCache[{-0.11, 
                    Rational[600, 197]}, {-0.11, 3.045685279187817}], 
                    "RoundingRadius" -> 0]}]]}, 3.045685279187817], 
                 Style[3.045685279187817, {
                   GrayLevel[0]}]]}, {
                Tooltip[
                 StatusArea[{
                   Directive[
                    GrayLevel[0.5], 
                    Opacity[0.25]], 
                   RawBoxes[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    RectangleBox[{-0.11, 0}, 
                    NCache[{-0.1, 
                    Rational[1100, 197]}, {-0.1, 5.583756345177665}], 
                    "RoundingRadius" -> 0]}]]}, 5.583756345177665], 
                 Style[5.583756345177665, {
                   GrayLevel[0]}]]}, {
                Tooltip[
                 StatusArea[{
                   Directive[
                    GrayLevel[0.5], 
                    Opacity[0.25]], 
                   RawBoxes[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    RectangleBox[{-0.1, 0}, 
                    NCache[{-0.09, 
                    Rational[2100, 197]}, {-0.09, 10.65989847715736}], 
                    "RoundingRadius" -> 0]}]]}, 10.65989847715736], 
                 Style[10.65989847715736, {
                   GrayLevel[0]}]]}, {
                Tooltip[
                 StatusArea[{
                   Directive[
                    GrayLevel[0.5], 
                    Opacity[0.25]], 
                   RawBoxes[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    RectangleBox[{-0.09, 0}, 
                    NCache[{-0.08, 
                    Rational[2800, 197]}, {-0.08, 14.213197969543147`}], 
                    "RoundingRadius" -> 0]}]]}, 14.213197969543147`], 
                 Style[14.213197969543147`, {
                   GrayLevel[0]}]]}, {
                Tooltip[
                 StatusArea[{
                   Directive[
                    GrayLevel[0.5], 
                    Opacity[0.25]], 
                   RawBoxes[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    RectangleBox[{-0.08, 0}, 
                    NCache[{-0.07, 
                    Rational[3000, 197]}, {-0.07, 15.228426395939087`}], 
                    "RoundingRadius" -> 0]}]]}, 15.228426395939087`], 
                 Style[15.228426395939087`, {
                   GrayLevel[0]}]]}, {
                Tooltip[
                 StatusArea[{
                   Directive[
                    GrayLevel[0.5], 
                    Opacity[0.25]], 
                   RawBoxes[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    RectangleBox[{-0.07, 0}, 
                    NCache[{-0.06, 
                    Rational[4600, 197]}, {-0.06, 23.3502538071066}], 
                    "RoundingRadius" -> 0]}]]}, 23.3502538071066], 
                 Style[23.3502538071066, {
                   GrayLevel[0]}]]}, {
                Tooltip[
                 StatusArea[{
                   Directive[
                    GrayLevel[0.5], 
                    Opacity[0.25]], 
                   RawBoxes[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    RectangleBox[{-0.06, 0}, 
                    NCache[{-0.05, 
                    Rational[4700, 197]}, {-0.05, 23.85786802030457}], 
                    "RoundingRadius" -> 0]}]]}, 23.85786802030457], 
                 Style[23.85786802030457, {
                   GrayLevel[0]}]]}, {
                Tooltip[
                 StatusArea[{
                   Directive[
                    GrayLevel[0.5], 
                    Opacity[0.25]], 
                   RawBoxes[
                    DynamicBox[{
                    FEPrivate`If[
                    CurrentValue["MouseOver"], 
                    EdgeForm[{
                    GrayLevel[0.5], 
                    AbsoluteThickness[1.5], 
                    Opacity[0.66]}], {}, {}], 
                    RectangleBox[{-0.05, 0}, 
                    NCache[{-0.04, 
                    Rational[300, 197]}, {-0.04, 1.5228426395939085`}], 
                    "RoundingRadius" -> 0]}]]}, 1.5228426395939085`], 
                 Style[1.5228426395939085`, {
                   GrayLevel[0]}]]}}}, {}, {}}}, 
           GraphicsComplex[CompressedData["
1:eJzllnkw1fv/xw/JHmUNLbJTJCrazutjjWtJctHVLUudo5BCtiSkhJRUsoTI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            "], {{{}, {
               EdgeForm[], 
               Directive[{
                 Opacity[0.2], 
                 Hue[0.67, 0.6, 0.6]}], 
               GraphicsGroup[{
                 Polygon[CompressedData["
1:eJwt0EdOQgEABNCvYNcL2FExsRcgsSGgxoqNRERFEBs2QLz/wkfC4s3sZjGR
50au3hkEQQfldg+LP31AhVm+SZBjiCb7PBHlizjXDLLX3pshxhUDZCgxzTqX
9JPmkSnWuKCPFEUirHJOL7s8MMknK2TpIck9E3ywzBnd/LLDHeNUWeKULhps
U2CMdxY5IUydLW4Z5Y0FjglRY5M8I7wyzxGtn3/Y4Kb1My/Mccg/LzgY1w==

                  "]]}]}, {}, {
               EdgeForm[], 
               Directive[{
                 Opacity[0.2], 
                 Hue[0.9060679774997897, 0.6, 0.6]}], 
               GraphicsGroup[{
                 Polygon[{{154, 144, 168, 150, 160, 129, 169}}]}]}, {}, {
               EdgeForm[], 
               Directive[{
                 Opacity[0.2], 
                 Hue[0.1421359549995791, 0.6, 0.6]}], 
               GraphicsGroup[{
                 Polygon[CompressedData["
1:eJwlzMk2wmEcx+F/JUPKPGTplmzsXUCuz1ThHCTRwlwdSZQFojiG0ONYPOfz
+y7ed35peSEVDoIgxCIRxxzb7qTea1iLmtCKvrHFrN38e6tHGteyvrLJjN0I
/j8/lGEtaYcs0/ad/lIgZl9qmwxT9q3+cMCQfaEvpJm06/pNnkH7XJ/ZYMK+
0S77DNhn2mKdcbumX+Tot0/1iTXG7Gv9ZI+ofaKPrDJqV/WDXfrsY31ghRH7
St/ZoQfBLjfb
                  
                  "]]}]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, \
{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               
               Line[{1, 70, 41, 99, 26, 85, 56, 108, 2, 71, 42, 100, 27, 86, 
                57, 109, 3, 72, 43, 101, 28, 87, 58, 110, 4, 73, 44, 102, 29, 
                88, 59, 111, 5, 74, 45, 103, 30, 89, 60, 112, 6, 75, 46, 104, 
                31, 90, 61, 7, 76, 47, 105, 32, 91, 62, 8, 77, 48, 33, 92, 63,
                 9, 78, 49, 34, 93, 64, 10, 79, 50, 35, 94, 65, 11, 80, 51, 
                36, 95, 66, 12, 81, 52, 106, 37, 96, 67, 113, 13, 82, 53, 107,
                 38, 97, 68, 114, 14, 83, 54, 39, 15, 16, 17, 18, 19, 20, 21, 
                22, 23, 24, 84, 55, 40, 98, 69, 115, 25}]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               
               Line[{116, 157, 147, 141, 117, 118, 119, 120, 121, 122, 123, 
                124, 125, 126, 127, 158, 148, 142, 163, 153, 128, 159, 149, 
                167, 143, 164, 154, 169, 129, 160, 150, 168, 144, 165, 155, 
                130, 161, 151, 145, 131, 132, 133, 134, 135, 136, 137, 138, 
                139, 162, 152, 146, 166, 156, 170, 140}]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Line[CompressedData["
1:eJwVzUVSQwEURcGPOyT4lC2xBBYQFkaA4O4OIQR3d3fXZtB16tYbvKqa2upI
ShAEEeq4YJ5RotTTQCMxmmimhVbaaKeDSxYY45UdOrlikTSPxvWNXQrtLr1m
iXR7Qt/Zo8ju1huWybAn9YN9QnaP3rJCpj2lnxwQtnv1jlWy7Gn94pBiu0/v
WSPbntFvjiix+/WBdXLsuP5wTKk9oI9skGvP6i8nlNmD+sQmeXZCAz2Vch3S
Z7bIt+f+z3qmFTqsL2xTYCc1Vc+1Ukf0D0T7SiA=
                "]]}}}], {{{}, {}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               Thickness[Large], 
               GrayLevel[0], 
               Opacity[0.5]], 
              Line[CompressedData["
1:eJwVlPc/1X0fgCkZUZmV0bD3KEnC9/0lUvaIuEVROYlKKCNZiWSG7JEc1CmS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               "]]}}}}, {
          Frame -> {True, False, False, False}, 
           FrameTicksStyle -> {
            FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, 
           PlotRange -> {{-0.3, 0.25}, {0, 40}}, LabelStyle -> 
           Directive[12, FontFamily -> "Helvetica"], Epilog -> {
             Text[
              Style[
              "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=-0.2", 12, FontFamily -> "Helvetica"], 
              Scaled[{
                Rational[7, 8], 
                Rational[3, 4]}]], 
             Text[
              Style["A", 14, Bold, FontFamily -> "Helvetica"], 
              Scaled[{0.05, 0.95}]], 
             Text[
              Style["platykurtic", 14, FontFamily -> "Helvetica"], 
              Scaled[{
                Rational[7, 8], 
                Rational[1, 2]}]]}, AspectRatio -> GoldenRatio^(-1), Axes -> 
           True, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
           Method -> {}, PlotRange -> {{-0.3, 0.25}, {0, All}}, 
           PlotRangeClipping -> True, PlotRangePadding -> {
             Scaled[0.02], Automatic}}], {
          Placed[
           Unevaluated[
            LineLegend[{
              Directive[
               Thickness[Large], 
               GrayLevel[0], 
               Opacity[0.5]]}, {
              Style["first-step", 12, FontFamily -> "Helvetica"]}, 
             LegendLayout -> "Column"]], 
           Scaled[{
             Rational[1, 8], 0.625}], Identity]}]& ],
       AutoDelete->True,
       Editable->True,
       SelectWithContents->False,
       Selectable->True],
      TraditionalForm], {189., -120.62305898749054`}, {
     Center, Center}, {360., 291.2461179749811}], InsetBox[
     GraphicsBox[{{{}, {}, 
        {GrayLevel[0.5], Thickness[Large], Dashing[{Small, Small}], 
         LineBox[CompressedData["
1:eJwVink41HsfQCm7yIw1ugqpUJmaklK/z89aSElxlUu2UJbKkiVkRCVrCFki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          "]]}, 
        {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxFyQk01XkfBnBi7CFClhBlzZalkP/3b6kREVFMJttMblkrW6RCsmS7lhAK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          "]]}}, 
       {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
        EdgeForm[Opacity[0.504]], {}, 
        {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
         EdgeForm[Opacity[0.504]], 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.3, 0}, 
           NCache[{-0.28, Rational[100, 1153]}, {-0.28, 0.08673026886383348}],
           
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.24, 0}, 
           NCache[{-0.22, Rational[200, 1153]}, {-0.22, 0.17346053772766695`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.22, 0}, 
           NCache[{-0.2, Rational[150, 1153]}, {-0.2, 0.13009540329575023`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.2, 0}, 
           NCache[{-0.18, Rational[700, 1153]}, {-0.18, 0.6071118820468343}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.18, 0}, 
           NCache[{-0.16, Rational[900, 1153]}, {-0.16, 0.7805724197745013}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.16, 0}, 
           NCache[{-0.14, Rational[650, 1153]}, {-0.14, 0.5637467476149176}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.14, 0}, 
           NCache[{-0.12, Rational[750, 1153]}, {-0.12, 0.6504770164787511}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.12, 0}, 
           NCache[{-0.1, Rational[1050, 1153]}, {-0.1, 0.9106678230702515}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.1, 0}, 
           NCache[{-0.08, Rational[1350, 1153]}, {-0.08, 1.170858629661752}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.08, 0}, 
           NCache[{-0.06, Rational[1900, 1153]}, {-0.06, 1.647875108412836}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.06, 0}, 
           NCache[{-0.04, Rational[2350, 1153]}, {-0.04, 2.038161318300087}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.04, 0}, 
           NCache[{-0.02, Rational[4100, 1153]}, {-0.02, 3.5559410234171724`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{-0.02, 0}, 
           NCache[{0., Rational[11200, 1153]}, {0., 9.713790112749349}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0., 0}, 
           NCache[{0.02, Rational[9450, 1153]}, {0.02, 8.196010407632263}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.02, 0}, 
           NCache[{0.04, Rational[7850, 1153]}, {0.04, 6.808326105810928}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.04, 0}, 
           NCache[{0.06, Rational[5400, 1153]}, {0.06, 4.683434518647008}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.06, 0}, 
           NCache[{0.08, Rational[3300, 1153]}, {0.08, 2.862098872506505}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.08, 0}, 
           NCache[{0.1, Rational[2200, 1153]}, {0.1, 1.9080659150043364`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.1, 0}, 
           NCache[{0.12, Rational[1700, 1153]}, {0.12, 1.4744145706851692`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.12, 0}, 
           NCache[{0.14, Rational[1050, 1153]}, {0.14, 0.9106678230702515}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.14, 0}, 
           NCache[{0.16, Rational[600, 1153]}, {0.16, 0.5203816131830009}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.16, 0}, 
           NCache[{0.18, Rational[350, 1153]}, {0.18, 0.30355594102341715`}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.18, 0}, 
           NCache[{0.2, Rational[50, 1153]}, {0.2, 0.04336513443191674}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.2, 0}, 
           NCache[{0.22, Rational[50, 1153]}, {0.22, 0.04336513443191674}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.22, 0}, 
           NCache[{0.24, Rational[100, 1153]}, {0.24, 0.08673026886383348}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.24, 0}, 
           NCache[{0.26, Rational[50, 1153]}, {0.26, 0.04336513443191674}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.26, 0}, 
           NCache[{0.28, Rational[50, 1153]}, {0.28, 0.04336513443191674}],
           RoundingRadius->0]}, 
         {GrayLevel[0.5], Opacity[0.25], 
          RectangleBox[{0.3, 0}, 
           NCache[{0.32, Rational[50, 1153]}, {0.32, 0.04336513443191674}],
           RoundingRadius->0]}}, {}, {}}, GraphicsComplexBox[CompressedData["
1:eJzllnkw1fv/xw/JHmUNLbJTJCrazutjjWtJctHVLUudo5BCtiSkhJRUsoTI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        "], {{{}, 
          {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
           GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwt0EdOQgEABNCvYNcL2FExsRcgsSGgxoqNRERFEBs2QLz/wkfC4s3sZjGR
50au3hkEQQfldg+LP31AhVm+SZBjiCb7PBHlizjXDLLX3pshxhUDZCgxzTqX
9JPmkSnWuKCPFEUirHJOL7s8MMknK2TpIck9E3ywzBnd/LLDHeNUWeKULhps
U2CMdxY5IUydLW4Z5Y0FjglRY5M8I7wyzxGtn3/Y4Kb1My/Mccg/LzgY1w==

             "]]]}, {}, 
          {Hue[0.9060679774997897, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
           GraphicsGroupBox[
            PolygonBox[{{154, 144, 168, 150, 160, 129, 169}}]]}, {}, 
          {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
           GraphicsGroupBox[PolygonBox[CompressedData["
1:eJwlzMk2wmEcx+F/JUPKPGTplmzsXUCuz1ThHCTRwlwdSZQFojiG0ONYPOfz
+y7ed35peSEVDoIgxCIRxxzb7qTea1iLmtCKvrHFrN38e6tHGteyvrLJjN0I
/j8/lGEtaYcs0/ad/lIgZl9qmwxT9q3+cMCQfaEvpJm06/pNnkH7XJ/ZYMK+
0S77DNhn2mKdcbumX+Tot0/1iTXG7Gv9ZI+ofaKPrDJqV/WDXfrsY31ghRH7
St/ZoQfBLjfb
             
             "]]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, \

          {Hue[0.67, 0.6, 0.6], 
           LineBox[{1, 70, 41, 99, 26, 85, 56, 108, 2, 71, 42, 100, 27, 86, 
            57, 109, 3, 72, 43, 101, 28, 87, 58, 110, 4, 73, 44, 102, 29, 88, 
            59, 111, 5, 74, 45, 103, 30, 89, 60, 112, 6, 75, 46, 104, 31, 90, 
            61, 7, 76, 47, 105, 32, 91, 62, 8, 77, 48, 33, 92, 63, 9, 78, 49, 
            34, 93, 64, 10, 79, 50, 35, 94, 65, 11, 80, 51, 36, 95, 66, 12, 
            81, 52, 106, 37, 96, 67, 113, 13, 82, 53, 107, 38, 97, 68, 114, 
            14, 83, 54, 39, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 84, 55, 
            40, 98, 69, 115, 25}]}, 
          {Hue[0.9060679774997897, 0.6, 0.6], 
           LineBox[{116, 157, 147, 141, 117, 118, 119, 120, 121, 122, 123, 
            124, 125, 126, 127, 158, 148, 142, 163, 153, 128, 159, 149, 167, 
            143, 164, 154, 169, 129, 160, 150, 168, 144, 165, 155, 130, 161, 
            151, 145, 131, 132, 133, 134, 135, 136, 137, 138, 139, 162, 152, 
            146, 166, 156, 170, 140}]}, 
          {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzUVSQwEURcGPOyT4lC2xBBYQFkaA4O4OIQR3d3fXZtB16tYbvKqa2upI
ShAEEeq4YJ5RotTTQCMxmmimhVbaaKeDSxYY45UdOrlikTSPxvWNXQrtLr1m
iXR7Qt/Zo8ju1huWybAn9YN9QnaP3rJCpj2lnxwQtnv1jlWy7Gn94pBiu0/v
WSPbntFvjiix+/WBdXLsuP5wTKk9oI9skGvP6i8nlNmD+sQmeXZCAz2Vch3S
Z7bIt+f+z3qmFTqsL2xTYCc1Vc+1Ukf0D0T7SiA=
            "]]}}}], {{}, {}, 
        {GrayLevel[0], Thickness[Large], Opacity[0.5], LineBox[CompressedData["
1:eJwVlPc/1X0fgCkZUZmV0bD3KEnC9/0lUvaIuEVROYlKKCNZiWSG7JEc1CmS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          "]]}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      Epilog->{
        InsetBox[
         FormBox[
          StyleBox[
          "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
           False], TraditionalForm], 
         Scaled[{0.05, 0.95}]], 
        InsetBox[
         FormBox[
          StyleBox[
          "\"leptokurtic\"", 14, FontFamily -> "Helvetica", StripOnInput -> 
           False], TraditionalForm], 
         NCache[
          Scaled[{
            Rational[7, 8], 
            Rational[1, 2]}], 
          Scaled[{0.875, 0.5}]]]},
      Frame->{True, False, False, False},
      FrameLabel->{
        FormBox["\"Growth rate\"", TraditionalForm]},
      FrameTicksStyle->{Automatic, Automatic, Automatic, Automatic},
      LabelStyle->Directive[12, FontFamily -> "Helvetica"],
      Method->{},
      PlotRange->{{-0.3, 0.25}, {0, 40}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], Automatic}], {189., -361.8691769624716}, 
     ImageScaled[{0.5, 0.5}], {360., 291.2461179749811}]}, {}},
  ContentSelectable->True,
  ImageSize->350,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.78490460654532*^9}]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Dimensionality, n", "Section",
 CellChangeTimes->{{3.780251618524732*^9, 3.780251621209381*^9}, {
  3.782259179675816*^9, 3.782259179931897*^9}}],

Cell[CellGroupData[{

Cell["\<\
Probability of rescue (figure S6A)\
\>", "Subsection",
 CellChangeTimes->{{3.7564892474960623`*^9, 3.756489252807234*^9}, 
   3.7606376392688437`*^9, {3.7642036999242487`*^9, 3.76420371369766*^9}, {
   3.769431834041813*^9, 3.769431845906336*^9}, {3.769431894299581*^9, 
   3.769431896986474*^9}, {3.769432022608979*^9, 3.76943202539149*^9}, {
   3.7694324961732264`*^9, 3.769432496341527*^9}, {3.7694327378288794`*^9, 
   3.769432739203771*^9}, {3.7694390881946793`*^9, 3.769439089784932*^9}, 
   3.7712459034631767`*^9, {3.780251653828335*^9, 3.780251661330201*^9}, {
   3.780252898262912*^9, 3.780252911301763*^9}, 3.78025362510145*^9, {
   3.782245714201285*^9, 3.782245722263949*^9}}],

Cell[CellGroupData[{

Cell["Numerical data", "Subsubsection",
 CellChangeTimes->{{3.782245848043803*^9, 3.7822458496666107`*^9}, {
   3.782246914412898*^9, 3.78224691827477*^9}, 3.7822628517270947`*^9}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"N0", "=", 
    SuperscriptBox["10", "4"]}], ";", "\[IndentingNewLine]", 
   RowBox[{"mmax", "=", "0.5"}], ";", "\[IndentingNewLine]", 
   RowBox[{"\[Lambda]", "=", 
    RowBox[{"2", 
     RowBox[{"Es", "/", "4"}]}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"Es", "=", "0.01"}], ";", "\[IndentingNewLine]", 
   RowBox[{"U", "=", 
    RowBox[{"2", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}]}], ";", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"m0min", "=", "mTempmin"}], ";", "\[IndentingNewLine]", 
   RowBox[{"m0max", "=", "mTempmax"}], ";", "\[IndentingNewLine]", 
   RowBox[{"mstep", "=", "step"}], ";", "\[IndentingNewLine]", 
   RowBox[{"m0list", "=", 
    RowBox[{"Table", "[", 
     RowBox[{"m0", ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"n", "=", "2"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"rate4", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"\[CapitalLambda]4Interpolated", "[", 
         RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate3", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"\[CapitalLambda]3Interpolated", "[", 
         RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate2", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"\[CapitalLambda]2Interpolated", "[", 
         RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate1", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"\[CapitalLambda]1Interpolated", "[", 
         RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"theory2", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m0list", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{
              RowBox[{"m0list", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"rate1", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m0list", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{
              RowBox[{"m0list", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"rate2", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m0list", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{
              RowBox[{"m0list", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"rate3", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m0list", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{
              RowBox[{"m0list", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"rate4", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}]}], 
     "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"alltheory2", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"m0list", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"prescue", "/.", 
         RowBox[{"p0", "\[Rule]", 
          RowBox[{"prescuem", "[", 
           RowBox[{
            RowBox[{"m0list", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"rate1", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate2", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate3", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate4", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "]"}]}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}]}], ";", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"n", "=", "20"}], ";", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"rate4", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"\[CapitalLambda]4Interpolated", "[", 
         RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate3", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"\[CapitalLambda]3Interpolated", "[", 
         RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate2", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"\[CapitalLambda]2Interpolated", "[", 
         RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"rate1", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m0", ",", 
        RowBox[{"\[CapitalLambda]1Interpolated", "[", 
         RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
         "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"theory20", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m0list", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{
              RowBox[{"m0list", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"rate1", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m0list", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{
              RowBox[{"m0list", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"rate2", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m0list", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{
              RowBox[{"m0list", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"rate3", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"m0list", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"prescue", "/.", 
           RowBox[{"p0", "\[Rule]", 
            RowBox[{"prescuem", "[", 
             RowBox[{
              RowBox[{"m0list", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", 
              RowBox[{"rate4", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}]}], 
     "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", 
   RowBox[{"alltheory20", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"m0list", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"prescue", "/.", 
         RowBox[{"p0", "\[Rule]", 
          RowBox[{"prescuem", "[", 
           RowBox[{
            RowBox[{"m0list", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"rate1", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate2", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate3", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate4", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "]"}]}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}]}], ";", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Clear", "[", 
    RowBox[{
    "N0", ",", "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", 
     "m0min", ",", "m0max", ",", "mstep"}], "]"}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.782245866101694*^9, 3.782245866581421*^9}, 
   3.7822459078819637`*^9, 3.7822466594581747`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"theory2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "7.550146599033525`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39`"}], ",", "1.3377479120002533`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38`"}], ",", "2.3541607676591525`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37`"}], ",", "4.114440329328062`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36000000000000004`"}], ",", 
         "7.141165515145431`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "0.000012307857882642992`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34`"}], ",", "0.000021063133737397877`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33`"}], ",", "0.00003579015229548954`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32`"}], ",", "0.00006037791098467693`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31000000000000005`"}], ",", 
         "0.00010112104250870058`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", 
         "0.0001681240890663016`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29000000000000004`"}], ",", 
         "0.00027747271956068964`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28`"}], ",", "0.0004545590158643309`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27`"}], ",", "0.0007391247295696068`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26`"}], ",", "0.001192832889703177`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.0019105140220078143`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24000000000000002`"}], ",", 
         "0.003036676940584293`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23`"}], ",", "0.004789432638810376`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22000000000000003`"}], ",", 
         "0.007494626601585619`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21000000000000002`"}], ",", 
         "0.011633600283353251`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.017908315887685933`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19000000000000003`"}], ",", "0.0273269168085416`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18000000000000002`"}], ",", "0.0413097839349571`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17`"}], ",", "0.06180814989432182`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16000000000000003`"}], ",", "0.0914097510605959`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", "0.1333718976425542`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14`"}], ",", "0.1914641788835304`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13`"}], ",", "0.2694211954092305`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12`"}], ",", "0.36973364252078456`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11000000000000004`"}], ",", "0.49156286756486567`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10000000000000003`"}], ",", "0.6280170641956851`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09000000000000002`"}], ",", "0.7642175408782299`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08000000000000002`"}], ",", "0.8792912943690248`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07`"}], ",", "0.9553462152859784`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06`"}], ",", "0.9900819921225776`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", "0.9990479451974486`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.040000000000000036`"}], ",", "0.9999791099242765`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.030000000000000027`"}], ",", "0.999999973930803`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.020000000000000018`"}], ",", "0.9999999999999477`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.010000000000000009`"}], ",", "1.`"}], "}"}]}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "0.000010199356035189844`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39`"}], ",", "0.000014677162872178684`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38`"}], ",", "0.000021111037750598527`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37`"}], ",", "0.000030349797471518336`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36000000000000004`"}], ",", 
         "0.000043608455296051396`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "0.000062621368339566`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34`"}], ",", "0.0000898592349781735`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33`"}], ",", "0.00012883241729277906`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32`"}], ",", "0.00018451270537933606`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31000000000000005`"}], ",", 
         "0.00026391758906829654`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", 
         "0.0003769004573965784`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29000000000000004`"}], ",", 
         "0.0005372530345478799`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28`"}], ",", "0.0007641511809506341`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27`"}], ",", "0.0010841140501735014`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26`"}], ",", "0.0015335761130844672`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.002162242734804587`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24000000000000002`"}], ",", 
         "0.0030374086953640633`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23`"}], ",", "0.0042494371132796305`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22000000000000003`"}], ",", 
         "0.005918601292685177`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21000000000000002`"}], ",", "0.00820347793649634`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.011311037236190646`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19000000000000003`"}], ",", 
         "0.015508491675123581`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18000000000000002`"}], ",", "0.02113682848606624`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17`"}], ",", "0.028625749384967758`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16000000000000003`"}], ",", 
         "0.038509470018561975`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", "0.05144249622823116`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14`"}], ",", "0.06821411823926604`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13`"}], ",", "0.08975999068405194`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12`"}], ",", "0.11716884620450363`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11000000000000004`"}], ",", "0.15168212525289082`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10000000000000003`"}], ",", "0.1946838891098458`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09000000000000002`"}], ",", "0.24767699622618855`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08000000000000002`"}], ",", "0.3122366866190842`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07`"}], ",", "0.3899175612242515`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06`"}], ",", "0.4820455848517148`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", "0.5892003916766011`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.040000000000000036`"}], ",", "0.709836933580263`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.030000000000000027`"}], ",", "0.8365501253166521`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.020000000000000018`"}], ",", "0.9469981107174836`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.010000000000000009`"}], ",", "0.9978818298362644`"}],
         "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "3.862056573100681`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39`"}], ",", "5.204170228867433`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38`"}], ",", "7.0108773162491644`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37`"}], ",", "9.444062044394741`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36000000000000004`"}], ",", 
         "0.000012723011729498523`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "0.00001714511504935512`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34`"}], ",", "0.000023114549685732122`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33`"}], ",", "0.00003118061729001642`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32`"}], ",", "0.00004209066999139033`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31000000000000005`"}], ",", 
         "0.00005686144346772615`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", 
         "0.00007687529434197149`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29000000000000004`"}], ",", 
         "0.00010400918245812019`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28`"}], ",", "0.00014080627657486744`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27`"}], ",", "0.00019070236208684754`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26`"}], ",", "0.00025832180874529875`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.0003498604302459851`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24000000000000002`"}], ",", 
         "0.00047357526281999185`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23`"}], ",", "0.0006404035994689306`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22000000000000003`"}], ",", 
         "0.0008647356474307255`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21000000000000002`"}], ",", 
         "0.0011653666578700372`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.0015666555986530994`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19000000000000003`"}], ",", 
         "0.0020999191363709757`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18000000000000002`"}], ",", 
         "0.0028050936332381093`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17`"}], ",", "0.0037327076614083188`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16000000000000003`"}], ",", 
         "0.004946229763691856`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", 
         "0.006524902693593848`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14`"}], ",", "0.008567266904699888`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13`"}], ",", "0.011195749646660036`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12`"}], ",", "0.01456301899912249`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11000000000000004`"}], ",", 
         "0.018861403567808188`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10000000000000003`"}], ",", 
         "0.024337817579831333`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09000000000000002`"}], ",", "0.03131886540486406`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08000000000000002`"}], ",", "0.04025541321305448`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07`"}], ",", "0.05180611277425151`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06`"}], ",", "0.06700390743821716`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", "0.0876152541771753`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.040000000000000036`"}], ",", 
         "0.11700327307874947`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.030000000000000027`"}], ",", 
         "0.16254620716433155`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.020000000000000018`"}], ",", 
         "0.24419952262430733`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.010000000000000009`"}], ",", 
         "0.43935473836510974`"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "5.338328372683776`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39`"}], ",", "7.072562302479213`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38`"}], ",", "9.373608661489286`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37`"}], ",", "1.2430571124655287`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36000000000000004`"}], ",", 
         "1.649783406221239`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "2.1918565153988823`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34`"}], ",", "2.915686786786331`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33`"}], ",", "3.8841721338167545`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32`"}], ",", "5.1827130552739575`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31000000000000005`"}], ",", 
         "6.927380244214909`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", 
         "9.275985834444889`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29000000000000004`"}], ",", 
         "0.000012442979246407582`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28`"}], ",", "0.00001671937282088365`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27`"}], ",", "0.000022499117118601752`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26`"}], ",", "0.00003031375183593088`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.000040877378766679406`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24000000000000002`"}], ",", 
         "0.00005514440657494735`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23`"}], ",", "0.00007438275838622666`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22000000000000003`"}], ",", 
         "0.00010026550102237852`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21000000000000002`"}], ",", 
         "0.00013498406279732755`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.00018138631638997538`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19000000000000003`"}], ",", 
         "0.00024314313662598952`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18000000000000002`"}], ",", 
         "0.00032494753038614377`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17`"}], ",", "0.0004327518267689401`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16000000000000003`"}], ",", 
         "0.0005740513735890129`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", 
         "0.0007582293256364059`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14`"}], ",", "0.0009969890612526733`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13`"}], ",", "0.0013049233523595438`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12`"}], ",", "0.0017003114586767731`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11000000000000004`"}], ",", 
         "0.002206314083509464`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10000000000000003`"}], ",", 
         "0.0028528869175930005`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09000000000000002`"}], ",", 
         "0.0036800338495649454`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08000000000000002`"}], ",", 
         "0.0047436536786403805`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07`"}], ",", "0.006126667221285187`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06`"}], ",", "0.007961666583326976`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", "0.01048121505556654`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.040000000000000036`"}], ",", 
         "0.014143839155673521`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.030000000000000027`"}], ",", 
         "0.02001029300962276`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.020000000000000018`"}], ",", 
         "0.03123097614317294`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.010000000000000009`"}], ",", 
         "0.06315917180894381`"}], "}"}]}], "}"}]}], "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.782246516979343*^9, 3.7822465244399147`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"alltheory2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.4`"}], ",", "0.000015350202181019235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.39`"}], ",", "0.000021926220291734744`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.38`"}], ",", "0.00003141319399246889`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.37`"}], ",", "0.00004515085310408118`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.36000000000000004`"}], ",", 
       "0.00006512135528791152`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.35000000000000003`"}], ",", 
       "0.00009426393931810662`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.34`"}], ",", "0.0001369477559153287`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.33`"}], ",", "0.00019967684960509047`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.32`"}], ",", "0.0002921410564045157`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.31000000000000005`"}], ",", "0.0004287770736822738`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.30000000000000004`"}], ",", "0.0006310647602509878`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.29000000000000004`"}], ",", "0.0009309326073357882`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.28`"}], ",", "0.0013756940254245897`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.27`"}], ",", "0.0020352456926138185`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.26`"}], ",", "0.0030124200353386366`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.25`"}], ",", "0.004457757273886531`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.24000000000000002`"}], ",", "0.006590343936563103`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.23`"}], ",", "0.009726798586397578`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.22000000000000003`"}], ",", "0.014320858948354664`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.21000000000000002`"}], ",", "0.02101611059527131`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.2`"}], ",", "0.030713710195301225`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.19000000000000003`"}], ",", "0.0446545404194304`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.18000000000000002`"}], ",", "0.06450934056844149`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.17`"}], ",", "0.09245805644330285`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.16000000000000003`"}], ",", "0.131216670813028`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.15000000000000002`"}], ",", "0.18393152366588073`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.14`"}], ",", "0.2538073877249182`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.13`"}], ",", "0.34328369492122546`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.12`"}], ",", "0.45258605307953326`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.11000000000000004`"}], ",", "0.5777030417626707`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.10000000000000003`"}], ",", "0.7084886985816767`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.09000000000000002`"}], ",", "0.8287134862581917`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.08000000000000002`"}], ",", "0.9206113607139523`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.07`"}], ",", "0.974263154496821`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.06`"}], ",", "0.9952181649470924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.04999999999999999`"}], ",", "0.9996420086675802`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.040000000000000036`"}], ",", "0.9999945277896636`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.030000000000000027`"}], ",", "0.9999999960926514`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.020000000000000018`"}], ",", "0.9999999999999969`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.010000000000000009`"}], ",", "1.`"}], "}"}]}], "}"}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.782246535810657*^9, 3.782246540267297*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"theory20", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "3.6721736207390165`*^-8"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39`"}], ",", "6.809108610283943`*^-8"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38`"}], ",", "1.254496430069807`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37`"}], ",", "2.2963628520944468`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36000000000000004`"}], ",", 
         "4.176091951135774`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "7.544562181660552`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34`"}], ",", "1.3539615881796863`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33`"}], ",", "2.413573102710842`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32`"}], ",", "4.2733913914183574`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31000000000000005`"}], ",", 
         "7.514843870071175`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", 
         "0.00001312444652046274`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29000000000000004`"}], ",", 
         "0.000022763350867927024`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28`"}], ",", "0.000039207417075748374`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27`"}], ",", "0.00006705980661603217`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26`"}], ",", "0.00011389547082241158`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.00019208432406314646`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24000000000000002`"}], ",", 
         "0.00032167205540878374`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23`"}], ",", "0.0005348952348056546`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22000000000000003`"}], ",", 
         "0.0008832005339582949`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21000000000000002`"}], ",", 
         "0.0014480669951962843`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.0023575498116308324`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19000000000000003`"}], ",", 
         "0.0038113391574159383`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18000000000000002`"}], ",", 
         "0.006118324069079195`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17`"}], ",", "0.009752194976848538`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16000000000000003`"}], ",", 
         "0.015432390043889188`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", "0.02423916555868677`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14`"}], ",", "0.037771223298540546`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13`"}], ",", "0.05834834323446625`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12`"}], ",", "0.08924118251846858`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11000000000000004`"}], ",", "0.1348578732623491`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10000000000000003`"}], ",", "0.20069983428605798`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09000000000000002`"}], ",", "0.2926736492678442`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08000000000000002`"}], ",", "0.4150076889285138`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07`"}], ",", "0.5658189827878293`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06`"}], ",", "0.7303782065372255`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", "0.8768257341172561`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.040000000000000036`"}], ",", "0.9680381655938813`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.030000000000000027`"}], ",", "0.997401209946258`"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.020000000000000018`"}], ",", "0.9999877420421525`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.010000000000000009`"}], ",", "0.9999999999959232`"}],
         "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "3.3918973174618117`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39`"}], ",", "5.085675043314808`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38`"}], ",", "7.625996985005656`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37`"}], ",", "1.1436489691929452`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36000000000000004`"}], ",", 
         "1.7153852600593211`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "2.573369322966812`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34`"}], ",", "3.860955236412167`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33`"}], ",", "5.792977115448572`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32`"}], ",", "8.690925778376268`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31000000000000005`"}], ",", 
         "0.000013034867132000194`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", 
         "0.000019540457110611698`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29000000000000004`"}], ",", 
         "0.000029270621799803997`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28`"}], ",", "0.0000437996351575487`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27`"}], ",", "0.00006544900849569935`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26`"}], ",", "0.00009762912538979762`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.00014532497281927181`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24000000000000002`"}], ",", 
         "0.00021578609861461207`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23`"}], ",", "0.0003194974825569963`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22000000000000003`"}], ",", 
         "0.00047153575691838423`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21000000000000002`"}], ",", 
         "0.0006934495257259199`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.0010158474654342609`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19000000000000003`"}], ",", 
         "0.001481936599165401`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18000000000000002`"}], ",", 
         "0.002152330882826514`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17`"}], ",", "0.0031115555113969684`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16000000000000003`"}], ",", 
         "0.004476819227912321`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", 
         "0.006409840660615118`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14`"}], ",", "0.00913283963940803`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13`"}], ",", "0.012950322828120253`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12`"}], ",", "0.018279157774303223`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11000000000000004`"}], ",", 
         "0.025690934022510548`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10000000000000003`"}], ",", "0.03597333089884225`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09000000000000002`"}], ",", 
         "0.050222320669574105`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08000000000000002`"}], ",", "0.06998700480546771`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07`"}], ",", "0.09750915039389374`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06`"}], ",", "0.13614255919434537`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", "0.19113291972491764`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.040000000000000036`"}], ",", 
         "0.27115351168889257`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.030000000000000027`"}], ",", "0.3914263666994825`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.020000000000000018`"}], ",", "0.5790997599763441`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.010000000000000009`"}], ",", "0.8608399819454431`"}],
         "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "9.661937527827291`*^-8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39`"}], ",", "1.362554422623674`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38`"}], ",", "1.9220290325971945`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37`"}], ",", "2.712574245222754`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36000000000000004`"}], ",", 
         "3.83096816936046`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "5.415377797302057`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34`"}], ",", "7.663589101092327`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33`"}], ",", "1.0859252058681435`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32`"}], ",", "1.5409917132336304`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31000000000000005`"}], ",", 
         "2.19020228642286`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", 
         "3.1180265545049934`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29000000000000004`"}], ",", 
         "4.446187976347993`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28`"}], ",", "6.350058124215963`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27`"}], ",", "9.082096045331944`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26`"}], ",", "0.00001300515908109201`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "0.00001863961154047189`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24000000000000002`"}], ",", 
         "0.00002672949786330925`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23`"}], ",", "0.000038334894368885486`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22000000000000003`"}], ",", 
         "0.00005495991431825331`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21000000000000002`"}], ",", 
         "0.00007872882747517185`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.00011262681718793299`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19000000000000003`"}], ",", 
         "0.00016082705542141973`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18000000000000002`"}], ",", 
         "0.00022913271266111757`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17`"}], ",", "0.0003255725469655246`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16000000000000003`"}], ",", 
         "0.00046120282584038996`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", 
         "0.0006511906351505115`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14`"}], ",", "0.0009162895834812224`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13`"}], ",", "0.0012848803473789472`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12`"}], ",", "0.0017958579720144252`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11000000000000004`"}], ",", 
         "0.0025028506466456824`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10000000000000003`"}], ",", "0.00348064615701138`"}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09000000000000002`"}], ",", 
         "0.004835492620642756`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08000000000000002`"}], ",", 
         "0.006722624862896098`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07`"}], ",", "0.00937820812429202`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06`"}], ",", "0.013182420037863407`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", 
         "0.018796767828342165`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.040000000000000036`"}], ",", 
         "0.02750298571925336`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.030000000000000027`"}], ",", 
         "0.04220002528993849`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.020000000000000018`"}], ",", 
         "0.07125431410015437`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.010000000000000009`"}], ",", 
         "0.15330403861172748`"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.4`"}], ",", "1.0911271886016038`*^-8"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.39`"}], ",", "1.5165646405357336`*^-8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.38`"}], ",", "2.1102008918028048`*^-8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.37`"}], ",", "2.939870547002954`*^-8"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.36000000000000004`"}], ",", 
         "4.1023850316790345`*^-8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.35000000000000003`"}], ",", 
         "5.7350789561816384`*^-8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.34`"}], ",", "8.034572707149579`*^-8"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.33`"}], ",", "1.1282418876934486`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.32`"}], ",", "1.5883404491656705`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.31000000000000005`"}], ",", 
         "2.2421284684437381`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.30000000000000004`"}], ",", 
         "3.173871782058413`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.29000000000000004`"}], ",", 
         "4.50536176255234`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.28`"}], ",", "6.412768283059478`*^-7"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.27`"}], ",", "9.15076491470046`*^-7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.26`"}], ",", "1.3086989646415859`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.25`"}], ",", "1.8751116518389566`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.24000000000000002`"}], ",", 
         "2.6904020712370524`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.23`"}], ",", "3.863469882126047`*^-6"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.22000000000000003`"}], ",", 
         "5.549512137048573`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.21000000000000002`"}], ",", 
         "7.968629597288057`*^-6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.2`"}], ",", "0.000011431327242572564`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.19000000000000003`"}], ",", 
         "0.00001637322207959091`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.18000000000000002`"}], ",", 
         "0.000023402016377183088`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.17`"}], ",", "0.00003336083728600059`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.16000000000000003`"}], ",", 
         "0.00004741354938231357`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.15000000000000002`"}], ",", 
         "0.00006715998630013598`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.14`"}], ",", "0.00009479288612268544`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.13`"}], ",", "0.00013331480113920602`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.12`"}], ",", "0.00018684503949184528`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.11000000000000004`"}], ",", 
         "0.00026106844205453505`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.10000000000000003`"}], ",", 
         "0.0003639201714409346`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.09000000000000002`"}], ",", 
         "0.0005066865483106531`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.08000000000000002`"}], ",", 
         "0.0007058861356389334`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.07`"}], ",", "0.0009867178388376363`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.06`"}], ",", "0.0013899202861142879`"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.04999999999999999`"}], ",", 
         "0.0019868453399276564`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.040000000000000036`"}], ",", 
         "0.0029171473631195433`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.030000000000000027`"}], ",", 
         "0.0045017862748640836`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.020000000000000018`"}], ",", 
         "0.0076938147012420854`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.010000000000000009`"}], ",", 
         "0.017208482985485385`"}], "}"}]}], "}"}]}], "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.782246551242796*^9, 3.782246557592292*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"alltheory20", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.4`"}], ",", "4.834442790535576`*^-7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.39`"}], ",", "7.280806675336038`*^-7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.38`"}], ",", "1.1013550670346817`*^-6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.37`"}], ",", "1.6739418127187378`*^-6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.36000000000000004`"}], ",", 
       "2.5571145922942407`*^-6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.35000000000000003`"}], ",", "3.926711245827441`*^-6"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.34`"}], ",", "6.0616106480892995`*^-6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.33`"}], ",", "9.405275660845369`*^-6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.32`"}], ",", "0.00001466408464945168`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.31000000000000005`"}], ",", 
       "0.00002296397914403059`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.30000000000000004`"}], ",", 
       "0.000036099947758549966`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.29000000000000004`"}], ",", 
       "0.000056929773823877206`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.28`"}], ",", "0.00008999608544957294`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.27`"}], ",", "0.00014250026368112234`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.26`"}], ",", "0.00022582428462614157`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.25`"}], ",", "0.0003578891368045678`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.24000000000000002`"}], ",", "0.0005667927225286862`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.23`"}], ",", "0.0008963839013724773`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.22000000000000003`"}], ",", "0.0014147467761264076`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.21000000000000002`"}], ",", "0.0022270230475007757`"}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.2`"}], ",", "0.003494639623003337`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.19000000000000003`"}], ",", "0.005463884823775689`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.18000000000000002`"}], ",", "0.008507921962300657`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.17`"}], ",", "0.013187701890287507`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.16000000000000003`"}], ",", "0.020338576198859037`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.15000000000000002`"}], ",", "0.031189923818135568`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.14`"}], ",", "0.04752275577813281`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.13`"}], ",", "0.07186039463277039`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.12`"}], ",", "0.10766009539364907`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.11000000000000004`"}], ",", "0.15941014043993607`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.10000000000000003`"}], ",", "0.23240769609962075`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.09000000000000002`"}], ",", "0.33176964127173436`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.08000000000000002`"}], ",", "0.4599591492094549`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.07`"}], ",", "0.6121606584397329`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.06`"}], ",", "0.7703936794609902`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.04999999999999999`"}], ",", "0.9023396525261022`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.040000000000000036`"}], ",", "0.9773439970496514`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.030000000000000027`"}], ",", "0.9984758621156562`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.020000000000000018`"}], ",", "0.9999949973318434`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.010000000000000009`"}], ",", "0.999999999999264`"}], 
      "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.782246565059643*^9, 3.782246570829389*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot", "Subsubsection",
 CellChangeTimes->{{3.78224585813904*^9, 3.782245858610935*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"N0", "=", 
   SuperscriptBox["10", "4"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "4"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"letter", "=", "\"\<A\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figS6a", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ListLogPlot", "[", 
      RowBox[{"theory2", ",", "\[IndentingNewLine]", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
       
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.4"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"5", "*", 
             SuperscriptBox["10", 
              RowBox[{"-", "7"}]]}], ",", "1"}], "}"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Frame", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Wildtype growth rate\>\"", ",", ",", ",", 
          "\"\<Probability of rescue\>\""}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"LineLegend", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{
             "\"\<1-step\>\"", ",", "\"\<2-step\>\"", ",", "\"\<3-step\>\"", 
              ",", "\"\<4-step\>\""}], "}"}]}], "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.85", ",", "0.23"}], "}"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ListLogPlot", "[", 
      RowBox[{"alltheory2", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick"}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"LineLegend", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", "\"\<total\>\"", "}"}]}], "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.56", ",", "0.23"}], "}"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ListLogPlot", "[", 
      RowBox[{"theory20", ",", "\[IndentingNewLine]", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", 
          RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ListLogPlot", "[", 
      RowBox[{"alltheory20", ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", "Thick", ",", 
          RowBox[{"Dashing", "[", "Large", "]"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"LineLegend", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Directive", "[", 
               RowBox[{"Thick", ",", "Gray"}], "]"}], ",", 
              RowBox[{"Directive", "[", 
               RowBox[{"Thick", ",", "Gray", ",", 
                RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}], 
            ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"#", ",", "12", ",", 
                RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
               "]"}], "&"}], "/@", 
             RowBox[{"{", 
              RowBox[{"\"\<\!\(\*
StyleBox[\"n\",
FontSlant->\"Italic\"]\)=2\>\"", ",", "\"\<\!\(\*
StyleBox[\"n\",
FontSlant->\"Italic\"]\)=20\>\""}], "}"}]}]}], "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"1", "/", "10"}], ",", 
             RowBox[{"7", "/", "10"}]}], "}"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"letter", ",", "Bold", ",", "14", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"braceLabel", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.125"}], ",", 
              RowBox[{"Log", "@", 
               SuperscriptBox["10", 
                RowBox[{"-", "6"}]]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.125"}], ",", 
              RowBox[{"Log", "@", 
               RowBox[{"(", 
                RowBox[{"2", "*", 
                 SuperscriptBox["10", 
                  RowBox[{"-", "4"}]]}], ")"}]}]}], "}"}]}], "}"}], ",", 
          RowBox[{"Style", "[", 
           RowBox[{"\"\<\>\"", ",", "Larger"}], "]"}]}], "]"}]}], 
       "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "N0", ",", "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", 
   "m0min", ",", "m0max", ",", "mstep", ",", "letter"}], "]"}]}], "Input",
 CellChangeTimes->{{3.771243438404381*^9, 3.771243505591201*^9}, {
   3.771243660674692*^9, 3.771243770343318*^9}, {3.7712438051594973`*^9, 
   3.771243806769825*^9}, {3.77124384246271*^9, 3.7712439832452*^9}, {
   3.771244074547236*^9, 3.771244075614129*^9}, {3.771244170126183*^9, 
   3.771244240128414*^9}, {3.771244491552649*^9, 3.771244539467946*^9}, {
   3.771244637848792*^9, 3.771244771807975*^9}, {3.77124482635817*^9, 
   3.771245429892724*^9}, 3.771246073841148*^9, 3.771246637425001*^9, {
   3.771252282261911*^9, 3.771252288712202*^9}, 3.771254690716058*^9, {
   3.771254724632944*^9, 3.771254752430646*^9}, 3.77125504889705*^9, {
   3.7715446486731167`*^9, 3.771544649294244*^9}, {3.780251817258157*^9, 
   3.780251837264227*^9}, 3.780252917208507*^9, {3.780255349776267*^9, 
   3.780255419507058*^9}, {3.780255450934721*^9, 3.780255487344339*^9}, {
   3.780256197190711*^9, 3.780256197383162*^9}, 3.780256244789771*^9, {
   3.7822458187658052`*^9, 3.782245834618273*^9}, 3.782245917905691*^9, {
   3.7822459636724367`*^9, 3.7822460368894444`*^9}, 3.7822460854417048`*^9, {
   3.784904627328817*^9, 3.78490464414844*^9}}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwtkHtI01EcxUczQ7dKa7qS3DJTV1uU5LI/elIyJSlnf/RH9lBZEaibSo+V
SIZhYriioAw1YgspZKAT2iB3vm1JFq42dS+ix0YYphJUs7AFeX/bgcvlcu/9
fM85WVXacs0SHo8nW1xsf9DFFERblbWgJl9B87IKgyMSQMtkYnGnUE7lVsn1
GXUAglDvO8XMJjKrQpdFZj9yM+fDZS4ZCfxG3e5kP2rzo6V8Sx6dPcPkQ8/W
ksHS7lxyRhjQC5vE1axszyHpIs0q8UKUdPPTiH4jXREx4iTmVAmWpXXZFOBw
E6gLpLdHNRuoYDvTBPpPGXsGKrPoloMBx5Gnrw/LK9fTrJoZ9MAhU+R8GZVQ
MbOn8qCvumk4zb+OTAxndONPetelhdkM4nFyY+dB8eSj5LVkY/Gsb3Gs8/QN
yTYx1bPnOhdWWToy2k+k0WZWh2wM+6dP2vl3VlOY4UNv0EieNeROpVh/r3Ho
Kf/xMnEKHeX6GsXtb/euGcaE8X5eoeb358ai5qR4HyMofFiYsLIokZq4/C+B
fWV7Tdn8eF4ntOMp7+cyefF8L1CrlZZPNywglocgF2Q7PX9/gRtntUOgLtG4
fd+h4Pw+R4Oy4mO/bQrdnD8bZsI+o3HkA4Scn2eYEx9YPqT0IDZ/CMYLP1r2
XCTE5g3ArFf+NFT3xflmHBZ3IHiuFfc53hO0TVmjhTuO4Cr33wTD+V2pg18j
duLe98K7QmoO/Dtuj93fRZDVrtsyHDu3ghfXf7XCS3g=
         "]]}, 
       {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJwtkGtI01EYxtfCvDIarZZlm7fWCitnJvShIMmUspEuEEmMbhaBtJIGbplR
BpIfCrRMcTaaECqtJM1Z2vPmNEuWTG2X/LLMQYTNmui6meX57//A4XA45/ze
53kSTpzPPy0UCATKpcX2xgamD5hz7PReW1BQUFl0q3/eg4h9lS5lpoLyrbIb
03keiGtLeqOrN5Ile1IvsbjxtNx+VjWSTNFus3Z3lBv2uFpfkySZzpQwueBW
1A0UHE0i2zwDOpEbKXqmfZBI8iWaVebEpWO5D/98SSCDhBHfQ7/ZOSZOSyAP
hxvHOWq2OvTxlL6DaRzpierAi2o53e5nwDHEL5rC+jbI6GseMziKKmPQuNAZ
RznMXvYofp0SRrrV66mF4cwOtMdUZDyajiUBJwf+GcvUUzVrqYfFs45gj2Su
2LtdShfYc+076HRiVYRnNW1hdSjt0HzfdXigSkKfGH5yGMNZBQfLM1ZRqL+3
uP54IrXGLyYN19cbrNGZ9ha1reT7GcLPrg5Tw4SI72MQFT9sel1pDF3m8g/g
0BPVbLgois9rg7VU7xP2hfP5XqHevbVVagjj8xD+5lmEgZzlxI2zvsRQS6Yh
bdMySuH89mLCWR/mT1lEE+evB1mDsWON234jhvPTjdSp5JnKI0GE5ncikOjx
d9+fRWheB64cWFd3MmkGIb4FJPQaXYWfcY/jtWJeIVXp/R9xlfvfgjv7n/vk
35wg7n0zyox3ZWLPa/6+Dl3mDE1gsp0/V6Hw4s0VruLj+A8FWlYP
         "]]}, 
       {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJwtkF1I01EYxmcp2jZJcemsNbep27AvwoiEIkhjUVBuEstYJIOyLHJeaLJm
KOnVLNfSaBHuYutjEgNL3WZr75smbepM5z7+JRWTUDC9cKHlRZjn7/+Bw+Fw
zvm9z/OItbWqK1tYLJZ8Y5H9qYXoC0hfOCSDS3JclWs6hlYoELxKNyafl6PK
LWz7paTgxMUE6LwydCriep4zBvwbl9Xz+TLkxGy6Y+wY/Dhd31BulGL1VaIo
NMys3+9KFOLwCgFGYE+tc8laWYh5GzS3MAIv+6rNl7AA7/AIMQz1F9YEKC1A
isZNw70zTr+vPR8PFRNNQ2nr/oA6IUHTEAGGAEoabz5US3BRSQxOgWn57G+9
V4yniD3FFCS+Z6fuE4vRTnC2SeC6BnoDbSJk0ZqEukeiwT/hPPSQeO4JaGri
v17sFmIdea4LwkTnfOjn9d1YROqQj8OBUbtGc1iAswQfH4Vzc8UHI8m7cLO/
AGiV16hQJBcr6L780JFSdTLq4DP9fAKjy2qpbMlh+hiBqv7PX8c02Wig838E
DGcZ2o/uYPIOQ41lwDAn4jH5PgCfolxsdhaTByFDDuNpfzORHuf2gVcmeTey
kIF7ab9eiO8stX0b3o7PaH8eMC8rbgU96cil/bhAvKZ/ruznMPP7oGxsfebI
223MvF4o6UnjPnamMnwncMpuv0drCj6heQ6IVlAtjfqt2Ez/t4M51zSbU5SE
SL/vBlXS8eauzH+wed8J2vKgvebBKnNuhTdKv++ucgH+A6h0U3Y=
         "]]}, 
       {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJwtkAtI01EYxce2wm2iq602S5ePzT2cEPbCubIsUAoMVy4MiWblyiE6KNa7
pIIgIodSKSbIFjTMVZC40dj3NbWHtbXNdJuQOREtC4RIkcSW99//wOVyuff+
vnNOVk2D7hSTwWAoVhbZ29uIYnDB3Df1bVKNC4rqe775KDzJPft3QqdGnUty
60dFFDhaWbHDl4fO0vhFoTMC/NruQWlBHvIitsad3AhwDyo3b+9SobGWaBTu
2LqXIVWF/fMEOALPeQHv4ytK3LRCc0lGYM9pR69/VoGXhIT4GTTHTcLsIwqM
Urhh+JDIkLb45Lh1C9EwNHD3ctPy5djsI8Aw7Dv6yNp7Pxd/VhCDIag2zNSc
S8iwjNgrDUGl9gbfbJShneBsQbiqylf7A1JkUArCruKxr+5tUnSTeK4A3E1q
8pg7ctBMnjf6QRATLu5g5aCK1KH4CLbdxgJ9XTZOEnx8COrGWdNp4Sz83997
+J5ge0OaLDxE9fUOSiD0ZcieSffzFjonzmjK+Zl0H4OQMjPL1i5J8DKVfwBu
98RTpmMZdN5++FR/jfPbk07new2BZ8miLvtGOg+CV95qYVo3IDXO5QXl3Pnm
5aY0VFN+PcAuf/qr0CLGDsqfGw7/GfMnN4owmfLTB236B/VVpvX0/JewIC4K
HjOuo+e9gHF2C+eEQUjznRA+MNqeXinAhxTPAauW9CJr0Vq8Tv23g9JgWexJ
WoNIve+EElbhwsD+VPq+FaqmzEzBKx59vgkn5ximN+LV+A+z10dr
         
         "]]}}, {}}, {{{}, {}, 
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwtkH9I00EYxof2a22o5cxKnFprWznB1iAJJAly1RY1M6opg8ISknK2kaFB
YyQYmFoUlURgKtE/g3DRRmPPbSZtWuG23JaUsYhtNocTnUIjyPtuDxzHcXef
93meskutdZezWCyWeG3RfeAZ1Tec5QuLZOVCsiJu7HMmg/hndLlH9HtInYXf
FVMFoYtLu/tsAmKShzp4pgBGuybzPVkCwgkMaas3B9CvifqU8t2k+QqVHzev
tl1I3NtFxpIUOA2RomHGPFFGStZoFv40VNVH7gyyy0gnjxK/QhoJeydrS0mQ
wflgqLH/Nq0rIbIDVD78LLdi4VYx6XdSoBdK3Uaf708RmVdRgx5Ikfs4rt5J
jlF7cg90Dztts+7tZJjihqaQsi0k6qsKCYvRFJwV45INrwqIlcazfMGqfrXF
tI1H2uhz7WcMRJ37c7u3kn20DvEnaGa/tyym8sgvig9NIHW/src+nEPS/bnh
UQsV8h8ccobpy4VlkWyvd3ZTpp+PSDUWm/Xx9Zk+xtFsNnmPc7PJbSb/Bzyp
uHhScZiVyTuG2EjeodOFKaTzOfBe1sRWJ5JI5yGojTi0rUWLYMZZ7OCIsgev
a+YgYfzaUPXgb/tcbwjPGX9WGA2x5aM5fnAZP+/Qkx9p6OC6kJ5vxrWCcOmK
5G1m3hs0KY0ndowOZPgmJLtqooKXOjxleK9x49TSeUn7QRiY/8Ngn5vxO5b8
dsK8f4Etnp6gxFVpT98/Apfpfd6WPt8FK6P/d5BQXw==
         "]]}}, {}}, {{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], Dashing[Large], 
        LineBox[CompressedData["
1:eJwtkm1I01EUxtcCKzMsnb23NjfXZtMmKmygUfhhahBpKVFGS1kmKNk7aZiY
gyAqzchVNiv9YCSLleVWa8/RFc5S2ZrLBWXoIBIlA9Fe/FDe//4HLpfLPfd3
nufhSouP5xuFAoFAubDYfuc2q084H3jaaBOn0Jyy6HrvbBDqpskGS62G8u1i
02ReEO2FXpPBs42s+rEqkXUElvJQqf9GMi0faavMjByB2S0aazUkUelRVh/x
NVanGUxRk3uWAQPoqRjSlkRspc0LNLs4AOnB9L9loyqqFjHiMOR76lu+O5QU
5HB+HK47HfPNvIXSUln5kV6UM3CsWkENvQz4Adea1M/OHkmgqTwm0IemM58F
cbvklM3k6X344jmZnK2VUTvDtXmx/193IFYVTwKuvKgTKu5VbZKSg9mzDyFh
2XNZTZyETrD2ykGEnJJF2+PFlMjiUA5gXOZ47JBspHGGH3sH1boD8grFegrn
14+keeNEQepa2svl5UF0rUV4Sr+az6cPzRmyLE+xiM/jLTpqBh+WmGLoAuf/
DSjU1298spL368aV6MQpce8K3l8PLq7JLetMj+T9ENJ6fmUufRVB3Di7C9rO
aaV332JSc3qd6JgDZSwRUAunz4Gfl726GdsfRHF6urHDcnW3q2MG4fldeO/D
LZN8CuF5Nlz63XxIoxtHmG9FS6d4lXPDMMwc7xGyogzndvoJtdz7dpS/rMt9
8eA+iOu34K6vYFSRZ+Tvb2I6p1A33zXhCp/roVn4gJIfja//A9hWTS0=
         "]]}, 
       {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], Dashing[Large], 
        LineBox[CompressedData["
1:eJwtkF9IU1Ecx+fCovXP1saG4nJutuu89dCU6EF9yNIGrTbTZBiBpBYJmzYw
XIUPikJIGwjLkSlNqCAWYuJdLn8/XbKVVtvMNumhrgijzPWiFbNYntv9wuFw
OOd8ft/vV9lgMTUKBQIBtbXI7h4gWoKQpvFA7txh/EnV353ZiIO29vLK5CaN
JkbRvWqMw9RRf/oMTaO3ku2QeGNQMWdzReqLcFfMYy0VxcCZoErK+7TY3ET0
EUT+7lLXy0IMbBDgIiybRrs+r1F4cIvGKBahVn/hukpBoV1CiB/goq/EYDNo
MM7hFmBJc97+7fYhLNYRLUDYfjY4/KwAHTMEGIWh7PkfL76o8buRGIyAulDT
c0msxipirzICoTa3YLJChSME5wnDtKRnItWejwJOYWB64z7DUyX6SDzmHchq
PL8TbB62kufWtyCTFhz/Jc9DLamDmodkpi6rzqPAZYJn30DZtbrWZnku/u/v
NQxeyflkdeZgNddXCG5kpE24N5vvJwjj+VF0OeR8H7NgtJxI0TIZ3uTyv4LN
c6fdjx5K+bwB0PcO2xQ6CZ9vGtjyP039ITGfB+GYc6xovWE/cuOYKQAm+lgk
zEKa8+uHlnHb17/6PXif8+eD6qstgb4BEe7m/EyAKvi+jU7u4Oc/hxq1s/3O
qUx+3ii41txm85CQ53vBbzkZ8STScI/jPYHVQZM4oyMFndz/EdgekpY52XVA
7v0DSK+Yi3Fbkr/vh1uzjiqlneXPXdC5byfSRwLwD66YTr4=
         "]]}, 
       {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], Dashing[Large], 
        LineBox[CompressedData["
1:eJwtkG9Ik1EYxTctUbNmYyqWzm22Nte2io2CYNQ3JQl0CwlcBJVmsdIxInFh
VrM0loUm5KphbRp9cBUIzX89j265Niumm21jwVJSkDLB2liElfftPXC5XO69
v+ecwz9Zr65JYTAY4vVFdksPUQSehweqM0R7MCHW3pmIh+G7sknPtu5GtZPb
+rUyDNoHirSVZTk6SueaOI4Q5A7Pt91SyXFTyNagygxBR/P4stcswzO1RB9h
TJO0dkal6IoT4Cx0ZZsbvSVSLFqnObmzUPF3Na3q0i40cggxCC8O4ZNitwTD
FC4A0vbyH4JsCSoVRAFY6o8ay6tL8O4EAc5As9/LeNQnxm+VxOA06BL5I7wV
EZYRe6XToG5T+Jb2i9BOcDY/GN0Hb+e07EQGJT+4+ZNFUx4hDpF4zg9w3bzP
cIAlRD153vAeIt2bg5aqHSghdYjfwciWgjWxtRjnCX7OB3Czc4NwUYD/+/PC
lWsGpl8uQA3V11vQ/Wy3nW3k0/14YLXrc0Tm4tF9vIGk3aRVs3h4mcrvhov6
p6fTh7l0XhcorzpTfccK6XzjkIxlJlm/t9N5EHRr8cJPvduQGud8Da500STz
cD5KKb+jEDzePZaXyMOHlL8hWIyZFk7ZczGL8vMKzp1gF4xqcuj5g6AyeKaO
pnDoeS+h/0bg/IUBNs13wJEv9T2uiq14n+I9g7rHqTULPha2UP/tIPyV0NRB
FiL13gq9rbUxizqDvr8HUfbMoI+/kT6bQLa3o0zL/AP/ABFqUQY=
         "]]}, 
       {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], Dashing[Large],
         LineBox[CompressedData["
1:eJwtkF9Ik1EYxpdkoXVhpiwa+/NNp9O5ubn1n5HdZFBQc7gw11ZhRUboYMHw
DwhtWEal1YVbmsmGIIxZYvQNovfdXJmly23ZN4mKKQSrBL2YWheR5+t74HA4
nHN+7/M81IXm2otZPB5PvrHI7nETzUPOmYNHLHVVuCo33wtnkhBsKLtauKkK
a2mR66chCV/j9jtOvwYDNanWggADy4b1taHTGtzGeFv0uQw8bQ8p67I0ePkS
0SeoDr+x9/jVOJEhwDmg7k4z1SY1ijdotGgOkvsHPoz+rcS2AkL8CPf3XD/b
e7ISkywuAR76RHHeoAp1WqIEmLb2SaklJfaECTAOzcYGV+SAEn8ZiMEY5NxK
C7JdFXiM2KuJwe+x7qU/UQX6CM47C0/4NPOer0Aeq1m4fW3zzIi1HIMkHh2F
1Nr3L7HhMrSR5y0zcN4XUnYvybGc1CGfho5vOq1YJ8cFgk+9g+e+K9mp1lL8
398UrEQdJkm4BI1sX2/BEgt0KXJLuH4mYf1BYvG4Ucb18Rpk8fzl8EAxtrP5
I2DslUUn00Vc3gk4J7S4nPuKuHwhsKs7fuR3Sbk8CHuVRxcdSQrZcfQriASo
Rq+CwgrW70vwqIRN1k4J9rP+gsBIbZpBvxi3s35egGpH1k26XsTNH4fhxI1x
7RYhN+8ZrAimIodGBRw/AHTw81Djqd3Yx/JGQGBmJM6FXdjJ/vdBm556pK/n
I7LvH4PN4hrL9Bdy9w/BvWp2lzp2cmcn6K3ppvnDefgPds1Nog==
         
         "]]}}, {}}, {{{}, {}, 
       {GrayLevel[0], Thickness[Large], Dashing[Large], 
        LineBox[CompressedData["
1:eJwtkXtI01EUx9dASV3YaoXKck1tTdso6AEJNixrs1WkK8oaluHK/qg9JAIn
IT0oIVkPHxmbLhzpxEaj19TmOXtIU7S29iwRWaYEWSSxikJo97cduFwu99zP
+X6/l3tGWamg02g0fnyR/WEnqQ8wwL0mGlgjxF98uc4Zi8DoZLYqpUyAlbbc
G18rIlDvY9jZqk1oEUcbWJYwlLYZ3O7OIswI96hK0sMguDfjCWIhnjtLKgTZ
oeLU4jk+umIEGATdrC7zeyofOXGaLTcI4qshB523EbUsQgxAgdVrMezmYYTC
+cEretH8R74Bt20l5Qe9I22H/FIB3nES4HuolrVUc2/n40IFEeiDfo9GZH6U
hxIiT+yDHEWr9uRLLpoIrscLFx8f2GwcX480qrzwtNn1c9jOwUFiz/YWykzl
89/m16GatKsmIbK4ytDCZGMRiYM/AcfUwx17duXgJ4KPjoN9X2O070IWJvIb
A8bskSyJcS3KqLw88Be35BlDrGQ+b2D/dN1nPnN1Mo9R0FYx2k8cZmIj5d8N
hmmpUl2YmfTrgoNtUqPbnpH054B611BAdmp50g/CTSk7TbMyBalxthGIlVzp
uxVYhgJK72uQlD8Zq6lZAj2lbxBCp3tL86t+A4PS8wr6f9hpwt5FSMx/DkdV
C7wVH79AYp4VmNp3E111M5DgW2Bn97Nav9ULDyieGczbp5TOQ0PQRL03Qbda
cVdzuQOQ6u+CKWET/f7S8eR9K+g5e2vb/wVGEufr0JAe/4a58/b/rjFReQ==

         "]]}}, {}}}, {InsetBox[
      TemplateBox[{
       StyleBox[
        "\"total\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"Directive", "[", 
                RowBox[{
                  RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                  RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], 
            ",", 
            RowBox[{"{", #, "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      Scaled[{0.56, 0.23}], ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TemplateBox[{
       StyleBox[
        "\"1-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"2-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"3-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"4-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.5470136627990908`", ",", "0.24`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24`", ",", "0.6`", ",", "0.33692049419863584`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      Scaled[{0.85, 0.23}], ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TemplateBox[{
       StyleBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\"]\\)=2\"\
", StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 12],StyleBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\"]\\)=20\
\"", StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}],
             ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      NCache[Scaled[{Rational[1, 10], Rational[7, 10]}], Scaled[{0.1, 0.7}]], 
      ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesOrigin->{-0.4, -14.508657738524219`},
   CoordinatesToolOptions:>{"DisplayFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& ), "CopiedValueFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& )},
   Epilog->{
     InsetBox[
      FormBox[
       StyleBox[
       "\"A\"", Bold, 14, FontFamily -> "Helvetica", StripOnInput -> False], 
       TraditionalForm], 
      Scaled[{0.05, 0.95}]], {
      Arrowheads[{{0.02, 0, {
          GraphicsBox[
           CircleBox[{1, -1}, 1, 
            
            NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
             3.141592653589793}]]], -1}}, {0.02, 1, {
          GraphicsBox[{
            CircleBox[{-1, 1}, 1, 
             NCache[{Rational[-1, 2] Pi, 0}, {-1.5707963267948966`, 0}]], 
            InsetBox[
             BoxData[
              FormBox[
               StyleBox["\"\"", Larger, StripOnInput -> False], 
               TraditionalForm]], {0, 2}]}], 1}}}], 
      ArrowBox[
       NCache[{{-0.125, -Log[1000000]}, {-0.125, 
          Rational[1, 2] (-Log[5000] - Log[
           1000000])}}, {{-0.125, -13.815510557964274`}, {-0.125, \
-11.166351874690257`}}]], 
      Arrowheads[{{0.02, 0, {
          GraphicsBox[
           CircleBox[{1, 1}, 1, 
            
            NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
             4.71238898038469}]]], -1}}, {0.02, 1, {
          GraphicsBox[
           CircleBox[{-1, -1}, 1, 
            NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]], 1}}}], 
      ArrowBox[
       NCache[{{-0.125, 
          Rational[1, 2] (-Log[5000] - Log[1000000])}, {-0.125, -
          Log[5000]}}, {{-0.125, -11.166351874690257`}, {-0.125, \
-8.517193191416238}}]]}},
   Frame->{True, False, False, True},
   FrameLabel->{{"", 
      FormBox["\"Probability of rescue\"", TraditionalForm]}, {
      FormBox["\"Wildtype growth rate\"", TraditionalForm], ""}},
   FrameTicks->{{None, {{-13.815510557964274`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-11.512925464970229`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-9.210340371976182, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-6.907755278982137, 
        FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
        FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
        FormBox["0.1`", TraditionalForm]}, {0., 
        FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.716898269296165`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.429216196844383`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.206072645530174`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.02375108873622, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.86960040890896, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.736069016284437`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.618285980628055`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.819778284410283`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.414313176302118`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.126631103850338`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.903487552536127, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.721165995742174, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.567015315914915, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.433483923290392, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.315700887634009, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-8.517193191416238, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-8.111728083308073, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.824046010856292, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.600902459542082, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.418580902748127, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.264430222920869, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.1308988302963465`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.013115794639964, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-6.214608098422191, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.298317366548036, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.995732273553991, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.659260036932778, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.407945608651872, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.6931471805599453, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659905, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.35667494393873245`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782616`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {True, False}},
   GridLines->{None, None},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.4, 0}, {-14.508657738524219`, 0.}},
   PlotRangeClipping->True,
   PlotRangePadding->{{None, None}, {None, None}},
   Ticks->{Automatic, {{-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.716898269296165`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.429216196844383`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.02375108873622, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.86960040890896, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.736069016284437`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.618285980628055`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}],
  InterpretTemplate[Legended[
    Graphics[{{{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJwtkHtI01EcxUczQ7dKa7qS3DJTV1uU5LI/elIyJSlnf/RH9lBZEaibSo+V
SIZhYriioAw1YgspZKAT2iB3vm1JFq42dS+ix0YYphJUs7AFeX/bgcvlcu/9
fM85WVXacs0SHo8nW1xsf9DFFERblbWgJl9B87IKgyMSQMtkYnGnUE7lVsn1
GXUAglDvO8XMJjKrQpdFZj9yM+fDZS4ZCfxG3e5kP2rzo6V8Sx6dPcPkQ8/W
ksHS7lxyRhjQC5vE1axszyHpIs0q8UKUdPPTiH4jXREx4iTmVAmWpXXZFOBw
E6gLpLdHNRuoYDvTBPpPGXsGKrPoloMBx5Gnrw/LK9fTrJoZ9MAhU+R8GZVQ
MbOn8qCvumk4zb+OTAxndONPetelhdkM4nFyY+dB8eSj5LVkY/Gsb3Gs8/QN
yTYx1bPnOhdWWToy2k+k0WZWh2wM+6dP2vl3VlOY4UNv0EieNeROpVh/r3Ho
Kf/xMnEKHeX6GsXtb/euGcaE8X5eoeb358ai5qR4HyMofFiYsLIokZq4/C+B
fWV7Tdn8eF4ntOMp7+cyefF8L1CrlZZPNywglocgF2Q7PX9/gRtntUOgLtG4
fd+h4Pw+R4Oy4mO/bQrdnD8bZsI+o3HkA4Scn2eYEx9YPqT0IDZ/CMYLP1r2
XCTE5g3ArFf+NFT3xflmHBZ3IHiuFfc53hO0TVmjhTuO4Cr33wTD+V2pg18j
duLe98K7QmoO/Dtuj93fRZDVrtsyHDu3ghfXf7XCS3g=
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJwtkGtI01EYxtfCvDIarZZlm7fWCitnJvShIMmUspEuEEmMbhaBtJIGbplR
BpIfCrRMcTaaECqtJM1Z2vPmNEuWTG2X/LLMQYTNmui6meX57//A4XA45/ze
53kSTpzPPy0UCATKpcX2xgamD5hz7PReW1BQUFl0q3/eg4h9lS5lpoLyrbIb
03keiGtLeqOrN5Ile1IvsbjxtNx+VjWSTNFus3Z3lBv2uFpfkySZzpQwueBW
1A0UHE0i2zwDOpEbKXqmfZBI8iWaVebEpWO5D/98SSCDhBHfQ7/ZOSZOSyAP
hxvHOWq2OvTxlL6DaRzpierAi2o53e5nwDHEL5rC+jbI6GseMziKKmPQuNAZ
RznMXvYofp0SRrrV66mF4cwOtMdUZDyajiUBJwf+GcvUUzVrqYfFs45gj2Su
2LtdShfYc+076HRiVYRnNW1hdSjt0HzfdXigSkKfGH5yGMNZBQfLM1ZRqL+3
uP54IrXGLyYN19cbrNGZ9ha1reT7GcLPrg5Tw4SI72MQFT9sel1pDF3m8g/g
0BPVbLgois9rg7VU7xP2hfP5XqHevbVVagjj8xD+5lmEgZzlxI2zvsRQS6Yh
bdMySuH89mLCWR/mT1lEE+evB1mDsWON234jhvPTjdSp5JnKI0GE5ncikOjx
d9+fRWheB64cWFd3MmkGIb4FJPQaXYWfcY/jtWJeIVXp/R9xlfvfgjv7n/vk
35wg7n0zyox3ZWLPa/6+Dl3mDE1gsp0/V6Hw4s0VruLj+A8FWlYP
           "]]}, {
          Hue[0.1421359549995791, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJwtkF1I01EYxmcp2jZJcemsNbep27AvwoiEIkhjUVBuEstYJIOyLHJeaLJm
KOnVLNfSaBHuYutjEgNL3WZr75smbepM5z7+JRWTUDC9cKHlRZjn7/+Bw+Fw
zvm9z/OItbWqK1tYLJZ8Y5H9qYXoC0hfOCSDS3JclWs6hlYoELxKNyafl6PK
LWz7paTgxMUE6LwydCriep4zBvwbl9Xz+TLkxGy6Y+wY/Dhd31BulGL1VaIo
NMys3+9KFOLwCgFGYE+tc8laWYh5GzS3MAIv+6rNl7AA7/AIMQz1F9YEKC1A
isZNw70zTr+vPR8PFRNNQ2nr/oA6IUHTEAGGAEoabz5US3BRSQxOgWn57G+9
V4yniD3FFCS+Z6fuE4vRTnC2SeC6BnoDbSJk0ZqEukeiwT/hPPSQeO4JaGri
v17sFmIdea4LwkTnfOjn9d1YROqQj8OBUbtGc1iAswQfH4Vzc8UHI8m7cLO/
AGiV16hQJBcr6L780JFSdTLq4DP9fAKjy2qpbMlh+hiBqv7PX8c02Wig838E
DGcZ2o/uYPIOQ41lwDAn4jH5PgCfolxsdhaTByFDDuNpfzORHuf2gVcmeTey
kIF7ab9eiO8stX0b3o7PaH8eMC8rbgU96cil/bhAvKZ/ruznMPP7oGxsfebI
223MvF4o6UnjPnamMnwncMpuv0drCj6heQ6IVlAtjfqt2Ez/t4M51zSbU5SE
SL/vBlXS8eauzH+wed8J2vKgvebBKnNuhTdKv++ucgH+A6h0U3Y=
           "]]}, {
          Hue[0.37820393249936934`, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJwtkAtI01EYxce2wm2iq602S5ePzT2cEPbCubIsUAoMVy4MiWblyiE6KNa7
pIIgIodSKSbIFjTMVZC40dj3NbWHtbXNdJuQOREtC4RIkcSW99//wOVyuff+
vnNOVk2D7hSTwWAoVhbZ29uIYnDB3Df1bVKNC4rqe775KDzJPft3QqdGnUty
60dFFDhaWbHDl4fO0vhFoTMC/NruQWlBHvIitsad3AhwDyo3b+9SobGWaBTu
2LqXIVWF/fMEOALPeQHv4ytK3LRCc0lGYM9pR69/VoGXhIT4GTTHTcLsIwqM
Urhh+JDIkLb45Lh1C9EwNHD3ctPy5djsI8Aw7Dv6yNp7Pxd/VhCDIag2zNSc
S8iwjNgrDUGl9gbfbJShneBsQbiqylf7A1JkUArCruKxr+5tUnSTeK4A3E1q
8pg7ctBMnjf6QRATLu5g5aCK1KH4CLbdxgJ9XTZOEnx8COrGWdNp4Sz83997
+J5ge0OaLDxE9fUOSiD0ZcieSffzFjonzmjK+Zl0H4OQMjPL1i5J8DKVfwBu
98RTpmMZdN5++FR/jfPbk07new2BZ8miLvtGOg+CV95qYVo3IDXO5QXl3Pnm
5aY0VFN+PcAuf/qr0CLGDsqfGw7/GfMnN4owmfLTB236B/VVpvX0/JewIC4K
HjOuo+e9gHF2C+eEQUjznRA+MNqeXinAhxTPAauW9CJr0Vq8Tv23g9JgWexJ
WoNIve+EElbhwsD+VPq+FaqmzEzBKx59vgkn5ximN+LV+A+z10dr
           
           "]]}}}, {}}, {{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          GrayLevel[0], 
          Thickness[Large], 
          Line[CompressedData["
1:eJwtkH9I00EYxof2a22o5cxKnFprWznB1iAJJAly1RY1M6opg8ISknK2kaFB
YyQYmFoUlURgKtE/g3DRRmPPbSZtWuG23JaUsYhtNocTnUIjyPtuDxzHcXef
93meskutdZezWCyWeG3RfeAZ1Tec5QuLZOVCsiJu7HMmg/hndLlH9HtInYXf
FVMFoYtLu/tsAmKShzp4pgBGuybzPVkCwgkMaas3B9CvifqU8t2k+QqVHzev
tl1I3NtFxpIUOA2RomHGPFFGStZoFv40VNVH7gyyy0gnjxK/QhoJeydrS0mQ
wflgqLH/Nq0rIbIDVD78LLdi4VYx6XdSoBdK3Uaf708RmVdRgx5Ikfs4rt5J
jlF7cg90Dztts+7tZJjihqaQsi0k6qsKCYvRFJwV45INrwqIlcazfMGqfrXF
tI1H2uhz7WcMRJ37c7u3kn20DvEnaGa/tyym8sgvig9NIHW/src+nEPS/bnh
UQsV8h8ccobpy4VlkWyvd3ZTpp+PSDUWm/Xx9Zk+xtFsNnmPc7PJbSb/Bzyp
uHhScZiVyTuG2EjeodOFKaTzOfBe1sRWJ5JI5yGojTi0rUWLYMZZ7OCIsgev
a+YgYfzaUPXgb/tcbwjPGX9WGA2x5aM5fnAZP+/Qkx9p6OC6kJ5vxrWCcOmK
5G1m3hs0KY0ndowOZPgmJLtqooKXOjxleK9x49TSeUn7QRiY/8Ngn5vxO5b8
dsK8f4Etnp6gxFVpT98/Apfpfd6WPt8FK6P/d5BQXw==
           
           "]]}}}, {}}, {{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJwtkm1I01EUxtcCKzMsnb23NjfXZtMmKmygUfhhahBpKVFGS1kmKNk7aZiY
gyAqzchVNiv9YCSLleVWa8/RFc5S2ZrLBWXoIBIlA9Fe/FDe//4HLpfLPfd3
nufhSouP5xuFAoFAubDYfuc2q084H3jaaBOn0Jyy6HrvbBDqpskGS62G8u1i
02ReEO2FXpPBs42s+rEqkXUElvJQqf9GMi0faavMjByB2S0aazUkUelRVh/x
NVanGUxRk3uWAQPoqRjSlkRspc0LNLs4AOnB9L9loyqqFjHiMOR76lu+O5QU
5HB+HK47HfPNvIXSUln5kV6UM3CsWkENvQz4Adea1M/OHkmgqTwm0IemM58F
cbvklM3k6X344jmZnK2VUTvDtXmx/193IFYVTwKuvKgTKu5VbZKSg9mzDyFh
2XNZTZyETrD2ykGEnJJF2+PFlMjiUA5gXOZ47JBspHGGH3sH1boD8grFegrn
14+keeNEQepa2svl5UF0rUV4Sr+az6cPzRmyLE+xiM/jLTpqBh+WmGLoAuf/
DSjU1298spL368aV6MQpce8K3l8PLq7JLetMj+T9ENJ6fmUufRVB3Di7C9rO
aaV332JSc3qd6JgDZSwRUAunz4Gfl726GdsfRHF6urHDcnW3q2MG4fldeO/D
LZN8CuF5Nlz63XxIoxtHmG9FS6d4lXPDMMwc7xGyogzndvoJtdz7dpS/rMt9
8eA+iOu34K6vYFSRZ+Tvb2I6p1A33zXhCp/roVn4gJIfja//A9hWTS0=
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJwtkF9IU1Ecx+fCovXP1saG4nJutuu89dCU6EF9yNIGrTbTZBiBpBYJmzYw
XIUPikJIGwjLkSlNqCAWYuJdLn8/XbKVVtvMNumhrgijzPWiFbNYntv9wuFw
OOd8ft/vV9lgMTUKBQIBtbXI7h4gWoKQpvFA7txh/EnV353ZiIO29vLK5CaN
JkbRvWqMw9RRf/oMTaO3ku2QeGNQMWdzReqLcFfMYy0VxcCZoErK+7TY3ET0
EUT+7lLXy0IMbBDgIiybRrs+r1F4cIvGKBahVn/hukpBoV1CiB/goq/EYDNo
MM7hFmBJc97+7fYhLNYRLUDYfjY4/KwAHTMEGIWh7PkfL76o8buRGIyAulDT
c0msxipirzICoTa3YLJChSME5wnDtKRnItWejwJOYWB64z7DUyX6SDzmHchq
PL8TbB62kufWtyCTFhz/Jc9DLamDmodkpi6rzqPAZYJn30DZtbrWZnku/u/v
NQxeyflkdeZgNddXCG5kpE24N5vvJwjj+VF0OeR8H7NgtJxI0TIZ3uTyv4LN
c6fdjx5K+bwB0PcO2xQ6CZ9vGtjyP039ITGfB+GYc6xovWE/cuOYKQAm+lgk
zEKa8+uHlnHb17/6PXif8+eD6qstgb4BEe7m/EyAKvi+jU7u4Oc/hxq1s/3O
qUx+3ii41txm85CQ53vBbzkZ8STScI/jPYHVQZM4oyMFndz/EdgekpY52XVA
7v0DSK+Yi3Fbkr/vh1uzjiqlneXPXdC5byfSRwLwD66YTr4=
           "]]}, {
          Hue[0.1421359549995791, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJwtkG9Ik1EYxTctUbNmYyqWzm22Nte2io2CYNQ3JQl0CwlcBJVmsdIxInFh
VrM0loUm5KphbRp9cBUIzX89j265Niumm21jwVJSkDLB2liElfftPXC5XO69
v+ecwz9Zr65JYTAY4vVFdksPUQSehweqM0R7MCHW3pmIh+G7sknPtu5GtZPb
+rUyDNoHirSVZTk6SueaOI4Q5A7Pt91SyXFTyNagygxBR/P4stcswzO1RB9h
TJO0dkal6IoT4Cx0ZZsbvSVSLFqnObmzUPF3Na3q0i40cggxCC8O4ZNitwTD
FC4A0vbyH4JsCSoVRAFY6o8ay6tL8O4EAc5As9/LeNQnxm+VxOA06BL5I7wV
EZYRe6XToG5T+Jb2i9BOcDY/GN0Hb+e07EQGJT+4+ZNFUx4hDpF4zg9w3bzP
cIAlRD153vAeIt2bg5aqHSghdYjfwciWgjWxtRjnCX7OB3Czc4NwUYD/+/PC
lWsGpl8uQA3V11vQ/Wy3nW3k0/14YLXrc0Tm4tF9vIGk3aRVs3h4mcrvhov6
p6fTh7l0XhcorzpTfccK6XzjkIxlJlm/t9N5EHRr8cJPvduQGud8Da500STz
cD5KKb+jEDzePZaXyMOHlL8hWIyZFk7ZczGL8vMKzp1gF4xqcuj5g6AyeKaO
pnDoeS+h/0bg/IUBNs13wJEv9T2uiq14n+I9g7rHqTULPha2UP/tIPyV0NRB
FiL13gq9rbUxizqDvr8HUfbMoI+/kT6bQLa3o0zL/AP/ABFqUQY=
           "]]}, {
          Hue[0.37820393249936934`, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJwtkF9Ik1EYxpdkoXVhpiwa+/NNp9O5ubn1n5HdZFBQc7gw11ZhRUboYMHw
DwhtWEal1YVbmsmGIIxZYvQNovfdXJmly23ZN4mKKQSrBL2YWheR5+t74HA4
nHN+7/M81IXm2otZPB5PvrHI7nETzUPOmYNHLHVVuCo33wtnkhBsKLtauKkK
a2mR66chCV/j9jtOvwYDNanWggADy4b1taHTGtzGeFv0uQw8bQ8p67I0ePkS
0SeoDr+x9/jVOJEhwDmg7k4z1SY1ijdotGgOkvsHPoz+rcS2AkL8CPf3XD/b
e7ISkywuAR76RHHeoAp1WqIEmLb2SaklJfaECTAOzcYGV+SAEn8ZiMEY5NxK
C7JdFXiM2KuJwe+x7qU/UQX6CM47C0/4NPOer0Aeq1m4fW3zzIi1HIMkHh2F
1Nr3L7HhMrSR5y0zcN4XUnYvybGc1CGfho5vOq1YJ8cFgk+9g+e+K9mp1lL8
398UrEQdJkm4BI1sX2/BEgt0KXJLuH4mYf1BYvG4Ucb18Rpk8fzl8EAxtrP5
I2DslUUn00Vc3gk4J7S4nPuKuHwhsKs7fuR3Sbk8CHuVRxcdSQrZcfQriASo
Rq+CwgrW70vwqIRN1k4J9rP+gsBIbZpBvxi3s35egGpH1k26XsTNH4fhxI1x
7RYhN+8ZrAimIodGBRw/AHTw81Djqd3Yx/JGQGBmJM6FXdjJ/vdBm556pK/n
I7LvH4PN4hrL9Bdy9w/BvWp2lzp2cmcn6K3ppvnDefgPds1Nog==
           
           "]]}}}, {}}, {{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          GrayLevel[0], 
          Thickness[Large], 
          Dashing[Large], 
          Line[CompressedData["
1:eJwtkXtI01EUx9dASV3YaoXKck1tTdso6AEJNixrs1WkK8oaluHK/qg9JAIn
IT0oIVkPHxmbLhzpxEaj19TmOXtIU7S29iwRWaYEWSSxikJo97cduFwu99zP
+X6/l3tGWamg02g0fnyR/WEnqQ8wwL0mGlgjxF98uc4Zi8DoZLYqpUyAlbbc
G18rIlDvY9jZqk1oEUcbWJYwlLYZ3O7OIswI96hK0sMguDfjCWIhnjtLKgTZ
oeLU4jk+umIEGATdrC7zeyofOXGaLTcI4qshB523EbUsQgxAgdVrMezmYYTC
+cEretH8R74Bt20l5Qe9I22H/FIB3nES4HuolrVUc2/n40IFEeiDfo9GZH6U
hxIiT+yDHEWr9uRLLpoIrscLFx8f2GwcX480qrzwtNn1c9jOwUFiz/YWykzl
89/m16GatKsmIbK4ytDCZGMRiYM/AcfUwx17duXgJ4KPjoN9X2O070IWJvIb
A8bskSyJcS3KqLw88Be35BlDrGQ+b2D/dN1nPnN1Mo9R0FYx2k8cZmIj5d8N
hmmpUl2YmfTrgoNtUqPbnpH054B611BAdmp50g/CTSk7TbMyBalxthGIlVzp
uxVYhgJK72uQlD8Zq6lZAj2lbxBCp3tL86t+A4PS8wr6f9hpwt5FSMx/DkdV
C7wVH79AYp4VmNp3E111M5DgW2Bn97Nav9ULDyieGczbp5TOQ0PQRL03Qbda
cVdzuQOQ6u+CKWET/f7S8eR9K+g5e2vb/wVGEufr0JAe/4a58/b/rjFReQ==

           "]]}}}, {}}}, {Epilog -> {
        Text[
         Style["A", Bold, 14, FontFamily -> "Helvetica"], 
         Scaled[{0.05, 0.95}]], {
         Arrowheads[{{0.02, 0, {
             Graphics[
              Circle[{1, -1}, 1, {Rational[1, 2] Pi, Pi}]], -1}}, {0.02, 1, {
             Graphics[{
               Circle[{-1, 1}, 1, {Rational[-1, 2] Pi, 0}], 
               Inset[
                Style["", Larger], {0, 2}]}], 1}}}], 
         Arrow[{{-0.125, -Log[1000000]}, {-0.125, 
            Rational[1, 2] (-Log[5000] - Log[1000000])}}], 
         Arrowheads[{{0.02, 0, {
             Graphics[
              Circle[{1, 1}, 1, {Pi, Rational[3, 2] Pi}]], -1}}, {0.02, 1, {
             Graphics[
              Circle[{-1, -1}, 1, {0, Rational[1, 2] Pi}]], 1}}}], 
         Arrow[{{-0.125, 
            Rational[1, 2] (-Log[5000] - Log[1000000])}, {-0.125, -
            Log[5000]}}]}}, 
      FrameLabel -> {{Null, "Probability of rescue"}, {
        "Wildtype growth rate", Null}}, 
      Ticks -> {Automatic, {{-13.815510557964274`, 
          Superscript[10, -6]}, {-11.512925464970229`, 
          Superscript[10, -5]}, {-9.210340371976182, 
          Superscript[10, -4]}, {-6.907755278982137, 
         0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 0.1}, {
         0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 0.}, {
           Thickness[0.001]}}}}, GridLines -> {None, None}, 
      FrameTicks -> {{None, {{-13.815510557964274`, 
           Superscript[10, -6]}, {-11.512925464970229`, 
           Superscript[10, -5]}, {-9.210340371976182, 
           Superscript[10, -4]}, {-6.907755278982137, 
          0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 0.1}, {
          0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 0.}, {
            Thickness[0.001]}}}}, {True, False}}, 
      AxesOrigin -> {-0.4, -14.508657738524219`}, 
      PlotRange -> {{-0.4, 0}, {-14.508657738524219`, 0.}}, AspectRatio -> 
      GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0, 0}, 
      CoordinatesToolOptions -> {"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )}, Frame -> {True, False, False, True}, 
      FrameLabel -> {
       "Wildtype growth rate", Null, Null, "Probability of rescue"}, 
      FrameTicks -> {True, False, False, True}, LabelStyle -> 
      Directive[12, FontFamily -> "Helvetica"], Method -> {}, 
      PlotRange -> {{-0.4, 0}, {-14.508657738524219`, 0.}}, PlotRangeClipping -> 
      True, PlotRangePadding -> {{None, None}, {None, None}}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          Thickness[Large], 
          GrayLevel[0.5]], 
         Directive[
          Thickness[Large], 
          GrayLevel[0.5], 
          Dashing[Medium]]}, {
         Style[
         "\!\(\*\nStyleBox[\"n\",\nFontSlant->\"Italic\"]\)=2", 12, 
          FontFamily -> "Helvetica"], 
         Style[
         "\!\(\*\nStyleBox[\"n\",\nFontSlant->\"Italic\"]\)=20", 12, 
          FontFamily -> "Helvetica"]}, LegendLayout -> "Column"]], 
      Scaled[{
        Rational[1, 10], 
        Rational[7, 10]}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{
  3.7802569179095497`*^9, 3.7822465791397343`*^9, {3.7822481793945*^9, 
   3.782248192462708*^9}, 3.78226286107908*^9, 3.782269762695731*^9, 
   3.7849046514962873`*^9}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Rescue genotype growth rate (figure S6B)\
\>", "Subsection",
 CellChangeTimes->{{3.7794704634668283`*^9, 3.779470474057392*^9}, {
  3.7794710306220827`*^9, 3.779471034112606*^9}, {3.779482842010936*^9, 
  3.7794828429873037`*^9}, {3.7800683415343847`*^9, 3.7800683444466963`*^9}, {
  3.780254196766683*^9, 3.780254196925116*^9}, {3.782245728379506*^9, 
  3.782245730680788*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"-", "0.3"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"xmax", "=", "0.25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ymax", "=", "40"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"N0", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "4"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", 
   RowBox[{"-", "0.2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xint", "=", "0.01"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "2"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", "established", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m2", ",", 
       FractionBox[
        RowBox[{
         RowBox[{"fm", "[", 
          RowBox[{"m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}],
           "]"}], 
         RowBox[{"pest", "[", 
          RowBox[{"m2", "-", "mwt"}], "]"}]}], 
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"fm", "[", 
            RowBox[{
            "m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
            "]"}], 
           RowBox[{"pest", "[", 
            RowBox[{"m2", "-", "mwt"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"m2", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"m2", ",", "mwt", ",", "xmax", ",", "xint"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory2", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", "Gray"}], "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", "\"\<established\>\"", "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1.5", "/", "8"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"1", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        RowBox[{"g1m", "/.", 
         RowBox[{"m", "\[Rule]", "m2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "0", ",", "xmax", ",", "xint"}], "}"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"2", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"total", "=", 
      RowBox[{"Re", "[", 
       RowBox[{"g2denominator", "[", "mwt", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"m2", ",", 
         RowBox[{
          FractionBox["1", "total"], 
          RowBox[{"g2numerator", "[", 
           RowBox[{"mwt", ",", "m2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "xmax", ",", "xint"}], "}"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory2", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", "Thick", "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{"\"\<1-step\>\"", ",", "\"\<2-step\>\""}], "}"}]}], "]"}],
          ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1.5", "/", "8"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "20"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", "established", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m2", ",", 
       FractionBox[
        RowBox[{
         RowBox[{"fm", "[", 
          RowBox[{"m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}],
           "]"}], 
         RowBox[{"pest", "[", 
          RowBox[{"m2", "-", "mwt"}], "]"}]}], 
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"fm", "[", 
            RowBox[{
            "m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
            "]"}], 
           RowBox[{"pest", "[", 
            RowBox[{"m2", "-", "mwt"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"m2", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"m2", ",", "mwt", ",", "xmax", ",", "xint"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory4", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", "Gray", ",", 
         RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"1", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        RowBox[{"g1m", "/.", 
         RowBox[{"m", "\[Rule]", "m2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "0", ",", "xmax", ",", "xint"}], "}"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"2", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"total", "=", 
      RowBox[{"Re", "[", 
       RowBox[{"g2denominator", "[", "mwt", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"m2", ",", 
         RowBox[{
          FractionBox["1", "total"], 
          RowBox[{"g2numerator", "[", 
           RowBox[{"mwt", ",", "m2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "xmax", ",", "xint"}], "}"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory4", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", 
         RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Directive", "[", 
              RowBox[{"Thick", ",", "Black"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
              RowBox[{"Thick", ",", "Black", ",", 
               RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{"\"\<\!\(\*
StyleBox[\"n\",
FontSlant->\"Italic\"]\)=2\>\"", ",", "\"\<\!\(\*
StyleBox[\"n\",
FontSlant->\"Italic\"]\)=20\>\""}], "}"}]}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"7", "/", "8"}], ",", 
            RowBox[{"3", "/", "10"}]}], "}"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figS6b", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "oldtheory2", ",", "theory2", ",", "oldtheory4", ",", "theory4"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontColor", "\[Rule]", "White"}], ",", "Automatic", ",", 
        "Automatic", ",", "Automatic"}], "}"}]}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<\!\(\*
StyleBox[SubscriptBox[\"m\", \"0\"],
FontSlant->\"Italic\"]\)=\>\"", "<>", 
             RowBox[{"ToString", "[", "mwt", "]"}]}], ",", "12", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"7", "/", "8"}], ",", 
             RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<B\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}], 
       "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt", ",", 
   "xmin", ",", "xmax", ",", "ymax", ",", "xint"}], "]"}]}], "Input",
 CellChangeTimes->{{3.751575679958344*^9, 3.751575707856783*^9}, {
   3.751575756450697*^9, 3.7515757716167583`*^9}, {3.751575806118587*^9, 
   3.751575998358532*^9}, {3.7515761122033863`*^9, 3.751576131258815*^9}, {
   3.751576172283361*^9, 3.751576174879533*^9}, {3.7515762580970592`*^9, 
   3.751576326479478*^9}, {3.7515763695777597`*^9, 3.751576370332637*^9}, {
   3.7515764174224873`*^9, 3.751576419272636*^9}, {3.751577234452231*^9, 
   3.751577234571393*^9}, {3.751598119440303*^9, 3.7515981249463587`*^9}, 
   3.751650792683756*^9, {3.751650847039688*^9, 3.751650935724555*^9}, {
   3.751651020576578*^9, 3.751651024456732*^9}, {3.7516511744217253`*^9, 
   3.751651271292901*^9}, {3.7516514431359167`*^9, 3.751651596903675*^9}, {
   3.75165167006041*^9, 3.7516517016743317`*^9}, {3.751651837998188*^9, 
   3.751651848660565*^9}, {3.751651901804051*^9, 3.751651938743773*^9}, {
   3.75165209054011*^9, 3.751652092941709*^9}, {3.751654667780588*^9, 
   3.751654726734174*^9}, {3.751654761368635*^9, 3.751654832140562*^9}, {
   3.751654888268785*^9, 3.7516548919393587`*^9}, 3.751656018745837*^9, {
   3.751656381036447*^9, 3.7516563882551813`*^9}, {3.7565000581145897`*^9, 
   3.7565001021945477`*^9}, {3.756500617190415*^9, 3.75650065699045*^9}, 
   3.75650069938904*^9, {3.756500741026494*^9, 3.756500755155011*^9}, {
   3.756501221346011*^9, 3.75650122389799*^9}, 3.756502363067445*^9, 
   3.756502628112669*^9, 3.7565026817972727`*^9, {3.756503286102932*^9, 
   3.756503290049591*^9}, 3.756503323237875*^9, {3.756503496903769*^9, 
   3.75650353646167*^9}, {3.7565038167736483`*^9, 3.756503833330291*^9}, {
   3.7565038702319183`*^9, 3.7565038987244377`*^9}, {3.7565039623685904`*^9, 
   3.7565039995283422`*^9}, 3.756511754548572*^9, 3.756511866105935*^9, {
   3.756511901000861*^9, 3.756511903883478*^9}, {3.7565119526094627`*^9, 
   3.756511957815688*^9}, {3.756512664854374*^9, 3.756512670495578*^9}, {
   3.7565186714828672`*^9, 3.756518674830636*^9}, {3.756518724785604*^9, 
   3.7565187318397303`*^9}, {3.756518775324299*^9, 3.75651877705446*^9}, {
   3.756518831207197*^9, 3.756518836010257*^9}, {3.7565191876130047`*^9, 
   3.7565192273750753`*^9}, 3.756557317943141*^9, 3.756565191609994*^9, {
   3.756565226853438*^9, 3.756565227347921*^9}, {3.756565372407086*^9, 
   3.756565372554656*^9}, {3.7642581275023746`*^9, 3.764258130547591*^9}, {
   3.764258191591094*^9, 3.7642582094474382`*^9}, 3.769438935312201*^9, {
   3.769440382123701*^9, 3.769440472454721*^9}, 3.769440550032837*^9, {
   3.769440597811926*^9, 3.76944060297188*^9}, {3.769440831103504*^9, 
   3.769440912756571*^9}, {3.769440959415164*^9, 3.769440994826437*^9}, {
   3.769441059064315*^9, 3.769441091058297*^9}, {3.769441130350876*^9, 
   3.76944116439666*^9}, {3.7694411991785088`*^9, 3.7694412021516743`*^9}, 
   3.76996874883585*^9, 3.769968810893046*^9, {3.771262388292754*^9, 
   3.771262479562519*^9}, {3.771262525425778*^9, 3.771262540854212*^9}, {
   3.771262571282227*^9, 3.771262676392552*^9}, 3.771262708817911*^9, {
   3.771262787550537*^9, 3.77126278925319*^9}, {3.771262848265294*^9, 
   3.7712628699284153`*^9}, {3.771263092625225*^9, 3.771263094812828*^9}, 
   3.771263271500595*^9, {3.771523030703679*^9, 3.7715230467362022`*^9}, {
   3.771523079011808*^9, 3.771523152186151*^9}, {3.77152320543019*^9, 
   3.771523315803763*^9}, {3.7715233464449253`*^9, 3.771523576781527*^9}, {
   3.771523631873809*^9, 3.7715236430826683`*^9}, {3.7715241526920757`*^9, 
   3.771524155896125*^9}, {3.7715242229465923`*^9, 3.771524257316955*^9}, {
   3.771524320220757*^9, 3.771524423589848*^9}, {3.771524462952353*^9, 
   3.771524468371491*^9}, 3.771524519796175*^9, {3.771524560722151*^9, 
   3.77152458745588*^9}, {3.7715456914503183`*^9, 3.771545693694459*^9}, 
   3.7715458002283154`*^9, {3.771545911589119*^9, 3.771545926111433*^9}, {
   3.77160975420442*^9, 3.7716097651557693`*^9}, {3.7716099182331963`*^9, 
   3.77160992062647*^9}, {3.771609967213895*^9, 3.771610003678589*^9}, {
   3.771610042996176*^9, 3.771610061906077*^9}, {3.771610106603993*^9, 
   3.771610114408716*^9}, {3.771610201107335*^9, 3.771610202727501*^9}, 
   3.771610248378283*^9, {3.7794686898536158`*^9, 3.7794688301324673`*^9}, {
   3.77946886396563*^9, 3.77946888729186*^9}, {3.779468925902836*^9, 
   3.7794689413547277`*^9}, {3.779469011076345*^9, 3.779469071332287*^9}, {
   3.779469527005124*^9, 3.779469555307827*^9}, {3.779469593442951*^9, 
   3.77946961429259*^9}, {3.779469796805294*^9, 3.779469866620295*^9}, {
   3.779469901788733*^9, 3.779470016571252*^9}, {3.779470051010948*^9, 
   3.779470158052433*^9}, {3.779470201565462*^9, 3.779470241549526*^9}, 
   3.780062293224526*^9, {3.780062341271126*^9, 3.7800623697424707`*^9}, {
   3.780062860795129*^9, 3.780062861799574*^9}, {3.7800666511707067`*^9, 
   3.7800666553558607`*^9}, {3.780066708471122*^9, 3.780066726219557*^9}, 
   3.780067723259276*^9, {3.7802542082187147`*^9, 3.780254230507213*^9}, {
   3.780256302536779*^9, 3.7802564037550087`*^9}, {3.780256434238928*^9, 
   3.780256437769991*^9}, {3.7802564759340487`*^9, 3.780256509276353*^9}, {
   3.780256558450182*^9, 3.7802565601620092`*^9}, {3.7802566206630383`*^9, 
   3.780256652521289*^9}, {3.780256688622583*^9, 3.7802566887965918`*^9}, {
   3.780256734472596*^9, 3.7802567644064074`*^9}, {3.780256799980043*^9, 
   3.780256866597209*^9}, {3.780256941027989*^9, 3.7802569671663017`*^9}, {
   3.780257186954887*^9, 3.7802571871000643`*^9}, {3.7802573149393377`*^9, 
   3.780257317817444*^9}, {3.78490466588303*^9, 3.784904672634948*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "izero"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Integral and error estimates are 0 on all integration \
subregions. Try increasing the value of the MinRecursion option. If value of \
integral may be 0, specify a finite value for the AccuracyGoal option. \\!\\(\
\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/NIntegrate\\\", ButtonNote -> \
\\\"NIntegrate::izero\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.779470161635611*^9, 3.779470252570225*^9, 3.780062310685498*^9, 
   3.780062391464891*^9, 3.7800628772268257`*^9, 3.7800667394757233`*^9, 
   3.780067840159727*^9, 3.780254249728323*^9, 3.780256522604405*^9, 
   3.78025658103601*^9, 3.7802566633868837`*^9, 3.780256780949135*^9, {
   3.78025681293653*^9, 3.780256838349967*^9}, 3.7802568812371387`*^9, 
   3.780257197395924*^9, 3.780257336556822*^9, 3.782262905032645*^9, 
   3.782269703256633*^9, 3.7849046854666843`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "izero"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Integral and error estimates are 0 on all integration \
subregions. Try increasing the value of the MinRecursion option. If value of \
integral may be 0, specify a finite value for the AccuracyGoal option. \\!\\(\
\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/NIntegrate\\\", ButtonNote -> \
\\\"NIntegrate::izero\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.779470161635611*^9, 3.779470252570225*^9, 3.780062310685498*^9, 
   3.780062391464891*^9, 3.7800628772268257`*^9, 3.7800667394757233`*^9, 
   3.780067840159727*^9, 3.780254249728323*^9, 3.780256522604405*^9, 
   3.78025658103601*^9, 3.7802566633868837`*^9, 3.780256780949135*^9, {
   3.78025681293653*^9, 3.780256838349967*^9}, 3.7802568812371387`*^9, 
   3.780257197395924*^9, 3.780257336556822*^9, 3.782262905032645*^9, 
   3.782269703256633*^9, 3.78490470854249*^9}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {{}, {}, 
       {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8HntjftuX14plHftlzX19c
YMt1fD9D16yWU2xcDoe/asT0Hzq6f+uvBm3lzUIO1SLr3B9WHdl/1CfmyPw2
cQcTYxA4vH9lzfd+viBphzeBIAMP7ufqZTpS90vWYQnQtOuLD+zv45CUdi6X
d9gJsm7Hvv0HzGMm7rgo76AFNP2rxp79b5dpb6lWlneAuG/n/nN3H1/1mizr
AHHP9v0TJ03U/Bkg7VADtn/Lft0EJ5F3EySg9m3cX3RF6uLGdlEHsHd2rNs/
7/v+bX9ShRzmgM1bub98v1Oz+2o+qP4l+32EnGQN33NA1c/b78c3l1XsGLND
A1h+yn7JEz/Twqf9s4fwW/av3f+MkUvwuz0s3EJPlqjXfvlgXwCRt58TZ3v2
g8cL+wqIfnujPT+79r1/YA813z77/6rrH/9eg8ovsTeblnThT/Q5+xkQ99kH
8Ml8qqw+DFW/zv77xPPcep477KH+s7/4WytWJnGtPdT/9qe1GN+8slpozwEJ
H/vDJ2d/mT55MtS8nfYLYhU/3G9ttdeAhK994ILGaYb3y6Dm77Nfnc8w+21Z
uj00fuynfn/Btc80HGrfQXul6q+Kh6Xc7KHxaz+t3qtS2dbEvgoS//Z6C9Lz
PE4q2h+CpA97x9nKsWZfeO25IOnH/u3C4m4v+R920PRlv2ajx8vYrkd20PRn
/2tHxz8vldN2j8AGnrJ/2yV64MT9TXYQ956xz96alDTn/gw7sPMKztorfPmo
/u9HnR3E/efs17BekPqomWQHiY0L9keZPxvM/e9sBwB2hmek
         
         "]]}}, {}}, {{}, {{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsf8d8qO61kPbAcKfYv87XMqtS83I
YYdc6+vAHfPsNz4KajBeZQiVX2J/20ai6cEJXYdZM0Fgpf1XTdnDp16rQdWv
s1e6HP5esVLB4U0gSGSjvY9dc/78eDGo/i32QcxKs84+43Hgur64wJZru/3D
lOiLjZcYoebttF/zeHWSCsdXe82Y/kNfNfbY/ylgDtl47Lk9xPx99nouF/zv
HbppvwSo+/riA/axx00K7Q6csofYd9D+XVbsuu1zdtkbg8Fh+/szfbayRqy0
h9h/xP5ce2KMmOh0+8NfNYA2HLWvs3x4uEakxR7inuP2py9kW/CuLLAPAlt4
wt7W9eSTFUFR9hD3nbQ35ajjennI2f5hFcjAU/Yy2+dP3aukA3XvGftJmWuf
9nwSsi8EOa/grL3MjgTHOcI/7CDuP2ffqLfyaPjxO3aQWLhg3/x92gdNhQN2
AGklv0Y=
         "]]}, 
       {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsWfLV1kiv17QAcKfYm8QvFbFMEfG
YYdc6+vAHfPsV2nU3a6OU4TKL7HX/byhcsddJYdZM0FgpX3/N3vn13LKUPXr
7D3Y7/++V6nk8CYQJLLRfk/0oyfK5jD9W+wzP1xac0hZ3oHr+uICW67t9lWv
wpa7FElDzdtp/2wH53P9ReIOmjH9h75q7LF/IpZx4O4LYaj5++zXZbEIZWcL
OCwB6r6++IC9Vku8q1gzF9S+g/Zv90/jbfzA4mAMBoftDbKDnu/SYIDaf8Q+
vNJr48mgH/aHv2oAbThq/81z28+M8x/tIe45bt9YH3rllc9L+yCwhSfsC4xe
s6+Jf2gPcd9Jeyv7BeG7/lyzf1gFMvCU/SSL1R1LjM7aQ9x7xt5tfU0Lw76D
9oUg5xWctWf5u2F95MQt9hD3n7NvP3Hwmei6ZfaQWLhgLzT9+FWBXdPtARUx
vrc=
         "]]}}, {}}, {{}, {{}, {}, 
       {GrayLevel[0.5], Thickness[Large], Dashing[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8Hnth/aLN8Ro8fuwP39cUF
tlzH92eeya+aZSTqcPirRkz/oaP7hS5UqzOUyzhUi6xzf1h1ZP+Ta7ZhMtsV
HEyMQeDw/qfmnT/4pZQc3gSCDDy4P+RPxrXVDUoOS4CmXV98YP+VFlO2v4JK
DjtB1u3Yt/9C59wtc34rOGgBTf+qsWe/CN+uX/dvyTlA3LdzP4/2Dbl+bWmo
e7bv33N+h2m+jbhDDdj+Lfulll3XPxAkDLVv434Th7cmz9z4HcDe2bFuf6XP
nx9JSzkc5oDNW7mft/6PLPMrJqj+JfsDz0x+GeD2xx6ift7+w1UV679M+WLf
AJafsl93FjP/Y523UH7L/gcTLkdtVnhiDws3RaaLZXmst+0LIPL2UzT5gyct
vmhfAdFv729W6P4t8RjMfHuJnomLMqfthsovsZcPvjijuWGD/QyI++wTVjSy
LVVdDFW/zv4HL4+XcftUe6j/7CvW8glJ5rfbQ/1vv0hxntLe1RX2HJDwsV9Z
lPj1kHgm1Lyd9p/VmH2vLYiw14CEr72yuGz3C293qPn77HlipZ+sMDW1h8aP
vUXcinOn+pSg9h20z5wk8i5ek98eGr/2R5Zp1n7k/2lXBYl/+xX/J50Udnts
dwiSPuyz7d9EmnmdseOCpB/7Ha3n3mQc3WwHTV/2+QdM51Y4zrKDpj/7uY5h
NfNaG+wegQ08Ze/mY9PPuTzZDuLeM/b2aQvEZdjd7MDOKzgLDOdtAdsM1O0g
7j9nv9N9SVrGTTY7SGxcsOdYkV988s8TWwDc2Fen
         "]]}}, {}}, {{}, {{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], Dashing[
        Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsU/S2i+1YImhA4Q/xb41qe+aWrSp
ww651teBO+bZ+7X8j3lzzwgqv8S+ntOA/cVlHYdZM0FgpX2O1CJFNz4VqPp1
9lZBwa9LGaQc3gSCRDbaF379x/zkGD9U/xZ76+jI3q/ZTA5c1xcX2HJtt/+a
VHB+TdgXe4h5O+2Dzx3caZj71F4zpv/QV4099gd2qxxf33/VHmL+PvsJIZNi
HXYfsV8C1H198QH7wGNb6xi4N9tD7Dto3891WCl68wJ7YzA4bH8/3XU998du
e4j9R+wjHsd+fO1SZn/4qwbQhqP26/sE3qY+SrCHuOe4fcT/hz2zAjzsg8AW
nrCX5TDt451hAHXfSfvfPfevFGaL2j+sAhl4yt5C4VuWmugvO4h7z9ir/JM7
9PjBXbtCkPMKztpH5jwy2cFzwA7i/nP2/WdLHebKLrCDxMIFe4d9gi7WSnV2
AASCvUE=
         "]]}, 
       {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], Dashing[
        Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsc9+K3RL7JW0A4Q/xV7eksVE4byK
ww651teBO+bZq3T9ujCzWx0qv8TeiTV238wl6g6zZoLASntbeffk6fJqUPXr
7Ne7BGQ82qrs8CYQJLLRntNx1ZbyFwpQ/VvsfyqdKAqVlnHgur64wJZru31e
77vI6dvFoObttK9kOlRX8VjQQTOm/9BXjT3272qaTzmVc0PN32e/R+751NM9
LA5LgLqvLz5gH+HnVrvy/V97iH0H7fu5DXq1DL7aG4PBYfvmibcbA4Tf2kPs
P2LvYbTTU8nzsf3hrxpAG47aM9xobni24oY9xD3H7ZV1g4U++JyzDwJbeMLe
rXHOfaVrB+0h7jtpn7JWZz6vwBb7h1UgA0/ZZ/u2XAhqWGoPce8Z+xwu3TC1
p1PtC0HOKzhrb6k18U6nQqs9xP3n7CfeWmkm4VxsD4mFC/Z/uyb6uXQn2AMA
YBu32g==
         "]]}}, {}}}, {InsetBox[
      TagBox[GridBox[{
         {
          
          TemplateBox[{
           StyleBox[
            "\"1-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
             FontSize -> 12],StyleBox[
            "\"2-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
             FontSize -> 12]},
           "LineLegend",
           DisplayFunction->(StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
             False]& ),
           Editable->True,
           InterpretationFunction:>(RowBox[{"LineLegend", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
                  "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{#, ",", #2}], "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]},
         {
          
          TemplateBox[{
           StyleBox[
            "\"established\"", StripOnInput -> False, FontFamily -> 
             "Helvetica", FontSize -> 12]},
           "LineLegend",
           DisplayFunction->(StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
             False]& ),
           Editable->True,
           InterpretationFunction:>(RowBox[{"LineLegend", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}]}], "]"}], "}"}], 
                ",", 
                RowBox[{"{", #, "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{0}}}],
       "Grid"], NCache[
      Scaled[{0.1875, Rational[1, 2]}], Scaled[{0.1875, 0.5}]], ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TemplateBox[{
       StyleBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\"]\\)=2\"\
", StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 12],StyleBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\"]\\)=20\
\"", StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}],
             ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )], 
      NCache[Scaled[{Rational[7, 8], Rational[3, 10]}], Scaled[{0.875, 0.3}]],
       ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesLabel->{None, None},
   AxesOrigin->{0., 0.},
   Epilog->{
     InsetBox[
      FormBox[
       StyleBox[
       "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=-0.2\"", 12, FontFamily -> 
        "Helvetica", StripOnInput -> False], TraditionalForm], 
      NCache[
       Scaled[{
         Rational[7, 8], 
         Rational[3, 4]}], 
       Scaled[{0.875, 0.75}]]], 
     InsetBox[
      FormBox[
       StyleBox[
       "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
       TraditionalForm], 
      Scaled[{0.05, 0.95}]]},
   Frame->{True, False, False, False},
   FrameTicksStyle->{
    FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.3, 0.25}, {0, 40}},
   PlotRangeClipping->True,
   PlotRangePadding->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           GrayLevel[0.5]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8HntjftuX14plHftlzX19c
YMt1fD9D16yWU2xcDoe/asT0Hzq6f+uvBm3lzUIO1SLr3B9WHdl/1CfmyPw2
cQcTYxA4vH9lzfd+viBphzeBIAMP7ufqZTpS90vWYQnQtOuLD+zv45CUdi6X
d9gJsm7Hvv0HzGMm7rgo76AFNP2rxp79b5dpb6lWlneAuG/n/nN3H1/1mizr
AHHP9v0TJ03U/Bkg7VADtn/Lft0EJ5F3EySg9m3cX3RF6uLGdlEHsHd2rNs/
7/v+bX9ShRzmgM1bub98v1Oz+2o+qP4l+32EnGQN33NA1c/b78c3l1XsGLND
A1h+yn7JEz/Twqf9s4fwW/av3f+MkUvwuz0s3EJPlqjXfvlgXwCRt58TZ3v2
g8cL+wqIfnujPT+79r1/YA813z77/6rrH/9eg8ovsTeblnThT/Q5+xkQ99kH
8Ml8qqw+DFW/zv77xPPcep477KH+s7/4WytWJnGtPdT/9qe1GN+8slpozwEJ
H/vDJ2d/mT55MtS8nfYLYhU/3G9ttdeAhK994ILGaYb3y6Dm77Nfnc8w+21Z
uj00fuynfn/Btc80HGrfQXul6q+Kh6Xc7KHxaz+t3qtS2dbEvgoS//Z6C9Lz
PE4q2h+CpA97x9nKsWZfeO25IOnH/u3C4m4v+R920PRlv2ajx8vYrkd20PRn
/2tHxz8vldN2j8AGnrJ/2yV64MT9TXYQ956xz96alDTn/gw7sPMKztorfPmo
/u9HnR3E/efs17BekPqomWQHiY0L9keZPxvM/e9sBwB2hmek
           
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           Thickness[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsf8d8qO61kPbAcKfYv87XMqtS83I
YYdc6+vAHfPsNz4KajBeZQiVX2J/20ai6cEJXYdZM0Fgpf1XTdnDp16rQdWv
s1e6HP5esVLB4U0gSGSjvY9dc/78eDGo/i32QcxKs84+43Hgur64wJZru/3D
lOiLjZcYoebttF/zeHWSCsdXe82Y/kNfNfbY/ylgDtl47Lk9xPx99nouF/zv
HbppvwSo+/riA/axx00K7Q6csofYd9D+XVbsuu1zdtkbg8Fh+/szfbayRqy0
h9h/xP5ce2KMmOh0+8NfNYA2HLWvs3x4uEakxR7inuP2py9kW/CuLLAPAlt4
wt7W9eSTFUFR9hD3nbQ35ajjennI2f5hFcjAU/Yy2+dP3aukA3XvGftJmWuf
9nwSsi8EOa/grL3MjgTHOcI/7CDuP2ffqLfyaPjxO3aQWLhg3/x92gdNhQN2
AGklv0Y=
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Directive[
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           Thickness[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsWfLV1kiv17QAcKfYm8QvFbFMEfG
YYdc6+vAHfPsV2nU3a6OU4TKL7HX/byhcsddJYdZM0FgpX3/N3vn13LKUPXr
7D3Y7/++V6nk8CYQJLLRfk/0oyfK5jD9W+wzP1xac0hZ3oHr+uICW67t9lWv
wpa7FElDzdtp/2wH53P9ReIOmjH9h75q7LF/IpZx4O4LYaj5++zXZbEIZWcL
OCwB6r6++IC9Vku8q1gzF9S+g/Zv90/jbfzA4mAMBoftDbKDnu/SYIDaf8Q+
vNJr48mgH/aHv2oAbThq/81z28+M8x/tIe45bt9YH3rllc9L+yCwhSfsC4xe
s6+Jf2gPcd9Jeyv7BeG7/lyzf1gFMvCU/SSL1R1LjM7aQ9x7xt5tfU0Lw76D
9oUg5xWctWf5u2F95MQt9hD3n7NvP3Hwmei6ZfaQWLhgLzT9+FWBXdPtARUx
vrc=
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           GrayLevel[0.5], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8Hnth/aLN8Ro8fuwP39cUF
tlzH92eeya+aZSTqcPirRkz/oaP7hS5UqzOUyzhUi6xzf1h1ZP+Ta7ZhMtsV
HEyMQeDw/qfmnT/4pZQc3gSCDDy4P+RPxrXVDUoOS4CmXV98YP+VFlO2v4JK
DjtB1u3Yt/9C59wtc34rOGgBTf+qsWe/CN+uX/dvyTlA3LdzP4/2Dbl+bWmo
e7bv33N+h2m+jbhDDdj+Lfulll3XPxAkDLVv434Th7cmz9z4HcDe2bFuf6XP
nx9JSzkc5oDNW7mft/6PLPMrJqj+JfsDz0x+GeD2xx6ift7+w1UV679M+WLf
AJafsl93FjP/Y523UH7L/gcTLkdtVnhiDws3RaaLZXmst+0LIPL2UzT5gyct
vmhfAdFv729W6P4t8RjMfHuJnomLMqfthsovsZcPvjijuWGD/QyI++wTVjSy
LVVdDFW/zv4HL4+XcftUe6j/7CvW8glJ5rfbQ/1vv0hxntLe1RX2HJDwsV9Z
lPj1kHgm1Lyd9p/VmH2vLYiw14CEr72yuGz3C293qPn77HlipZ+sMDW1h8aP
vUXcinOn+pSg9h20z5wk8i5ek98eGr/2R5Zp1n7k/2lXBYl/+xX/J50Udnts
dwiSPuyz7d9EmnmdseOCpB/7Ha3n3mQc3WwHTV/2+QdM51Y4zrKDpj/7uY5h
NfNaG+wegQ08Ze/mY9PPuTzZDuLeM/b2aQvEZdjd7MDOKzgLDOdtAdsM1O0g
7j9nv9N9SVrGTTY7SGxcsOdYkV988s8TWwDc2Fen
           
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsU/S2i+1YImhA4Q/xb41qe+aWrSp
ww651teBO+bZ+7X8j3lzzwgqv8S+ntOA/cVlHYdZM0FgpX2O1CJFNz4VqPp1
9lZBwa9LGaQc3gSCRDbaF379x/zkGD9U/xZ76+jI3q/ZTA5c1xcX2HJtt/+a
VHB+TdgXe4h5O+2Dzx3caZj71F4zpv/QV4099gd2qxxf33/VHmL+PvsJIZNi
HXYfsV8C1H198QH7wGNb6xi4N9tD7Dto3891WCl68wJ7YzA4bH8/3XU998du
e4j9R+wjHsd+fO1SZn/4qwbQhqP26/sE3qY+SrCHuOe4fcT/hz2zAjzsg8AW
nrCX5TDt451hAHXfSfvfPfevFGaL2j+sAhl4yt5C4VuWmugvO4h7z9ir/JM7
9PjBXbtCkPMKztpH5jwy2cFzwA7i/nP2/WdLHebKLrCDxMIFe4d9gi7WSnV2
AASCvUE=
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Directive[
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsc9+K3RL7JW0A4Q/xV7eksVE4byK
ww651teBO+bZq3T9ujCzWx0qv8TeiTV238wl6g6zZoLASntbeffk6fJqUPXr
7Ne7BGQ82qrs8CYQJLLRntNx1ZbyFwpQ/VvsfyqdKAqVlnHgur64wJZru31e
77vI6dvFoObttK9kOlRX8VjQQTOm/9BXjT3272qaTzmVc0PN32e/R+751NM9
LA5LgLqvLz5gH+HnVrvy/V97iH0H7fu5DXq1DL7aG4PBYfvmibcbA4Tf2kPs
P2LvYbTTU8nzsf3hrxpAG47aM9xobni24oY9xD3H7ZV1g4U++JyzDwJbeMLe
rXHOfaVrB+0h7jtpn7JWZz6vwBb7h1UgA0/ZZ/u2XAhqWGoPce8Z+xwu3TC1
p1PtC0HOKzhrb6k18U6nQqs9xP3n7CfeWmkm4VxsD4mFC/Z/uyb6uXQn2AMA
YBu32g==
           "]]}}}, {}}}, {
     PlotRange -> {{-0.3, 0.25}, {0, 40}}, 
      Frame -> {True, False, False, False}, LabelStyle -> 
      Directive[12, FontFamily -> "Helvetica"], 
      FrameTicksStyle -> {
       FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, Epilog -> {
        Text[
         Style[
         "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=-0.2", 12, FontFamily -> "Helvetica"], 
         Scaled[{
           Rational[7, 8], 
           Rational[3, 4]}]], 
        Text[
         Style["B", 14, Bold, FontFamily -> "Helvetica"], 
         Scaled[{0.05, 0.95}]]}, AxesLabel -> {None, None}, AspectRatio -> 
      GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0., 0.}, Method -> {}, 
      PlotRange -> {All, All}, PlotRangeClipping -> True, 
      PlotRangePadding -> {Automatic, Automatic}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          Thickness[Large], 
          GrayLevel[0]], 
         Directive[
          Thickness[Large], 
          GrayLevel[0], 
          Dashing[Medium]]}, {
         Style[
         "\!\(\*\nStyleBox[\"n\",\nFontSlant->\"Italic\"]\)=2", 12, 
          FontFamily -> "Helvetica"], 
         Style[
         "\!\(\*\nStyleBox[\"n\",\nFontSlant->\"Italic\"]\)=20", 12, 
          FontFamily -> "Helvetica"]}, LegendLayout -> "Column", 
        LegendMarkers -> False]], 
      Scaled[{
        Rational[7, 8], 
        Rational[3, 10]}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{{3.779468795408979*^9, 3.779468830949634*^9}, 
   3.779468917873926*^9, {3.779469011820323*^9, 3.779469047660637*^9}, {
   3.779469821103179*^9, 3.779469830115543*^9}, {3.779470013240581*^9, 
   3.77947001697924*^9}, {3.779470060618907*^9, 3.779470094444737*^9}, 
   3.779470124926302*^9, 3.7794701689603777`*^9, 3.7794702603696213`*^9, 
   3.78006231915749*^9, 3.780062399351725*^9, 3.780062885347563*^9, 
   3.780066748143722*^9, 3.780067848691842*^9, 3.780254256385449*^9, 
   3.78025654685863*^9, 3.7802566056431427`*^9, 3.7802566879888897`*^9, 
   3.780256788170679*^9, {3.7802568199542313`*^9, 3.780256845738853*^9}, 
   3.7802569054429827`*^9, 3.780257228032707*^9, 3.780257366897098*^9, 
   3.7822629395186167`*^9, 3.782269738649062*^9, 3.784904716574737*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
2-step intermediate growth rate (figure S6C)\
\>", "Subsection",
 CellChangeTimes->{{3.779477356570382*^9, 3.779477361850051*^9}, {
   3.779482848762312*^9, 3.779482851539497*^9}, {3.780068347007688*^9, 
   3.780068352358201*^9}, 3.780254198935792*^9, {3.782245728961809*^9, 
   3.782245732783947*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"-", "0.3"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmax", "=", "0.25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ymax", "=", "30"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"N0", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"U", "=", 
   RowBox[{"2", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "4"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "2"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"exact2", "=", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
    RowBox[{"prescuem", "[", 
     RowBox[{"m1", ",", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"allexact2", "=", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{"exact2", ",", 
     RowBox[{"{", 
      RowBox[{"m1", ",", "mwt", ",", "0.1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory2", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fm", "[", 
        RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
        "]"}], 
       RowBox[{"pest", "[", 
        RowBox[{"m1", "-", "mwt"}], "]"}], 
       RowBox[{"HeavisideTheta", "[", 
        RowBox[{"m1", "-", "mwt"}], "]"}]}], ")"}], "/", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fm", "[", 
         RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"pest", "[", 
         RowBox[{"m1", "-", "mwt"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "20"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"exact4", "=", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
    RowBox[{"prescuem", "[", 
     RowBox[{"m1", ",", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"allexact4", "=", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{"exact4", ",", 
     RowBox[{"{", 
      RowBox[{"m1", ",", "mwt", ",", "0.1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory4", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"fm", "[", 
        RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
        "]"}], 
       RowBox[{"pest", "[", 
        RowBox[{"m1", "-", "mwt"}], "]"}], 
       RowBox[{"HeavisideTheta", "[", 
        RowBox[{"m1", "-", "mwt"}], "]"}]}], ")"}], "/", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fm", "[", 
         RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"pest", "[", 
         RowBox[{"m1", "-", "mwt"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figS6c", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Plot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"oldtheory2", ",", "oldtheory4"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Directive", "[", 
           RowBox[{"Gray", ",", "Thick"}], "]"}], ",", 
          RowBox[{"Directive", "[", 
           RowBox[{"Gray", ",", "Thick", ",", 
            RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"LineLegend", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", "\"\<established\>\"", "}"}]}], "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"1", "/", "8"}], ",", 
             RowBox[{"1.25", "/", "2"}]}], "}"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"exact2", "/", "allexact2"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", "Thick", "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"LineLegend", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", "\"\<first-step\>\"", "}"}]}], "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"1", "/", "8"}], ",", 
             RowBox[{"1.25", "/", "2"}]}], "}"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"exact4", "/", "allexact4"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", 
          RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotLegends", "\[Rule]", 
        RowBox[{"Placed", "[", 
         RowBox[{
          RowBox[{"LineLegend", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Directive", "[", 
               RowBox[{"Thick", ",", "Black"}], "]"}], ",", 
              RowBox[{"Directive", "[", 
               RowBox[{"Thick", ",", "Black", ",", 
                RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}], 
            ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"#", ",", "12", ",", 
                RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
               "]"}], "&"}], "/@", 
             RowBox[{"{", 
              RowBox[{"\"\<\!\(\*
StyleBox[\"n\",
FontSlant->\"Italic\"]\)=2\>\"", ",", "\"\<\!\(\*
StyleBox[\"n\",
FontSlant->\"Italic\"]\)=20\>\""}], "}"}]}]}], "]"}], ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"7", "/", "8"}], ",", 
             RowBox[{"3", "/", "10"}]}], "}"}]}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "Automatic", ",", "Automatic", ",", "Automatic", ",", "Automatic"}], 
       "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", "\"\<Growth rate\>\"", "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Epilog", "\[Rule]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"\"\<\!\(\*
StyleBox[SubscriptBox[\"m\", \"0\"],
FontSlant->\"Italic\"]\)=\>\"", "<>", 
             RowBox[{"ToString", "[", "mwt", "]"}]}], ",", "12", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"7", "/", "8"}], ",", 
             RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<C\>\"", ",", "14", ",", "Bold", ",", 
            RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
          ",", 
          RowBox[{"Scaled", "@", 
           RowBox[{"{", 
            RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}], 
       "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt", ",", 
   "xmin", ",", "xmax", ",", "ymax", ",", "N0"}], "]"}]}], "Input",
 CellChangeTimes->{{3.771259863315041*^9, 3.771259875817935*^9}, {
   3.77125993618959*^9, 3.7712599967791033`*^9}, {3.7712600806108303`*^9, 
   3.771260101998229*^9}, {3.7712601420091887`*^9, 3.771260164023238*^9}, {
   3.7712604866075153`*^9, 3.7712604916540623`*^9}, {3.771260596998*^9, 
   3.7712606779327497`*^9}, {3.771260742113587*^9, 3.77126078863237*^9}, {
   3.7712608356681213`*^9, 3.771260853796445*^9}, 3.77126088730492*^9, {
   3.771260950376927*^9, 3.771260951994858*^9}, {3.771260988204628*^9, 
   3.771261046264202*^9}, {3.771261095976034*^9, 3.771261100349186*^9}, {
   3.771261221602476*^9, 3.771261223165237*^9}, {3.7712612596219587`*^9, 
   3.771261376814014*^9}, {3.7712614254017878`*^9, 3.771261458422593*^9}, {
   3.771261523796259*^9, 3.771261558803645*^9}, {3.771525291980131*^9, 
   3.771525296404852*^9}, {3.771525340514213*^9, 3.771525362538801*^9}, {
   3.771525476715866*^9, 3.771525481529388*^9}, {3.771525527353706*^9, 
   3.771525572057776*^9}, {3.771525611182823*^9, 3.77152571017303*^9}, {
   3.771525850691698*^9, 3.771525923002439*^9}, {3.771525956576083*^9, 
   3.771525983790447*^9}, {3.771526019222022*^9, 3.7715260269883137`*^9}, {
   3.771526062519966*^9, 3.77152607841735*^9}, {3.771526152732314*^9, 
   3.771526160701219*^9}, {3.771526280292366*^9, 3.771526400673423*^9}, 
   3.771526440426137*^9, {3.7794773959510937`*^9, 3.7794774153789377`*^9}, 
   3.779479818451282*^9, {3.779482804081335*^9, 3.779482804522912*^9}, {
   3.780063051430872*^9, 3.78006305162116*^9}, {3.780063286850298*^9, 
   3.780063305483961*^9}, {3.780067547237227*^9, 3.780067619007799*^9}, {
   3.780254430235753*^9, 3.780254449602309*^9}, {3.7802547336341*^9, 
   3.780254734411544*^9}, {3.780257012559074*^9, 3.7802570858592567`*^9}, {
   3.780257124286892*^9, 3.7802572680528307`*^9}, {3.78025742903951*^9, 
   3.7802576687584457`*^9}, {3.780257712102442*^9, 3.780257724677702*^9}, {
   3.780257755591942*^9, 3.7802577557274637`*^9}, {3.78025778871243*^9, 
   3.7802579013536158`*^9}, 3.782262918417039*^9, {3.78490468210609*^9, 
   3.784904689488925*^9}}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxFxwk01Hsfx3Ej1xJSRJZQIxpky1W66f/9J0TiEqFU5MoIoaxlhKLS4JKS
DEWWwS3GPrb5WYaxL7mydJEihShbyo3nec55Dp9z3udzXrudvE5d4ubi4kr6
b/97xcnH0traPYjr/5s5mSElwrthZj5Dcqr/1bpP+DVLpN/csDfXiqhYS/e6
/Z7OdT3Q71r3UANfKH9u+7qLXTnNXhYbvi94V6xvqW3dupa89MxjG96y0PBF
aLJ13eMJEb/5xm74wT88HfpDLeu2S1MWEKVsWNbF3GBUesPvVHxCGOXN686e
fVwRYteMPjPHaqPu9oJncdWi+bcmNMiLSzWzJkH7+qimXEITSj23f0HXeBFY
3Kr0qh4O4pacvdZ2gRvfpZVgzn+dg1qMbn71HP4Fv+1AWLKS46BItT/SvYwF
cOOqPoMp10Yk1RfRdrtLBM+d1J8+sKURXfGrX8z33YYLSeXF3ypqQLeyNSlS
X0Xxbr/wd1KrbBQIrX/7l4jjxEbroHYaG1kztk+8Et+B+0oobg87xEaT1B2K
6Rck8QaXxRe/9tUjF8lTZxdjpHCJsgbDj771KOASk7aSKY2T+RKGaaL1iBRi
fUo4XQZn2roE/M6oQ0FJ3Mv0iJ345uwDWzeZ16GZxIZwLzNZ3H6ZN6d0qhbZ
OwpEqf+QxZ2TXmnoUGvROE2RzyNSDvfUe1papFKLrtqeGUpblcMDhy8f2d9S
gwRust/ynZXHw0J12IzLNShRrM3xG00ev08kmGoI1CCZu5TpT2x5nBT5JN3e
EqHjxL0DAb3y+G/tmgV2sSwkGBweZ9Mhj5tta2Kd7qxGeuYahTYMeTyJNJ1h
KlONjCKEfqGGyuMfYCv1KLkKHf+po+KLyePatr9ePVhUierGgmK+TsrhoZ52
tmprFYg/6Wn8lztyeHsE5YiCaQVqzSFx3MTkcOmUVAWpx+Wo6t1mEec4Wdyl
mC0g8p6JHMo3d30kyOJFrR9neTSYqFlOWFTIZSc+rNTHbHEvQ4ZzJYUWDBmc
/1ZDWGx2KTqUJ7yfOSONn9d9LraTWIIkVNyyEsykcL5M+4Pa4oVoi9HBNpsK
cdxK0+2ORWM2Kja8mOFQKoz/22MW9t2Rjtwn0jUH5YTwrAAtyvOVTPTUv0z4
Sexm/Dtr+eqCZjram2W01yOeD3/u9I9HSmsa8mD9obWmyIuf5K0hG7mkoqEn
/sq9bB4caFsqNQ/SUEgsbZSozI0LzK0ertNIRH2OivGHe7nwHuPZKivSI+S0
eLenibgGHdPPgj/vj0HV5R4W+b4/wCkpNGTrnnvINmAqQs18GZaOXwzTFr+F
rtc5htCPL4Fv1P3tH4bIaKw9QNc9cQ6+PLsx+EpyD9o38GzHW4Gv4K97uLz1
7CU4Q6BfiVWeBX9hEYsHK35gN6hTnuc9DXZQc3EkIxRcZyetnCY+wdK3QNqi
6R0IwtsW+qgTEM/Q6hWcp8LxjjyDvefGYSLWck9yajwY9+kpkQNHgTXEUzrB
SICqt+5jPw+NQIIK87h27ROoZqQmD71+A54B7gM3u5OhqNEP9Or6wYgt594y
+gxMz7A/fVvqhT/5L69uvp4GMU02InzePbCSp8/RJKSDY46MVSipG8ind8ba
RGZAGgHz0z/YAT0ri3aUbVkgrVkZQ49sgQv27y77P6BDQ7+G06IZByYrOm54
i+VAtL/ete1ubPCTrqS6PcwFY0KwePDrWuC6QU92Fn8BW4UW3hMlEVAH4l9e
SHgJpB+Eeoy/EiQOhbLsduRD9v0MpTrvMrA4WUpWPsmAateAnd8Ni0GCss87
S6gALvEQPHiCC+B5v3iqSk0BaCetRbS65IGazlpnnk8hdLE1QOF8LjDjPq7t
31sEV0knUoidWWAw061RNlgEza/ezH/LT4euE5UOh2OKodZOqeztfCqco2f8
iY6WgPGo1iHdXSnwcVMMOrZYAsxoS4eKxUTwcQyY5WSXgoj9yK7rNo9g9/UE
PYp7GTA/N2YFzMdBZ1xJpKY6E0KnLtDSZGMgOPfv12NfmICo0k7CmpGgWj+v
8KSoHPKZvY/GuSJg4I3oVTP/ClBU9VQ57B8Gdxe0WIRDlbAqxqfqMEcBHWFL
wdKVSkiLGhK0mQqA94redm6sKgjv5bdUK/YBG3fudkXfaqD3peaeueQNLYyH
R0eVWSAcVOxAOuAO2JJSafIIC4Q8Rqczwl2g8HC5it0jBL+QM6OWHzpBfE1m
Z6RiDXzQS9mX/PACmL2fiSSH1oCD8lS3/Y4zwMera2D4pgYOSkqYSNy1hlpS
2CrxQC1EblNoLGVZQJTyJU5iYi2QI54pPWCfADsVk9gtK7UwQkgjjloagoKq
2pnw83VwwpkV93gKhxnVbcQfqA7+CZzOLq37Dcr3LU56EeuBhavblYrrQLja
QNF4eD1oObrd14nWBAv1aor9RD2c6g77Nem9MshopBl2m7DhzdOOIy9V94D6
cOQuSi4bZPP7Czi+8nA0+tqKkmADEFyPHanwkgRrPfvX3e4NQHs0lm71SRTI
U8cKKG0NsBAR7lNFEoYbSfui9qo1Aq1dX+aeMy9Em4iTX0U3Qphowl//7iJA
6vLPo8EzjTA30j9QLPUDK6J/2En6nQNBHlcKFDvmMeXP96g2ORzQG+uaCwqb
wZ7tV/0RvqkJCoTu72a5TmDige2uReebwMR58Gff+ChGrfbqGy1rgn81mgyt
DN5ghE2iRltFm2GgyroTL/gbCzAuLsY8mqFk0+2RQJNO7HO0jcKVxmbQytEt
ffcnB/ujZzmOtqsFDszbFg+9qMUml3REnG61gK5g0uMGdjl2TdonijTWAv0P
trP5Cgux70cYArOGrZCj7jnpupaLhV78fKeE3gpE3xMiYi7pGF+ECg9FoA1u
ju9WdKymYTHZ5DB99zbwMR+jLlfGYxJtGav87W2QbGAyfHWWiqXMjgZ1qreD
d/1CY+RftzGXEezO4r12+P1Fmq6CDQVT76TFyrxvh+HgzDJ3S1/sG2s56eiR
Djh9YDuplesKVpN3OpP8uANqK00DbyU5Y5FPC/Ojv3ZA8OD4qXPE89ipGJGK
ItNOKNP4NMwJscZkbnqwBzI7QfaYbXxK8Uls7Epzx9paJ+xL26OStnYM+w/a
0n1C
        "]]}, 
      {GrayLevel[0.5], Thickness[Large], Dashing[Large], 
       LineBox[CompressedData["
1:eJxFxwk01PsfxnEkdCWyjCxXzLXvslyK3+dHKa6d0pSWq8VUJMoeslayNCiU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        "]]}}, {{}, {}, 
      {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwV1Pc/lX8fwHEhI3tHihwNWyQVXe8LkRJJWZGkOBkhI5QdRUZHRJKVmSK7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        "]]}}, {{}, {}, 
      {Hue[0.67, 0.6, 0.6], Thickness[Large], Dashing[Large], 
       LineBox[CompressedData["
1:eJwVlvk/lH0bhokmkeyE8pQtSzKhlHJfN5XKlmzpEUq2ImVPWYZkSWQpWUJC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        "]]}}}, {InsetBox[
      TagBox[GridBox[{
         {
          
          TemplateBox[{
           StyleBox[
            "\"first-step\"", StripOnInput -> False, FontFamily -> 
             "Helvetica", FontSize -> 12]},
           "LineLegend",
           DisplayFunction->(StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
             False]& ),
           Editable->True,
           InterpretationFunction:>(RowBox[{"LineLegend", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Hue", "[", 
                    RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], 
                ",", 
                RowBox[{"{", #, "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
              "]"}]& )]},
         {
          
          TemplateBox[{
           StyleBox[
            "\"established\"", StripOnInput -> False, FontFamily -> 
             "Helvetica", FontSize -> 12]},
           "LineLegend",
           DisplayFunction->(StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
             False]& ),
           Editable->True,
           InterpretationFunction:>(RowBox[{"LineLegend", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}], "}"}], 
                ",", 
                RowBox[{"{", #, "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{0}}}],
       "Grid"], NCache[
      Scaled[{Rational[1, 8], 0.625}], Scaled[{0.125, 0.625}]], ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TemplateBox[{
       StyleBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\"]\\)=2\"\
", StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 12],StyleBox[
        "\"\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\"]\\)=20\
\"", StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}],
             ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      NCache[Scaled[{Rational[7, 8], Rational[3, 10]}], Scaled[{0.875, 0.3}]],
       ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesLabel->{None, None},
   AxesOrigin->{0, 0},
   Epilog->{
     InsetBox[
      FormBox[
       StyleBox[
       "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=-0.2\"", 12, FontFamily -> 
        "Helvetica", StripOnInput -> False], TraditionalForm], 
      NCache[
       Scaled[{
         Rational[7, 8], 
         Rational[3, 4]}], 
       Scaled[{0.875, 0.75}]]], 
     InsetBox[
      FormBox[
       StyleBox[
       "\"C\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> False], 
       TraditionalForm], 
      Scaled[{0.05, 0.95}]]},
   Frame->{True, False, False, False},
   FrameLabel->{
     FormBox["\"Growth rate\"", TraditionalForm]},
   FrameTicksStyle->{Automatic, Automatic, Automatic, Automatic},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.3, 0.25}, {0, 30}},
   PlotRangeClipping->True,
   PlotRangePadding->{
     Scaled[0.02], Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          GrayLevel[0.5], 
          Thickness[Large]], 
         Line[CompressedData["
1:eJxFxwk01Hsfx3Ej1xJSRJZQIxpky1W66f/9J0TiEqFU5MoIoaxlhKLS4JKS
DEWWwS3GPrb5WYaxL7mydJEihShbyo3nec55Dp9z3udzXrudvE5d4ubi4kr6
b/97xcnH0traPYjr/5s5mSElwrthZj5Dcqr/1bpP+DVLpN/csDfXiqhYS/e6
/Z7OdT3Q71r3UANfKH9u+7qLXTnNXhYbvi94V6xvqW3dupa89MxjG96y0PBF
aLJ13eMJEb/5xm74wT88HfpDLeu2S1MWEKVsWNbF3GBUesPvVHxCGOXN686e
fVwRYteMPjPHaqPu9oJncdWi+bcmNMiLSzWzJkH7+qimXEITSj23f0HXeBFY
3Kr0qh4O4pacvdZ2gRvfpZVgzn+dg1qMbn71HP4Fv+1AWLKS46BItT/SvYwF
cOOqPoMp10Yk1RfRdrtLBM+d1J8+sKURXfGrX8z33YYLSeXF3ypqQLeyNSlS
X0Xxbr/wd1KrbBQIrX/7l4jjxEbroHYaG1kztk+8Et+B+0oobg87xEaT1B2K
6Rck8QaXxRe/9tUjF8lTZxdjpHCJsgbDj771KOASk7aSKY2T+RKGaaL1iBRi
fUo4XQZn2roE/M6oQ0FJ3Mv0iJ345uwDWzeZ16GZxIZwLzNZ3H6ZN6d0qhbZ
OwpEqf+QxZ2TXmnoUGvROE2RzyNSDvfUe1papFKLrtqeGUpblcMDhy8f2d9S
gwRust/ynZXHw0J12IzLNShRrM3xG00ev08kmGoI1CCZu5TpT2x5nBT5JN3e
EqHjxL0DAb3y+G/tmgV2sSwkGBweZ9Mhj5tta2Kd7qxGeuYahTYMeTyJNJ1h
KlONjCKEfqGGyuMfYCv1KLkKHf+po+KLyePatr9ePVhUierGgmK+TsrhoZ52
tmprFYg/6Wn8lztyeHsE5YiCaQVqzSFx3MTkcOmUVAWpx+Wo6t1mEec4Wdyl
mC0g8p6JHMo3d30kyOJFrR9neTSYqFlOWFTIZSc+rNTHbHEvQ4ZzJYUWDBmc
/1ZDWGx2KTqUJ7yfOSONn9d9LraTWIIkVNyyEsykcL5M+4Pa4oVoi9HBNpsK
cdxK0+2ORWM2Kja8mOFQKoz/22MW9t2Rjtwn0jUH5YTwrAAtyvOVTPTUv0z4
Sexm/Dtr+eqCZjram2W01yOeD3/u9I9HSmsa8mD9obWmyIuf5K0hG7mkoqEn
/sq9bB4caFsqNQ/SUEgsbZSozI0LzK0ertNIRH2OivGHe7nwHuPZKivSI+S0
eLenibgGHdPPgj/vj0HV5R4W+b4/wCkpNGTrnnvINmAqQs18GZaOXwzTFr+F
rtc5htCPL4Fv1P3tH4bIaKw9QNc9cQ6+PLsx+EpyD9o38GzHW4Gv4K97uLz1
7CU4Q6BfiVWeBX9hEYsHK35gN6hTnuc9DXZQc3EkIxRcZyetnCY+wdK3QNqi
6R0IwtsW+qgTEM/Q6hWcp8LxjjyDvefGYSLWck9yajwY9+kpkQNHgTXEUzrB
SICqt+5jPw+NQIIK87h27ROoZqQmD71+A54B7gM3u5OhqNEP9Or6wYgt594y
+gxMz7A/fVvqhT/5L69uvp4GMU02InzePbCSp8/RJKSDY46MVSipG8ind8ba
RGZAGgHz0z/YAT0ri3aUbVkgrVkZQ49sgQv27y77P6BDQ7+G06IZByYrOm54
i+VAtL/ete1ubPCTrqS6PcwFY0KwePDrWuC6QU92Fn8BW4UW3hMlEVAH4l9e
SHgJpB+Eeoy/EiQOhbLsduRD9v0MpTrvMrA4WUpWPsmAateAnd8Ni0GCss87
S6gALvEQPHiCC+B5v3iqSk0BaCetRbS65IGazlpnnk8hdLE1QOF8LjDjPq7t
31sEV0knUoidWWAw061RNlgEza/ezH/LT4euE5UOh2OKodZOqeztfCqco2f8
iY6WgPGo1iHdXSnwcVMMOrZYAsxoS4eKxUTwcQyY5WSXgoj9yK7rNo9g9/UE
PYp7GTA/N2YFzMdBZ1xJpKY6E0KnLtDSZGMgOPfv12NfmICo0k7CmpGgWj+v
8KSoHPKZvY/GuSJg4I3oVTP/ClBU9VQ57B8Gdxe0WIRDlbAqxqfqMEcBHWFL
wdKVSkiLGhK0mQqA94redm6sKgjv5bdUK/YBG3fudkXfaqD3peaeueQNLYyH
R0eVWSAcVOxAOuAO2JJSafIIC4Q8Rqczwl2g8HC5it0jBL+QM6OWHzpBfE1m
Z6RiDXzQS9mX/PACmL2fiSSH1oCD8lS3/Y4zwMera2D4pgYOSkqYSNy1hlpS
2CrxQC1EblNoLGVZQJTyJU5iYi2QI54pPWCfADsVk9gtK7UwQkgjjloagoKq
2pnw83VwwpkV93gKhxnVbcQfqA7+CZzOLq37Dcr3LU56EeuBhavblYrrQLja
QNF4eD1oObrd14nWBAv1aor9RD2c6g77Nem9MshopBl2m7DhzdOOIy9V94D6
cOQuSi4bZPP7Czi+8nA0+tqKkmADEFyPHanwkgRrPfvX3e4NQHs0lm71SRTI
U8cKKG0NsBAR7lNFEoYbSfui9qo1Aq1dX+aeMy9Em4iTX0U3Qphowl//7iJA
6vLPo8EzjTA30j9QLPUDK6J/2En6nQNBHlcKFDvmMeXP96g2ORzQG+uaCwqb
wZ7tV/0RvqkJCoTu72a5TmDige2uReebwMR58Gff+ChGrfbqGy1rgn81mgyt
DN5ghE2iRltFm2GgyroTL/gbCzAuLsY8mqFk0+2RQJNO7HO0jcKVxmbQytEt
ffcnB/ujZzmOtqsFDszbFg+9qMUml3REnG61gK5g0uMGdjl2TdonijTWAv0P
trP5Cgux70cYArOGrZCj7jnpupaLhV78fKeE3gpE3xMiYi7pGF+ECg9FoA1u
ju9WdKymYTHZ5DB99zbwMR+jLlfGYxJtGav87W2QbGAyfHWWiqXMjgZ1qreD
d/1CY+RftzGXEezO4r12+P1Fmq6CDQVT76TFyrxvh+HgzDJ3S1/sG2s56eiR
Djh9YDuplesKVpN3OpP8uANqK00DbyU5Y5FPC/Ojv3ZA8OD4qXPE89ipGJGK
ItNOKNP4NMwJscZkbnqwBzI7QfaYbXxK8Uls7Epzx9paJ+xL26OStnYM+w/a
0n1C
          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          GrayLevel[0.5], 
          Thickness[Large], 
          Dashing[Large]], 
         Line[CompressedData["
1:eJxFxwk01PsfxnEkdCWyjCxXzLXvslyK3+dHKa6d0pSWq8VUJMoeslayNCiU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          "]]}}}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          Thickness[Large]], 
         Line[CompressedData["
1:eJwV1Pc/lX8fwHEhI3tHihwNWyQVXe8LkRJJWZGkOBkhI5QdRUZHRJKVmSK7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          "]]}}}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          Thickness[Large], 
          Dashing[Large]], 
         Line[CompressedData["
1:eJwVlvk/lH0bhokmkeyE8pQtSzKhlHJfN5XKlmzpEUq2ImVPWYZkSWQpWUJC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          "]]}}}}, {
     Frame -> {True, False, False, False}, 
      FrameTicksStyle -> {Automatic, Automatic, Automatic, Automatic}, 
      FrameLabel -> {"Growth rate"}, PlotRange -> {{-0.3, 0.25}, {0, 30}}, 
      LabelStyle -> Directive[12, FontFamily -> "Helvetica"], Epilog -> {
        Text[
         Style[
         "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=-0.2", 12, FontFamily -> "Helvetica"], 
         Scaled[{
           Rational[7, 8], 
           Rational[3, 4]}]], 
        Text[
         Style["C", 14, Bold, FontFamily -> "Helvetica"], 
         Scaled[{0.05, 0.95}]]}, AspectRatio -> GoldenRatio^(-1), Axes -> 
      True, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
      PlotRange -> {{-0.3, 0.25}, {0, All}}, PlotRangeClipping -> True, 
      PlotRangePadding -> {
        Scaled[0.02], Automatic}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          Thickness[Large], 
          GrayLevel[0]], 
         Directive[
          Thickness[Large], 
          GrayLevel[0], 
          Dashing[Medium]]}, {
         Style[
         "\!\(\*\nStyleBox[\"n\",\nFontSlant->\"Italic\"]\)=2", 12, 
          FontFamily -> "Helvetica"], 
         Style[
         "\!\(\*\nStyleBox[\"n\",\nFontSlant->\"Italic\"]\)=20", 12, 
          FontFamily -> "Helvetica"]}, LegendLayout -> "Column"]], 
      Scaled[{
        Rational[7, 8], 
        Rational[3, 10]}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{{3.780257452734988*^9, 3.780257477453064*^9}, {
   3.7802575410524187`*^9, 3.780257618687738*^9}, 3.780257684159048*^9, 
   3.7802577273734303`*^9, {3.780257866716571*^9, 3.780257912914888*^9}, 
   3.782262962700006*^9, 3.782269762190576*^9, 3.7849047362787247`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure S6", "Subsection",
 CellChangeTimes->{{3.784904190220097*^9, 3.7849041931292152`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"GraphicsColumn", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"figS6a", ",", "figS6b", ",", "figS6c"}], "}"}], ",", 
   RowBox[{"Spacings", "\[Rule]", 
    RowBox[{"-", "110"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "350"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{
    RowBox[{"supfigdir", "<>", "\"\<FigureS6.eps\>\""}], ",", "%"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7849047092915*^9, 3.784904757647605*^9}, {
  3.7849050028293867`*^9, 3.784905004037328*^9}, {3.78490546303727*^9, 
  3.784905463319522*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     FormBox[
      TagBox[
       FormBox[
        GraphicsBox[{{{{{}, {}, 
             {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwtkHtI01EcxUczQ7dKa7qS3DJTV1uU5LI/elIyJSlnf/RH9lBZEaibSo+V
SIZhYriioAw1YgspZKAT2iB3vm1JFq42dS+ix0YYphJUs7AFeX/bgcvlcu/9
fM85WVXacs0SHo8nW1xsf9DFFERblbWgJl9B87IKgyMSQMtkYnGnUE7lVsn1
GXUAglDvO8XMJjKrQpdFZj9yM+fDZS4ZCfxG3e5kP2rzo6V8Sx6dPcPkQ8/W
ksHS7lxyRhjQC5vE1axszyHpIs0q8UKUdPPTiH4jXREx4iTmVAmWpXXZFOBw
E6gLpLdHNRuoYDvTBPpPGXsGKrPoloMBx5Gnrw/LK9fTrJoZ9MAhU+R8GZVQ
MbOn8qCvumk4zb+OTAxndONPetelhdkM4nFyY+dB8eSj5LVkY/Gsb3Gs8/QN
yTYx1bPnOhdWWToy2k+k0WZWh2wM+6dP2vl3VlOY4UNv0EieNeROpVh/r3Ho
Kf/xMnEKHeX6GsXtb/euGcaE8X5eoeb358ai5qR4HyMofFiYsLIokZq4/C+B
fWV7Tdn8eF4ntOMp7+cyefF8L1CrlZZPNywglocgF2Q7PX9/gRtntUOgLtG4
fd+h4Pw+R4Oy4mO/bQrdnD8bZsI+o3HkA4Scn2eYEx9YPqT0IDZ/CMYLP1r2
XCTE5g3ArFf+NFT3xflmHBZ3IHiuFfc53hO0TVmjhTuO4Cr33wTD+V2pg18j
duLe98K7QmoO/Dtuj93fRZDVrtsyHDu3ghfXf7XCS3g=
               "]]}, 
             {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
              LineBox[CompressedData["
1:eJwtkGtI01EYxtfCvDIarZZlm7fWCitnJvShIMmUspEuEEmMbhaBtJIGbplR
BpIfCrRMcTaaECqtJM1Z2vPmNEuWTG2X/LLMQYTNmui6meX57//A4XA45/ze
53kSTpzPPy0UCATKpcX2xgamD5hz7PReW1BQUFl0q3/eg4h9lS5lpoLyrbIb
03keiGtLeqOrN5Ile1IvsbjxtNx+VjWSTNFus3Z3lBv2uFpfkySZzpQwueBW
1A0UHE0i2zwDOpEbKXqmfZBI8iWaVebEpWO5D/98SSCDhBHfQ7/ZOSZOSyAP
hxvHOWq2OvTxlL6DaRzpierAi2o53e5nwDHEL5rC+jbI6GseMziKKmPQuNAZ
RznMXvYofp0SRrrV66mF4cwOtMdUZDyajiUBJwf+GcvUUzVrqYfFs45gj2Su
2LtdShfYc+076HRiVYRnNW1hdSjt0HzfdXigSkKfGH5yGMNZBQfLM1ZRqL+3
uP54IrXGLyYN19cbrNGZ9ha1reT7GcLPrg5Tw4SI72MQFT9sel1pDF3m8g/g
0BPVbLgois9rg7VU7xP2hfP5XqHevbVVagjj8xD+5lmEgZzlxI2zvsRQS6Yh
bdMySuH89mLCWR/mT1lEE+evB1mDsWON234jhvPTjdSp5JnKI0GE5ncikOjx
d9+fRWheB64cWFd3MmkGIb4FJPQaXYWfcY/jtWJeIVXp/R9xlfvfgjv7n/vk
35wg7n0zyox3ZWLPa/6+Dl3mDE1gsp0/V6Hw4s0VruLj+A8FWlYP
               "]]}, 
             {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
              LineBox[CompressedData["
1:eJwtkF1I01EYxmcp2jZJcemsNbep27AvwoiEIkhjUVBuEstYJIOyLHJeaLJm
KOnVLNfSaBHuYutjEgNL3WZr75smbepM5z7+JRWTUDC9cKHlRZjn7/+Bw+Fw
zvm9z/OItbWqK1tYLJZ8Y5H9qYXoC0hfOCSDS3JclWs6hlYoELxKNyafl6PK
LWz7paTgxMUE6LwydCriep4zBvwbl9Xz+TLkxGy6Y+wY/Dhd31BulGL1VaIo
NMys3+9KFOLwCgFGYE+tc8laWYh5GzS3MAIv+6rNl7AA7/AIMQz1F9YEKC1A
isZNw70zTr+vPR8PFRNNQ2nr/oA6IUHTEAGGAEoabz5US3BRSQxOgWn57G+9
V4yniD3FFCS+Z6fuE4vRTnC2SeC6BnoDbSJk0ZqEukeiwT/hPPSQeO4JaGri
v17sFmIdea4LwkTnfOjn9d1YROqQj8OBUbtGc1iAswQfH4Vzc8UHI8m7cLO/
AGiV16hQJBcr6L780JFSdTLq4DP9fAKjy2qpbMlh+hiBqv7PX8c02Wig838E
DGcZ2o/uYPIOQ41lwDAn4jH5PgCfolxsdhaTByFDDuNpfzORHuf2gVcmeTey
kIF7ab9eiO8stX0b3o7PaH8eMC8rbgU96cil/bhAvKZ/ruznMPP7oGxsfebI
223MvF4o6UnjPnamMnwncMpuv0drCj6heQ6IVlAtjfqt2Ez/t4M51zSbU5SE
SL/vBlXS8eauzH+wed8J2vKgvebBKnNuhTdKv++ucgH+A6h0U3Y=
               "]]}, 
             {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], 
              LineBox[CompressedData["
1:eJwtkAtI01EYxce2wm2iq602S5ePzT2cEPbCubIsUAoMVy4MiWblyiE6KNa7
pIIgIodSKSbIFjTMVZC40dj3NbWHtbXNdJuQOREtC4RIkcSW99//wOVyuff+
vnNOVk2D7hSTwWAoVhbZ29uIYnDB3Df1bVKNC4rqe775KDzJPft3QqdGnUty
60dFFDhaWbHDl4fO0vhFoTMC/NruQWlBHvIitsad3AhwDyo3b+9SobGWaBTu
2LqXIVWF/fMEOALPeQHv4ytK3LRCc0lGYM9pR69/VoGXhIT4GTTHTcLsIwqM
Urhh+JDIkLb45Lh1C9EwNHD3ctPy5djsI8Aw7Dv6yNp7Pxd/VhCDIag2zNSc
S8iwjNgrDUGl9gbfbJShneBsQbiqylf7A1JkUArCruKxr+5tUnSTeK4A3E1q
8pg7ctBMnjf6QRATLu5g5aCK1KH4CLbdxgJ9XTZOEnx8COrGWdNp4Sz83997
+J5ge0OaLDxE9fUOSiD0ZcieSffzFjonzmjK+Zl0H4OQMjPL1i5J8DKVfwBu
98RTpmMZdN5++FR/jfPbk07new2BZ8miLvtGOg+CV95qYVo3IDXO5QXl3Pnm
5aY0VFN+PcAuf/qr0CLGDsqfGw7/GfMnN4owmfLTB236B/VVpvX0/JewIC4K
HjOuo+e9gHF2C+eEQUjznRA+MNqeXinAhxTPAauW9CJr0Vq8Tv23g9JgWexJ
WoNIve+EElbhwsD+VPq+FaqmzEzBKx59vgkn5ximN+LV+A+z10dr
               
               "]]}}, {}}, {{{}, {}, 
             {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwtkH9I00EYxof2a22o5cxKnFprWznB1iAJJAly1RY1M6opg8ISknK2kaFB
YyQYmFoUlURgKtE/g3DRRmPPbSZtWuG23JaUsYhtNocTnUIjyPtuDxzHcXef
93meskutdZezWCyWeG3RfeAZ1Tec5QuLZOVCsiJu7HMmg/hndLlH9HtInYXf
FVMFoYtLu/tsAmKShzp4pgBGuybzPVkCwgkMaas3B9CvifqU8t2k+QqVHzev
tl1I3NtFxpIUOA2RomHGPFFGStZoFv40VNVH7gyyy0gnjxK/QhoJeydrS0mQ
wflgqLH/Nq0rIbIDVD78LLdi4VYx6XdSoBdK3Uaf708RmVdRgx5Ikfs4rt5J
jlF7cg90Dztts+7tZJjihqaQsi0k6qsKCYvRFJwV45INrwqIlcazfMGqfrXF
tI1H2uhz7WcMRJ37c7u3kn20DvEnaGa/tyym8sgvig9NIHW/src+nEPS/bnh
UQsV8h8ccobpy4VlkWyvd3ZTpp+PSDUWm/Xx9Zk+xtFsNnmPc7PJbSb/Bzyp
uHhScZiVyTuG2EjeodOFKaTzOfBe1sRWJ5JI5yGojTi0rUWLYMZZ7OCIsgev
a+YgYfzaUPXgb/tcbwjPGX9WGA2x5aM5fnAZP+/Qkx9p6OC6kJ5vxrWCcOmK
5G1m3hs0KY0ndowOZPgmJLtqooKXOjxleK9x49TSeUn7QRiY/8Ngn5vxO5b8
dsK8f4Etnp6gxFVpT98/Apfpfd6WPt8FK6P/d5BQXw==
               
               "]]}}, {}}, {{{}, {}, 
             {Hue[0.67, 0.6, 0.6], Thickness[Large], Dashing[Large], 
              LineBox[CompressedData["
1:eJwtkm1I01EUxtcCKzMsnb23NjfXZtMmKmygUfhhahBpKVFGS1kmKNk7aZiY
gyAqzchVNiv9YCSLleVWa8/RFc5S2ZrLBWXoIBIlA9Fe/FDe//4HLpfLPfd3
nufhSouP5xuFAoFAubDYfuc2q084H3jaaBOn0Jyy6HrvbBDqpskGS62G8u1i
02ReEO2FXpPBs42s+rEqkXUElvJQqf9GMi0faavMjByB2S0aazUkUelRVh/x
NVanGUxRk3uWAQPoqRjSlkRspc0LNLs4AOnB9L9loyqqFjHiMOR76lu+O5QU
5HB+HK47HfPNvIXSUln5kV6UM3CsWkENvQz4Adea1M/OHkmgqTwm0IemM58F
cbvklM3k6X344jmZnK2VUTvDtXmx/193IFYVTwKuvKgTKu5VbZKSg9mzDyFh
2XNZTZyETrD2ykGEnJJF2+PFlMjiUA5gXOZ47JBspHGGH3sH1boD8grFegrn
14+keeNEQepa2svl5UF0rUV4Sr+az6cPzRmyLE+xiM/jLTpqBh+WmGLoAuf/
DSjU1298spL368aV6MQpce8K3l8PLq7JLetMj+T9ENJ6fmUufRVB3Di7C9rO
aaV332JSc3qd6JgDZSwRUAunz4Gfl726GdsfRHF6urHDcnW3q2MG4fldeO/D
LZN8CuF5Nlz63XxIoxtHmG9FS6d4lXPDMMwc7xGyogzndvoJtdz7dpS/rMt9
8eA+iOu34K6vYFSRZ+Tvb2I6p1A33zXhCp/roVn4gJIfja//A9hWTS0=
               
               "]]}, 
             {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], Dashing[
              Large], LineBox[CompressedData["
1:eJwtkF9IU1Ecx+fCovXP1saG4nJutuu89dCU6EF9yNIGrTbTZBiBpBYJmzYw
XIUPikJIGwjLkSlNqCAWYuJdLn8/XbKVVtvMNumhrgijzPWiFbNYntv9wuFw
OOd8ft/vV9lgMTUKBQIBtbXI7h4gWoKQpvFA7txh/EnV353ZiIO29vLK5CaN
JkbRvWqMw9RRf/oMTaO3ku2QeGNQMWdzReqLcFfMYy0VxcCZoErK+7TY3ET0
EUT+7lLXy0IMbBDgIiybRrs+r1F4cIvGKBahVn/hukpBoV1CiB/goq/EYDNo
MM7hFmBJc97+7fYhLNYRLUDYfjY4/KwAHTMEGIWh7PkfL76o8buRGIyAulDT
c0msxipirzICoTa3YLJChSME5wnDtKRnItWejwJOYWB64z7DUyX6SDzmHchq
PL8TbB62kufWtyCTFhz/Jc9DLamDmodkpi6rzqPAZYJn30DZtbrWZnku/u/v
NQxeyflkdeZgNddXCG5kpE24N5vvJwjj+VF0OeR8H7NgtJxI0TIZ3uTyv4LN
c6fdjx5K+bwB0PcO2xQ6CZ9vGtjyP039ITGfB+GYc6xovWE/cuOYKQAm+lgk
zEKa8+uHlnHb17/6PXif8+eD6qstgb4BEe7m/EyAKvi+jU7u4Oc/hxq1s/3O
qUx+3ii41txm85CQ53vBbzkZ8STScI/jPYHVQZM4oyMFndz/EdgekpY52XVA
7v0DSK+Yi3Fbkr/vh1uzjiqlneXPXdC5byfSRwLwD66YTr4=
               "]]}, 
             {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], Dashing[
              Large], LineBox[CompressedData["
1:eJwtkG9Ik1EYxTctUbNmYyqWzm22Nte2io2CYNQ3JQl0CwlcBJVmsdIxInFh
VrM0loUm5KphbRp9cBUIzX89j265Niumm21jwVJSkDLB2liElfftPXC5XO69
v+ecwz9Zr65JYTAY4vVFdksPUQSehweqM0R7MCHW3pmIh+G7sknPtu5GtZPb
+rUyDNoHirSVZTk6SueaOI4Q5A7Pt91SyXFTyNagygxBR/P4stcswzO1RB9h
TJO0dkal6IoT4Cx0ZZsbvSVSLFqnObmzUPF3Na3q0i40cggxCC8O4ZNitwTD
FC4A0vbyH4JsCSoVRAFY6o8ay6tL8O4EAc5As9/LeNQnxm+VxOA06BL5I7wV
EZYRe6XToG5T+Jb2i9BOcDY/GN0Hb+e07EQGJT+4+ZNFUx4hDpF4zg9w3bzP
cIAlRD153vAeIt2bg5aqHSghdYjfwciWgjWxtRjnCX7OB3Czc4NwUYD/+/PC
lWsGpl8uQA3V11vQ/Wy3nW3k0/14YLXrc0Tm4tF9vIGk3aRVs3h4mcrvhov6
p6fTh7l0XhcorzpTfccK6XzjkIxlJlm/t9N5EHRr8cJPvduQGud8Da500STz
cD5KKb+jEDzePZaXyMOHlL8hWIyZFk7ZczGL8vMKzp1gF4xqcuj5g6AyeKaO
pnDoeS+h/0bg/IUBNs13wJEv9T2uiq14n+I9g7rHqTULPha2UP/tIPyV0NRB
FiL13gq9rbUxizqDvr8HUfbMoI+/kT6bQLa3o0zL/AP/ABFqUQY=
               "]]}, 
             {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], Dashing[
              Large], LineBox[CompressedData["
1:eJwtkF9Ik1EYxpdkoXVhpiwa+/NNp9O5ubn1n5HdZFBQc7gw11ZhRUboYMHw
DwhtWEal1YVbmsmGIIxZYvQNovfdXJmly23ZN4mKKQSrBL2YWheR5+t74HA4
nHN+7/M81IXm2otZPB5PvrHI7nETzUPOmYNHLHVVuCo33wtnkhBsKLtauKkK
a2mR66chCV/j9jtOvwYDNanWggADy4b1taHTGtzGeFv0uQw8bQ8p67I0ePkS
0SeoDr+x9/jVOJEhwDmg7k4z1SY1ijdotGgOkvsHPoz+rcS2AkL8CPf3XD/b
e7ISkywuAR76RHHeoAp1WqIEmLb2SaklJfaECTAOzcYGV+SAEn8ZiMEY5NxK
C7JdFXiM2KuJwe+x7qU/UQX6CM47C0/4NPOer0Aeq1m4fW3zzIi1HIMkHh2F
1Nr3L7HhMrSR5y0zcN4XUnYvybGc1CGfho5vOq1YJ8cFgk+9g+e+K9mp1lL8
398UrEQdJkm4BI1sX2/BEgt0KXJLuH4mYf1BYvG4Ucb18Rpk8fzl8EAxtrP5
I2DslUUn00Vc3gk4J7S4nPuKuHwhsKs7fuR3Sbk8CHuVRxcdSQrZcfQriASo
Rq+CwgrW70vwqIRN1k4J9rP+gsBIbZpBvxi3s35egGpH1k26XsTNH4fhxI1x
7RYhN+8ZrAimIodGBRw/AHTw81Djqd3Yx/JGQGBmJM6FXdjJ/vdBm556pK/n
I7LvH4PN4hrL9Bdy9w/BvWp2lzp2cmcn6K3ppvnDefgPds1Nog==
               
               "]]}}, {}}, {{{}, {}, 
             {GrayLevel[0], Thickness[Large], Dashing[Large], 
              LineBox[CompressedData["
1:eJwtkXtI01EUx9dASV3YaoXKck1tTdso6AEJNixrs1WkK8oaluHK/qg9JAIn
IT0oIVkPHxmbLhzpxEaj19TmOXtIU7S29iwRWaYEWSSxikJo97cduFwu99zP
+X6/l3tGWamg02g0fnyR/WEnqQ8wwL0mGlgjxF98uc4Zi8DoZLYqpUyAlbbc
G18rIlDvY9jZqk1oEUcbWJYwlLYZ3O7OIswI96hK0sMguDfjCWIhnjtLKgTZ
oeLU4jk+umIEGATdrC7zeyofOXGaLTcI4qshB523EbUsQgxAgdVrMezmYYTC
+cEretH8R74Bt20l5Qe9I22H/FIB3nES4HuolrVUc2/n40IFEeiDfo9GZH6U
hxIiT+yDHEWr9uRLLpoIrscLFx8f2GwcX480qrzwtNn1c9jOwUFiz/YWykzl
89/m16GatKsmIbK4ytDCZGMRiYM/AcfUwx17duXgJ4KPjoN9X2O070IWJvIb
A8bskSyJcS3KqLw88Be35BlDrGQ+b2D/dN1nPnN1Mo9R0FYx2k8cZmIj5d8N
hmmpUl2YmfTrgoNtUqPbnpH054B611BAdmp50g/CTSk7TbMyBalxthGIlVzp
uxVYhgJK72uQlD8Zq6lZAj2lbxBCp3tL86t+A4PS8wr6f9hpwt5FSMx/DkdV
C7wVH79AYp4VmNp3E111M5DgW2Bn97Nav9ULDyieGczbp5TOQ0PQRL03Qbda
cVdzuQOQ6u+CKWET/f7S8eR9K+g5e2vb/wVGEufr0JAe/4a58/b/rjFReQ==

               "]]}}, {}}}, {InsetBox[
            
            TemplateBox[{
             StyleBox[
              "\"total\"", StripOnInput -> False, FontFamily -> "Helvetica", 
               FontSize -> 12]},
             "LineLegend",
             DisplayFunction->(StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
               False]& ),
             Editable->True,
             InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], 
                  ",", 
                  RowBox[{"{", #, "}"}], ",", 
                  RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                "]"}]& )], Scaled[{0.56, 0.23}], ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm], InsetBox[
            
            TemplateBox[{
             StyleBox[
              "\"1-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
               FontSize -> 12],StyleBox[
              "\"2-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
               FontSize -> 12],StyleBox[
              "\"3-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
               FontSize -> 12],StyleBox[
              "\"4-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
               FontSize -> 12]},
             "LineLegend",
             DisplayFunction->(StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
               False]& ),
             Editable->True,
             InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.24720000000000014`", ",", "0.24`", ",", 
                    "0.6`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.6`", ",", "0.24`", ",", 
                    "0.4428931686004542`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.6`", ",", "0.5470136627990908`", ",", 
                    "0.24`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.24`", ",", "0.6`", ",", 
                    "0.33692049419863584`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
                    "}"}], ",", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
                  RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                "]"}]& )], Scaled[{0.85, 0.23}], ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm], InsetBox[
            
            TemplateBox[{
             StyleBox[
              "\"\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)=2\"", StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 12],
              StyleBox[
              "\"\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)=20\"", StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 12]},
             
             "LineLegend",
             DisplayFunction->(StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
               False]& ),
             Editable->True,
             InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}],
                   ",", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                  RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                "]"}]& )], NCache[
            Scaled[{Rational[1, 10], Rational[7, 10]}], Scaled[{0.1, 0.7}]], 
            ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm]}},
         AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
         Axes->True,
         AxesOrigin->{-0.4, -14.508657738524219`},
         CoordinatesToolOptions:>{"DisplayFunction" -> ({
             Part[#, 1], 
             Exp[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             Part[#, 1], 
             Exp[
              Part[#, 2]]}& )},
         Epilog->{
           InsetBox[
            FormBox[
             StyleBox[
             "\"A\"", Bold, 14, FontFamily -> "Helvetica", StripOnInput -> 
              False], TraditionalForm], 
            Scaled[{0.05, 0.95}]], {
            Arrowheads[{{0.02, 0, {
                GraphicsBox[
                 CircleBox[{1, -1}, 1, 
                  
                  NCache[{Rational[1, 2] Pi, Pi}, {1.5707963267948966`, 
                   3.141592653589793}]]], -1}}, {0.02, 1, {
                GraphicsBox[{
                  CircleBox[{-1, 1}, 1, 
                   
                   NCache[{
                    Rational[-1, 2] Pi, 0}, {-1.5707963267948966`, 0}]], 
                  InsetBox[
                   BoxData[
                    FormBox[
                    StyleBox["\"\"", Larger, StripOnInput -> False], 
                    TraditionalForm]], {0, 2}]}], 1}}}], 
            ArrowBox[
             
             NCache[{{-0.125, -Log[1000000]}, {-0.125, 
                Rational[1, 2] (-Log[5000] - Log[
                 1000000])}}, {{-0.125, -13.815510557964274`}, {-0.125, \
-11.166351874690257`}}]], 
            Arrowheads[{{0.02, 0, {
                GraphicsBox[
                 CircleBox[{1, 1}, 1, 
                  
                  NCache[{Pi, Rational[3, 2] Pi}, {3.141592653589793, 
                   4.71238898038469}]]], -1}}, {0.02, 1, {
                GraphicsBox[
                 CircleBox[{-1, -1}, 1, 
                  NCache[{0, Rational[1, 2] Pi}, {0, 1.5707963267948966`}]]], 
                1}}}], 
            ArrowBox[
             
             NCache[{{-0.125, 
                Rational[1, 2] (-Log[5000] - Log[1000000])}, {-0.125, -
                Log[5000]}}, {{-0.125, -11.166351874690257`}, {-0.125, \
-8.517193191416238}}]]}},
         Frame->{True, False, False, True},
         FrameLabel->{{"", 
            FormBox["\"Probability of rescue\"", TraditionalForm]}, {
            FormBox["\"Wildtype growth rate\"", TraditionalForm], ""}},
         FrameTicks->{{None, {{-13.815510557964274`, 
              FormBox[
               TemplateBox[{"10", 
                 RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
                SuperscriptBox], TraditionalForm]}, {-11.512925464970229`, 
              FormBox[
               TemplateBox[{"10", 
                 RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
                SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
              FormBox[
               TemplateBox[{"10", 
                 RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
                SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
              FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
              FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
              FormBox["0.1`", TraditionalForm]}, {0., 
              FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-12.716898269296165`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-12.429216196844383`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-12.206072645530174`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-12.02375108873622, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-11.86960040890896, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-11.736069016284437`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-11.618285980628055`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-10.819778284410283`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-10.414313176302118`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-10.126631103850338`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.903487552536127, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.721165995742174, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.567015315914915, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.433483923290392, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-9.315700887634009, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-8.517193191416238, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-8.111728083308073, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.824046010856292, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.600902459542082, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.418580902748127, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.264430222920869, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.1308988302963465`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-7.013115794639964, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-6.214608098422191, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-5.809142990314028, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-5.521460917862246, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-5.298317366548036, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-5.115995809754082, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-4.961845129926823, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-4.8283137373023015`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-4.710530701645918, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-3.912023005428146, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-3.506557897319982, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-3.2188758248682006`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.995732273553991, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.8134107167600364`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.659260036932778, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.5257286443082556`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-2.407945608651872, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-1.6094379124341003`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-1.203972804325936, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.916290731874155, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.6931471805599453, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.5108256237659905, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.35667494393873245`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.2231435513142097, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}, {-0.10536051565782616`, 
              FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
               Thickness[0.001]}}}}, {True, False}},
         GridLines->{None, None},
         LabelStyle->Directive[12, FontFamily -> "Helvetica"],
         Method->{},
         PlotRange->{{-0.4, 0}, {-14.508657738524219`, 0.}},
         PlotRangeClipping->True,
         PlotRangePadding->{{None, None}, {None, None}},
         Ticks->{Automatic, {{-13.815510557964274`, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm]}, {-11.512925464970229`, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm]}, {-9.210340371976182, 
             FormBox[
              TemplateBox[{"10", 
                RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox], TraditionalForm]}, {-6.907755278982137, 
             FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
             FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
             FormBox["0.1`", TraditionalForm]}, {0., 
             FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-12.716898269296165`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-12.429216196844383`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-12.206072645530174`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-12.02375108873622, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-11.86960040890896, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-11.736069016284437`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-11.618285980628055`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-10.819778284410283`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-10.414313176302118`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-10.126631103850338`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.903487552536127, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.721165995742174, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.567015315914915, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.433483923290392, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-9.315700887634009, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-8.517193191416238, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-8.111728083308073, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.824046010856292, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.600902459542082, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.418580902748127, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.264430222920869, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.1308988302963465`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-7.013115794639964, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-6.214608098422191, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-5.809142990314028, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-5.521460917862246, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-5.298317366548036, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-5.115995809754082, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-4.961845129926823, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-4.8283137373023015`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-4.710530701645918, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-3.912023005428146, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-3.506557897319982, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-3.2188758248682006`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.995732273553991, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.8134107167600364`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.659260036932778, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.5257286443082556`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-2.407945608651872, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-1.6094379124341003`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-1.203972804325936, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.916290731874155, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.6931471805599453, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.5108256237659905, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.35667494393873245`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.2231435513142097, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}, {-0.10536051565782616`, 
             FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
              Thickness[0.001]}}}}],
        TraditionalForm],
       InterpretTemplate[Legended[
         Graphics[{{{{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Thickness[Large], 
               Line[CompressedData["
1:eJwtkHtI01EcxUczQ7dKa7qS3DJTV1uU5LI/elIyJSlnf/RH9lBZEaibSo+V
SIZhYriioAw1YgspZKAT2iB3vm1JFq42dS+ix0YYphJUs7AFeX/bgcvlcu/9
fM85WVXacs0SHo8nW1xsf9DFFERblbWgJl9B87IKgyMSQMtkYnGnUE7lVsn1
GXUAglDvO8XMJjKrQpdFZj9yM+fDZS4ZCfxG3e5kP2rzo6V8Sx6dPcPkQ8/W
ksHS7lxyRhjQC5vE1axszyHpIs0q8UKUdPPTiH4jXREx4iTmVAmWpXXZFOBw
E6gLpLdHNRuoYDvTBPpPGXsGKrPoloMBx5Gnrw/LK9fTrJoZ9MAhU+R8GZVQ
MbOn8qCvumk4zb+OTAxndONPetelhdkM4nFyY+dB8eSj5LVkY/Gsb3Gs8/QN
yTYx1bPnOhdWWToy2k+k0WZWh2wM+6dP2vl3VlOY4UNv0EieNeROpVh/r3Ho
Kf/xMnEKHeX6GsXtb/euGcaE8X5eoeb358ai5qR4HyMofFiYsLIokZq4/C+B
fWV7Tdn8eF4ntOMp7+cyefF8L1CrlZZPNywglocgF2Q7PX9/gRtntUOgLtG4
fd+h4Pw+R4Oy4mO/bQrdnD8bZsI+o3HkA4Scn2eYEx9YPqT0IDZ/CMYLP1r2
XCTE5g3ArFf+NFT3xflmHBZ3IHiuFfc53hO0TVmjhTuO4Cr33wTD+V2pg18j
duLe98K7QmoO/Dtuj93fRZDVrtsyHDu3ghfXf7XCS3g=
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Thickness[Large], 
               Line[CompressedData["
1:eJwtkGtI01EYxtfCvDIarZZlm7fWCitnJvShIMmUspEuEEmMbhaBtJIGbplR
BpIfCrRMcTaaECqtJM1Z2vPmNEuWTG2X/LLMQYTNmui6meX57//A4XA45/ze
53kSTpzPPy0UCATKpcX2xgamD5hz7PReW1BQUFl0q3/eg4h9lS5lpoLyrbIb
03keiGtLeqOrN5Ile1IvsbjxtNx+VjWSTNFus3Z3lBv2uFpfkySZzpQwueBW
1A0UHE0i2zwDOpEbKXqmfZBI8iWaVebEpWO5D/98SSCDhBHfQ7/ZOSZOSyAP
hxvHOWq2OvTxlL6DaRzpierAi2o53e5nwDHEL5rC+jbI6GseMziKKmPQuNAZ
RznMXvYofp0SRrrV66mF4cwOtMdUZDyajiUBJwf+GcvUUzVrqYfFs45gj2Su
2LtdShfYc+076HRiVYRnNW1hdSjt0HzfdXigSkKfGH5yGMNZBQfLM1ZRqL+3
uP54IrXGLyYN19cbrNGZ9ha1reT7GcLPrg5Tw4SI72MQFT9sel1pDF3m8g/g
0BPVbLgois9rg7VU7xP2hfP5XqHevbVVagjj8xD+5lmEgZzlxI2zvsRQS6Yh
bdMySuH89mLCWR/mT1lEE+evB1mDsWON234jhvPTjdSp5JnKI0GE5ncikOjx
d9+fRWheB64cWFd3MmkGIb4FJPQaXYWfcY/jtWJeIVXp/R9xlfvfgjv7n/vk
35wg7n0zyox3ZWLPa/6+Dl3mDE1gsp0/V6Hw4s0VruLj+A8FWlYP
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Thickness[Large], 
               Line[CompressedData["
1:eJwtkF1I01EYxmcp2jZJcemsNbep27AvwoiEIkhjUVBuEstYJIOyLHJeaLJm
KOnVLNfSaBHuYutjEgNL3WZr75smbepM5z7+JRWTUDC9cKHlRZjn7/+Bw+Fw
zvm9z/OItbWqK1tYLJZ8Y5H9qYXoC0hfOCSDS3JclWs6hlYoELxKNyafl6PK
LWz7paTgxMUE6LwydCriep4zBvwbl9Xz+TLkxGy6Y+wY/Dhd31BulGL1VaIo
NMys3+9KFOLwCgFGYE+tc8laWYh5GzS3MAIv+6rNl7AA7/AIMQz1F9YEKC1A
isZNw70zTr+vPR8PFRNNQ2nr/oA6IUHTEAGGAEoabz5US3BRSQxOgWn57G+9
V4yniD3FFCS+Z6fuE4vRTnC2SeC6BnoDbSJk0ZqEukeiwT/hPPSQeO4JaGri
v17sFmIdea4LwkTnfOjn9d1YROqQj8OBUbtGc1iAswQfH4Vzc8UHI8m7cLO/
AGiV16hQJBcr6L780JFSdTLq4DP9fAKjy2qpbMlh+hiBqv7PX8c02Wig838E
DGcZ2o/uYPIOQ41lwDAn4jH5PgCfolxsdhaTByFDDuNpfzORHuf2gVcmeTey
kIF7ab9eiO8stX0b3o7PaH8eMC8rbgU96cil/bhAvKZ/ruznMPP7oGxsfebI
223MvF4o6UnjPnamMnwncMpuv0drCj6heQ6IVlAtjfqt2Ez/t4M51zSbU5SE
SL/vBlXS8eauzH+wed8J2vKgvebBKnNuhTdKv++ucgH+A6h0U3Y=
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Thickness[Large], 
               Line[CompressedData["
1:eJwtkAtI01EYxce2wm2iq602S5ePzT2cEPbCubIsUAoMVy4MiWblyiE6KNa7
pIIgIodSKSbIFjTMVZC40dj3NbWHtbXNdJuQOREtC4RIkcSW99//wOVyuff+
vnNOVk2D7hSTwWAoVhbZ29uIYnDB3Df1bVKNC4rqe775KDzJPft3QqdGnUty
60dFFDhaWbHDl4fO0vhFoTMC/NruQWlBHvIitsad3AhwDyo3b+9SobGWaBTu
2LqXIVWF/fMEOALPeQHv4ytK3LRCc0lGYM9pR69/VoGXhIT4GTTHTcLsIwqM
Urhh+JDIkLb45Lh1C9EwNHD3ctPy5djsI8Aw7Dv6yNp7Pxd/VhCDIag2zNSc
S8iwjNgrDUGl9gbfbJShneBsQbiqylf7A1JkUArCruKxr+5tUnSTeK4A3E1q
8pg7ctBMnjf6QRATLu5g5aCK1KH4CLbdxgJ9XTZOEnx8COrGWdNp4Sz83997
+J5ge0OaLDxE9fUOSiD0ZcieSffzFjonzmjK+Zl0H4OQMjPL1i5J8DKVfwBu
98RTpmMZdN5++FR/jfPbk07new2BZ8miLvtGOg+CV95qYVo3IDXO5QXl3Pnm
5aY0VFN+PcAuf/qr0CLGDsqfGw7/GfMnN4owmfLTB236B/VVpvX0/JewIC4K
HjOuo+e9gHF2C+eEQUjznRA+MNqeXinAhxTPAauW9CJr0Vq8Tv23g9JgWexJ
WoNIve+EElbhwsD+VPq+FaqmzEzBKx59vgkn5ximN+LV+A+z10dr
                
                "]]}}}, {}}, {{{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               GrayLevel[0], 
               Thickness[Large], 
               Line[CompressedData["
1:eJwtkH9I00EYxof2a22o5cxKnFprWznB1iAJJAly1RY1M6opg8ISknK2kaFB
YyQYmFoUlURgKtE/g3DRRmPPbSZtWuG23JaUsYhtNocTnUIjyPtuDxzHcXef
93meskutdZezWCyWeG3RfeAZ1Tec5QuLZOVCsiJu7HMmg/hndLlH9HtInYXf
FVMFoYtLu/tsAmKShzp4pgBGuybzPVkCwgkMaas3B9CvifqU8t2k+QqVHzev
tl1I3NtFxpIUOA2RomHGPFFGStZoFv40VNVH7gyyy0gnjxK/QhoJeydrS0mQ
wflgqLH/Nq0rIbIDVD78LLdi4VYx6XdSoBdK3Uaf708RmVdRgx5Ikfs4rt5J
jlF7cg90Dztts+7tZJjihqaQsi0k6qsKCYvRFJwV45INrwqIlcazfMGqfrXF
tI1H2uhz7WcMRJ37c7u3kn20DvEnaGa/tyym8sgvig9NIHW/src+nEPS/bnh
UQsV8h8ccobpy4VlkWyvd3ZTpp+PSDUWm/Xx9Zk+xtFsNnmPc7PJbSb/Bzyp
uHhScZiVyTuG2EjeodOFKaTzOfBe1sRWJ5JI5yGojTi0rUWLYMZZ7OCIsgev
a+YgYfzaUPXgb/tcbwjPGX9WGA2x5aM5fnAZP+/Qkx9p6OC6kJ5vxrWCcOmK
5G1m3hs0KY0ndowOZPgmJLtqooKXOjxleK9x49TSeUn7QRiY/8Ngn5vxO5b8
dsK8f4Etnp6gxFVpT98/Apfpfd6WPt8FK6P/d5BQXw==
                
                "]]}}}, {}}, {{{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                Thickness[Large], 
                Dashing[Large]], 
               Line[CompressedData["
1:eJwtkm1I01EUxtcCKzMsnb23NjfXZtMmKmygUfhhahBpKVFGS1kmKNk7aZiY
gyAqzchVNiv9YCSLleVWa8/RFc5S2ZrLBWXoIBIlA9Fe/FDe//4HLpfLPfd3
nufhSouP5xuFAoFAubDYfuc2q084H3jaaBOn0Jyy6HrvbBDqpskGS62G8u1i
02ReEO2FXpPBs42s+rEqkXUElvJQqf9GMi0faavMjByB2S0aazUkUelRVh/x
NVanGUxRk3uWAQPoqRjSlkRspc0LNLs4AOnB9L9loyqqFjHiMOR76lu+O5QU
5HB+HK47HfPNvIXSUln5kV6UM3CsWkENvQz4Adea1M/OHkmgqTwm0IemM58F
cbvklM3k6X344jmZnK2VUTvDtXmx/193IFYVTwKuvKgTKu5VbZKSg9mzDyFh
2XNZTZyETrD2ykGEnJJF2+PFlMjiUA5gXOZ47JBspHGGH3sH1boD8grFegrn
14+keeNEQepa2svl5UF0rUV4Sr+az6cPzRmyLE+xiM/jLTpqBh+WmGLoAuf/
DSjU1298spL368aV6MQpce8K3l8PLq7JLetMj+T9ENJ6fmUufRVB3Di7C9rO
aaV332JSc3qd6JgDZSwRUAunz4Gfl726GdsfRHF6urHDcnW3q2MG4fldeO/D
LZN8CuF5Nlz63XxIoxtHmG9FS6d4lXPDMMwc7xGyogzndvoJtdz7dpS/rMt9
8eA+iOu34K6vYFSRZ+Tvb2I6p1A33zXhCp/roVn4gJIfja//A9hWTS0=
                
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                Thickness[Large], 
                Dashing[Large]], 
               Line[CompressedData["
1:eJwtkF9IU1Ecx+fCovXP1saG4nJutuu89dCU6EF9yNIGrTbTZBiBpBYJmzYw
XIUPikJIGwjLkSlNqCAWYuJdLn8/XbKVVtvMNumhrgijzPWiFbNYntv9wuFw
OOd8ft/vV9lgMTUKBQIBtbXI7h4gWoKQpvFA7txh/EnV353ZiIO29vLK5CaN
JkbRvWqMw9RRf/oMTaO3ku2QeGNQMWdzReqLcFfMYy0VxcCZoErK+7TY3ET0
EUT+7lLXy0IMbBDgIiybRrs+r1F4cIvGKBahVn/hukpBoV1CiB/goq/EYDNo
MM7hFmBJc97+7fYhLNYRLUDYfjY4/KwAHTMEGIWh7PkfL76o8buRGIyAulDT
c0msxipirzICoTa3YLJChSME5wnDtKRnItWejwJOYWB64z7DUyX6SDzmHchq
PL8TbB62kufWtyCTFhz/Jc9DLamDmodkpi6rzqPAZYJn30DZtbrWZnku/u/v
NQxeyflkdeZgNddXCG5kpE24N5vvJwjj+VF0OeR8H7NgtJxI0TIZ3uTyv4LN
c6fdjx5K+bwB0PcO2xQ6CZ9vGtjyP039ITGfB+GYc6xovWE/cuOYKQAm+lgk
zEKa8+uHlnHb17/6PXif8+eD6qstgb4BEe7m/EyAKvi+jU7u4Oc/hxq1s/3O
qUx+3ii41txm85CQ53vBbzkZ8STScI/jPYHVQZM4oyMFndz/EdgekpY52XVA
7v0DSK+Yi3Fbkr/vh1uzjiqlneXPXdC5byfSRwLwD66YTr4=
                "]]}, {
               Hue[0.1421359549995791, 0.6, 0.6], 
               Directive[
                Thickness[Large], 
                Dashing[Large]], 
               Line[CompressedData["
1:eJwtkG9Ik1EYxTctUbNmYyqWzm22Nte2io2CYNQ3JQl0CwlcBJVmsdIxInFh
VrM0loUm5KphbRp9cBUIzX89j265Niumm21jwVJSkDLB2liElfftPXC5XO69
v+ecwz9Zr65JYTAY4vVFdksPUQSehweqM0R7MCHW3pmIh+G7sknPtu5GtZPb
+rUyDNoHirSVZTk6SueaOI4Q5A7Pt91SyXFTyNagygxBR/P4stcswzO1RB9h
TJO0dkal6IoT4Cx0ZZsbvSVSLFqnObmzUPF3Na3q0i40cggxCC8O4ZNitwTD
FC4A0vbyH4JsCSoVRAFY6o8ay6tL8O4EAc5As9/LeNQnxm+VxOA06BL5I7wV
EZYRe6XToG5T+Jb2i9BOcDY/GN0Hb+e07EQGJT+4+ZNFUx4hDpF4zg9w3bzP
cIAlRD153vAeIt2bg5aqHSghdYjfwciWgjWxtRjnCX7OB3Czc4NwUYD/+/PC
lWsGpl8uQA3V11vQ/Wy3nW3k0/14YLXrc0Tm4tF9vIGk3aRVs3h4mcrvhov6
p6fTh7l0XhcorzpTfccK6XzjkIxlJlm/t9N5EHRr8cJPvduQGud8Da500STz
cD5KKb+jEDzePZaXyMOHlL8hWIyZFk7ZczGL8vMKzp1gF4xqcuj5g6AyeKaO
pnDoeS+h/0bg/IUBNs13wJEv9T2uiq14n+I9g7rHqTULPha2UP/tIPyV0NRB
FiL13gq9rbUxizqDvr8HUfbMoI+/kT6bQLa3o0zL/AP/ABFqUQY=
                "]]}, {
               Hue[0.37820393249936934`, 0.6, 0.6], 
               Directive[
                Thickness[Large], 
                Dashing[Large]], 
               Line[CompressedData["
1:eJwtkF9Ik1EYxpdkoXVhpiwa+/NNp9O5ubn1n5HdZFBQc7gw11ZhRUboYMHw
DwhtWEal1YVbmsmGIIxZYvQNovfdXJmly23ZN4mKKQSrBL2YWheR5+t74HA4
nHN+7/M81IXm2otZPB5PvrHI7nETzUPOmYNHLHVVuCo33wtnkhBsKLtauKkK
a2mR66chCV/j9jtOvwYDNanWggADy4b1taHTGtzGeFv0uQw8bQ8p67I0ePkS
0SeoDr+x9/jVOJEhwDmg7k4z1SY1ijdotGgOkvsHPoz+rcS2AkL8CPf3XD/b
e7ISkywuAR76RHHeoAp1WqIEmLb2SaklJfaECTAOzcYGV+SAEn8ZiMEY5NxK
C7JdFXiM2KuJwe+x7qU/UQX6CM47C0/4NPOer0Aeq1m4fW3zzIi1HIMkHh2F
1Nr3L7HhMrSR5y0zcN4XUnYvybGc1CGfho5vOq1YJ8cFgk+9g+e+K9mp1lL8
398UrEQdJkm4BI1sX2/BEgt0KXJLuH4mYf1BYvG4Ucb18Rpk8fzl8EAxtrP5
I2DslUUn00Vc3gk4J7S4nPuKuHwhsKs7fuR3Sbk8CHuVRxcdSQrZcfQriASo
Rq+CwgrW70vwqIRN1k4J9rP+gsBIbZpBvxi3s35egGpH1k26XsTNH4fhxI1x
7RYhN+8ZrAimIodGBRw/AHTw81Djqd3Yx/JGQGBmJM6FXdjJ/vdBm556pK/n
I7LvH4PN4hrL9Bdy9w/BvWp2lzp2cmcn6K3ppvnDefgPds1Nog==
                
                "]]}}}, {}}, {{{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               GrayLevel[0], 
               Thickness[Large], 
               Dashing[Large], 
               Line[CompressedData["
1:eJwtkXtI01EUx9dASV3YaoXKck1tTdso6AEJNixrs1WkK8oaluHK/qg9JAIn
IT0oIVkPHxmbLhzpxEaj19TmOXtIU7S29iwRWaYEWSSxikJo97cduFwu99zP
+X6/l3tGWamg02g0fnyR/WEnqQ8wwL0mGlgjxF98uc4Zi8DoZLYqpUyAlbbc
G18rIlDvY9jZqk1oEUcbWJYwlLYZ3O7OIswI96hK0sMguDfjCWIhnjtLKgTZ
oeLU4jk+umIEGATdrC7zeyofOXGaLTcI4qshB523EbUsQgxAgdVrMezmYYTC
+cEretH8R74Bt20l5Qe9I22H/FIB3nES4HuolrVUc2/n40IFEeiDfo9GZH6U
hxIiT+yDHEWr9uRLLpoIrscLFx8f2GwcX480qrzwtNn1c9jOwUFiz/YWykzl
89/m16GatKsmIbK4ytDCZGMRiYM/AcfUwx17duXgJ4KPjoN9X2O070IWJvIb
A8bskSyJcS3KqLw88Be35BlDrGQ+b2D/dN1nPnN1Mo9R0FYx2k8cZmIj5d8N
hmmpUl2YmfTrgoNtUqPbnpH054B611BAdmp50g/CTSk7TbMyBalxthGIlVzp
uxVYhgJK72uQlD8Zq6lZAj2lbxBCp3tL86t+A4PS8wr6f9hpwt5FSMx/DkdV
C7wVH79AYp4VmNp3E111M5DgW2Bn97Nav9ULDyieGczbp5TOQ0PQRL03Qbda
cVdzuQOQ6u+CKWET/f7S8eR9K+g5e2vb/wVGEufr0JAe/4a58/b/rjFReQ==

                "]]}}}, {}}}, {Epilog -> {
             Text[
              Style["A", Bold, 14, FontFamily -> "Helvetica"], 
              Scaled[{0.05, 0.95}]], {
              Arrowheads[{{0.02, 0, {
                  Graphics[
                   Circle[{1, -1}, 1, {Rational[1, 2] Pi, Pi}]], -1}}, {
                0.02, 1, {
                  Graphics[{
                    Circle[{-1, 1}, 1, {Rational[-1, 2] Pi, 0}], 
                    Inset[
                    Style["", Larger], {0, 2}]}], 1}}}], 
              
              Arrow[{{-0.125, -Log[1000000]}, {-0.125, 
                 Rational[1, 2] (-Log[5000] - Log[1000000])}}], 
              Arrowheads[{{0.02, 0, {
                  Graphics[
                   Circle[{1, 1}, 1, {Pi, Rational[3, 2] Pi}]], -1}}, {
                0.02, 1, {
                  Graphics[
                   Circle[{-1, -1}, 1, {0, Rational[1, 2] Pi}]], 1}}}], 
              
              Arrow[{{-0.125, 
                 Rational[1, 2] (-Log[5000] - Log[1000000])}, {-0.125, -
                 Log[5000]}}]}}, 
           FrameLabel -> {{Null, "Probability of rescue"}, {
             "Wildtype growth rate", Null}}, 
           Ticks -> {Automatic, {{-13.815510557964274`, 
               Superscript[10, -6]}, {-11.512925464970229`, 
               Superscript[10, -5]}, {-9.210340371976182, 
               Superscript[10, -4]}, {-6.907755278982137, 
              0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 
              0.1}, {0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
                Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
               
                Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
               
                Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 
               0.}, {
                Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
               
                Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 
               0.}, {
                Thickness[0.001]}}}}, GridLines -> {None, None}, 
           FrameTicks -> {{None, {{-13.815510557964274`, 
                Superscript[10, -6]}, {-11.512925464970229`, 
                Superscript[10, -5]}, {-9.210340371976182, 
                Superscript[10, -4]}, {-6.907755278982137, 
               0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 
               0.1}, {0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
                 Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
                
                 Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
                 Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
                 Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
                 Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 
                0.}, {
                 Thickness[0.001]}}}}, {True, False}}, 
           AxesOrigin -> {-0.4, -14.508657738524219`}, 
           PlotRange -> {{-0.4, 0}, {-14.508657738524219`, 0.}}, AspectRatio -> 
           GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0, 0}, 
           CoordinatesToolOptions -> {"DisplayFunction" -> ({
               Part[#, 1], 
               Exp[
                Part[#, 2]]}& ), "CopiedValueFunction" -> ({
               Part[#, 1], 
               Exp[
                Part[#, 2]]}& )}, Frame -> {True, False, False, True}, 
           FrameLabel -> {
            "Wildtype growth rate", Null, Null, "Probability of rescue"}, 
           FrameTicks -> {True, False, False, True}, LabelStyle -> 
           Directive[12, FontFamily -> "Helvetica"], Method -> {}, 
           PlotRange -> {{-0.4, 0}, {-14.508657738524219`, 0.}}, 
           PlotRangeClipping -> True, 
           PlotRangePadding -> {{None, None}, {None, None}}}], {
          Placed[
           Unevaluated[
            LineLegend[{
              Directive[
               Thickness[Large], 
               GrayLevel[0.5]], 
              Directive[
               Thickness[Large], 
               GrayLevel[0.5], 
               Dashing[Medium]]}, {
              Style[
              "\!\(\*\nStyleBox[\"n\",\nFontSlant->\"Italic\"]\)=2", 12, 
               FontFamily -> "Helvetica"], 
              Style[
              "\!\(\*\nStyleBox[\"n\",\nFontSlant->\"Italic\"]\)=20", 12, 
               FontFamily -> "Helvetica"]}, LegendLayout -> "Column"]], 
           Scaled[{
             Rational[1, 10], 
             Rational[7, 10]}], Identity]}]& ],
       AutoDelete->True,
       Editable->True,
       SelectWithContents->False,
       Selectable->True],
      TraditionalForm], {189., -125}, {Center, Center}, {360., 360}], InsetBox[
     FormBox[
      TagBox[
       FormBox[
        GraphicsBox[{{{{}, {{}, {}, 
             {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8HntjftuX14plHftlzX19c
YMt1fD9D16yWU2xcDoe/asT0Hzq6f+uvBm3lzUIO1SLr3B9WHdl/1CfmyPw2
cQcTYxA4vH9lzfd+viBphzeBIAMP7ufqZTpS90vWYQnQtOuLD+zv45CUdi6X
d9gJsm7Hvv0HzGMm7rgo76AFNP2rxp79b5dpb6lWlneAuG/n/nN3H1/1mizr
AHHP9v0TJ03U/Bkg7VADtn/Lft0EJ5F3EySg9m3cX3RF6uLGdlEHsHd2rNs/
7/v+bX9ShRzmgM1bub98v1Oz+2o+qP4l+32EnGQN33NA1c/b78c3l1XsGLND
A1h+yn7JEz/Twqf9s4fwW/av3f+MkUvwuz0s3EJPlqjXfvlgXwCRt58TZ3v2
g8cL+wqIfnujPT+79r1/YA813z77/6rrH/9eg8ovsTeblnThT/Q5+xkQ99kH
8Ml8qqw+DFW/zv77xPPcep477KH+s7/4WytWJnGtPdT/9qe1GN+8slpozwEJ
H/vDJ2d/mT55MtS8nfYLYhU/3G9ttdeAhK994ILGaYb3y6Dm77Nfnc8w+21Z
uj00fuynfn/Btc80HGrfQXul6q+Kh6Xc7KHxaz+t3qtS2dbEvgoS//Z6C9Lz
PE4q2h+CpA97x9nKsWZfeO25IOnH/u3C4m4v+R920PRlv2ajx8vYrkd20PRn
/2tHxz8vldN2j8AGnrJ/2yV64MT9TXYQ956xz96alDTn/gw7sPMKztorfPmo
/u9HnR3E/efs17BekPqomWQHiY0L9keZPxvM/e9sBwB2hmek
               
               "]]}}, {}}, {{}, {{}, {}, 
             {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
              LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsf8d8qO61kPbAcKfYv87XMqtS83I
YYdc6+vAHfPsNz4KajBeZQiVX2J/20ai6cEJXYdZM0Fgpf1XTdnDp16rQdWv
s1e6HP5esVLB4U0gSGSjvY9dc/78eDGo/i32QcxKs84+43Hgur64wJZru/3D
lOiLjZcYoebttF/zeHWSCsdXe82Y/kNfNfbY/ylgDtl47Lk9xPx99nouF/zv
HbppvwSo+/riA/axx00K7Q6csofYd9D+XVbsuu1zdtkbg8Fh+/szfbayRqy0
h9h/xP5ce2KMmOh0+8NfNYA2HLWvs3x4uEakxR7inuP2py9kW/CuLLAPAlt4
wt7W9eSTFUFR9hD3nbQ35ajjennI2f5hFcjAU/Yy2+dP3aukA3XvGftJmWuf
9nwSsi8EOa/grL3MjgTHOcI/7CDuP2ffqLfyaPjxO3aQWLhg3/x92gdNhQN2
AGklv0Y=
               "]]}, 
             {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
              LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsWfLV1kiv17QAcKfYm8QvFbFMEfG
YYdc6+vAHfPsV2nU3a6OU4TKL7HX/byhcsddJYdZM0FgpX3/N3vn13LKUPXr
7D3Y7/++V6nk8CYQJLLRfk/0oyfK5jD9W+wzP1xac0hZ3oHr+uICW67t9lWv
wpa7FElDzdtp/2wH53P9ReIOmjH9h75q7LF/IpZx4O4LYaj5++zXZbEIZWcL
OCwB6r6++IC9Vku8q1gzF9S+g/Zv90/jbfzA4mAMBoftDbKDnu/SYIDaf8Q+
vNJr48mgH/aHv2oAbThq/81z28+M8x/tIe45bt9YH3rllc9L+yCwhSfsC4xe
s6+Jf2gPcd9Jeyv7BeG7/lyzf1gFMvCU/SSL1R1LjM7aQ9x7xt5tfU0Lw76D
9oUg5xWctWf5u2F95MQt9hD3n7NvP3Hwmei6ZfaQWLhgLzT9+FWBXdPtARUx
vrc=
               "]]}}, {}}, {{}, {{}, {}, 
             {GrayLevel[0.5], Thickness[Large], Dashing[Large], 
              LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8Hnth/aLN8Ro8fuwP39cUF
tlzH92eeya+aZSTqcPirRkz/oaP7hS5UqzOUyzhUi6xzf1h1ZP+Ta7ZhMtsV
HEyMQeDw/qfmnT/4pZQc3gSCDDy4P+RPxrXVDUoOS4CmXV98YP+VFlO2v4JK
DjtB1u3Yt/9C59wtc34rOGgBTf+qsWe/CN+uX/dvyTlA3LdzP4/2Dbl+bWmo
e7bv33N+h2m+jbhDDdj+Lfulll3XPxAkDLVv434Th7cmz9z4HcDe2bFuf6XP
nx9JSzkc5oDNW7mft/6PLPMrJqj+JfsDz0x+GeD2xx6ift7+w1UV679M+WLf
AJafsl93FjP/Y523UH7L/gcTLkdtVnhiDws3RaaLZXmst+0LIPL2UzT5gyct
vmhfAdFv729W6P4t8RjMfHuJnomLMqfthsovsZcPvjijuWGD/QyI++wTVjSy
LVVdDFW/zv4HL4+XcftUe6j/7CvW8glJ5rfbQ/1vv0hxntLe1RX2HJDwsV9Z
lPj1kHgm1Lyd9p/VmH2vLYiw14CEr72yuGz3C293qPn77HlipZ+sMDW1h8aP
vUXcinOn+pSg9h20z5wk8i5ek98eGr/2R5Zp1n7k/2lXBYl/+xX/J50Udnts
dwiSPuyz7d9EmnmdseOCpB/7Ha3n3mQc3WwHTV/2+QdM51Y4zrKDpj/7uY5h
NfNaG+wegQ08Ze/mY9PPuTzZDuLeM/b2aQvEZdjd7MDOKzgLDOdtAdsM1O0g
7j9nv9N9SVrGTTY7SGxcsOdYkV988s8TWwDc2Fen
               
               "]]}}, {}}, {{}, {{}, {}, 
             {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
              Dashing[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsU/S2i+1YImhA4Q/xb41qe+aWrSp
ww651teBO+bZ+7X8j3lzzwgqv8S+ntOA/cVlHYdZM0FgpX2O1CJFNz4VqPp1
9lZBwa9LGaQc3gSCRDbaF379x/zkGD9U/xZ76+jI3q/ZTA5c1xcX2HJtt/+a
VHB+TdgXe4h5O+2Dzx3caZj71F4zpv/QV4099gd2qxxf33/VHmL+PvsJIZNi
HXYfsV8C1H198QH7wGNb6xi4N9tD7Dto3891WCl68wJ7YzA4bH8/3XU998du
e4j9R+wjHsd+fO1SZn/4qwbQhqP26/sE3qY+SrCHuOe4fcT/hz2zAjzsg8AW
nrCX5TDt451hAHXfSfvfPfevFGaL2j+sAhl4yt5C4VuWmugvO4h7z9ir/JM7
9PjBXbtCkPMKztpH5jwy2cFzwA7i/nP2/WdLHebKLrCDxMIFe4d9gi7WSnV2
AASCvUE=
               "]]}, 
             {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
              Dashing[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsc9+K3RL7JW0A4Q/xV7eksVE4byK
ww651teBO+bZq3T9ujCzWx0qv8TeiTV238wl6g6zZoLASntbeffk6fJqUPXr
7Ne7BGQ82qrs8CYQJLLRntNx1ZbyFwpQ/VvsfyqdKAqVlnHgur64wJZru31e
77vI6dvFoObttK9kOlRX8VjQQTOm/9BXjT3272qaTzmVc0PN32e/R+751NM9
LA5LgLqvLz5gH+HnVrvy/V97iH0H7fu5DXq1DL7aG4PBYfvmibcbA4Tf2kPs
P2LvYbTTU8nzsf3hrxpAG47aM9xobni24oY9xD3H7ZV1g4U++JyzDwJbeMLe
rXHOfaVrB+0h7jtpn7JWZz6vwBb7h1UgA0/ZZ/u2XAhqWGoPce8Z+xwu3TC1
p1PtC0HOKzhrb6k18U6nQqs9xP3n7CfeWmkm4VxsD4mFC/Z/uyb6uXQn2AMA
YBu32g==
               "]]}}, {}}}, {InsetBox[
            TagBox[GridBox[{
               {
                
                TemplateBox[{
                 StyleBox[
                  "\"1-step\"", StripOnInput -> False, FontFamily -> 
                   "Helvetica", FontSize -> 12],StyleBox[
                  "\"2-step\"", StripOnInput -> False, FontFamily -> 
                   "Helvetica", FontSize -> 12]},
                 "LineLegend",
                 DisplayFunction->(StyleBox[
                   StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                   FontFamily -> "Times"}, Background -> Automatic, 
                   StripOnInput -> False]& ),
                 Editable->True,
                 InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.24720000000000014`", ",", "0.24`", ",", 
                    "0.6`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{"0.6`", ",", "0.24`", ",", 
                    "0.4428931686004542`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
                    "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                    RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], 
                    "]"}]& )]},
               {
                
                TemplateBox[{
                 StyleBox[
                  "\"established\"", StripOnInput -> False, FontFamily -> 
                   "Helvetica", FontSize -> 12]},
                 "LineLegend",
                 DisplayFunction->(StyleBox[
                   StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                   FontFamily -> "Times"}, Background -> Automatic, 
                   StripOnInput -> False]& ),
                 Editable->True,
                 InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}]}], "]"}], "}"}], 
                    ",", 
                    RowBox[{"{", #, "}"}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                    RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]}
              },
              AutoDelete->False,
              GridBoxAlignment->{"Columns" -> {{Left}}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
              GridBoxSpacings->{"Columns" -> {{0}}}],
             "Grid"], NCache[
            Scaled[{0.1875, Rational[1, 2]}], Scaled[{0.1875, 0.5}]], 
            ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm], InsetBox[
            
            TemplateBox[{
             StyleBox[
              "\"\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)=2\"", StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 12],
              StyleBox[
              "\"\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)=20\"", StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 12]},
             
             "LineLegend",
             DisplayFunction->(StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
               False]& ),
             Editable->True,
             InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}],
                   ",", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                  RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                  RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )], 
            NCache[Scaled[{Rational[7, 8], Rational[3, 10]}], 
             Scaled[{0.875, 0.3}]], ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm]}},
         AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
         Axes->True,
         AxesLabel->{None, None},
         AxesOrigin->{0., 0.},
         Epilog->{
           InsetBox[
            FormBox[
             StyleBox[
             "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=-0.2\"", 12, FontFamily -> 
              "Helvetica", StripOnInput -> False], TraditionalForm], 
            NCache[
             Scaled[{
               Rational[7, 8], 
               Rational[3, 4]}], 
             Scaled[{0.875, 0.75}]]], 
           InsetBox[
            FormBox[
             StyleBox[
             "\"B\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
              False], TraditionalForm], 
            Scaled[{0.05, 0.95}]]},
         Frame->{True, False, False, False},
         FrameTicksStyle->{
          FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
         LabelStyle->Directive[12, FontFamily -> "Helvetica"],
         Method->{},
         PlotRange->{{-0.3, 0.25}, {0, 40}},
         PlotRangeClipping->True,
         PlotRangePadding->{Automatic, Automatic}],
        TraditionalForm],
       InterpretTemplate[Legended[
         Graphics[{{{}, {{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                Thickness[Large], 
                GrayLevel[0.5]], 
               Line[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8HntjftuX14plHftlzX19c
YMt1fD9D16yWU2xcDoe/asT0Hzq6f+uvBm3lzUIO1SLr3B9WHdl/1CfmyPw2
cQcTYxA4vH9lzfd+viBphzeBIAMP7ufqZTpS90vWYQnQtOuLD+zv45CUdi6X
d9gJsm7Hvv0HzGMm7rgo76AFNP2rxp79b5dpb6lWlneAuG/n/nN3H1/1mizr
AHHP9v0TJ03U/Bkg7VADtn/Lft0EJ5F3EySg9m3cX3RF6uLGdlEHsHd2rNs/
7/v+bX9ShRzmgM1bub98v1Oz+2o+qP4l+32EnGQN33NA1c/b78c3l1XsGLND
A1h+yn7JEz/Twqf9s4fwW/av3f+MkUvwuz0s3EJPlqjXfvlgXwCRt58TZ3v2
g8cL+wqIfnujPT+79r1/YA813z77/6rrH/9eg8ovsTeblnThT/Q5+xkQ99kH
8Ml8qqw+DFW/zv77xPPcep477KH+s7/4WytWJnGtPdT/9qe1GN+8slpozwEJ
H/vDJ2d/mT55MtS8nfYLYhU/3G9ttdeAhK994ILGaYb3y6Dm77Nfnc8w+21Z
uj00fuynfn/Btc80HGrfQXul6q+Kh6Xc7KHxaz+t3qtS2dbEvgoS//Z6C9Lz
PE4q2h+CpA97x9nKsWZfeO25IOnH/u3C4m4v+R920PRlv2ajx8vYrkd20PRn
/2tHxz8vldN2j8AGnrJ/2yV64MT9TXYQ956xz96alDTn/gw7sPMKztorfPmo
/u9HnR3E/efs17BekPqomWQHiY0L9keZPxvM/e9sBwB2hmek
                
                "]]}}}, {}}, {{}, {{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                RGBColor[0.24720000000000014`, 0.24, 0.6], 
                Thickness[Large]], 
               Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsf8d8qO61kPbAcKfYv87XMqtS83I
YYdc6+vAHfPsNz4KajBeZQiVX2J/20ai6cEJXYdZM0Fgpf1XTdnDp16rQdWv
s1e6HP5esVLB4U0gSGSjvY9dc/78eDGo/i32QcxKs84+43Hgur64wJZru/3D
lOiLjZcYoebttF/zeHWSCsdXe82Y/kNfNfbY/ylgDtl47Lk9xPx99nouF/zv
HbppvwSo+/riA/axx00K7Q6csofYd9D+XVbsuu1zdtkbg8Fh+/szfbayRqy0
h9h/xP5ce2KMmOh0+8NfNYA2HLWvs3x4uEakxR7inuP2py9kW/CuLLAPAlt4
wt7W9eSTFUFR9hD3nbQ35ajjennI2f5hFcjAU/Yy2+dP3aukA3XvGftJmWuf
9nwSsi8EOa/grL3MjgTHOcI/7CDuP2ffqLfyaPjxO3aQWLhg3/x92gdNhQN2
AGklv0Y=
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                RGBColor[0.6, 0.24, 0.4428931686004542], 
                Thickness[Large]], 
               Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsWfLV1kiv17QAcKfYm8QvFbFMEfG
YYdc6+vAHfPsV2nU3a6OU4TKL7HX/byhcsddJYdZM0FgpX3/N3vn13LKUPXr
7D3Y7/++V6nk8CYQJLLRfk/0oyfK5jD9W+wzP1xac0hZ3oHr+uICW67t9lWv
wpa7FElDzdtp/2wH53P9ReIOmjH9h75q7LF/IpZx4O4LYaj5++zXZbEIZWcL
OCwB6r6++IC9Vku8q1gzF9S+g/Zv90/jbfzA4mAMBoftDbKDnu/SYIDaf8Q+
vNJr48mgH/aHv2oAbThq/81z28+M8x/tIe45bt9YH3rllc9L+yCwhSfsC4xe
s6+Jf2gPcd9Jeyv7BeG7/lyzf1gFMvCU/SSL1R1LjM7aQ9x7xt5tfU0Lw76D
9oUg5xWctWf5u2F95MQt9hD3n7NvP3Hwmei6ZfaQWLhgLzT9+FWBXdPtARUx
vrc=
                "]]}}}, {}}, {{}, {{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                Thickness[Large], 
                GrayLevel[0.5], 
                Dashing[Large]], 
               Line[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8Hnth/aLN8Ro8fuwP39cUF
tlzH92eeya+aZSTqcPirRkz/oaP7hS5UqzOUyzhUi6xzf1h1ZP+Ta7ZhMtsV
HEyMQeDw/qfmnT/4pZQc3gSCDDy4P+RPxrXVDUoOS4CmXV98YP+VFlO2v4JK
DjtB1u3Yt/9C59wtc34rOGgBTf+qsWe/CN+uX/dvyTlA3LdzP4/2Dbl+bWmo
e7bv33N+h2m+jbhDDdj+Lfulll3XPxAkDLVv434Th7cmz9z4HcDe2bFuf6XP
nx9JSzkc5oDNW7mft/6PLPMrJqj+JfsDz0x+GeD2xx6ift7+w1UV679M+WLf
AJafsl93FjP/Y523UH7L/gcTLkdtVnhiDws3RaaLZXmst+0LIPL2UzT5gyct
vmhfAdFv729W6P4t8RjMfHuJnomLMqfthsovsZcPvjijuWGD/QyI++wTVjSy
LVVdDFW/zv4HL4+XcftUe6j/7CvW8glJ5rfbQ/1vv0hxntLe1RX2HJDwsV9Z
lPj1kHgm1Lyd9p/VmH2vLYiw14CEr72yuGz3C293qPn77HlipZ+sMDW1h8aP
vUXcinOn+pSg9h20z5wk8i5ek98eGr/2R5Zp1n7k/2lXBYl/+xX/J50Udnts
dwiSPuyz7d9EmnmdseOCpB/7Ha3n3mQc3WwHTV/2+QdM51Y4zrKDpj/7uY5h
NfNaG+wegQ08Ze/mY9PPuTzZDuLeM/b2aQvEZdjd7MDOKzgLDOdtAdsM1O0g
7j9nv9N9SVrGTTY7SGxcsOdYkV988s8TWwDc2Fen
                
                "]]}}}, {}}, {{}, {{{}, {}, {
               Hue[0.67, 0.6, 0.6], 
               Directive[
                RGBColor[0.24720000000000014`, 0.24, 0.6], 
                Thickness[Large], 
                Dashing[Large]], 
               Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsU/S2i+1YImhA4Q/xb41qe+aWrSp
ww651teBO+bZ+7X8j3lzzwgqv8S+ntOA/cVlHYdZM0FgpX2O1CJFNz4VqPp1
9lZBwa9LGaQc3gSCRDbaF379x/zkGD9U/xZ76+jI3q/ZTA5c1xcX2HJtt/+a
VHB+TdgXe4h5O+2Dzx3caZj71F4zpv/QV4099gd2qxxf33/VHmL+PvsJIZNi
HXYfsV8C1H198QH7wGNb6xi4N9tD7Dto3891WCl68wJ7YzA4bH8/3XU998du
e4j9R+wjHsd+fO1SZn/4qwbQhqP26/sE3qY+SrCHuOe4fcT/hz2zAjzsg8AW
nrCX5TDt451hAHXfSfvfPfevFGaL2j+sAhl4yt5C4VuWmugvO4h7z9ir/JM7
9PjBXbtCkPMKztpH5jwy2cFzwA7i/nP2/WdLHebKLrCDxMIFe4d9gi7WSnV2
AASCvUE=
                "]]}, {
               Hue[0.9060679774997897, 0.6, 0.6], 
               Directive[
                RGBColor[0.6, 0.24, 0.4428931686004542], 
                Thickness[Large], 
                Dashing[Large]], 
               Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsc9+K3RL7JW0A4Q/xV7eksVE4byK
ww651teBO+bZq3T9ujCzWx0qv8TeiTV238wl6g6zZoLASntbeffk6fJqUPXr
7Ne7BGQ82qrs8CYQJLLRntNx1ZbyFwpQ/VvsfyqdKAqVlnHgur64wJZru31e
77vI6dvFoObttK9kOlRX8VjQQTOm/9BXjT3272qaTzmVc0PN32e/R+751NM9
LA5LgLqvLz5gH+HnVrvy/V97iH0H7fu5DXq1DL7aG4PBYfvmibcbA4Tf2kPs
P2LvYbTTU8nzsf3hrxpAG47aM9xobni24oY9xD3H7ZV1g4U++JyzDwJbeMLe
rXHOfaVrB+0h7jtpn7JWZz6vwBb7h1UgA0/ZZ/u2XAhqWGoPce8Z+xwu3TC1
p1PtC0HOKzhrb6k18U6nQqs9xP3n7CfeWmkm4VxsD4mFC/Z/uyb6uXQn2AMA
YBu32g==
                "]]}}}, {}}}, {
          PlotRange -> {{-0.3, 0.25}, {0, 40}}, 
           Frame -> {True, False, False, False}, LabelStyle -> 
           Directive[12, FontFamily -> "Helvetica"], 
           FrameTicksStyle -> {
            FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, 
           Epilog -> {
             Text[
              Style[
              "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=-0.2", 12, FontFamily -> "Helvetica"], 
              Scaled[{
                Rational[7, 8], 
                Rational[3, 4]}]], 
             Text[
              Style["B", 14, Bold, FontFamily -> "Helvetica"], 
              Scaled[{0.05, 0.95}]]}, AxesLabel -> {None, None}, AspectRatio -> 
           GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0., 0.}, 
           Method -> {}, PlotRange -> {All, All}, PlotRangeClipping -> True, 
           PlotRangePadding -> {Automatic, Automatic}}], {
          Placed[
           Unevaluated[
            LineLegend[{
              Directive[
               Thickness[Large], 
               GrayLevel[0]], 
              Directive[
               Thickness[Large], 
               GrayLevel[0], 
               Dashing[Medium]]}, {
              Style[
              "\!\(\*\nStyleBox[\"n\",\nFontSlant->\"Italic\"]\)=2", 12, 
               FontFamily -> "Helvetica"], 
              Style[
              "\!\(\*\nStyleBox[\"n\",\nFontSlant->\"Italic\"]\)=20", 12, 
               FontFamily -> "Helvetica"]}, LegendLayout -> "Column", 
             LegendMarkers -> False]], 
           Scaled[{
             Rational[7, 8], 
             Rational[3, 10]}], Identity]}]& ],
       AutoDelete->True,
       Editable->True,
       SelectWithContents->False,
       Selectable->True],
      TraditionalForm], {189., -375}, {Center, Center}, {360., 360}], InsetBox[
     FormBox[
      TagBox[
       FormBox[
        GraphicsBox[{{{{}, {}, 
            {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxFxwk01Hsfx3Ej1xJSRJZQIxpky1W66f/9J0TiEqFU5MoIoaxlhKLS4JKS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              "]]}, 
            {GrayLevel[0.5], Thickness[Large], Dashing[Large], 
             LineBox[CompressedData["
1:eJxFxwk01PsfxnEkdCWyjCxXzLXvslyK3+dHKa6d0pSWq8VUJMoeslayNCiU
NFlHSkaDJHwHg8ggKrqFtOCSpTSWbLf/Of/Dc877POelcOyc80keLi6u3F/9
75VG06X19bsR1/83YZsnJcy35soS+pax3q5V/+XfQsgNX7MP14KoWOvLVfvf
/d6ZYtG56r5G/giBIvaqy041t5xzXPM1wStiPTNtqzZ24qPl71zzph+NUxtH
X6z6S1rsdj/KmlPe87Zb9LWumpSttkE0dM2/e9jvGpRe80f1C5foT1tWXTiZ
XnWJ1IJ4B3jpkg2fwLusmmM/+xyVfLz7NlZsDvSDB3Xl0p6jEw/eVMW38OC1
PBq06u5mtGTG1XxJWxiX10uzFwhuRoZ7jRmuxqJ49FHuGRe5ZvShScjStVgc
H0r0yqI2NCFzLrupZA4Bt6ru2TV2qgnN3/OXuSkihReNWnw12tSECEU6BcRl
aXyj1KPUKEYjulSXMaNfK4t775Ha0U5qRCrtxsWzjnL4S/+Yj1LLLLTDg76u
s2IrTmzae5GdyUKH7Zhh1jHyuB9BSTzShIVKqId/3BVTwBs9OA8NehrQw6V0
Ou81BZzwpNFyxK8BRQepVumPKOBk/rT+TNEGdEVg8eaKNhGv3O8R6ECvR1G2
JoMuR4n4b4VGIuvs6xFFs5ytF0LE3eb47leM1SHzGPbl4ggifuJ2l45hfB1S
Jr8+7uRHxL1N71Yw1OuQjHq6YLwrEQ/qP222rZWJqBcoWpdViXhkhCGLfpqJ
kJuaWsCYAn6NyG2js4GJ7nyQvJd6TwFXjbuV6+aEkOneLElpawV8O1u3lESp
RaM21cWWQ/K43ebntfs6apD5J4Vhx2B5/Lbq1zwbmRqU1vX5M1VQHh8CkXhz
cjVySco8bqO9FY/wJu3XWqlCWd3pr3R3/I4zXoxM8upUookjZZr+3FJ4v3JP
ZavnE8SY1ciN7JbEBaIaIymFFUjyMtPdOZ+AHzbOEZMllqMXBeNZWfbi+NVU
yvvBI2WofVY+5JuqGP54IjyflslATX3Dtc8ERHH+fLc/9SUeI6p+bNHbp8K4
V/eb3m9HSpHhCFmRq0UI7+R2DqEX0pG61KjM62FBXLeGEuIW9AhdHXeKMiEJ
4PNSV2p6BYtRG9s0Xe8BH14fEMblSn2AqtYHTRaLrMdddM9cdmwqRGE5pC0O
4jz4Yrdd5PzfNERkapJ8n3LhBYF6oTkL+Yi0PKJOHVwGRxmJQJu0PMS0ofmG
+S3CfO2c7w/dXJSheyZwXv0n5Bx775X1Ihu5iPbgHrxzYMvHJO/2uIe29t2o
+b7CAcjc9Ez3z0xE4SI7Jx34Dhu+L++o18lAVq1lCXKpU9BtNVntonoTGZ7p
v2kzMA5Z1AGzL/IpyL6jV1Ho3Si0f6WGjW9LQq57RKbVCSNw7HbEJRHFq0gq
kuFtmvgFZva4R+pLRKFKpROxnaafQGwsmq94YxB6k2W75K8wCH4J18SH+sjI
8Dp/V+y5fpiihvzTtUURVZ1c/95G7x0EGO94+uLgSZiPtTiwH+uFACFhx5QF
f9BaYcz4J78GEjDdB/IioMDd4x1VqRtmZoMyOTaXoa3MIHqR0wmpdL3XgtPx
EMIctGUvsCHDwJ9/M5sCFPVNYf2+rTBMcVK8cy8V2MnCvsiyGWr7eCuG6WkQ
sT29QcmIBWnqlXv0627BFckI177IOvAO9Hwb/vIO8Ex/uzgHtbCbJefZOkiF
EIXTC+dFquC6wOnl34KzIcGW5vzqZAUsPLJo1uXOhfqdYcE/9RhA3idLcY3L
A2tGf/NXMh26Fzik0M0FMOVx8BZ19gEccft4OiCFBouz4lbTPTQYrWoP8RG7
D9Rxw9Qlyzzwl34Wf+ZGEYSldZ7g6GYDVwjtzgmJhzA1nPPcWywL4t+mFh9J
Kwax4MAk59gMIJhE1JIkS+AnWSVwO/UGONpWkNVs6UBgG0Z42iQDIVTTp2Bj
KQw49rJUxxMgp1finjqzFC5wA6fd8ypoGa50PLrwGD6qFy7+S4mByuSRlW0q
DJjUm7ibtzsSdk281HnyDwMudWxWPDQdCp1/PTu6I6kM+tYFbPipFwSHaHnX
kXk5rGxTntPU8IORdUloJ6cclq4rKJWyfODC34GTzYUV4H5lM0mxwxMUgtNM
Qz2fQPVx9pdN2R7QkVwep6tdCc4lr5Kk3Y5BWNGrN5+nKiGq6Yaycslh0GiY
/uMW4ynkxC8lF3/dD2/fifraBVSBjXMevt3YBa780KvlNnkGK/pRj3Y224Oh
kJNgxcIzkB4wk/9x3Qo+KfmQztRWQ67I+SWVuJ3g6snDVvKrAaPwjrMjfgCt
9Bvmg2q1oHN6fo8AbgLYjHLFnYFaeL987R+OgQE83vFUnXQTQYpIiZvMVl1I
ZeZ3xCkxwZ1rIVkkXw3sPk3EkSOYEG/RK2u9TxH4+Yx3Wb5jgl/sAyN5UXmo
U41cJhrVQShTqJHmLAUJaiebMzLqIMAOJ7uHigFJ3ZqyaaEOTnBYX+8PCMEf
GloHYg7XA1Nuvcn1Dj6Y0NhM/InqIVj+pPHZA9zwVJMzeo7YAJ6swaw/rX9i
MVpvGV9iGmDs/HkH/dfTmKN2Tajb8C/bkw9ZtI9jMjrZli+tWRDabVsxYDeE
affHyYcWsWCkws5qqvwDZp54fkFZsBG0kcY471QvttfU7c1Lz0b4d5L3A/NK
F0Ye21ka2tYIJkFHk/Z4vcBCbmsmqGg1wXDLwdIUAxaWaC1B7kpsAiTLExuV
X4Pdm1syD5togjEV57uptHKMQRuSVXVohu/To4Tw8BJMbfxqvOv9Zjhm1vDq
lB0No27T+Bmz7jno1+83ddDMxiSC2KcYh5+D5ChP5IDhLSy+5lzP4JNf3k4g
Tp9NwbjXie4WEW2BLWbErYGvr2GBVmVlmFcLcJd1G2n5RWPjia5/nG1qAUJb
Eu0UIRQ73j2XnCnfCj5OKZFhun7Y6Iyh8LGoVqDdsINZghd2XvpCgurnVsjY
uGvunM9xbN6MvmHS8gVE28hpnm84iEW4j18up/3yom+eloszxh+rzhu6oQ22
OXSyZDhWWFIhOdLCsw3M3u0+WDmEY4S2vGUBdhsI3d70RrPBCMuaHLzYoc0G
kZRv36UvamMeA9hlzlU28LY5VLz+rohpd2RSZD6xITrIe/lMgSw2Wzt329ys
HXrGyyV6wsQw5qN9+eT0dhgzFP/sfOw3LO7u45LEb+0QKwCHHBu4Meck4SqG
TQfcPFT1UKV11kwm3Iv1Nr8DMprSRWTok2afz7a0r6x0QOxLaYP2xc9m/wG/
Zsbs
              "]]}}, {{}, {}, 
            {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwV1Pc/lX8fwHEhI3tHihwNWyQVXe8LkRJJWZGkOBkhI5QdRUZHRJKVmSK7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              "]]}}, {{}, {}, 
            {Hue[0.67, 0.6, 0.6], Thickness[Large], Dashing[Large], 
             LineBox[CompressedData["
1:eJwVlvk/lH0bhokmkeyE8pQtSzKhlHJfN5XKlmzpEUq2ImVPWYZkSWQpWUJC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              "]]}}}, {InsetBox[
            TagBox[GridBox[{
               {
                
                TemplateBox[{
                 StyleBox[
                  "\"first-step\"", StripOnInput -> False, FontFamily -> 
                   "Helvetica", FontSize -> 12]},
                 "LineLegend",
                 DisplayFunction->(StyleBox[
                   StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                   FontFamily -> "Times"}, Background -> Automatic, 
                   StripOnInput -> False]& ),
                 Editable->True,
                 InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Hue", "[", 
                    RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], 
                    ",", 
                    RowBox[{"{", #, "}"}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                    "]"}]& )]},
               {
                
                TemplateBox[{
                 StyleBox[
                  "\"established\"", StripOnInput -> False, FontFamily -> 
                   "Helvetica", FontSize -> 12]},
                 "LineLegend",
                 DisplayFunction->(StyleBox[
                   StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                   FontFamily -> "Times"}, Background -> Automatic, 
                   StripOnInput -> False]& ),
                 Editable->True,
                 InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}], "}"}], 
                    ",", 
                    RowBox[{"{", #, "}"}], ",", 
                    RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                    "]"}]& )]}
              },
              AutoDelete->False,
              GridBoxAlignment->{"Columns" -> {{Left}}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
              GridBoxSpacings->{"Columns" -> {{0}}}],
             "Grid"], NCache[
            Scaled[{Rational[1, 8], 0.625}], Scaled[{0.125, 0.625}]], 
            ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm], InsetBox[
            
            TemplateBox[{
             StyleBox[
              "\"\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)=2\"", StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 12],
              StyleBox[
              "\"\\!\\(\\*\\nStyleBox[\\\"n\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)=20\"", StripOnInput -> False, FontFamily -> "Helvetica", FontSize -> 12]},
             
             "LineLegend",
             DisplayFunction->(StyleBox[
               StyleBox[
                PaneBox[
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"], Alignment -> Left, AppearanceElements -> None, 
                 ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                 "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
               FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
               False]& ),
             Editable->True,
             InterpretationFunction:>(RowBox[{"LineLegend", "[", 
                RowBox[{
                  RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}],
                   ",", 
                  RowBox[{"{", 
                    RowBox[{#, ",", #2}], "}"}], ",", 
                  RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
                "]"}]& )], NCache[
            Scaled[{Rational[7, 8], Rational[3, 10]}], Scaled[{0.875, 0.3}]], 
            ImageScaled[{0.5, 0.5}],
            BaseStyle->{FontSize -> Larger},
            FormatType->StandardForm]}},
         AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
         Axes->True,
         AxesLabel->{None, None},
         AxesOrigin->{0, 0},
         Epilog->{
           InsetBox[
            FormBox[
             StyleBox[
             "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=-0.2\"", 12, FontFamily -> 
              "Helvetica", StripOnInput -> False], TraditionalForm], 
            NCache[
             Scaled[{
               Rational[7, 8], 
               Rational[3, 4]}], 
             Scaled[{0.875, 0.75}]]], 
           InsetBox[
            FormBox[
             StyleBox[
             "\"C\"", 14, Bold, FontFamily -> "Helvetica", StripOnInput -> 
              False], TraditionalForm], 
            Scaled[{0.05, 0.95}]]},
         Frame->{True, False, False, False},
         FrameLabel->{
           FormBox["\"Growth rate\"", TraditionalForm]},
         FrameTicksStyle->{Automatic, Automatic, Automatic, Automatic},
         LabelStyle->Directive[12, FontFamily -> "Helvetica"],
         Method->{},
         PlotRange->{{-0.3, 0.25}, {0, 30}},
         PlotRangeClipping->True,
         PlotRangePadding->{
           Scaled[0.02], Automatic}],
        TraditionalForm],
       InterpretTemplate[Legended[
         Graphics[{{{{}, {}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               GrayLevel[0.5], 
               Thickness[Large]], 
              Line[CompressedData["
1:eJxFxwk01Hsfx3Ej1xJSRJZQIxpky1W66f/9J0TiEqFU5MoIoaxlhKLS4JKS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               "]]}, {
              Hue[0.9060679774997897, 0.6, 0.6], 
              Directive[
               GrayLevel[0.5], 
               Thickness[Large], 
               Dashing[Large]], 
              Line[CompressedData["
1:eJxFxwk01PsfxnEkdCWyjCxXzLXvslyK3+dHKa6d0pSWq8VUJMoeslayNCiU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               "]]}}}, {{{}, {}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               Thickness[Large]], 
              Line[CompressedData["
1:eJwV1Pc/lX8fwHEhI3tHihwNWyQVXe8LkRJJWZGkOBkhI5QdRUZHRJKVmSK7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               "]]}}}, {{{}, {}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               Thickness[Large], 
               Dashing[Large]], 
              Line[CompressedData["
1:eJwVlvk/lH0bhokmkeyE8pQtSzKhlHJfN5XKlmzpEUq2ImVPWYZkSWQpWUJC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               "]]}}}}, {
          Frame -> {True, False, False, False}, 
           FrameTicksStyle -> {Automatic, Automatic, Automatic, Automatic}, 
           FrameLabel -> {"Growth rate"}, 
           PlotRange -> {{-0.3, 0.25}, {0, 30}}, LabelStyle -> 
           Directive[12, FontFamily -> "Helvetica"], Epilog -> {
             Text[
              Style[
              "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=-0.2", 12, FontFamily -> "Helvetica"], 
              Scaled[{
                Rational[7, 8], 
                Rational[3, 4]}]], 
             Text[
              Style["C", 14, Bold, FontFamily -> "Helvetica"], 
              Scaled[{0.05, 0.95}]]}, AspectRatio -> GoldenRatio^(-1), Axes -> 
           True, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
           Method -> {}, PlotRange -> {{-0.3, 0.25}, {0, All}}, 
           PlotRangeClipping -> True, PlotRangePadding -> {
             Scaled[0.02], Automatic}}], {
          Placed[
           Unevaluated[
            LineLegend[{
              Directive[
               Thickness[Large], 
               GrayLevel[0]], 
              Directive[
               Thickness[Large], 
               GrayLevel[0], 
               Dashing[Medium]]}, {
              Style[
              "\!\(\*\nStyleBox[\"n\",\nFontSlant->\"Italic\"]\)=2", 12, 
               FontFamily -> "Helvetica"], 
              Style[
              "\!\(\*\nStyleBox[\"n\",\nFontSlant->\"Italic\"]\)=20", 12, 
               FontFamily -> "Helvetica"]}, LegendLayout -> "Column"]], 
           Scaled[{
             Rational[7, 8], 
             Rational[3, 10]}], Identity]}]& ],
       AutoDelete->True,
       Editable->True,
       SelectWithContents->False,
       Selectable->True],
      TraditionalForm], {189., -625}, {Center, Center}, {360., 360}]}, {}},
  ContentSelectable->True,
  ImageSize->350,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.784904737777111*^9, 3.7849047580638733`*^9}, 
   3.784905004461711*^9, 3.7849054638594437`*^9}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Mutation rate U vs mutational variance \[Lambda]\
\>", "Section",
 CellChangeTimes->{{3.780251618524732*^9, 3.780251621209381*^9}, {
  3.78026143982154*^9, 3.780261441307313*^9}, {3.780261726809947*^9, 
  3.780261729993729*^9}, {3.782259158796598*^9, 3.782259167234475*^9}}],

Cell[CellGroupData[{

Cell["Rate, U", "Subsection",
 CellChangeTimes->{{3.7802617352674723`*^9, 3.780261738674717*^9}, {
  3.782259169890827*^9, 3.7822591704985847`*^9}}],

Cell[CellGroupData[{

Cell["Probability of rescue", "Subsubsection",
 CellChangeTimes->{{3.7564892474960623`*^9, 3.756489252807234*^9}, 
   3.7606376392688437`*^9, {3.7642036999242487`*^9, 3.76420371369766*^9}, {
   3.769431834041813*^9, 3.769431845906336*^9}, {3.769431894299581*^9, 
   3.769431896986474*^9}, {3.769432022608979*^9, 3.76943202539149*^9}, {
   3.7694324961732264`*^9, 3.769432496341527*^9}, {3.7694327378288794`*^9, 
   3.769432739203771*^9}, {3.7694390881946793`*^9, 3.769439089784932*^9}, 
   3.7712459034631767`*^9, {3.780251653828335*^9, 3.780251661330201*^9}, {
   3.780252898262912*^9, 3.780252911301763*^9}, 3.78025362510145*^9, {
   3.780261742230752*^9, 3.780261744274851*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"N0", "=", 
   SuperscriptBox["10", "4"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "4"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m0min", "=", "mTempmin"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m0max", "=", "mTempmax"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mstep", "=", "step"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"m0list", "=", 
    RowBox[{"Table", "[", 
     RowBox[{"m0", ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"U", "=", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate4", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]4Interpolated", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate3", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]3Interpolated", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]2Interpolated", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]1Interpolated", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"theory2", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m0list", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"prescue", "/.", 
          RowBox[{"p0", "\[Rule]", 
           RowBox[{"prescuem", "[", 
            RowBox[{
             RowBox[{"m0list", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"rate1", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m0list", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"prescue", "/.", 
          RowBox[{"p0", "\[Rule]", 
           RowBox[{"prescuem", "[", 
            RowBox[{
             RowBox[{"m0list", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"rate2", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m0list", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"prescue", "/.", 
          RowBox[{"p0", "\[Rule]", 
           RowBox[{"prescuem", "[", 
            RowBox[{
             RowBox[{"m0list", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"rate3", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m0list", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"prescue", "/.", 
          RowBox[{"p0", "\[Rule]", 
           RowBox[{"prescuem", "[", 
            RowBox[{
             RowBox[{"m0list", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"rate4", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}]}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alltheory2", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"m0list", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"prescue", "/.", 
         RowBox[{"p0", "\[Rule]", 
          RowBox[{"prescuem", "[", 
           RowBox[{
            RowBox[{"m0list", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"rate1", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate2", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate3", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate4", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "]"}]}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"U", "=", 
    SuperscriptBox["10", 
     RowBox[{"-", "4"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate4", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]4Interpolated", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate3", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]3Interpolated", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]2Interpolated", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]1Interpolated", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"theory4", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m0list", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"prescue", "/.", 
          RowBox[{"p0", "\[Rule]", 
           RowBox[{"prescuem", "[", 
            RowBox[{
             RowBox[{"m0list", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"rate1", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m0list", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"prescue", "/.", 
          RowBox[{"p0", "\[Rule]", 
           RowBox[{"prescuem", "[", 
            RowBox[{
             RowBox[{"m0list", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"rate2", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m0list", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"prescue", "/.", 
          RowBox[{"p0", "\[Rule]", 
           RowBox[{"prescuem", "[", 
            RowBox[{
             RowBox[{"m0list", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"rate3", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m0list", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"prescue", "/.", 
          RowBox[{"p0", "\[Rule]", 
           RowBox[{"prescuem", "[", 
            RowBox[{
             RowBox[{"m0list", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"rate4", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}]}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alltheory4", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"m0list", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"prescue", "/.", 
         RowBox[{"p0", "\[Rule]", 
          RowBox[{"prescuem", "[", 
           RowBox[{
            RowBox[{"m0list", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"rate1", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate2", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate3", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate4", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "]"}]}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"theory2", ",", "\[IndentingNewLine]", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.4"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"5", "*", 
            SuperscriptBox["10", 
             RowBox[{"-", "7"}]]}], ",", "1"}], "}"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Frame", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Wildtype growth rate\>\"", ",", ",", ",", 
         "\"\<Probability of rescue\>\""}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"FrameTicks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{
            "\"\<1-step\>\"", ",", "\"\<2-step\>\"", ",", "\"\<3-step\>\"", 
             ",", "\"\<4-step\>\""}], "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "/", "4"}], ",", 
            RowBox[{"1", "/", "4"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"alltheory2", ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Thick"}], "}"}]}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", "\"\<1-, 2-, 3-, or 4-step\>\"", "}"}]}], "]"}], ",", 
         
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "4"}], ",", 
            RowBox[{"8", "/", "10"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"theory4", ",", "\[IndentingNewLine]", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", 
         RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"alltheory4", ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Thick", ",", 
         RowBox[{"Dashing", "[", "Large", "]"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Directive", "[", 
              RowBox[{"Thick", ",", "Gray"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
              RowBox[{"Thick", ",", "Gray", ",", 
               RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{
             "\"\<U=\!\(\*SuperscriptBox[\(10\), \(-3\)]\)\>\"", ",", 
              "\"\<U=\!\(\*SuperscriptBox[\(10\), \(-4\)]\)\>\""}], "}"}]}]}],
           "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "10"}], ",", 
            RowBox[{"6", "/", "10"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"Text", "[", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<A\>\"", ",", "Bold", ",", "14"}], "]"}], ",", 
       RowBox[{"Scaled", "@", 
        RowBox[{"{", 
         RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "N0", ",", "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", 
   "m0min", ",", "m0max", ",", "mstep"}], "]"}]}], "Input",
 CellChangeTimes->{{3.771243438404381*^9, 3.771243505591201*^9}, {
   3.771243660674692*^9, 3.771243770343318*^9}, {3.7712438051594973`*^9, 
   3.771243806769825*^9}, {3.77124384246271*^9, 3.7712439832452*^9}, {
   3.771244074547236*^9, 3.771244075614129*^9}, {3.771244170126183*^9, 
   3.771244240128414*^9}, {3.771244491552649*^9, 3.771244539467946*^9}, {
   3.771244637848792*^9, 3.771244771807975*^9}, {3.77124482635817*^9, 
   3.771245429892724*^9}, 3.771246073841148*^9, 3.771246637425001*^9, {
   3.771252282261911*^9, 3.771252288712202*^9}, 3.771254690716058*^9, {
   3.771254724632944*^9, 3.771254752430646*^9}, 3.77125504889705*^9, {
   3.7715446486731167`*^9, 3.771544649294244*^9}, {3.780251817258157*^9, 
   3.780251837264227*^9}, 3.780252917208507*^9, {3.780255349776267*^9, 
   3.780255419507058*^9}, {3.780255450934721*^9, 3.780255487344339*^9}, {
   3.780256197190711*^9, 3.780256197383162*^9}, 3.780256244789771*^9, {
   3.780261452504554*^9, 3.78026153410004*^9}, {3.782262999938053*^9, 
   3.782263000295635*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(7.279705329608732`*^-8\\)\[NoBreak] and \
\[NoBreak]\\!\\(8.761530263711027`*^-13\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263002657207*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(1.0286191497588282`*^-7\\)\[NoBreak] and \
\[NoBreak]\\!\\(1.124360034010241`*^-12\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263002759365*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(1.4522794837384644`*^-7\\)\[NoBreak] and \
\[NoBreak]\\!\\(2.2232504361922817`*^-12\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263002855695*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(NIntegrate :: ncvb\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263002884678*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(1.4807240285122168`*^-8\\)\[NoBreak] and \
\[NoBreak]\\!\\(7.012035920314079`*^-13\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263099256928*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(1.961272248188249`*^-8\\)\[NoBreak] and \
\[NoBreak]\\!\\(1.2926522573741938`*^-12\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263099332532*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(2.5960369823117813`*^-8\\)\[NoBreak] and \
\[NoBreak]\\!\\(2.0146265215810807`*^-12\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263099412847*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(NIntegrate :: ncvb\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263099448538*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(7.279705329608732`*^-8\\)\[NoBreak] and \
\[NoBreak]\\!\\(8.761530263711027`*^-13\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263192029089*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(1.0286191497588282`*^-7\\)\[NoBreak] and \
\[NoBreak]\\!\\(1.124360034010241`*^-12\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.7822631921264*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(1.4522794837384644`*^-7\\)\[NoBreak] and \
\[NoBreak]\\!\\(2.2232504361922817`*^-12\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.7822631922154512`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(NIntegrate :: ncvb\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263192238674*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(7.594589776123759`*^-9\\)\[NoBreak] and \
\[NoBreak]\\!\\(4.002636289199166`*^-13\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263343455594*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(1.0811191772406686`*^-8\\)\[NoBreak] and \
\[NoBreak]\\!\\(6.179494725282621`*^-13\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263343547699*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(1.539096864690094`*^-8\\)\[NoBreak] and \
\[NoBreak]\\!\\(1.0371883643828802`*^-12\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263343639027*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(NIntegrate :: ncvb\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263343662455*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(1.9750026573164113`*^-10\\)\[NoBreak] and \
\[NoBreak]\\!\\(1.9587973588764628`*^-13\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.7822634375789757`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(2.6362598419413893`*^-10\\)\[NoBreak] and \
\[NoBreak]\\!\\(3.2561917484902713`*^-13\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263437666657*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(3.518449596971985`*^-10\\)\[NoBreak] and \
\[NoBreak]\\!\\(5.369851615725374`*^-13\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.78226343776269*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(NIntegrate :: ncvb\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.78226343779989*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(7.594589776123759`*^-9\\)\[NoBreak] and \
\[NoBreak]\\!\\(4.002636289199166`*^-13\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263528032734*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(1.0811191772406686`*^-8\\)\[NoBreak] and \
\[NoBreak]\\!\\(6.179494725282621`*^-13\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.7822635281143923`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(1.539096864690094`*^-8\\)\[NoBreak] and \
\[NoBreak]\\!\\(1.0371883643828802`*^-12\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263528200863*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(NIntegrate :: ncvb\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.780261580683486*^9, 3.782263528229026*^9}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQLRMSrRvz7sZ++8X1J/NYdA8E7ZBrfR14Y3+42WPz
2W+1D6xzf1glsu76/hJHy11iZ7UOcF9fXGDLdX1/t1bfdqkNmgfS00Dg2v4w
qbI966dpHDj8VSOm/9DV/fXavAL3GtQPyANN2yF3dX//VMeja/PUDlSLgEy8
sj/+w+OJagmqB26Ajbu8fwKf9WH/UJUDJsYgcHn//po7BgZ+ygcmHAIZeGm/
7dNerXNeSgfeBIIceHE/q0dEkb634gEPkPPcL+5Pc3AxjvRXOLAEZNziC/vl
shx5FqyTO8AABhf2TxK9y29wTObATpD3dpzb7xCmL5r1VOpAIUh5wdn9BSYb
H4TySB7QArr+q8aZ/U9eOvb+sRI/8Ahk/MNT+3n6N9dkFYoemDUTBE7ub1Bb
GbFpvfCBYHB4ndif8oht1sevgtDwOb7/jaaEdbiLADQ8ju6veX35TZQZ74Ea
sP+P7H8nsbfv/FdOqH8P719vyz4v9wQb1H8H9/NcdJ3qsYEZ6p8D+294Hbte
vIHhANi6Hfv2P/j/88bNWb/364Ddu2d/od8d/SDpb/vngN23c7/Jdf3wSV8+
7OcBu2f7/o0/8q/PqH+xH2L/lv3LGbXf37d5sB9i38b9k7h2xNc9u7QfYv66
/bO79Fpv3zu4fwbYvJX75+54nmazdvn+BrD+JfuX7RO2emLWsP8AWP28/Y8P
M3069toMKj9lv9fnKtesU4v3Qfgt+0tA0dAgtxcA2nVGoA==
         "]]}, 
       {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQPWsmCNzczy0/JfBrntaBbxox/Ye+3th/8GzH8b8b
NA8E7ZBrfR14Y//fzb8NJT5rHFjn/rBKZN31/e8kFig7mWoc4L6+uMCW6/p+
n1eveprK1Q+kp4HAtf0TvToTHu5UO3D4K8jAq/v1576tzf2jekAeaNoOuav7
M6X9rtrZqx6oFgGZeGW/5DnrL3lNKgdugI27vN/22PQihWPKB0yMQeDy/rU5
1jFVXMoHJhwCGXhpf/H/Zckr/JUOvAkEOfDift0WG6ZbUxUPeICc535xv9TC
9S2OdxUOLAEZt/jC/qUqFpzCagoHGMDgwv7lLPs/sT2UO7AT5L0d5/ZrrY0Q
6a+UPVAIUl5wdv8mzfWTVMVkDmiBgkPjzP7tl2YU6G6XOvAIZPzDU/t1Ipe9
Zo6VPAAJv5P7K5VXPPrHLnEgGBxeJ/Zrzvttl71DDBo+x/eHc+V5dueJQsPj
6P4LkutOTNESOVAD9v+R/by1u/eseyME9e/h/YypryrfbRGE+u/g/uJY3gvB
zQJQ/xzYnxob3d++nu8A2Lod+/YvepwzjSmF54AO2L179qdX/q52VeY6MAfs
vp37dyn8+sD6hv0AD9g92/f/Z5mXEraHFWr/lv2yk2fkJU9khtq3cf/M3u4A
nnRGqPnr9s9ebvO9PO/f/hlg81buj1vefGb+x5/7G8D6l+yvdPlmF2r9df8B
sPp5+223/t87Ve4DVH7K/n5TxvszVjyB8lv2H55X0eqicnY/AP9mT40=
         "]]}, 
       {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJwtkF1I01EYxqeow0xmbrPyY7q29i0o1YWQCXVhbVlOoW4mmNlks3QJEmlZ
mHblsqSohRhrGg3CWg03a/S+02p+45xza0lpeJE02YJmJZR5/vwfOBwO55zf
+zwPv6ax4lw8g8GQbC2ynx/L6Qj8DkKJ5dp4Q0I+rks03SOxILSV+/WtcflY
4eR1flcHIVSsLnxUq8DB0uUWzmAAss7Yu60eOaYELIbibQEQ1H+60yaTY52W
aAEm15Rz8UYZjsYI0A9mnmA9OyLF3C2ak+eH6RcMlaNciq0cQpyHcGRA67ZJ
MEjhfCC25zgL0yW4fx+RD1hGMZvZJMbbIwQ4BxntQyylV4RhNTHoheqVs5Op
BSI8SuyVesHMviA33NqL/QRnmYWbSYrnprAQGZRmIfJ4ocWlFOIwieecgcMT
xo10qwAvkueGaVj8l8T6zBSgjNQhmYKTsRPhmro9+JXglyegiul2ffPw8aGJ
aBzKdlfrhqR8rKT6GgNvKFCQZsyj+/HAvVc3ZvQruXQf7+Fg4+UG10seXqHy
v4NeVc+zps4cOu8oNLfrmD5NNp3PDYlT6gOJRVl0HoSoFdwpmZlIjXO+hb7N
+3mvN3ehgvLrAtPVxadPVndiL+VvGPRFP1e5gQzcTvlxQOmSbi30gUvPt8Mv
7cc/QgeHnmcD7l/zJdkAm+YPQmXUEe3pSscHFM8KmiNd8ae1O/A69b8fmk/F
2apEaYjU+z44VFZyTFWfSt/fhR+a41+WMJk+d8Cbjdp5XnIC/getkk0U
         "]]}, 
       {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGCQB2IQbSXjtPtvxuX99ovrT+ax6B4wMQaBy/vvqO34xH5R
58CEQ181Yvov7b//RNAx3FjnwJvAHXKtry/uf6paunTmFO0DHg+rRNa5X9zf
9cON5+MXrQNLCmy5ri++sD/4VPeRnhCtAwxgcGG//JvWsBWbNQ/sBOoO3HFu
f2TDVbYuIc0DhSDlBWf3y+z8KtFQqHFAK6YfaOOZ/ddcHpvdu6B+4BHI+Ien
9p/yl0r6ZaB+YNZMEDi5X9zwtrjWJLUDwSDnBJ7Yr9z6qGb/F9UD3EDTbLmO
768W8N3HFql64DDI+YeO7pe89mGe836VAzUg46qO7P9pOItnvboK1L+H97O+
PTO/ZJIy1H8H9x/dYH9w/X8lqH8O7J/pksmdka90AGzdjn37l2Z2lPU8VDyg
A3bvnv1dUU0Fb0IVD8wBu2/n/vba8Km6ZxQO8IDds31/xGn2C7udFaD2b9kf
/Ojeqvhyeah9G/fvexcZ6JEqBzV/3f7tyy23XvCRPTADbN7K/cxs7dG31GQO
NID1L9l/YJuxrNBzqQMHwOrn7RePMOi9VSoJlZ+yv8HMZ07FXHEov2W//KOr
7gkbRQ4AAJBTASI=
         "]]}}, {}}, {{{}, {}, 
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwtkW1I01EUxsd6QVRMxFlGTWepm2khDSTSisyWCoYrB22GFKQfArchIssK
WZM+iREzZoUfnEKWjqxF21Cf40ut0tbWXlwUphKKWRKVgyQy73//A5fL5Z77
O8/zXMlFrfKSUCAQSDcW2+92svoAV8E5ivXIKCKtbh9bDSO+Zl5kiJGR0iFu
Xa4Mo7qL2vTHpGRTzF1Jtk1j7d6BKX9jNsVNW3VFsdPoNg6YzQ+yqK6WVQh5
7hi5K5xJ46sMGIRX9aPpwtZMStugOcRBFLsKVCP5e6k5mRED8J0+XyrS7KEw
h/MjPaALDRkzSH6QlR8ZNtNaSp+Ebo0x4Hv4Ou4o2zzp9K2SCfRh7Ovss9TF
NDrF5Cl8UP/sr92cL6YehrN6sX+T6chA8y4ScOVFvbph9KN7JzmZPYcHDy3C
xdKUVNKzdt1brBsbj1vrtlMOi0M6hciCYbJ1SETzDD/3BpFy31GTKJmi+b3G
jsszh3MakugMl9crtOs6FMJQIp+PG1lLmsHCawl8Hi/gfLdNpNDE0VXO/wQk
mUUVdkUM73ccpA0m3jyxhfc3ivi/Krv2rJD3Q1hpV8kORf6BG+cYwY0v1+Vl
zX+Qy+kdgtriaZGe/I37nD4nnGVVnSWBFcRzep6jptw8qRAuIDrfjuLlwmzZ
k0+IzhtEW6A3YabCy/NtePm05Hv9xDAsHK8Ps7/Ufnl/N1q49z3YN7mU91jf
BOL6u2DVVknWHuXy92b0Gnd/NqzfHomeTUhi30CC4f8qolFL
         
         "]]}}, {}}, {{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], Dashing[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQPWsmCNzc77R5xiXGLMMD3zRi+g99vbHfZvehCNdr
BgeCdsi1vg68sf8FW80jZxeDA+vcH1aJrLu+//6hGc7MGfoHuK8vLrDlur6f
cQqfObu33oH0NBC4tj/Opu3fbEPdA4e/ggy8ut+z7xTPKWmdA/JA03bIXd3P
+10icyan9oFqEZCJV/Z7HN66UPC35oEbYOMu7/81se+D5QeNAybGIHB5v9XU
I9ckXqofmHAIZOCl/Q/Xb/Tf8lTtwJtAkAMv7l/qerRJ8JnqAQ+Q89wv7l/Q
ZbTW5JXKgSUg4xZf2L/FRO69wiflAwxgcGH/xvkcsjf+Kh3YCfLejnP7G05o
dETxKh0oBCkvOLv/5KLoPcsUFA9ogYJD48z+DMOHBjvNFQ48Ahn/8NT+xfU/
n4kvlTsACb+T+0v7d7frPJI5EAwOrxP721YyO89Qk4aGz/H9gQe+TLQukoSG
x9H9Jh7nbN8dET9QA/b/kf2Kod856+TEoP49vF/M/Lz22joRqP8O7r+zKLLN
4KkQ1D8H9hfqpSxYGyh4AGzdjn37dU+umlnQzn9AB+zePfsZolmEFpTyHJgD
dt/O/cX/XubtyuE8wAN2z/b9m59eaIjNZoPav2U/w5sLvp/zmaH2bdz/7kP0
sb0VDFDz1+3/IhKhxsfxe/8MsHkr96fV/U6rVPy6vwGsf8l+FduvBb6N7/Yf
AKuft//ImU5t0S+PoPJT9hfHX0zqbbsA5bfsv5RwvrDhwdz9AKKhUZY=
         "]]}, 
       {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], Dashing[Large], 
        LineBox[CompressedData["
1:eJwtkHFIU1EYxceqP1qhMRatNTadtl661mYSpUUglEkITVdpG1qhWxCVIwlN
rUVFWpRaEbYkCAcm1maz8pm573POzaLE5aaTDFwFFi0ly2GxVd7XO3C5XO69
v++ck3jkZF4pl8PhUAuL7JY7ROMQrzPOXPOqMULp611zQci5P3HhoUGNebTk
0ldNEBYrszSWJWq0ZYfOCGxjUD0FGp1VhcvGWsq288agtl3RO5OlQqOBaBTq
5RUlA66N2D9HgAE4dOoLXfNXidIFGi0JAP2plFJsU2KVgBD9cDh374nfFRsw
yOBGILMyIyp6psD0TUQjMG2197h/pGKDiwDfgn4eD6SnpWJYQwz64E/oPLSZ
UnA3sZftA93UbLPBsR6tBNcyDJ6+WvmjnxRyGA1D4+yNK84tFHaTePQQ6Ntb
n4+fXYcm8rzsDRTeTHqQ4ZVjCqmDeg1uATcs5MvxA8GHXoHzXUNaa/Fa/N/f
S7gb7trJ70jGfKavQbi8eWiPeVEy248Xarhx/viDSWwfAxBwRD2jnTKsZvK7
Yfxj8NfkChmbtx8KO/cVKU2JbL4+EEeEVR3+BDYPQsy7Y3pXZgIy42gnzNu/
fS7PkaKC8fsCBuelJccSJdjM+OsGrUX2vTwmxuWMny4wO0RXZRNr2PlPgPf0
fV1Rj4id9xjElXUNgqbVLN8Gquv26O3jQmxieG3gjwm3nk5fhWbmvxV857Ra
3uRKROb9PSjdL8oyFgjY+1vQ2FtQ3G3ks+eLoD8ayV3qicN/rFlUAQ==
         "]]}, 
       {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], Dashing[Large], 
        LineBox[CompressedData["
1:eJwtkGFIU1EYhm+xFqkY5URqNVnpnHPTu7vt19gqGFgUgQ4MMiiMshGi+xcl
LsRmY6BRGqtGE5yCodZKcKPR9+k2nLXFbM5phbKNjJwUMWa/jDy3+8LhcDjn
PN/7vuKW9sZruymKku4ssj99QrQCK2f2vXnRpsEt6aX+2fwy/Cn9uhY8qsFG
r+hetmEZRq58GPsSUeNkfeq2YDIJtw7xK+SdaixMDnfoCpLgk3R1l9SosfU6
0RI8/hUVTq+oMJAnwARg2u3I9KqwfIfmFSUgaGnadmpUeEdAiIswr00LY2kG
l1lcHDzxLXNPP4NqFVEcWl0Jo1/L4INZAvwEn6nLG93flbjZQAwuwH5eeH3j
oRJPE3v1C/Bz7ne2WK9EN8ENx0BXyNgKftBIsYrB4atdIv4AjT4Sz/sRdCOj
5yQnaDST5x1RcIdrTzKJOpSROqQRMPeWjx5Q1GGa4FPvoTSVMZ2y1uL//ubB
rreulqQUaGT7CkOZwXdzSafg+pmD80O5s1GnnOsjBHnb4Cv13xrsZPMHweKw
TWhbari8ARiceKvkzcu4fDNgUPVlXYyMy4Ow3uz3FLmqkR3nfQdL/LUyurga
5axfPzioifsxixSdrD8fhMble+y5Kixi/UzDwuvAwcCNKm7+FAzZNw22VQk3
zwO8I1Xb7UYJx58Ei13QpA9VooPljQEdyUWb6Uq8y/53Q0YsH3/UV4HIvn8O
JuFF597F49z9AFyQzlj9345x5x54aXqm3dUmxn/s8lAb
         "]]}, 
       {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], Dashing[Large],
         LineBox[CompressedData["
1:eJwtkGtI01EYxlcxTPODwgihsFZBo6m7/XezG1bg2IfWVExj0Qin4T6o84O1
WVkaVlQLjLZMSpkiRozCbFOj93UXymGxNXUrSVolXbQiajqasTz//g8cDodz
zu99nod7vK7EsJrFYvFWFtk7bxG9hgC37XNsayEu8nRWTzwKNxd+J8a+KrHE
nXthXhuFpOZKsM6kRGdxzMxxRqBltrXny2Ylros46ndnRKB6o1rbGlJgTTXR
NCyp2ONv2xXojRPgFETKGrkZOxW4aYXmzp0C6ujo3qsf5GjhEOIkqPsuJZR2
OUZpXBhc1toN7fvlSEmIwmA0FU73/ZLhdQ8BvgLND9GBb90yXNASgyG425E/
ozsoQxWxVxyC77KhCmlSir0E5wjCx8fzyfP9UmTRCkJW83b7YqkUh0k890tI
rzk58jdFYQN5Xv8CjpVnR2bvU7iD1MGbgIrlHE5/JYXvCT4WgH16Pj8rjcL/
/Y3DG37KVDQkwVK6r+dgWD8jkVRJmH6eQdek5YSaI2H68INZzzc0+cXYTOf3
wbV7suy5JjGT1wt/KCNngC9m8o3BqtTPueA7EZMHQT+4ZumITYT0OPdTMIZ8
Rbs0Isyj/T6BeM+5s7q1Iuyi/Q3DKV9H+UWPEDNpPy4wC9iNTaeFzPxH4LWo
0gcVQmbeQ7gcsG3J/CRg+E7Y0zAhdVYK0E7zBsBVlmC7/QXYQv/vhQeHaq3L
2woQ6fd3YNSWU+Uw5jP3N0Bgvh0eOZPHnNsgfDjS3ZnGx3+BjVJz
         
         "]]}}, {}}, {{{}, {}, 
       {GrayLevel[0], Thickness[Large], Dashing[Large], 
        LineBox[CompressedData["
1:eJwtkG1Ik1EYht9miNqwjIUfzemW5ZyfURBEmvS1pUipy6xGLSsLotQoxdkP
cSlBxEQiMqY/2jBXOtIVvjPredIyNzW21toc1D6iMB2ryPnDIPO8vTccDodz
zvXc9y2sqik7x6EoSryyyH6/k2gG0sN7Lhz35eGiWKEZDbvhyY7uGpMyD8to
Qet8qRum93K6bkEuGqV+Fc/oAp6Bujz7PAfXuHS1+TEuGHf7DxYOZeP5aqKP
ILx0KEU2mIVjYQJ0QuTWaoWuPxNTVmi0wAmaUHj1F4MEm3iE+AHuFmcE1A8z
0M3gHJAfd8z1s0eM27cROeBEbME3dW86to8S4HuIvaKV3+zbgsFSYtAOnfXx
HbtMm1FG7EntkFvO9TpG0lBPcDobNLbcDjZYNiHFyAZeXsLGohkRmkk8+h1k
izxtZ4NCrCPPa6fhKzY6PRwhSkgd4imQpx4dH+anYoDg/Vbor5NJEq8K8H9/
Fohqlsh7nvGxnOlrAkIV+/Yn/E1i+3kLvZZPZ06VJLJ9vIFf31topS4erzP5
X4N9lZofXt7A5h0Dn7kpebaKx+Z7BUuDLzoWJ9ezeRCsPxo+T+2MQ2Yc/RLW
TSQbo0+uxSzG7wiYfvfBgcNc1DL+zKBXWc2ZxdHIZfwMwRwdJVKWRLLzn8Lj
9j8RlUci2HkDoPbkqJWnKZZvBC3MSXXeJbjH8AzQpmotqFxegGbmvx6gfuBB
TFEIkHnfDb7heTd3MsDe34GkR5pgWoWNPd+AhWsXFYW7u+AfSUNUrA==
         
         "]]}}, {}}}, {InsetBox[
      TemplateBox[{
       StyleBox[
        "\"1-, 2-, 3-, or 4-step\"", StripOnInput -> False, FontFamily -> 
         "Helvetica", FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"Directive", "[", 
                RowBox[{
                  RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                  RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], 
            ",", 
            RowBox[{"{", #, "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      NCache[Scaled[{Rational[1, 4], Rational[4, 5]}], Scaled[{0.25, 0.8}]], 
      ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TemplateBox[{
       StyleBox[
        "\"1-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"2-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"3-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"4-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.5470136627990908`", ",", "0.24`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24`", ",", "0.6`", ",", "0.33692049419863584`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      NCache[Scaled[{Rational[3, 4], Rational[1, 4]}], Scaled[{0.75, 0.25}]], 
      ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TemplateBox[{
       StyleBox[
        "\"U=\\!\\(\\*SuperscriptBox[\\(10\\), \\(-3\\)]\\)\"", StripOnInput -> 
         False, FontFamily -> "Helvetica", FontSize -> 12],StyleBox[
        "\"U=\\!\\(\\*SuperscriptBox[\\(10\\), \\(-4\\)]\\)\"", StripOnInput -> 
         False, FontFamily -> "Helvetica", FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}],
             ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      NCache[Scaled[{Rational[1, 10], Rational[3, 5]}], Scaled[{0.1, 0.6}]], 
      ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesOrigin->{-0.4, -14.508657738524219`},
   CoordinatesToolOptions:>{"DisplayFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& ), "CopiedValueFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& )},
   Epilog->InsetBox[
     FormBox[
      StyleBox["\"A\"", Bold, 14, StripOnInput -> False], TraditionalForm], 
     Scaled[{0.05, 0.95}]],
   Frame->{True, False, False, True},
   FrameLabel->{{"", 
      FormBox["\"Probability of rescue\"", TraditionalForm]}, {
      FormBox["\"Wildtype growth rate\"", TraditionalForm], ""}},
   FrameTicks->{{None, {{-13.815510557964274`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-11.512925464970229`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-9.210340371976182, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-6.907755278982137, 
        FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
        FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
        FormBox["0.1`", TraditionalForm]}, {0., 
        FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.716898269296165`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.429216196844383`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.206072645530174`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.02375108873622, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.86960040890896, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.736069016284437`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.618285980628055`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.819778284410283`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.414313176302118`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.126631103850338`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.903487552536127, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.721165995742174, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.567015315914915, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.433483923290392, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.315700887634009, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-8.517193191416238, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-8.111728083308073, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.824046010856292, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.600902459542082, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.418580902748127, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.264430222920869, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.1308988302963465`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.013115794639964, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-6.214608098422191, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.298317366548036, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.995732273553991, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.659260036932778, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.407945608651872, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.6931471805599453, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659905, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.35667494393873245`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782616`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {True, False}},
   GridLines->{None, None},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.4, 0}, {-14.508657738524219`, 0.}},
   PlotRangeClipping->True,
   PlotRangePadding->{{None, None}, {None, None}},
   Ticks->{Automatic, {{-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.716898269296165`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.429216196844383`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.02375108873622, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.86960040890896, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.736069016284437`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.618285980628055`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}],
  InterpretTemplate[Legended[
    Graphics[{{{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJxTTMoPSmViYGBQB2IQLRMSrRvz7sZ++8X1J/NYdA8E7ZBrfR14Y3+42WPz
2W+1D6xzf1glsu76/hJHy11iZ7UOcF9fXGDLdX1/t1bfdqkNmgfS00Dg2v4w
qbI966dpHDj8VSOm/9DV/fXavAL3GtQPyANN2yF3dX//VMeja/PUDlSLgEy8
sj/+w+OJagmqB26Ajbu8fwKf9WH/UJUDJsYgcHn//po7BgZ+ygcmHAIZeGm/
7dNerXNeSgfeBIIceHE/q0dEkb634gEPkPPcL+5Pc3AxjvRXOLAEZNziC/vl
shx5FqyTO8AABhf2TxK9y29wTObATpD3dpzb7xCmL5r1VOpAIUh5wdn9BSYb
H4TySB7QArr+q8aZ/U9eOvb+sRI/8Ahk/MNT+3n6N9dkFYoemDUTBE7ub1Bb
GbFpvfCBYHB4ndif8oht1sevgtDwOb7/jaaEdbiLADQ8ju6veX35TZQZ74Ea
sP+P7H8nsbfv/FdOqH8P719vyz4v9wQb1H8H9/NcdJ3qsYEZ6p8D+294Hbte
vIHhANi6Hfv2P/j/88bNWb/364Ddu2d/od8d/SDpb/vngN23c7/Jdf3wSV8+
7OcBu2f7/o0/8q/PqH+xH2L/lv3LGbXf37d5sB9i38b9k7h2xNc9u7QfYv66
/bO79Fpv3zu4fwbYvJX75+54nmazdvn+BrD+JfuX7RO2emLWsP8AWP28/Y8P
M3069toMKj9lv9fnKtesU4v3Qfgt+0tA0dAgtxcA2nVGoA==
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJxTTMoPSmViYGDQAGIQPWsmCNzczy0/JfBrntaBbxox/Ye+3th/8GzH8b8b
NA8E7ZBrfR14Y//fzb8NJT5rHFjn/rBKZN31/e8kFig7mWoc4L6+uMCW6/p+
n1eveprK1Q+kp4HAtf0TvToTHu5UO3D4K8jAq/v1576tzf2jekAeaNoOuav7
M6X9rtrZqx6oFgGZeGW/5DnrL3lNKgdugI27vN/22PQihWPKB0yMQeDy/rU5
1jFVXMoHJhwCGXhpf/H/Zckr/JUOvAkEOfDift0WG6ZbUxUPeICc535xv9TC
9S2OdxUOLAEZt/jC/qUqFpzCagoHGMDgwv7lLPs/sT2UO7AT5L0d5/ZrrY0Q
6a+UPVAIUl5wdv8mzfWTVMVkDmiBgkPjzP7tl2YU6G6XOvAIZPzDU/t1Ipe9
Zo6VPAAJv5P7K5VXPPrHLnEgGBxeJ/Zrzvttl71DDBo+x/eHc+V5dueJQsPj
6P4LkutOTNESOVAD9v+R/by1u/eseyME9e/h/YypryrfbRGE+u/g/uJY3gvB
zQJQ/xzYnxob3d++nu8A2Lod+/YvepwzjSmF54AO2L179qdX/q52VeY6MAfs
vp37dyn8+sD6hv0AD9g92/f/Z5mXEraHFWr/lv2yk2fkJU9khtq3cf/M3u4A
nnRGqPnr9s9ebvO9PO/f/hlg81buj1vefGb+x5/7G8D6l+yvdPlmF2r9df8B
sPp5+223/t87Ve4DVH7K/n5TxvszVjyB8lv2H55X0eqicnY/AP9mT40=
           "]]}, {
          Hue[0.1421359549995791, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJwtkF1I01EYxqeow0xmbrPyY7q29i0o1YWQCXVhbVlOoW4mmNlks3QJEmlZ
mHblsqSohRhrGg3CWg03a/S+02p+45xza0lpeJE02YJmJZR5/vwfOBwO55zf
+zwPv6ax4lw8g8GQbC2ynx/L6Qj8DkKJ5dp4Q0I+rks03SOxILSV+/WtcflY
4eR1flcHIVSsLnxUq8DB0uUWzmAAss7Yu60eOaYELIbibQEQ1H+60yaTY52W
aAEm15Rz8UYZjsYI0A9mnmA9OyLF3C2ak+eH6RcMlaNciq0cQpyHcGRA67ZJ
MEjhfCC25zgL0yW4fx+RD1hGMZvZJMbbIwQ4BxntQyylV4RhNTHoheqVs5Op
BSI8SuyVesHMviA33NqL/QRnmYWbSYrnprAQGZRmIfJ4ocWlFOIwieecgcMT
xo10qwAvkueGaVj8l8T6zBSgjNQhmYKTsRPhmro9+JXglyegiul2ffPw8aGJ
aBzKdlfrhqR8rKT6GgNvKFCQZsyj+/HAvVc3ZvQruXQf7+Fg4+UG10seXqHy
v4NeVc+zps4cOu8oNLfrmD5NNp3PDYlT6gOJRVl0HoSoFdwpmZlIjXO+hb7N
+3mvN3ehgvLrAtPVxadPVndiL+VvGPRFP1e5gQzcTvlxQOmSbi30gUvPt8Mv
7cc/QgeHnmcD7l/zJdkAm+YPQmXUEe3pSscHFM8KmiNd8ae1O/A69b8fmk/F
2apEaYjU+z44VFZyTFWfSt/fhR+a41+WMJk+d8Cbjdp5XnIC/getkk0U
           "]]}, {
          Hue[0.37820393249936934`, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJxTTMoPSmViYGCQB2IQbSXjtPtvxuX99ovrT+ax6B4wMQaBy/vvqO34xH5R
58CEQ181Yvov7b//RNAx3FjnwJvAHXKtry/uf6paunTmFO0DHg+rRNa5X9zf
9cON5+MXrQNLCmy5ri++sD/4VPeRnhCtAwxgcGG//JvWsBWbNQ/sBOoO3HFu
f2TDVbYuIc0DhSDlBWf3y+z8KtFQqHFAK6YfaOOZ/ddcHpvdu6B+4BHI+Ien
9p/yl0r6ZaB+YNZMEDi5X9zwtrjWJLUDwSDnBJ7Yr9z6qGb/F9UD3EDTbLmO
768W8N3HFql64DDI+YeO7pe89mGe836VAzUg46qO7P9pOItnvboK1L+H97O+
PTO/ZJIy1H8H9x/dYH9w/X8lqH8O7J/pksmdka90AGzdjn37l2Z2lPU8VDyg
A3bvnv1dUU0Fb0IVD8wBu2/n/vba8Km6ZxQO8IDds31/xGn2C7udFaD2b9kf
/Ojeqvhyeah9G/fvexcZ6JEqBzV/3f7tyy23XvCRPTADbN7K/cxs7dG31GQO
NID1L9l/YJuxrNBzqQMHwOrn7RePMOi9VSoJlZ+yv8HMZ07FXHEov2W//KOr
7gkbRQ4AAJBTASI=
           "]]}}}, {}}, {{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          GrayLevel[0], 
          Thickness[Large], 
          Line[CompressedData["
1:eJwtkW1I01EUxsd6QVRMxFlGTWepm2khDSTSisyWCoYrB22GFKQfArchIssK
WZM+iREzZoUfnEKWjqxF21Cf40ut0tbWXlwUphKKWRKVgyQy73//A5fL5Z77
O8/zXMlFrfKSUCAQSDcW2+92svoAV8E5ivXIKCKtbh9bDSO+Zl5kiJGR0iFu
Xa4Mo7qL2vTHpGRTzF1Jtk1j7d6BKX9jNsVNW3VFsdPoNg6YzQ+yqK6WVQh5
7hi5K5xJ46sMGIRX9aPpwtZMStugOcRBFLsKVCP5e6k5mRED8J0+XyrS7KEw
h/MjPaALDRkzSH6QlR8ZNtNaSp+Ebo0x4Hv4Ou4o2zzp9K2SCfRh7Ovss9TF
NDrF5Cl8UP/sr92cL6YehrN6sX+T6chA8y4ScOVFvbph9KN7JzmZPYcHDy3C
xdKUVNKzdt1brBsbj1vrtlMOi0M6hciCYbJ1SETzDD/3BpFy31GTKJmi+b3G
jsszh3MakugMl9crtOs6FMJQIp+PG1lLmsHCawl8Hi/gfLdNpNDE0VXO/wQk
mUUVdkUM73ccpA0m3jyxhfc3ivi/Krv2rJD3Q1hpV8kORf6BG+cYwY0v1+Vl
zX+Qy+kdgtriaZGe/I37nD4nnGVVnSWBFcRzep6jptw8qRAuIDrfjuLlwmzZ
k0+IzhtEW6A3YabCy/NtePm05Hv9xDAsHK8Ps7/Ufnl/N1q49z3YN7mU91jf
BOL6u2DVVknWHuXy92b0Gnd/NqzfHomeTUhi30CC4f8qolFL
           
           "]]}}}, {}}, {{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGDQAGIQPWsmCNzc77R5xiXGLMMD3zRi+g99vbHfZvehCNdr
BgeCdsi1vg68sf8FW80jZxeDA+vcH1aJrLu+//6hGc7MGfoHuK8vLrDlur6f
cQqfObu33oH0NBC4tj/Opu3fbEPdA4e/ggy8ut+z7xTPKWmdA/JA03bIXd3P
+10icyan9oFqEZCJV/Z7HN66UPC35oEbYOMu7/81se+D5QeNAybGIHB5v9XU
I9ckXqofmHAIZOCl/Q/Xb/Tf8lTtwJtAkAMv7l/qerRJ8JnqAQ+Q89wv7l/Q
ZbTW5JXKgSUg4xZf2L/FRO69wiflAwxgcGH/xvkcsjf+Kh3YCfLejnP7G05o
dETxKh0oBCkvOLv/5KLoPcsUFA9ogYJD48z+DMOHBjvNFQ48Ahn/8NT+xfU/
n4kvlTsACb+T+0v7d7frPJI5EAwOrxP721YyO89Qk4aGz/H9gQe+TLQukoSG
x9H9Jh7nbN8dET9QA/b/kf2Kod856+TEoP49vF/M/Lz22joRqP8O7r+zKLLN
4KkQ1D8H9hfqpSxYGyh4AGzdjn37dU+umlnQzn9AB+zePfsZolmEFpTyHJgD
dt/O/cX/XubtyuE8wAN2z/b9m59eaIjNZoPav2U/w5sLvp/zmaH2bdz/7kP0
sb0VDFDz1+3/IhKhxsfxe/8MsHkr96fV/U6rVPy6vwGsf8l+FduvBb6N7/Yf
AKuft//ImU5t0S+PoPJT9hfHX0zqbbsA5bfsv5RwvrDhwdz9AKKhUZY=
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJwtkHFIU1EYxceqP1qhMRatNTadtl661mYSpUUglEkITVdpG1qhWxCVIwlN
rUVFWpRaEbYkCAcm1maz8pm573POzaLE5aaTDFwFFi0ly2GxVd7XO3C5XO69
v++ck3jkZF4pl8PhUAuL7JY7ROMQrzPOXPOqMULp611zQci5P3HhoUGNebTk
0ldNEBYrszSWJWq0ZYfOCGxjUD0FGp1VhcvGWsq288agtl3RO5OlQqOBaBTq
5RUlA66N2D9HgAE4dOoLXfNXidIFGi0JAP2plFJsU2KVgBD9cDh374nfFRsw
yOBGILMyIyp6psD0TUQjMG2197h/pGKDiwDfgn4eD6SnpWJYQwz64E/oPLSZ
UnA3sZftA93UbLPBsR6tBNcyDJ6+WvmjnxRyGA1D4+yNK84tFHaTePQQ6Ntb
n4+fXYcm8rzsDRTeTHqQ4ZVjCqmDeg1uATcs5MvxA8GHXoHzXUNaa/Fa/N/f
S7gb7trJ70jGfKavQbi8eWiPeVEy248Xarhx/viDSWwfAxBwRD2jnTKsZvK7
Yfxj8NfkChmbtx8KO/cVKU2JbL4+EEeEVR3+BDYPQsy7Y3pXZgIy42gnzNu/
fS7PkaKC8fsCBuelJccSJdjM+OsGrUX2vTwmxuWMny4wO0RXZRNr2PlPgPf0
fV1Rj4id9xjElXUNgqbVLN8Gquv26O3jQmxieG3gjwm3nk5fhWbmvxV857Ra
3uRKROb9PSjdL8oyFgjY+1vQ2FtQ3G3ks+eLoD8ayV3qicN/rFlUAQ==
           "]]}, {
          Hue[0.1421359549995791, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJwtkGFIU1EYhm+xFqkY5URqNVnpnHPTu7vt19gqGFgUgQ4MMiiMshGi+xcl
LsRmY6BRGqtGE5yCodZKcKPR9+k2nLXFbM5phbKNjJwUMWa/jDy3+8LhcDjn
PN/7vuKW9sZruymKku4ssj99QrQCK2f2vXnRpsEt6aX+2fwy/Cn9uhY8qsFG
r+hetmEZRq58GPsSUeNkfeq2YDIJtw7xK+SdaixMDnfoCpLgk3R1l9SosfU6
0RI8/hUVTq+oMJAnwARg2u3I9KqwfIfmFSUgaGnadmpUeEdAiIswr00LY2kG
l1lcHDzxLXNPP4NqFVEcWl0Jo1/L4INZAvwEn6nLG93flbjZQAwuwH5eeH3j
oRJPE3v1C/Bz7ne2WK9EN8ENx0BXyNgKftBIsYrB4atdIv4AjT4Sz/sRdCOj
5yQnaDST5x1RcIdrTzKJOpSROqQRMPeWjx5Q1GGa4FPvoTSVMZ2y1uL//ubB
rreulqQUaGT7CkOZwXdzSafg+pmD80O5s1GnnOsjBHnb4Cv13xrsZPMHweKw
TWhbari8ARiceKvkzcu4fDNgUPVlXYyMy4Ow3uz3FLmqkR3nfQdL/LUyurga
5axfPzioifsxixSdrD8fhMble+y5Kixi/UzDwuvAwcCNKm7+FAzZNw22VQk3
zwO8I1Xb7UYJx58Ei13QpA9VooPljQEdyUWb6Uq8y/53Q0YsH3/UV4HIvn8O
JuFF597F49z9AFyQzlj9345x5x54aXqm3dUmxn/s8lAb
           "]]}, {
          Hue[0.37820393249936934`, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJwtkGtI01EYxlcxTPODwgihsFZBo6m7/XezG1bg2IfWVExj0Qin4T6o84O1
WVkaVlQLjLZMSpkiRozCbFOj93UXymGxNXUrSVolXbQiajqasTz//g8cDodz
zu99nod7vK7EsJrFYvFWFtk7bxG9hgC37XNsayEu8nRWTzwKNxd+J8a+KrHE
nXthXhuFpOZKsM6kRGdxzMxxRqBltrXny2Ylros46ndnRKB6o1rbGlJgTTXR
NCyp2ONv2xXojRPgFETKGrkZOxW4aYXmzp0C6ujo3qsf5GjhEOIkqPsuJZR2
OUZpXBhc1toN7fvlSEmIwmA0FU73/ZLhdQ8BvgLND9GBb90yXNASgyG425E/
ozsoQxWxVxyC77KhCmlSir0E5wjCx8fzyfP9UmTRCkJW83b7YqkUh0k890tI
rzk58jdFYQN5Xv8CjpVnR2bvU7iD1MGbgIrlHE5/JYXvCT4WgH16Pj8rjcL/
/Y3DG37KVDQkwVK6r+dgWD8jkVRJmH6eQdek5YSaI2H68INZzzc0+cXYTOf3
wbV7suy5JjGT1wt/KCNngC9m8o3BqtTPueA7EZMHQT+4ZumITYT0OPdTMIZ8
Rbs0Isyj/T6BeM+5s7q1Iuyi/Q3DKV9H+UWPEDNpPy4wC9iNTaeFzPxH4LWo
0gcVQmbeQ7gcsG3J/CRg+E7Y0zAhdVYK0E7zBsBVlmC7/QXYQv/vhQeHaq3L
2woQ6fd3YNSWU+Uw5jP3N0Bgvh0eOZPHnNsgfDjS3ZnGx3+BjVJz
           
           "]]}}}, {}}, {{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          GrayLevel[0], 
          Thickness[Large], 
          Dashing[Large], 
          Line[CompressedData["
1:eJwtkG1Ik1EYht9miNqwjIUfzemW5ZyfURBEmvS1pUipy6xGLSsLotQoxdkP
cSlBxEQiMqY/2jBXOtIVvjPredIyNzW21toc1D6iMB2ryPnDIPO8vTccDodz
zvXc9y2sqik7x6EoSryyyH6/k2gG0sN7Lhz35eGiWKEZDbvhyY7uGpMyD8to
Qet8qRum93K6bkEuGqV+Fc/oAp6Bujz7PAfXuHS1+TEuGHf7DxYOZeP5aqKP
ILx0KEU2mIVjYQJ0QuTWaoWuPxNTVmi0wAmaUHj1F4MEm3iE+AHuFmcE1A8z
0M3gHJAfd8z1s0eM27cROeBEbME3dW86to8S4HuIvaKV3+zbgsFSYtAOnfXx
HbtMm1FG7EntkFvO9TpG0lBPcDobNLbcDjZYNiHFyAZeXsLGohkRmkk8+h1k
izxtZ4NCrCPPa6fhKzY6PRwhSkgd4imQpx4dH+anYoDg/Vbor5NJEq8K8H9/
Fohqlsh7nvGxnOlrAkIV+/Yn/E1i+3kLvZZPZ06VJLJ9vIFf31topS4erzP5
X4N9lZofXt7A5h0Dn7kpebaKx+Z7BUuDLzoWJ9ezeRCsPxo+T+2MQ2Yc/RLW
TSQbo0+uxSzG7wiYfvfBgcNc1DL+zKBXWc2ZxdHIZfwMwRwdJVKWRLLzn8Lj
9j8RlUci2HkDoPbkqJWnKZZvBC3MSXXeJbjH8AzQpmotqFxegGbmvx6gfuBB
TFEIkHnfDb7heTd3MsDe34GkR5pgWoWNPd+AhWsXFYW7u+AfSUNUrA==
           
           "]]}}}, {}}}, {Epilog -> Text[
        Style["A", Bold, 14], 
        Scaled[{0.05, 0.95}]], 
      FrameLabel -> {{Null, "Probability of rescue"}, {
        "Wildtype growth rate", Null}}, 
      Ticks -> {Automatic, {{-13.815510557964274`, 
          Superscript[10, -6]}, {-11.512925464970229`, 
          Superscript[10, -5]}, {-9.210340371976182, 
          Superscript[10, -4]}, {-6.907755278982137, 
         0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 0.1}, {
         0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 0.}, {
           Thickness[0.001]}}}}, GridLines -> {None, None}, 
      FrameTicks -> {{None, {{-13.815510557964274`, 
           Superscript[10, -6]}, {-11.512925464970229`, 
           Superscript[10, -5]}, {-9.210340371976182, 
           Superscript[10, -4]}, {-6.907755278982137, 
          0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 0.1}, {
          0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 0.}, {
            Thickness[0.001]}}}}, {True, False}}, 
      AxesOrigin -> {-0.4, -14.508657738524219`}, 
      PlotRange -> {{-0.4, 0}, {-14.508657738524219`, 0.}}, AspectRatio -> 
      GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0, 0}, 
      CoordinatesToolOptions -> {"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )}, Frame -> {True, False, False, True}, 
      FrameLabel -> {
       "Wildtype growth rate", Null, Null, "Probability of rescue"}, 
      FrameTicks -> {True, False, False, True}, LabelStyle -> 
      Directive[12, FontFamily -> "Helvetica"], Method -> {}, 
      PlotRange -> {{-0.4, 0}, {-14.508657738524219`, 0.}}, PlotRangeClipping -> 
      True, PlotRangePadding -> {{None, None}, {None, None}}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          Thickness[Large], 
          GrayLevel[0.5]], 
         Directive[
          Thickness[Large], 
          GrayLevel[0.5], 
          Dashing[Medium]]}, {
         Style[
         "U=\!\(\*SuperscriptBox[\(10\), \(-3\)]\)", 12, FontFamily -> 
          "Helvetica"], 
         Style[
         "U=\!\(\*SuperscriptBox[\(10\), \(-4\)]\)", 12, FontFamily -> 
          "Helvetica"]}, LegendLayout -> "Column"]], 
      Scaled[{
        Rational[1, 10], 
        Rational[3, 5]}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{3.7802569179095497`*^9, 3.780262152208013*^9, 
  3.782263681324931*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Rescue genotype growth rate", "Subsubsection",
 CellChangeTimes->{{3.7794704634668283`*^9, 3.779470474057392*^9}, {
  3.7794710306220827`*^9, 3.779471034112606*^9}, {3.779482842010936*^9, 
  3.7794828429873037`*^9}, {3.7800683415343847`*^9, 3.7800683444466963`*^9}, {
  3.780254196766683*^9, 3.780254196925116*^9}, {3.780261750764731*^9, 
  3.780261751742078*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"-", "0.3"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"xmax", "=", "0.25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymax", "=", "40"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xint", "=", "0.01"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"N0", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mwt", "=", 
    RowBox[{"-", "0.2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"U", "=", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", "established", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m2", ",", 
       FractionBox[
        RowBox[{
         RowBox[{"fm", "[", 
          RowBox[{"m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}],
           "]"}], 
         RowBox[{"pest", "[", 
          RowBox[{"m2", "-", "mwt"}], "]"}]}], 
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"fm", "[", 
            RowBox[{
            "m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
            "]"}], 
           RowBox[{"pest", "[", 
            RowBox[{"m2", "-", "mwt"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"m2", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"m2", ",", "mwt", ",", "xmax", ",", "xint"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory2", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", "Gray"}], "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", "\"\<established\>\"", "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1.5", "/", "8"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"1", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        RowBox[{"g1m", "/.", 
         RowBox[{"m", "\[Rule]", "m2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "0", ",", "xmax", ",", "xint"}], "}"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"2", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"total", "=", 
      RowBox[{"Re", "[", 
       RowBox[{"g2denominator", "[", "mwt", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"m2", ",", 
         RowBox[{
          FractionBox["1", "total"], 
          RowBox[{"g2numerator", "[", 
           RowBox[{"mwt", ",", "m2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "xmax", ",", "xint"}], "}"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory2", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", "Thick", "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{"\"\<1-step\>\"", ",", "\"\<2-step\>\""}], "}"}]}], "]"}],
          ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1.5", "/", "8"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"U", "=", 
    SuperscriptBox["10", 
     RowBox[{"-", "4"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", "established", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m2", ",", 
       FractionBox[
        RowBox[{
         RowBox[{"fm", "[", 
          RowBox[{"m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}],
           "]"}], 
         RowBox[{"pest", "[", 
          RowBox[{"m2", "-", "mwt"}], "]"}]}], 
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"fm", "[", 
            RowBox[{
            "m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
            "]"}], 
           RowBox[{"pest", "[", 
            RowBox[{"m2", "-", "mwt"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"m2", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"m2", ",", "mwt", ",", "xmax", ",", "xint"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory4", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", "Gray", ",", 
         RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"1", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        RowBox[{"g1m", "/.", 
         RowBox[{"m", "\[Rule]", "m2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "0", ",", "xmax", ",", "xint"}], "}"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"2", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"total", "=", 
      RowBox[{"Re", "[", 
       RowBox[{"g2denominator", "[", "mwt", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"m2", ",", 
         RowBox[{
          FractionBox["1", "total"], 
          RowBox[{"g2numerator", "[", 
           RowBox[{"mwt", ",", "m2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "xmax", ",", "xint"}], "}"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory4", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", 
         RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Directive", "[", 
              RowBox[{"Thick", ",", "Black"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
              RowBox[{"Thick", ",", "Black", ",", 
               RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{
             "\"\<U=\!\(\*SuperscriptBox[\(10\), \(-3\)]\)\>\"", ",", 
              "\"\<U=\!\(\*SuperscriptBox[\(10\), \(-4\)]\)\>\""}], "}"}]}]}],
           "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"7", "/", "8"}], ",", 
            RowBox[{"3", "/", "10"}]}], "}"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "oldtheory2", ",", "theory2", ",", "oldtheory4", ",", "theory4"}], "}"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"FrameTicksStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontColor", "\[Rule]", "White"}], ",", "Automatic", ",", 
       "Automatic", ",", "Automatic"}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{
           RowBox[{"\"\<\!\(\*
StyleBox[SubscriptBox[\"m\", \"0\"],
FontSlant->\"Italic\"]\)=\>\"", "<>", 
            RowBox[{"ToString", "[", "mwt", "]"}]}], ",", "12", ",", 
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
         ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"7", "/", "8"}], ",", 
            RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<B\>\"", ",", "14", ",", "Bold"}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt", ",", 
   "xmin", ",", "xmax", ",", "ymax", ",", "xint"}], "]"}]}], "Input",
 CellChangeTimes->{{3.751575679958344*^9, 3.751575707856783*^9}, {
   3.751575756450697*^9, 3.7515757716167583`*^9}, {3.751575806118587*^9, 
   3.751575998358532*^9}, {3.7515761122033863`*^9, 3.751576131258815*^9}, {
   3.751576172283361*^9, 3.751576174879533*^9}, {3.7515762580970592`*^9, 
   3.751576326479478*^9}, {3.7515763695777597`*^9, 3.751576370332637*^9}, {
   3.7515764174224873`*^9, 3.751576419272636*^9}, {3.751577234452231*^9, 
   3.751577234571393*^9}, {3.751598119440303*^9, 3.7515981249463587`*^9}, 
   3.751650792683756*^9, {3.751650847039688*^9, 3.751650935724555*^9}, {
   3.751651020576578*^9, 3.751651024456732*^9}, {3.7516511744217253`*^9, 
   3.751651271292901*^9}, {3.7516514431359167`*^9, 3.751651596903675*^9}, {
   3.75165167006041*^9, 3.7516517016743317`*^9}, {3.751651837998188*^9, 
   3.751651848660565*^9}, {3.751651901804051*^9, 3.751651938743773*^9}, {
   3.75165209054011*^9, 3.751652092941709*^9}, {3.751654667780588*^9, 
   3.751654726734174*^9}, {3.751654761368635*^9, 3.751654832140562*^9}, {
   3.751654888268785*^9, 3.7516548919393587`*^9}, 3.751656018745837*^9, {
   3.751656381036447*^9, 3.7516563882551813`*^9}, {3.7565000581145897`*^9, 
   3.7565001021945477`*^9}, {3.756500617190415*^9, 3.75650065699045*^9}, 
   3.75650069938904*^9, {3.756500741026494*^9, 3.756500755155011*^9}, {
   3.756501221346011*^9, 3.75650122389799*^9}, 3.756502363067445*^9, 
   3.756502628112669*^9, 3.7565026817972727`*^9, {3.756503286102932*^9, 
   3.756503290049591*^9}, 3.756503323237875*^9, {3.756503496903769*^9, 
   3.75650353646167*^9}, {3.7565038167736483`*^9, 3.756503833330291*^9}, {
   3.7565038702319183`*^9, 3.7565038987244377`*^9}, {3.7565039623685904`*^9, 
   3.7565039995283422`*^9}, 3.756511754548572*^9, 3.756511866105935*^9, {
   3.756511901000861*^9, 3.756511903883478*^9}, {3.7565119526094627`*^9, 
   3.756511957815688*^9}, {3.756512664854374*^9, 3.756512670495578*^9}, {
   3.7565186714828672`*^9, 3.756518674830636*^9}, {3.756518724785604*^9, 
   3.7565187318397303`*^9}, {3.756518775324299*^9, 3.75651877705446*^9}, {
   3.756518831207197*^9, 3.756518836010257*^9}, {3.7565191876130047`*^9, 
   3.7565192273750753`*^9}, 3.756557317943141*^9, 3.756565191609994*^9, {
   3.756565226853438*^9, 3.756565227347921*^9}, {3.756565372407086*^9, 
   3.756565372554656*^9}, {3.7642581275023746`*^9, 3.764258130547591*^9}, {
   3.764258191591094*^9, 3.7642582094474382`*^9}, 3.769438935312201*^9, {
   3.769440382123701*^9, 3.769440472454721*^9}, 3.769440550032837*^9, {
   3.769440597811926*^9, 3.76944060297188*^9}, {3.769440831103504*^9, 
   3.769440912756571*^9}, {3.769440959415164*^9, 3.769440994826437*^9}, {
   3.769441059064315*^9, 3.769441091058297*^9}, {3.769441130350876*^9, 
   3.76944116439666*^9}, {3.7694411991785088`*^9, 3.7694412021516743`*^9}, 
   3.76996874883585*^9, 3.769968810893046*^9, {3.771262388292754*^9, 
   3.771262479562519*^9}, {3.771262525425778*^9, 3.771262540854212*^9}, {
   3.771262571282227*^9, 3.771262676392552*^9}, 3.771262708817911*^9, {
   3.771262787550537*^9, 3.77126278925319*^9}, {3.771262848265294*^9, 
   3.7712628699284153`*^9}, {3.771263092625225*^9, 3.771263094812828*^9}, 
   3.771263271500595*^9, {3.771523030703679*^9, 3.7715230467362022`*^9}, {
   3.771523079011808*^9, 3.771523152186151*^9}, {3.77152320543019*^9, 
   3.771523315803763*^9}, {3.7715233464449253`*^9, 3.771523576781527*^9}, {
   3.771523631873809*^9, 3.7715236430826683`*^9}, {3.7715241526920757`*^9, 
   3.771524155896125*^9}, {3.7715242229465923`*^9, 3.771524257316955*^9}, {
   3.771524320220757*^9, 3.771524423589848*^9}, {3.771524462952353*^9, 
   3.771524468371491*^9}, 3.771524519796175*^9, {3.771524560722151*^9, 
   3.77152458745588*^9}, {3.7715456914503183`*^9, 3.771545693694459*^9}, 
   3.7715458002283154`*^9, {3.771545911589119*^9, 3.771545926111433*^9}, {
   3.77160975420442*^9, 3.7716097651557693`*^9}, {3.7716099182331963`*^9, 
   3.77160992062647*^9}, {3.771609967213895*^9, 3.771610003678589*^9}, {
   3.771610042996176*^9, 3.771610061906077*^9}, {3.771610106603993*^9, 
   3.771610114408716*^9}, {3.771610201107335*^9, 3.771610202727501*^9}, 
   3.771610248378283*^9, {3.7794686898536158`*^9, 3.7794688301324673`*^9}, {
   3.77946886396563*^9, 3.77946888729186*^9}, {3.779468925902836*^9, 
   3.7794689413547277`*^9}, {3.779469011076345*^9, 3.779469071332287*^9}, {
   3.779469527005124*^9, 3.779469555307827*^9}, {3.779469593442951*^9, 
   3.77946961429259*^9}, {3.779469796805294*^9, 3.779469866620295*^9}, {
   3.779469901788733*^9, 3.779470016571252*^9}, {3.779470051010948*^9, 
   3.779470158052433*^9}, {3.779470201565462*^9, 3.779470241549526*^9}, 
   3.780062293224526*^9, {3.780062341271126*^9, 3.7800623697424707`*^9}, {
   3.780062860795129*^9, 3.780062861799574*^9}, {3.7800666511707067`*^9, 
   3.7800666553558607`*^9}, {3.780066708471122*^9, 3.780066726219557*^9}, 
   3.780067723259276*^9, {3.7802542082187147`*^9, 3.780254230507213*^9}, {
   3.780256302536779*^9, 3.7802564037550087`*^9}, {3.780256434238928*^9, 
   3.780256437769991*^9}, {3.7802564759340487`*^9, 3.780256509276353*^9}, {
   3.780256558450182*^9, 3.7802565601620092`*^9}, {3.7802566206630383`*^9, 
   3.780256652521289*^9}, {3.780256688622583*^9, 3.7802566887965918`*^9}, {
   3.780256734472596*^9, 3.7802567644064074`*^9}, {3.780256799980043*^9, 
   3.780256866597209*^9}, {3.780256941027989*^9, 3.7802569671663017`*^9}, {
   3.780257186954887*^9, 3.7802571871000643`*^9}, {3.7802573149393377`*^9, 
   3.780257317817444*^9}, {3.780261589636335*^9, 3.780261636437409*^9}, {
   3.7822630133159943`*^9, 3.782263013763772*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "izero"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Integral and error estimates are 0 on all integration \
subregions. Try increasing the value of the MinRecursion option. If value of \
integral may be 0, specify a finite value for the AccuracyGoal option. \\!\\(\
\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/NIntegrate\\\", ButtonNote -> \
\\\"NIntegrate::izero\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.779470161635611*^9, 3.779470252570225*^9, 3.780062310685498*^9, 
   3.780062391464891*^9, 3.7800628772268257`*^9, 3.7800667394757233`*^9, 
   3.780067840159727*^9, 3.780254249728323*^9, 3.780256522604405*^9, 
   3.78025658103601*^9, 3.7802566633868837`*^9, 3.780256780949135*^9, {
   3.78025681293653*^9, 3.780256838349967*^9}, 3.7802568812371387`*^9, 
   3.780257197395924*^9, 3.780257336556822*^9, 3.780262161351169*^9, 
   3.78226370082661*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "izero"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Integral and error estimates are 0 on all integration \
subregions. Try increasing the value of the MinRecursion option. If value of \
integral may be 0, specify a finite value for the AccuracyGoal option. \\!\\(\
\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/NIntegrate\\\", ButtonNote -> \
\\\"NIntegrate::izero\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.779470161635611*^9, 3.779470252570225*^9, 3.780062310685498*^9, 
   3.780062391464891*^9, 3.7800628772268257`*^9, 3.7800667394757233`*^9, 
   3.780067840159727*^9, 3.780254249728323*^9, 3.780256522604405*^9, 
   3.78025658103601*^9, 3.7802566633868837`*^9, 3.780256780949135*^9, {
   3.78025681293653*^9, 3.780256838349967*^9}, 3.7802568812371387`*^9, 
   3.780257197395924*^9, 3.780257336556822*^9, 3.780262161351169*^9, 
   3.782263721450786*^9}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {{}, {}, 
       {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8HntgvvNJtOveCP/bc1xcX
2HId3192c0Ke+kJuh8NfNWL6Dx3dfyXoXW36FmGHapF17g+rjuyfqxPTsHKW
hIOJMQgc3r//wVGFJ1EyDm8CQQYe3G9xyZGj8r6cwxKgadcXH9i/Kjvnp4mw
gsNOkHU79u3Pddm60khBwUELaPpXjT37l4YH37L1k3eAuG/n/uz/E5WUamUd
IO7Zvl+/T3EFN5O0Qw3Y/i37+bPDPr0RkYDat3H/IvUZq1XeiDiAvbNj3f64
/wsql+8QdJgDNm/l/oYY5muJbrxQ/Uv2z1KvWug6lR2qft7+6h7BCsV2JocG
sPyU/fMSrx9yTf5jD+G37JcomNEdZfzVHhZuTvM7Sr7efmdfAJG3/5QV5rPg
wVP7Coh++yzDSe49xvfsoebbd8jejbzncQUqv8Re/19bR0j9KfsZEPfZd7T8
a4u8eACqfp39Ou3NK4/s2mIP9Z/9H33GeRanVthD/W+vctFNq27PHHsOSPjY
O/wt+/BLYQLUvJ32eQGsB9Y0N9prQMLXfocH59uZCUVQ8/fZ1/Rf2SI2J8ke
Gj/2fy+lH7qoGQS176D91c0ny77zO9pD49eeU/bA59xzevZVkPi3X3Zhr/3h
dVL2hyDpw9765rtZuUps9lyQ9GOfdmivbmLvRzto+rJnVWr7YNJ3yw6a/ux7
X01jeCB32O4R2MBT9jWbWO79UFllB3HvGXulr+tt3N9OsAM7r+Cs/T/2VZFB
m0rsIO4/Z++XnjPlwcVwO0hsXLDfvrRkB+d2SzsAfQxhnA==
         
         "]]}}, {}}, {{}, {{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsb+6kzfPVFnHAcKfYv+MT87zVJuR
ww651teBO+bZt28umZR/3RAqv8TejlU8deYhXYdZM0Fgpb2U5NNde5epQdWv
s38rd0f8moSCw5tAkMhG+9jq4Oqdc0Sh+rfYH9X2OeYwnduB6/riAluu7fb1
045M9z3PADVvp/35pLmyZ6d/tteM6T/0VWOP/dQXny+cuvfUHmL+PvtdO/dP
PZJ83X4JUPf1xQfs1edeCXX6ftweYt9B+/83Vh/Va9lubwwGh+2Fz71efk9k
mT3E/iP2x1i2rdC/NNn+8FcNoA1H7bULdlTO/dNgD3HPcfu5FzUt5hzMtg8C
W3jC/oN4M8PGKaH2EPedtH/U6W5y4769/cMqkIGn7G/8lef57acGde8Z+5ec
c1/sb+W1LwQ5r+CsfUx6fSlf9ic7iPvP2R8+8uqY9ayrdpBYuGCfszbh5dU9
2+0AUg3FSw==
         "]]}, 
       {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsS+6PP+X4G1BBwh/iv1F5wc5Uldl
HHbItb4O3DHP3m62rpH9CkWo/BJ7TY/7Ht8NlB1mzQSBlfavZ/rs3FmgDFW/
zn7aszVrZx9UcngTCBLZaK9ZtiT9QR5M/xZ71YOPKibmyDtwXV9cYMu13f6Q
76QI+0nSUPN22uvl+2SdnCXuoBnTf+irxh57Semz+xz3CUPN32cv8vTFug3K
Ag5LgLqvLz5gXzVnw2TOE5xQ+w7aNywuWXNUksXBGAwO27s8Pst4uOefPcT+
I/arVlz34J76zf7wVw2gDUftJyTI/+w2+mAPcc9xe52bL+8/qX5mHwS28IR9
9exnu3Jk7tlD3HfSfi9DYsnFlMv2D6tABp6yb+v9UBn79bg9xL1n7DNUtnMc
9d1jXwhyXsFZ+2zvzfolj9fbQ9x/zn5h+/ZiYbGF9pBYuGBv/tKw/1jcRHsA
XHLAgQ==
         "]]}}, {}}, {{}, {{}, {}, 
       {GrayLevel[0.5], Thickness[Large], Dashing[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8HntgvvNJtOveCP/bc1xcX
2HId3192c0Ke+kJuh8NfNWL6Dx3dfyXoXW36FmGHapF17g+rjuyfqxPTsHKW
hIOJMQgc3r//wVGFJ1EyDm8CQQYe3G9xyZGj8r6cwxKgadcXH9i/Kjvnp4mw
gsNOkHU79u3Pddm60khBwUELaPpXjT37l4YH37L1k3eAuG/n/uz/E5WUamUd
IO7Zvl+/T3EFN5O0Qw3Y/i37+bPDPr0RkYDat3H/IvUZq1XeiDiAvbNj3f64
/wsql+8QdJgDNm/l/oYY5muJbrxQ/Uv2z1KvWug6lR2qft7+6h7BCsV2JocG
sPyU/fMSrx9yTf5jD+G37JcomNEdZfzVHhZuTvM7Sr7efmdfAJG3/5QV5rPg
wVP7Coh++yzDSe49xvfsoebbd8jejbzncQUqv8Re/19bR0j9KfsZEPfZd7T8
a4u8eACqfp39Ou3NK4/s2mIP9Z/9H33GeRanVthD/W+vctFNq27PHHsOSPjY
O/wt+/BLYQLUvJ32eQGsB9Y0N9prQMLXfocH59uZCUVQ8/fZ1/Rf2SI2J8ke
Gj/2fy+lH7qoGQS176D91c0ny77zO9pD49eeU/bA59xzevZVkPi3X3Zhr/3h
dVL2hyDpw9765rtZuUps9lyQ9GOfdmivbmLvRzto+rJnVWr7YNJ3yw6a/ux7
X01jeCB32O4R2MBT9jWbWO79UFllB3HvGXulr+tt3N9OsAM7r+Cs/T/2VZFB
m0rsIO4/Z++XnjPlwcVwO0hsXLDfvrRkB+d2SzsAfQxhnA==
         
         "]]}}, {}}, {{}, {{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], Dashing[
        Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsb+6kzfPVFnHAcKfYv+MT87zVJuR
ww651teBO+bZt28umZR/3RAqv8TejlU8deYhXYdZM0Fgpb2U5NNde5epQdWv
s38rd0f8moSCw5tAkMhG+9jq4Oqdc0Sh+rfYH9X2OeYwnduB6/riAluu7fb1
045M9z3PADVvp/35pLmyZ6d/tteM6T/0VWOP/dQXny+cuvfUHmL+PvtdO/dP
PZJ83X4JUPf1xQfs1edeCXX6ftweYt9B+/83Vh/Va9lubwwGh+2Fz71efk9k
mT3E/iP2x1i2rdC/NNn+8FcNoA1H7bULdlTO/dNgD3HPcfu5FzUt5hzMtg8C
W3jC/oN4M8PGKaH2EPedtH/U6W5y4769/cMqkIGn7G/8lef57acGde8Z+5ec
c1/sb+W1LwQ5r+CsfUx6fSlf9ic7iPvP2R8+8uqY9ayrdpBYuGCfszbh5dU9
2+0AUg3FSw==
         "]]}, 
       {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], Dashing[
        Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsd97KT3p8jR+Bwh/iv2KG1IFT6Ol
HHbItb4O3DHPXvX22hP+sxSg8kvsF2XrTFNrVHKYNRMEVtoH3q/msdFRhqpf
Z3/+yFqLKfeVHN4EgkQ22gdxPBU5dVMRqn+Lfd8f4+lWwQoOXNcXF9hybbdf
tXkfX9gvGah5O+0rZ4nuLGeSdNCM6T/0VWOPvWbBHKMCJlGo+fvse/VVQ4v0
BB2WAHVfX3zA3kAucpltBDfUvoP277uOxNWqszoYg8Fh+ysXK89ZHf9vD7H/
iP2fVduj9JW/2x/+qgG04aj9i2nZMy76fLCHuOe4vbuXx5J83Wf2QWALT9jn
rF7CFyZ81x7ivpP2AXlXLJWDL9k/rAIZeMpe1fzXcVGNY/YQ956xl/rl9ubz
op32hSDnFZy1lwl32iwRuMYe4v5z9o+Un61yOTHXHhILF+xX1acVr9jfaw8A
ema6Kw==
         "]]}}, {}}}, {InsetBox[
      TagBox[GridBox[{
         {
          
          TemplateBox[{
           StyleBox[
            "\"1-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
             FontSize -> 12],StyleBox[
            "\"2-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
             FontSize -> 12]},
           "LineLegend",
           DisplayFunction->(StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
             False]& ),
           Editable->True,
           InterpretationFunction:>(RowBox[{"LineLegend", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
                  "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{#, ",", #2}], "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]},
         {
          
          TemplateBox[{
           StyleBox[
            "\"established\"", StripOnInput -> False, FontFamily -> 
             "Helvetica", FontSize -> 12]},
           "LineLegend",
           DisplayFunction->(StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
             False]& ),
           Editable->True,
           InterpretationFunction:>(RowBox[{"LineLegend", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}]}], "]"}], "}"}], 
                ",", 
                RowBox[{"{", #, "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{0}}}],
       "Grid"], NCache[
      Scaled[{0.1875, Rational[1, 2]}], Scaled[{0.1875, 0.5}]], ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TemplateBox[{
       StyleBox[
        "\"U=\\!\\(\\*SuperscriptBox[\\(10\\), \\(-3\\)]\\)\"", StripOnInput -> 
         False, FontFamily -> "Helvetica", FontSize -> 12],StyleBox[
        "\"U=\\!\\(\\*SuperscriptBox[\\(10\\), \\(-4\\)]\\)\"", StripOnInput -> 
         False, FontFamily -> "Helvetica", FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}],
             ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )], 
      NCache[Scaled[{Rational[7, 8], Rational[3, 10]}], Scaled[{0.875, 0.3}]],
       ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesLabel->{None, None},
   AxesOrigin->{0., 0.},
   Epilog->{
     InsetBox[
      FormBox[
       StyleBox[
       "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=-0.2\"", 12, FontFamily -> 
        "Helvetica", StripOnInput -> False], TraditionalForm], 
      NCache[
       Scaled[{
         Rational[7, 8], 
         Rational[3, 4]}], 
       Scaled[{0.875, 0.75}]]], 
     InsetBox[
      FormBox[
       StyleBox["\"B\"", 14, Bold, StripOnInput -> False], TraditionalForm], 
      Scaled[{0.05, 0.95}]]},
   Frame->{True, False, False, False},
   FrameTicksStyle->{
    FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.3, 0.25}, {0, 40}},
   PlotRangeClipping->True,
   PlotRangePadding->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           GrayLevel[0.5]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8HntgvvNJtOveCP/bc1xcX
2HId3192c0Ke+kJuh8NfNWL6Dx3dfyXoXW36FmGHapF17g+rjuyfqxPTsHKW
hIOJMQgc3r//wVGFJ1EyDm8CQQYe3G9xyZGj8r6cwxKgadcXH9i/Kjvnp4mw
gsNOkHU79u3Pddm60khBwUELaPpXjT37l4YH37L1k3eAuG/n/uz/E5WUamUd
IO7Zvl+/T3EFN5O0Qw3Y/i37+bPDPr0RkYDat3H/IvUZq1XeiDiAvbNj3f64
/wsql+8QdJgDNm/l/oYY5muJbrxQ/Uv2z1KvWug6lR2qft7+6h7BCsV2JocG
sPyU/fMSrx9yTf5jD+G37JcomNEdZfzVHhZuTvM7Sr7efmdfAJG3/5QV5rPg
wVP7Coh++yzDSe49xvfsoebbd8jejbzncQUqv8Re/19bR0j9KfsZEPfZd7T8
a4u8eACqfp39Ou3NK4/s2mIP9Z/9H33GeRanVthD/W+vctFNq27PHHsOSPjY
O/wt+/BLYQLUvJ32eQGsB9Y0N9prQMLXfocH59uZCUVQ8/fZ1/Rf2SI2J8ke
Gj/2fy+lH7qoGQS176D91c0ny77zO9pD49eeU/bA59xzevZVkPi3X3Zhr/3h
dVL2hyDpw9765rtZuUps9lyQ9GOfdmivbmLvRzto+rJnVWr7YNJ3yw6a/ux7
X01jeCB32O4R2MBT9jWbWO79UFllB3HvGXulr+tt3N9OsAM7r+Cs/T/2VZFB
m0rsIO4/Z++XnjPlwcVwO0hsXLDfvrRkB+d2SzsAfQxhnA==
           
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           Thickness[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsb+6kzfPVFnHAcKfYv+MT87zVJuR
ww651teBO+bZt28umZR/3RAqv8TejlU8deYhXYdZM0Fgpb2U5NNde5epQdWv
s38rd0f8moSCw5tAkMhG+9jq4Oqdc0Sh+rfYH9X2OeYwnduB6/riAluu7fb1
045M9z3PADVvp/35pLmyZ6d/tteM6T/0VWOP/dQXny+cuvfUHmL+PvtdO/dP
PZJ83X4JUPf1xQfs1edeCXX6ftweYt9B+/83Vh/Va9lubwwGh+2Fz71efk9k
mT3E/iP2x1i2rdC/NNn+8FcNoA1H7bULdlTO/dNgD3HPcfu5FzUt5hzMtg8C
W3jC/oN4M8PGKaH2EPedtH/U6W5y4769/cMqkIGn7G/8lef57acGde8Z+5ec
c1/sb+W1LwQ5r+CsfUx6fSlf9ic7iPvP2R8+8uqY9ayrdpBYuGCfszbh5dU9
2+0AUg3FSw==
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Directive[
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           Thickness[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsS+6PP+X4G1BBwh/iv1F5wc5Uldl
HHbItb4O3DHP3m62rpH9CkWo/BJ7TY/7Ht8NlB1mzQSBlfavZ/rs3FmgDFW/
zn7aszVrZx9UcngTCBLZaK9ZtiT9QR5M/xZ71YOPKibmyDtwXV9cYMu13f6Q
76QI+0nSUPN22uvl+2SdnCXuoBnTf+irxh57Semz+xz3CUPN32cv8vTFug3K
Ag5LgLqvLz5gXzVnw2TOE5xQ+w7aNywuWXNUksXBGAwO27s8Pst4uOefPcT+
I/arVlz34J76zf7wVw2gDUftJyTI/+w2+mAPcc9xe52bL+8/qX5mHwS28IR9
9exnu3Jk7tlD3HfSfi9DYsnFlMv2D6tABp6yb+v9UBn79bg9xL1n7DNUtnMc
9d1jXwhyXsFZ+2zvzfolj9fbQ9x/zn5h+/ZiYbGF9pBYuGBv/tKw/1jcRHsA
XHLAgQ==
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           GrayLevel[0.5], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8HntgvvNJtOveCP/bc1xcX
2HId3192c0Ke+kJuh8NfNWL6Dx3dfyXoXW36FmGHapF17g+rjuyfqxPTsHKW
hIOJMQgc3r//wVGFJ1EyDm8CQQYe3G9xyZGj8r6cwxKgadcXH9i/Kjvnp4mw
gsNOkHU79u3Pddm60khBwUELaPpXjT37l4YH37L1k3eAuG/n/uz/E5WUamUd
IO7Zvl+/T3EFN5O0Qw3Y/i37+bPDPr0RkYDat3H/IvUZq1XeiDiAvbNj3f64
/wsql+8QdJgDNm/l/oYY5muJbrxQ/Uv2z1KvWug6lR2qft7+6h7BCsV2JocG
sPyU/fMSrx9yTf5jD+G37JcomNEdZfzVHhZuTvM7Sr7efmdfAJG3/5QV5rPg
wVP7Coh++yzDSe49xvfsoebbd8jejbzncQUqv8Re/19bR0j9KfsZEPfZd7T8
a4u8eACqfp39Ou3NK4/s2mIP9Z/9H33GeRanVthD/W+vctFNq27PHHsOSPjY
O/wt+/BLYQLUvJ32eQGsB9Y0N9prQMLXfocH59uZCUVQ8/fZ1/Rf2SI2J8ke
Gj/2fy+lH7qoGQS176D91c0ny77zO9pD49eeU/bA59xzevZVkPi3X3Zhr/3h
dVL2hyDpw9765rtZuUps9lyQ9GOfdmivbmLvRzto+rJnVWr7YNJ3yw6a/ux7
X01jeCB32O4R2MBT9jWbWO79UFllB3HvGXulr+tt3N9OsAM7r+Cs/T/2VZFB
m0rsIO4/Z++XnjPlwcVwO0hsXLDfvrRkB+d2SzsAfQxhnA==
           
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsb+6kzfPVFnHAcKfYv+MT87zVJuR
ww651teBO+bZt28umZR/3RAqv8TejlU8deYhXYdZM0Fgpb2U5NNde5epQdWv
s38rd0f8moSCw5tAkMhG+9jq4Oqdc0Sh+rfYH9X2OeYwnduB6/riAluu7fb1
045M9z3PADVvp/35pLmyZ6d/tteM6T/0VWOP/dQXny+cuvfUHmL+PvtdO/dP
PZJ83X4JUPf1xQfs1edeCXX6ftweYt9B+/83Vh/Va9lubwwGh+2Fz71efk9k
mT3E/iP2x1i2rdC/NNn+8FcNoA1H7bULdlTO/dNgD3HPcfu5FzUt5hzMtg8C
W3jC/oN4M8PGKaH2EPedtH/U6W5y4769/cMqkIGn7G/8lef57acGde8Z+5ec
c1/sb+W1LwQ5r+CsfUx6fSlf9ic7iPvP2R8+8uqY9ayrdpBYuGCfszbh5dU9
2+0AUg3FSw==
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Directive[
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsd97KT3p8jR+Bwh/iv2KG1IFT6Ol
HHbItb4O3DHPXvX22hP+sxSg8kvsF2XrTFNrVHKYNRMEVtoH3q/msdFRhqpf
Z3/+yFqLKfeVHN4EgkQ22gdxPBU5dVMRqn+Lfd8f4+lWwQoOXNcXF9hybbdf
tXkfX9gvGah5O+0rZ4nuLGeSdNCM6T/0VWOPvWbBHKMCJlGo+fvse/VVQ4v0
BB2WAHVfX3zA3kAucpltBDfUvoP277uOxNWqszoYg8Fh+ysXK89ZHf9vD7H/
iP2fVduj9JW/2x/+qgG04aj9i2nZMy76fLCHuOe4vbuXx5J83Wf2QWALT9jn
rF7CFyZ81x7ivpP2AXlXLJWDL9k/rAIZeMpe1fzXcVGNY/YQ956xl/rl9ubz
op32hSDnFZy1lwl32iwRuMYe4v5z9o+Un61yOTHXHhILF+xX1acVr9jfaw8A
ema6Kw==
           "]]}}}, {}}}, {
     PlotRange -> {{-0.3, 0.25}, {0, 40}}, 
      Frame -> {True, False, False, False}, LabelStyle -> 
      Directive[12, FontFamily -> "Helvetica"], 
      FrameTicksStyle -> {
       FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, Epilog -> {
        Text[
         Style[
         "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=-0.2", 12, FontFamily -> "Helvetica"], 
         Scaled[{
           Rational[7, 8], 
           Rational[3, 4]}]], 
        Text[
         Style["B", 14, Bold], 
         Scaled[{0.05, 0.95}]]}, AxesLabel -> {None, None}, AspectRatio -> 
      GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0., 0.}, Method -> {}, 
      PlotRange -> {All, All}, PlotRangeClipping -> True, 
      PlotRangePadding -> {Automatic, Automatic}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          Thickness[Large], 
          GrayLevel[0]], 
         Directive[
          Thickness[Large], 
          GrayLevel[0], 
          Dashing[Medium]]}, {
         Style[
         "U=\!\(\*SuperscriptBox[\(10\), \(-3\)]\)", 12, FontFamily -> 
          "Helvetica"], 
         Style[
         "U=\!\(\*SuperscriptBox[\(10\), \(-4\)]\)", 12, FontFamily -> 
          "Helvetica"]}, LegendLayout -> "Column", LegendMarkers -> False]], 
      Scaled[{
        Rational[7, 8], 
        Rational[3, 10]}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{{3.779468795408979*^9, 3.779468830949634*^9}, 
   3.779468917873926*^9, {3.779469011820323*^9, 3.779469047660637*^9}, {
   3.779469821103179*^9, 3.779469830115543*^9}, {3.779470013240581*^9, 
   3.77947001697924*^9}, {3.779470060618907*^9, 3.779470094444737*^9}, 
   3.779470124926302*^9, 3.7794701689603777`*^9, 3.7794702603696213`*^9, 
   3.78006231915749*^9, 3.780062399351725*^9, 3.780062885347563*^9, 
   3.780066748143722*^9, 3.780067848691842*^9, 3.780254256385449*^9, 
   3.78025654685863*^9, 3.7802566056431427`*^9, 3.7802566879888897`*^9, 
   3.780256788170679*^9, {3.7802568199542313`*^9, 3.780256845738853*^9}, 
   3.7802569054429827`*^9, 3.780257228032707*^9, 3.780257366897098*^9, 
   3.780262187265337*^9, 3.7822637306225986`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2-step intermediate growth rate", "Subsubsection",
 CellChangeTimes->{{3.779477356570382*^9, 3.779477361850051*^9}, {
   3.779482848762312*^9, 3.779482851539497*^9}, {3.780068347007688*^9, 
   3.780068352358201*^9}, 3.780254198935792*^9, {3.780261755444825*^9, 
   3.780261756169991*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"-", "0.3"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmax", "=", "0.25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ymax", "=", "30"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"N0", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]", "=", 
   RowBox[{"2", 
    RowBox[{"Es", "/", "n"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", 
   RowBox[{"-", "0.2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "4"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"U", "=", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"exact2", "=", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
    RowBox[{"prescuem", "[", 
     RowBox[{"m1", ",", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"allexact2", "=", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{"exact2", ",", 
     RowBox[{"{", 
      RowBox[{"m1", ",", "mwt", ",", "0.1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory2", "=", 
    FractionBox[
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"pest", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}]}], 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fm", "[", 
         RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"pest", "[", 
         RowBox[{"m1", "-", "mwt"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"U", "=", 
    SuperscriptBox["10", 
     RowBox[{"-", "4"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"exact4", "=", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
    RowBox[{"prescuem", "[", 
     RowBox[{"m1", ",", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"allexact4", "=", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{"exact4", ",", 
     RowBox[{"{", 
      RowBox[{"m1", ",", "mwt", ",", "0.1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory4", "=", 
    FractionBox[
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"pest", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}]}], 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fm", "[", 
         RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"pest", "[", 
         RowBox[{"m1", "-", "mwt"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"oldtheory2", ",", "oldtheory4"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{"Gray", ",", "Thick"}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Gray", ",", "Thick", ",", 
           RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", "\"\<established\>\"", "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "8"}], ",", 
            RowBox[{"1.25", "/", "2"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"exact2", "/", "allexact2"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", "Thick", "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", "\"\<first-step\>\"", "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "8"}], ",", 
            RowBox[{"1.25", "/", "2"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"exact4", "/", "allexact4"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", 
         RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Directive", "[", 
              RowBox[{"Thick", ",", "Black"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
              RowBox[{"Thick", ",", "Black", ",", 
               RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{
             "\"\<U=\!\(\*SuperscriptBox[\(10\), \(-3\)]\)\>\"", ",", 
              "\"\<U=\!\(\*SuperscriptBox[\(10\), \(-4\)]\)\>\""}], "}"}]}]}],
           "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"7", "/", "8"}], ",", 
            RowBox[{"3", "/", "10"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"FrameTicksStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "Automatic", ",", "Automatic", ",", "Automatic", ",", "Automatic"}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", "\"\<Growth rate\>\"", "}"}]}], ",", "\[IndentingNewLine]", 
    
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{
           RowBox[{"\"\<\!\(\*
StyleBox[SubscriptBox[\"m\", \"0\"],
FontSlant->\"Italic\"]\)=\>\"", "<>", 
            RowBox[{"ToString", "[", "mwt", "]"}]}], ",", "12", ",", 
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
         ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"7", "/", "8"}], ",", 
            RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<C\>\"", ",", "14", ",", "Bold"}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt", ",", 
   "xmin", ",", "xmax", ",", "ymax", ",", "N0"}], "]"}]}], "Input",
 CellChangeTimes->{{3.771259863315041*^9, 3.771259875817935*^9}, {
   3.77125993618959*^9, 3.7712599967791033`*^9}, {3.7712600806108303`*^9, 
   3.771260101998229*^9}, {3.7712601420091887`*^9, 3.771260164023238*^9}, {
   3.7712604866075153`*^9, 3.7712604916540623`*^9}, {3.771260596998*^9, 
   3.7712606779327497`*^9}, {3.771260742113587*^9, 3.77126078863237*^9}, {
   3.7712608356681213`*^9, 3.771260853796445*^9}, 3.77126088730492*^9, {
   3.771260950376927*^9, 3.771260951994858*^9}, {3.771260988204628*^9, 
   3.771261046264202*^9}, {3.771261095976034*^9, 3.771261100349186*^9}, {
   3.771261221602476*^9, 3.771261223165237*^9}, {3.7712612596219587`*^9, 
   3.771261376814014*^9}, {3.7712614254017878`*^9, 3.771261458422593*^9}, {
   3.771261523796259*^9, 3.771261558803645*^9}, {3.771525291980131*^9, 
   3.771525296404852*^9}, {3.771525340514213*^9, 3.771525362538801*^9}, {
   3.771525476715866*^9, 3.771525481529388*^9}, {3.771525527353706*^9, 
   3.771525572057776*^9}, {3.771525611182823*^9, 3.77152571017303*^9}, {
   3.771525850691698*^9, 3.771525923002439*^9}, {3.771525956576083*^9, 
   3.771525983790447*^9}, {3.771526019222022*^9, 3.7715260269883137`*^9}, {
   3.771526062519966*^9, 3.77152607841735*^9}, {3.771526152732314*^9, 
   3.771526160701219*^9}, {3.771526280292366*^9, 3.771526400673423*^9}, 
   3.771526440426137*^9, {3.7794773959510937`*^9, 3.7794774153789377`*^9}, 
   3.779479818451282*^9, {3.779482804081335*^9, 3.779482804522912*^9}, {
   3.780063051430872*^9, 3.78006305162116*^9}, {3.780063286850298*^9, 
   3.780063305483961*^9}, {3.780067547237227*^9, 3.780067619007799*^9}, {
   3.780254430235753*^9, 3.780254449602309*^9}, {3.7802547336341*^9, 
   3.780254734411544*^9}, {3.780257012559074*^9, 3.7802570858592567`*^9}, {
   3.780257124286892*^9, 3.7802572680528307`*^9}, {3.78025742903951*^9, 
   3.7802576687584457`*^9}, {3.780257712102442*^9, 3.780257724677702*^9}, {
   3.780257755591942*^9, 3.7802577557274637`*^9}, {3.78025778871243*^9, 
   3.7802579013536158`*^9}, {3.7802616510463943`*^9, 3.780261691559404*^9}, {
   3.7822630235259*^9, 3.7822630241256523`*^9}}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxFyQk01XkfBnBi7CFClhBlzZalkP/3b6kREVFMJttMblkrW6RCsmS7lhAK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        "]]}, 
      {GrayLevel[0.5], Thickness[Large], Dashing[Large], 
       LineBox[CompressedData["
1:eJxFyQk01XkfBnBi7CFClhBlzZalkP/3b6kREVFMJttMblkrW6RCsmS7lhAK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        "]]}}, {{}, {}, 
      {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwV1vc/1X0fwHFKZGdmpMvOSORklb7vL4VKZESu60TpkiOrhIxkpbIvUZQR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        "]]}}, {{}, {}, 
      {Hue[0.67, 0.6, 0.6], Thickness[Large], Dashing[Large], 
       LineBox[CompressedData["
1:eJwV0fk/lHsfgHFKtoQsUxIhCmVXZLk/d0R1lIgQERWTpWQryTIksiY6yC5k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        "]]}}}, {InsetBox[
      TagBox[GridBox[{
         {
          
          TemplateBox[{
           StyleBox[
            "\"first-step\"", StripOnInput -> False, FontFamily -> 
             "Helvetica", FontSize -> 12]},
           "LineLegend",
           DisplayFunction->(StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
             False]& ),
           Editable->True,
           InterpretationFunction:>(RowBox[{"LineLegend", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Hue", "[", 
                    RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], 
                ",", 
                RowBox[{"{", #, "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
              "]"}]& )]},
         {
          
          TemplateBox[{
           StyleBox[
            "\"established\"", StripOnInput -> False, FontFamily -> 
             "Helvetica", FontSize -> 12]},
           "LineLegend",
           DisplayFunction->(StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
             False]& ),
           Editable->True,
           InterpretationFunction:>(RowBox[{"LineLegend", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}], "}"}], 
                ",", 
                RowBox[{"{", #, "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{0}}}],
       "Grid"], NCache[
      Scaled[{Rational[1, 8], 0.625}], Scaled[{0.125, 0.625}]], ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TemplateBox[{
       StyleBox[
        "\"U=\\!\\(\\*SuperscriptBox[\\(10\\), \\(-3\\)]\\)\"", StripOnInput -> 
         False, FontFamily -> "Helvetica", FontSize -> 12],StyleBox[
        "\"U=\\!\\(\\*SuperscriptBox[\\(10\\), \\(-4\\)]\\)\"", StripOnInput -> 
         False, FontFamily -> "Helvetica", FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}],
             ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      NCache[Scaled[{Rational[7, 8], Rational[3, 10]}], Scaled[{0.875, 0.3}]],
       ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesLabel->{None, None},
   AxesOrigin->{0, 0},
   Epilog->{
     InsetBox[
      FormBox[
       StyleBox[
       "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=-0.2\"", 12, FontFamily -> 
        "Helvetica", StripOnInput -> False], TraditionalForm], 
      NCache[
       Scaled[{
         Rational[7, 8], 
         Rational[3, 4]}], 
       Scaled[{0.875, 0.75}]]], 
     InsetBox[
      FormBox[
       StyleBox["\"C\"", 14, Bold, StripOnInput -> False], TraditionalForm], 
      Scaled[{0.05, 0.95}]]},
   Frame->{True, False, False, False},
   FrameLabel->{
     FormBox["\"Growth rate\"", TraditionalForm]},
   FrameTicksStyle->{Automatic, Automatic, Automatic, Automatic},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.3, 0.25}, {0, 30}},
   PlotRangeClipping->True,
   PlotRangePadding->{
     Scaled[0.02], Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          GrayLevel[0.5], 
          Thickness[Large]], 
         Line[CompressedData["
1:eJxFyQk01XkfBnBi7CFClhBlzZalkP/3b6kREVFMJttMblkrW6RCsmS7lhAK
RZYpXZHd/V3bvbZru5N1Sta8KEokinfec97Dc85znvM5zwFXn7OXdjExMT3+
t//bQ3PpYpqaDMT0/3w6nS/Kx7bj6pekffND/ds2828Xfnp7x1eZNgQEO/q2
7f/4S2+yUe+237ayh3KU0LddcZnW7mO14/vcUYKDq13bPmbNVlhgvGPer61L
PHOd255Ou6fnR9xx8j+s3UZvO7Ztn6fIKRCy4/1ulibjYjueUPK9Q6pp33bR
YnrtHft2pDLlbCmrMAjeFfUrlt/akGd+umBWxQJoBo2rS6a1ocz9+yPZOleB
vEu5sJ5BQ4WX/zq8K50Fl9ZIs+QIoiFxESpiO8mO33ViXrWRpKESpO6gMsKF
m9YPmsxfpqLRLM7e3xn8eMmc0YIOLxUZdP+QWvUUwHlES1PCy1tRTdjzXz4v
C+J9/hETopstaID7lkx/qzAuQ7W9Sc9qQTLcI9oExX24n/ChvWG6LahjcuoM
6boo3uq28lxrsBllJ2yRR3LFcOGq1hOzfs1IZk6b63i5OE5gT3uXJdCM6vac
zjxbLIFX27kFniE1oTteBbup4ftxriIdfhbLJuRErtEhgCTusMZWXDnfiJi9
q1rVxiTxPzP71bRjG5GZpoGUlLMU7n38cWW5UiPSrtBSedYqhd94d8XgSAcF
WUXoxAhzSONhodotpCsUxDTRMy0pLY3fl2E2V+OkoPLvyUaGytK4QszDpw7W
CBn+nBsdV5TG9ejqZfZEMvInaXP6SkjjFnvayOd6GhDjS5GYH4s0nqmwkG8u
3oBKo23uubZI4TPAH2tIqEdnbq6jPB8pXNNO69rR8jrkaJ+q+oxTCg/1trdT
2apFB8Y+a4SkSOL0eyEGsua1KD/4jKUeryQu9ihXVjS9Bg1ObxzZCt6Pl3fO
LrKqVaO3xH/EtdUk8Hdyg9UdHlWocObWguIVcZwjvDWMWFSJYt54vTTJEMMv
HnsiKCHzGv3RxKsyNLoPZy9wOKop9ArFMy3tdpEWwj0ZA0OfHcvQvZYg+Xr9
vXgv89lgUhEJOcKLCR47QVy9gRjscKMUXR18uSmbtAe3UXePtKIWIRcGd+aS
NQ/+g2ER9t25EN10ltEn1HPhzwI1Qp5sFKCSUQP7eA1O/Dt57dpX9adI6JzC
XSZgw5+4/uP5qDMP+flSxpOHWPHTbBTCSbdcJFOdvex8hwWHLN469aNZSHEf
2wOhVSac88umfpNaBvKX54lLvrAFDNPFehuFB2h9aoJqO/cDHuWMGUxLJ6OS
ZrNC/6x16F7IufXxSALyOJuk1uK1Bq6ZoXf4D0ajR6/6DMecV2H1V5cwTaFw
JOJg/Lue31fwi7u/d+YtAZ1/3y/ftLYESznBI/37DqKn6cE+YqyLEHBMv6bz
wiX4+TLBbNB0AQJ281klb/jD17Cv0XMN/wF7oLiM5YfCkSqnM+4uH2D1242s
FfNIyDDvG7HXmIYUksYb7uVYOLls1VGsPAkZWv7se+hEWF6v5P/Vchw+EK0P
ZuemgPnSvKCy6hiQ37JWfiClgVYo1Y9AG4U0pepfNRsfgtfkt/sipCHwDvQY
vt2XDYqC43arE2/gZIukR8d4DmxwXTYcucCARI4rm1xBefCl+MH7eoE+2Cg1
oqkzP4WeRAmTu9zdQDgnQTwfkw/sWpvRAY4dwNhYsQ/Z8wzMIsyinIVo4Ogw
cSUguRBSp+dZn2u1wFxtd/BVwWKg3jCI989vBH+xulj31BLoy+DP56sjA1Nw
YfafQs9BLjl6r96rWogdTnnhmPYC3offvUY+UAXCuqFke5GX8FM8q6j7ZzlY
na4kKJ4mQeKD93MB+mUgHHL46jOeMpjx5ahQz3sBT4aEcpUoZfAno54o/LwY
VLS3ekp9X0GqAXsUh8YzqE6a3ToiXw4jrt7TuOxTMPnUp1Y1Ug5y6os6PIG5
0GtW56SfUAFWLE6OAcbZ8HthfiIyfA05pd3HFTQzYJYlARmvvAavKbpx9F+p
4OscuEgrqgTNwI+hudlJcCAo7XiIRxXEPGS2iY6Mh56k1zHqqtWgfv02y+EX
0XCr5O+BqaVqEJXLVGclRoBy87Lsw/IacKlnpp8SCoPhUYFrFgG1QCnNjU48
HQJRXzXIzLp1MFDaLiftGAjau625KzfqIPEC0cL9uC9MHrpq706uB8/nun9L
JvvAeY9d9EN+DXBN4IWttIo7dJBSDccVycDjsqn6V/4lwFblKrPHyOBmGsVn
PeQCr/RrlOwfILC2UI0ZtbsIKZSCnphDFDi0myRny2sPFpOfYgihFPgyr+so
WGID7GzHTE6MUuCcjWQOO7sVNCqEbcroNIKjuat1Oo8ZxCleomVkNMKxVrdh
/noTsFc6ReTdaAQNfk6a1HUcZJVVfou42ATt/ZGU9E1d+KS8R2YdNQHR2NZV
4IYW1BxemfORaYYN0YNKu/nUIUJluHw6ohlmabpAFFMEK9WGEIcPzTDA/yZO
M04WxNXyTvSdaoEy1VjVOBtJUH0XIx1S0gJOSrJDTrEiYBh/fUOOuxUcVx+9
7dEWANvjDgN9Hq0wnaWwXMnHA4R547KQrlZw9/2tOirmFwjOPBwnr0IF0Zs0
HYFAJog/JUToj6eCFN44dFTwO5a79tPw1icqeD25oGzFuoyVF85IKJyhQfuP
+yv7axcwxY/RseeLacAFVuki7DNYzhHl9QiWNgj3Ns8z+fs9JnSDfrn8YhuY
1hgEkB8PY7ENPoPjVW3g/FmurdaLgTGzCJzkF2gH9oquyc8X6FigaUUF5tkO
Cb/Zpt4UoWIf48/LelHbYUKk6T/ERAr2B2MtKUu6AyadO8r06qqxuVVtPtfw
DthychupWyzDrov5xilM/fsfDrVImyrGvhuQOBdPdMJ7GeFQu4dPsFCXj5Gv
CzuhSPNjf1paJsZ+T4k1hLMLlIKqyhZmk7GEIkKYkUcXnExqurzadB8T7srf
5KB3gffUksnoQDj2aHH8Zo8qHfjebextdQ3G3MawyJVoOvRapYyXzl7HVHuy
iOKTdFg8NXFXft0d+0ZeyzQ06Ib6KT1alPwfGKX0XAEhvRtcJuljVgIOWMzj
Vy/jP3fDPn2NozOcNtjZBL7acvMemPUMspwrMMPEb3u2DBf0QAqj1/RhghE2
5dXevbXVA7H+2CxvlS72X5kdkLk=
          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          GrayLevel[0.5], 
          Thickness[Large], 
          Dashing[Large]], 
         Line[CompressedData["
1:eJxFyQk01XkfBnBi7CFClhBlzZalkP/3b6kREVFMJttMblkrW6RCsmS7lhAK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          "]]}}}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          Thickness[Large]], 
         Line[CompressedData["
1:eJwV1vc/1X0fwHFKZGdmpMvOSORklb7vL4VKZESu60TpkiOrhIxkpbIvUZQR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          "]]}}}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          Thickness[Large], 
          Dashing[Large]], 
         Line[CompressedData["
1:eJwV0fk/lHsfgHFKtoQsUxIhCmVXZLk/d0R1lIgQERWTpWQryTIksiY6yC5k
qWxjD18aw1iHcWTPISTKUtmL5zw/XK/3H3CJ33C9bL+DiYmp8r/+r9RswgEV
lV5kYT/ZkvhMEeYvZAvxsPYi+q+THZZVKlBVVLx/boCBTJ2S5wvd1SCQr25f
yxsG+pSHzbH3a8JfXq2ELH8Gcoo7td1NwkFgoE8wwJiBnM+xjPuH6cKoxoSA
lSQDmdzKS4P9Z+F16jy/2moPEneaXQ7RMYB7TJt8/G096I55R7kHrxEo/qrm
PPyyBwmPzeVLyZrA0hfvHSq3e1DEyMuaBoYZlA6rbeio9SCzJoU/0+JW4E5f
WbrM2oOGnEovWAvZggql/OuNvm6U+NUy/yjfTfhV4Tnunt2NyoLkIvmjHKCs
QGUwyKMbveCif72W5gReaT+6Y3W60d6UyyMs1q7A0vLP1r8C3YjFQ5zXHNzh
6NidqzZddDTiRuDjVfECfUXl8g13OnLtYnvKm+ANtwJXeBP20VHyECfdwMcX
ghg1Liq1XUgnmEOu/D4JMg4H0Oi2Xeg8M0Pem/kx1HvqSrrs6kI3l7kOkb88
gVEqG4m9oBNNhnHYNKqGQdntllZXo040ET/hIDEeCeG7Q/n7VzpQAlE3uig4
BuwK9a2x1A40OyDgPjgaC+rGrLk5uh1I32Se+PHx38D9i7rINduOSLfZDkkE
JMJU/BMNz5h2VE478GplIBlqT+kFD59sR2qttmfNktMhdoSlS2e0DTk0hCeF
z2SCRaYMB59vG7pNMVITfZgNIg6GZ8YPtCG/PsMm0rVcmJD1CCiubkWSLrwi
dskFkLeQUBNg0Yrcwm7ZCkIh3C2rXTZcpSEi6GjQpUtA5eG4omg8DXmqXRLt
u0uGNW1Wl++qNGTm46bw12o51O84llvb24LKerQLlWlVIKYUb8j+sAVFuCcF
/Cx6D4+vM6+YiLYg/02/ATReD9NRLqnplGaUNaQklK7UCOdq+8/M3W5G5PWA
PUdFKFAwq/PtJHczavmzJBB0kgpcQoVxQWQqutdOeMYgtUCPV/CE0FYT2hmw
sOdMeQdINJs+6kxuQoPcdE7GFzp4EqQEAk81IbMaY5Wxkh6gOiy/Ve2nIHWL
3qnC+F4gVFL1ZjwpKMRqhjcouw+IbPGfkvko6JX7SS3/0X6oMnd4cKn4A5of
vKbVoDsEVmus+RVzjaj81li5TsYY3EpiKJyIaER4epnsLv1xuKuVVkGWbUSC
RPsaj74JCCSdaCp2bEBiF2Ze8pyZhnAJZgMFjgYU1ORXnik5A9JhL7OsjBHi
PbST/4n4LFzcS6u/Qq9DisVivoru85Ak/S3bQLgO5al2Jg4ZLsI08EacJtai
2bd66gluS0C6a2Eut12DPk0d0tL/9BM6n/hqHzaoQYcvp+YbSC/DgdSMw0IJ
1WiUZSndI2AFyO0zCywKVUh1ep0qeWUdPh3pr2pzrkR/NPQCw35tAHsQNTAm
rwJ1OK/E2mb9Bmv1V/wHJcpRa621yPg+JvxpXMzIuE0Z6jcJCB1iZcZL5/1z
cpPJSEZkZvf2H2acLcdKTUWwFG0nSDkdYWXBXXo/DizZlKBQewpWsmsX3s18
2ac4rxgFBanmqnKz4op1MT5W3oWorzNSaU6bHV8XCq0b2P0OLZqnR9UQOfAP
9/2YzNLfoJmoqJKJdE7cRNEpxKg5D+WlCx1N0tuD/+69GLhum4vK57IoBaXc
+OsHSr6vNnMQRj//tVGEFzcSFnxgEJ+NfFlD7qj/5MXX69fcfilmIQ+D3z8G
Rvfir26MuKS2Z6K4s740kc98+AXWBqK+QwZi8La2O3MK4N9MzlI/MaehjpH8
gSVrQRySud8rqiUjTU2iAs83As7xY0vzg0IiYqr15Pm4sh/vPbdQayL9NzIX
8CGnPBXGU9PHtKfEYpFzukbMkylRvOtbut935Wi0QNzreoIijt9IIgXwSj5F
M3yrd3yPSeErZ+0CVQSDUGu7rRsqkcX55x6zvuPyRpU2/0hpRCrjnpHhAtOj
RJRG97g9RAB8Md1niLFfEq2/THlamGeE31fXrG63tIfLC7/CP0dp4/f38BjF
bnpB1c9/JYaLFXALaLAbyybBpGOBYIKdJL6y6p28bBACle1+/TojB/G4YqW+
3T8jIPXqTZmxVEE8UdWLbW9nDGzURHKu0XjxLzHGkikZceAT9Dj5cwUnXj/K
UvGlOB6eWs1rWJ7ZhcfLVp1VaXwJNonPb5jJM+N3HzgP+vekgBO9xsCG5zfo
N4k6t42nw26Bq02D+1fhGbvjFufDTDBc6/FiEvsJm4U6LYrMWaC3hYm10ReA
eOVgjFlYNvTLmlt3h89C7+ayhe/e19C8GB2joTwNNlYTjvdjc2G9KkfL//UE
zNZ0+dzjz4c0AsvpYpsx8DrwPsLpRQFYHP3OFn1rCJh8clNuCb4FrYaAxTjV
jxAxGPfOJv4d5B6X0GN7xwDCKVK9xb4iIJXZ5rHZ08HoQgVR5kIxtElJ049Y
twHB9/i911wl4J33u01fpBleDQhmyDaUQFzNmSOZ6APIndimF3qUAsVw7Hc1
QlD1fGZb+SgZWlguePzpr4Ez8z0KlUNkuB4r3G+SXwHdf72/rhldBnw0mrqL
EBmu5WY/Q6fLIVioQKdobzHM7IxGusvloNdy8ZrtnwLwsH2w0JJXAdiDD29d
0l+D+MN4LV/nSjDSzujIyXoF9OflYYryVZCwz5xKzUoDv4J/Pk4uVoEpeY5U
JvoSjlF+Hn5JrgZ1+QzRsPAXMDjM53bxfg3YNE8yP2uIgdBfSvXMp97Dc2p4
8jBEwIk9xrsrNt/D0o81UqZQCHyWumfhVF8LJFPPq5ZjgWDmvKNTyrMO1Njq
RRnaftBW/OL0uEw9CHi9f/Z9+AFgK0cqUsbqoejtk8CHTh5Qqlkta/E3gjp4
9HnusSvENeTQw6QaIMmLfXMy0BEufp4PI5IaoFDpy42b8beAjVX9jN5wA0xy
LzYxnttCo3TglsTJRui68rHLLdESImXsWxITG6FTk0d7dsIULGTPx3BvNoKn
yUpdooURHD4mdzXY+gPQ2NlOTfqfh/ljeyU2/vukqWHEydStC9XHl2ddJSgQ
VMAUYV6IQbDcIHkqmAJWhJ7rqm/UwEi+ztfqCwVMRQgXNxSVQVghU6/nfBP8
tmuaCh0+BvKfwsR8C5rgqh/tbqmlFJyOct88spsKjlsEyqihGJhqWX3scaaC
THbWgk/3fiDO6Zb4dlDhimHUxp0uPvBJOh55VK4ZuItFvWXsuSDqvCCREdUM
exR0cRHLXZCx9ue033wzlNQyrddvbmPk3OmD0pdaYK4jdNJxeBWT+f40wiy/
BZ4nhPEvCvzA0pWPbQTvpAFzopqW6aU5TNC78zbZmgbfkoR5jSMnsYg61/7x
ShpcWfmZfa3rE8a8k0+fl68VFDn2cbsw92MPzpWVYS6tQDi5ZXJVpAf7HmV2
+E5zK3A9o2TkW7diN3vXnieLtcFgTMq0YfUHbHblBM+NoDYwFvz2ncqowdwP
eERKT7bBfsUpa91DZGxdu5hjQa8dqqzNXX6Lv8FIdt9DynPb4VqKt2v30SyM
7Yksiy9HB/AtVX2u/5qERecRA3WcO4CEHok9p8dihI7sLfbODnjTECMgJxOO
pS6MP6LLdwL1/OJjyv4gzGEMC1l+2gkxG00k15yHmDw9OUb4cyeIVFz4sURw
x1br15JOa3eBVIhWf4qDI9ZQeCWHmNAFskds4seRHRaWVloUtdQFIhcLhVaL
LLDL0Tw1ZAM6KPgru7QJGmPC/i5Ngzl0INAq69ZCz2KTd1q7trfpgLlwHY89
hGP/A7rYt3s=
          "]]}}}}, {
     Frame -> {True, False, False, False}, 
      FrameTicksStyle -> {Automatic, Automatic, Automatic, Automatic}, 
      FrameLabel -> {"Growth rate"}, PlotRange -> {{-0.3, 0.25}, {0, 30}}, 
      LabelStyle -> Directive[12, FontFamily -> "Helvetica"], Epilog -> {
        Text[
         Style[
         "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=-0.2", 12, FontFamily -> "Helvetica"], 
         Scaled[{
           Rational[7, 8], 
           Rational[3, 4]}]], 
        Text[
         Style["C", 14, Bold], 
         Scaled[{0.05, 0.95}]]}, AspectRatio -> GoldenRatio^(-1), Axes -> 
      True, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
      PlotRange -> {{-0.3, 0.25}, {0, All}}, PlotRangeClipping -> True, 
      PlotRangePadding -> {
        Scaled[0.02], Automatic}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          Thickness[Large], 
          GrayLevel[0]], 
         Directive[
          Thickness[Large], 
          GrayLevel[0], 
          Dashing[Medium]]}, {
         Style[
         "U=\!\(\*SuperscriptBox[\(10\), \(-3\)]\)", 12, FontFamily -> 
          "Helvetica"], 
         Style[
         "U=\!\(\*SuperscriptBox[\(10\), \(-4\)]\)", 12, FontFamily -> 
          "Helvetica"]}, LegendLayout -> "Column"]], 
      Scaled[{
        Rational[7, 8], 
        Rational[3, 10]}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{{3.780257452734988*^9, 3.780257477453064*^9}, {
   3.7802575410524187`*^9, 3.780257618687738*^9}, 3.780257684159048*^9, 
   3.7802577273734303`*^9, {3.780257866716571*^9, 3.780257912914888*^9}, 
   3.780262210192553*^9, 3.782263760213317*^9}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Variance, \[Lambda]", "Subsection",
 CellChangeTimes->{{3.7802617352674723`*^9, 3.780261738674717*^9}, {
  3.780261768932378*^9, 3.780261769163059*^9}, {3.7822591739242563`*^9, 
  3.782259176819401*^9}}],

Cell[CellGroupData[{

Cell["Probability of rescue", "Subsubsection",
 CellChangeTimes->{{3.7564892474960623`*^9, 3.756489252807234*^9}, 
   3.7606376392688437`*^9, {3.7642036999242487`*^9, 3.76420371369766*^9}, {
   3.769431834041813*^9, 3.769431845906336*^9}, {3.769431894299581*^9, 
   3.769431896986474*^9}, {3.769432022608979*^9, 3.76943202539149*^9}, {
   3.7694324961732264`*^9, 3.769432496341527*^9}, {3.7694327378288794`*^9, 
   3.769432739203771*^9}, {3.7694390881946793`*^9, 3.769439089784932*^9}, 
   3.7712459034631767`*^9, {3.780251653828335*^9, 3.780251661330201*^9}, {
   3.780252898262912*^9, 3.780252911301763*^9}, 3.78025362510145*^9, {
   3.780261742230752*^9, 3.780261744274851*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"N0", "=", 
   SuperscriptBox["10", "4"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"U", "=", 
    RowBox[{"2", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m0min", "=", "mTempmin"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"m0max", "=", "mTempmax"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mstep", "=", "step"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"m0list", "=", 
    RowBox[{"Table", "[", 
     RowBox[{"m0", ",", 
      RowBox[{"{", 
       RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Lambda]", "=", "0.005"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate4", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]4Interpolated", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate3", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]3Interpolated", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]2Interpolated", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]1Interpolated", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"theory2", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m0list", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"prescue", "/.", 
          RowBox[{"p0", "\[Rule]", 
           RowBox[{"prescuem", "[", 
            RowBox[{
             RowBox[{"m0list", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"rate1", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m0list", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"prescue", "/.", 
          RowBox[{"p0", "\[Rule]", 
           RowBox[{"prescuem", "[", 
            RowBox[{
             RowBox[{"m0list", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"rate2", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m0list", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"prescue", "/.", 
          RowBox[{"p0", "\[Rule]", 
           RowBox[{"prescuem", "[", 
            RowBox[{
             RowBox[{"m0list", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"rate3", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m0list", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"prescue", "/.", 
          RowBox[{"p0", "\[Rule]", 
           RowBox[{"prescuem", "[", 
            RowBox[{
             RowBox[{"m0list", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"rate4", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}]}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alltheory2", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"m0list", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"prescue", "/.", 
         RowBox[{"p0", "\[Rule]", 
          RowBox[{"prescuem", "[", 
           RowBox[{
            RowBox[{"m0list", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"rate1", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate2", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate3", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate4", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "]"}]}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Lambda]", "=", 
    FractionBox["0.005", "2"]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate4", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]4Interpolated", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate3", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]3Interpolated", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]2Interpolated", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rate1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m0", ",", 
       RowBox[{"\[CapitalLambda]1Interpolated", "[", 
        RowBox[{"m0", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"m0", ",", "m0min", ",", "m0max", ",", "mstep"}], "}"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"theory4", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m0list", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"prescue", "/.", 
          RowBox[{"p0", "\[Rule]", 
           RowBox[{"prescuem", "[", 
            RowBox[{
             RowBox[{"m0list", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"rate1", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m0list", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"prescue", "/.", 
          RowBox[{"p0", "\[Rule]", 
           RowBox[{"prescuem", "[", 
            RowBox[{
             RowBox[{"m0list", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"rate2", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m0list", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"prescue", "/.", 
          RowBox[{"p0", "\[Rule]", 
           RowBox[{"prescuem", "[", 
            RowBox[{
             RowBox[{"m0list", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"rate3", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m0list", "[", 
          RowBox[{"[", "i", "]"}], "]"}], ",", 
         RowBox[{"prescue", "/.", 
          RowBox[{"p0", "\[Rule]", 
           RowBox[{"prescuem", "[", 
            RowBox[{
             RowBox[{"m0list", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"rate4", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}]}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}]}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alltheory4", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"m0list", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"prescue", "/.", 
         RowBox[{"p0", "\[Rule]", 
          RowBox[{"prescuem", "[", 
           RowBox[{
            RowBox[{"m0list", "[", 
             RowBox[{"[", "i", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{"rate1", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate2", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate3", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}], "+", 
             RowBox[{"rate4", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}]}], "]"}]}]}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", 
        RowBox[{"Length", "[", "m0list", "]"}]}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ListLogPlot", "[", "\[IndentingNewLine]", 
     RowBox[{"theory2", ",", "\[IndentingNewLine]", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", "Thick"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.4"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"5", "*", 
            SuperscriptBox["10", 
             RowBox[{"-", "7"}]]}], ",", "1"}], "}"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Frame", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Wildtype growth rate\>\"", ",", ",", ",", 
         "\"\<Probability of rescue\>\""}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"FrameTicks", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"True", ",", "False", ",", "False", ",", "True"}], "}"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{
            "\"\<1-step\>\"", ",", "\"\<2-step\>\"", ",", "\"\<3-step\>\"", 
             ",", "\"\<4-step\>\""}], "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "/", "4"}], ",", 
            RowBox[{"1", "/", "4"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"alltheory2", ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Thick"}], "}"}]}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", "\"\<1-, 2-, 3-, or 4-step\>\"", "}"}]}], "]"}], ",", 
         
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "4"}], ",", 
            RowBox[{"8", "/", "10"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"theory4", ",", "\[IndentingNewLine]", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", 
         RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{"alltheory4", ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Black", ",", "Thick", ",", 
         RowBox[{"Dashing", "[", "Large", "]"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Directive", "[", 
              RowBox[{"Thick", ",", "Gray"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
              RowBox[{"Thick", ",", "Gray", ",", 
               RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{
             "\"\<\[Lambda]=0.005\>\"", ",", "\"\<\[Lambda]=0.0025\>\""}], 
             "}"}]}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "10"}], ",", 
            RowBox[{"6", "/", "10"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"Text", "[", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<A\>\"", ",", "Bold", ",", "14"}], "]"}], ",", 
       RowBox[{"Scaled", "@", 
        RowBox[{"{", 
         RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "N0", ",", "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", 
   "m0min", ",", "m0max", ",", "mstep"}], "]"}]}], "Input",
 CellChangeTimes->{{3.771243438404381*^9, 3.771243505591201*^9}, {
   3.771243660674692*^9, 3.771243770343318*^9}, {3.7712438051594973`*^9, 
   3.771243806769825*^9}, {3.77124384246271*^9, 3.7712439832452*^9}, {
   3.771244074547236*^9, 3.771244075614129*^9}, {3.771244170126183*^9, 
   3.771244240128414*^9}, {3.771244491552649*^9, 3.771244539467946*^9}, {
   3.771244637848792*^9, 3.771244771807975*^9}, {3.77124482635817*^9, 
   3.771245429892724*^9}, 3.771246073841148*^9, 3.771246637425001*^9, {
   3.771252282261911*^9, 3.771252288712202*^9}, 3.771254690716058*^9, {
   3.771254724632944*^9, 3.771254752430646*^9}, 3.77125504889705*^9, {
   3.7715446486731167`*^9, 3.771544649294244*^9}, {3.780251817258157*^9, 
   3.780251837264227*^9}, 3.780252917208507*^9, {3.780255349776267*^9, 
   3.780255419507058*^9}, {3.780255450934721*^9, 3.780255487344339*^9}, {
   3.780256197190711*^9, 3.780256197383162*^9}, 3.780256244789771*^9, {
   3.780261452504554*^9, 3.78026153410004*^9}, {3.780261776978413*^9, 
   3.780261793201942*^9}, {3.780261827824634*^9, 3.780261903135303*^9}, {
   3.7802619470801783`*^9, 3.780261948041774*^9}, {3.780261999446536*^9, 
   3.780262023533655*^9}, {3.780263443349515*^9, 3.780263462955304*^9}, {
   3.7802642818311167`*^9, 3.780264301212077*^9}, {3.7802646320950613`*^9, 
   3.780264632224587*^9}, {3.780264809267377*^9, 3.780264810179904*^9}, {
   3.780264869159597*^9, 3.780264884846908*^9}, {3.782263035454726*^9, 
   3.782263035798542*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(1.4363490176861695`*^-7\\)\[NoBreak] and \
\[NoBreak]\\!\\(1.034782441470326`*^-12\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7822637615333643`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(2.0246698484863734`*^-7\\)\[NoBreak] and \
\[NoBreak]\\!\\(1.0921054693023465`*^-12\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7822637616343393`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(2.850952330867838`*^-7\\)\[NoBreak] and \
\[NoBreak]\\!\\(2.321744002394699`*^-12\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.78226376175578*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(NIntegrate :: ncvb\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7822637617864513`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(5.3450453526009294`*^-8\\)\[NoBreak] and \
\[NoBreak]\\!\\(5.951525075263353`*^-13\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.782263863360815*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(7.059025621526559`*^-8\\)\[NoBreak] and \
\[NoBreak]\\!\\(8.588848983658455`*^-13\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.782263863472796*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(9.314638149255934`*^-8\\)\[NoBreak] and \
\[NoBreak]\\!\\(1.711619241364099`*^-12\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.782263863631857*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(NIntegrate :: ncvb\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7822638636713457`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(1.4363490176861695`*^-7\\)\[NoBreak] and \
\[NoBreak]\\!\\(1.034782441470326`*^-12\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7822639676829*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(2.0246698484863734`*^-7\\)\[NoBreak] and \
\[NoBreak]\\!\\(1.0921054693023465`*^-12\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.782263967790802*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(2.850952330867838`*^-7\\)\[NoBreak] and \
\[NoBreak]\\!\\(2.321744002394699`*^-12\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.782263967897409*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(NIntegrate :: ncvb\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.782263967939406*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({\\(-0.19962336247647916`\\)}\\)\[NoBreak]. NIntegrate \
obtained \[NoBreak]\\!\\(1.371611099561599`*^-10\\)\[NoBreak] and \
\[NoBreak]\\!\\(3.2533774948230864`*^-16\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7822641241455173`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({\\(-0.19962336247647916`\\)}\\)\[NoBreak]. NIntegrate \
obtained \[NoBreak]\\!\\(2.459129528372128`*^-10\\)\[NoBreak] and \
\[NoBreak]\\!\\(5.379711113614932`*^-16\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7822641245289583`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({\\(-0.19962336247647916`\\)}\\)\[NoBreak]. NIntegrate \
obtained \[NoBreak]\\!\\(4.382809860895368`*^-10\\)\[NoBreak] and \
\[NoBreak]\\!\\(8.119644899145538`*^-16\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.782264124885974*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(NIntegrate :: ncvb\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.782264124918275*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(2.830813641888082`*^-9\\)\[NoBreak] and \
\[NoBreak]\\!\\(3.4578366587790035`*^-15\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.782264282297827*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(4.427814198985973`*^-9\\)\[NoBreak] and \
\[NoBreak]\\!\\(8.978439335615778`*^-15\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.782264282486959*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({0.0007672625235208453`}\\)\[NoBreak]. NIntegrate obtained \
\[NoBreak]\\!\\(6.8986954726390565`*^-9\\)\[NoBreak] and \
\[NoBreak]\\!\\(2.174871671811652`*^-14\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.782264282660488*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(NIntegrate :: ncvb\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7822642826970387`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({\\(-0.19962336247647916`\\)}\\)\[NoBreak]. NIntegrate \
obtained \[NoBreak]\\!\\(1.371611099561599`*^-10\\)\[NoBreak] and \
\[NoBreak]\\!\\(3.2533774948230864`*^-16\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.782264463242383*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({\\(-0.19962336247647916`\\)}\\)\[NoBreak]. NIntegrate \
obtained \[NoBreak]\\!\\(2.459129528372128`*^-10\\)\[NoBreak] and \
\[NoBreak]\\!\\(5.379711113614932`*^-16\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7822644636121693`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "ncvb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"NIntegrate failed to converge to prescribed accuracy after \
\[NoBreak]\\!\\(9\\)\[NoBreak] recursive bisections in \[NoBreak]\\!\\(m\\)\
\[NoBreak] near \[NoBreak]\\!\\({m}\\)\[NoBreak] = \
\[NoBreak]\\!\\({\\(-0.19962336247647916`\\)}\\)\[NoBreak]. NIntegrate \
obtained \[NoBreak]\\!\\(4.382809860895368`*^-10\\)\[NoBreak] and \
\[NoBreak]\\!\\(8.119644899145538`*^-16\\)\[NoBreak] for the integral and \
error estimates. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/ncvb\\\", ButtonNote -> \
\\\"NIntegrate::ncvb\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.78226446398013*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(NIntegrate :: ncvb\\), \\\"MessageName\\\"]\\)\
\[NoBreak] will be suppressed during this calculation. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/General/stop\\\", \
ButtonNote -> \\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.7822644640172663`*^9}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwtkF1I01EYxv9pZKhNVzOWoc6PdE7TUOdVrcKLZRTojMASpKlFBWrQRO3z
QgkinUuTirKLCdaFk2W2abXnTdPlSnHOua0LaX2wygSz1AiLdv7bA4fD4Zzz
e5/nSVTXqKpCOI6T+hfb795h8iD956pJPptJK9Iy7fCyGyM1Y2HPDBmkMsc3
zxe7kd8ywZmuy8ig9DaKDC4sVxj1OWfSKcKlr90T7kKW71d//mEpnTrJNIu8
gQLnm9w0GllmQCeWFJ3lf+JSKcFPM8c7cb7eqrFF7KALIkacwZVm4fuCv8nk
5nEO3P/RKa5eSqK8XCYHsha9+UXzidQ2zIDT6PMpfi/6JPS9mBm0Q90X1do7
lUAHmD2lHT0dsf1RnjjqZjj9FB6rNzhFX7cTx2sKC5vUu21cLA2yeOZJVBZa
S/ZKxHSOPa+dQLnePnRNuZVkrA7pW/hqDzZY6kT0geG9Nkw+fWcPN2ymQH/j
mEnZWNWzEE0lfF+voR1XZXjOCoL9WLHr9NFPFkFEsI9R7Ouqb28ZDaOLfP5X
yBq9HKq7uT6YdwRzW6Ty5IZ1wXwvodO0K3aurSGQh9CVI7vRWLQKfpzZgm3a
mDlByBIyeb/PEZ1Wqrt05Bvu8f4GETqkybZPexHJ+zHBkf3l88AtJwLznyCm
QptySDyGwDwjRMqOBzhuDPIN+KeTf2x9qMNtnvcIK0mFkv3CE7jK/+9GpLm0
rKpACOLfd+FYXWV9m6DJErjvQJ7AX3tq9YvAuQlcUP8Bo3NLMw==
         "]]}, 
       {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJwtkF9Ik1EYxtcKpC2W01nJUnPZmhFp2rKbNVqExhi0CRERYemqm8pZFKkX
I0wRJ2qWbZGZzBGlzYqB3yj2vk1tFpttU9saBG1+JNjoj5sjaBd5vn0PHA6H
c87vfZ6n+PxVnZ7L4XBka4vsDy1EX2CQjmwueLkbU7IzPe7VMKSs7W3nElLU
UYV3fmjDoLrmUEQOStFeHW0W2UNwu2P0ial5F/JD1kYFLwQJbdzS7CrBixeI
PkNyZtE9xi3ByVUCXIA/3KZgefVOLFqjUYULEJ7P8+WbJNgiIsR5kAsFQmOg
GMMMbg78iesu49ZiPFBJNAfBulNdyrM7sNdNgEGYUlVxp9RFGNcSgwFYCX4/
Jv1agDXEXnUAbgrSpesM23GE4Kx+OKzRWxxZYuQw8sMJm2LIOpyPThKPmoVU
3/1UhXIbGsjzRh9U8YbfeL5twT2kDpkXLtn61e/b8zBG8NGPIBdXnu7bL8JM
fx8gEXMqO6M5WMv0NQPjHXQL/4GQ7ccD5fEb+iZdNtvHNMR6636VygTYyuSf
ghVbja6b4rN5J8EtftpgP7mRzfcOBiSfNCXrs9g8CD4v39Tq2oDMOMoFxw23
6EOdXNzL+H0L6aDd463n4CPGnxPkZZO0fDANmxg/E0DfpZLL/X8hM98BDS9+
HlWPJSEz7xVcHqpVZS/9hgzfDpKJ7iVD1zKYGd4z8ONzns68CEbm/wgcGTXv
G8iNADLvH0NBRa5jvN7L3t+Dfz20P2f1NXtug7JpTXLWcwX+AxnkWJE=
         "]]}, 
       {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJwtkGtI01EYxrdRIqtV6qjZ2tbMXcwCwUV+yKhUNCRCqzWjICxXYjDFGJub
4IeK6kMXZ+h0WeaIWTTK1P23yvdNu9jQpblrtWxGLMz6EK0LRuX5+3/gcDic
c37v8zzSSl15FYfFYinnF9nbrUQRaJWEk7bcysIfyoMXhxJh6HnnuhFdloXl
lPj057IwHIr6q631SnQWxxr4zhC08qd694cVuCTUXZvPDYErT7ONla/AY1qi
IBzvv7zZ3CXH4QQBBmBvjUjRt1iOknkaJQ7AdIXMcaVahiY+IfqBvS+XShnL
xDCNmwQjW/dVnJOJqlyiSfBtdXg9zevw0hABvgJrmy0+8z0DZ8uIwQlIPQOB
R+oMLCH2iifAd3KgpZSSop3gusfBZOVb+tOlyKI1DhV3d2yUm9aim8SjfGB7
bddec0uwjjyvHQONLic52CjG9aQO5ShYVEFHTYEIpwk+5gXO4evGGHcNLvT3
Aq6WaHd5/KtxD93XCDxTP1Dru9KZfp7D25aG6IU6AdPHUzAk4vG6olVopvM/
gaYiG9UoWsnkHYbmjp0f5n7zmXyPwVN/ziJ8k8bkQXBtKjgxg6lIj6MGwSQs
FJTeTsENtN+HYNcPyz5ZV6CN9ueGfwZZZLtgOS6l/bjgW6G3KsLmMfP7oP2m
sOPAFy4z7x6opszvRwLJDN8JVXf0lUfuJ2EbzeuBXg3bAMZF2ET/twNvzpD9
MY2DSL/vhE6eJO/swF9YuG+BX6ODAH9+MudTcPTlbm72+Vn4D6fQUYY=
         "]]}, 
       {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGBQB2IQzfzn41b7Fzf22y+uP5nHonsgaIdc6+vAG/tXvXhU
UVOrc2Cd+8MqkXXX92+YMUlA6JX2Ae7riwtsua7vN99/i8coTPtAehoIXNt/
cEHEqX0HtQ4c/qoR03/o6v4M5VmBs3W0DsgDTdshd3X/tY40nbXTNA9Ui4BM
vLI//Lqv373/GgdugI27vF9qyYxZchkaB0yMQeDy/pS7d/6mnlc/MOEQyMBL
+xkUa79sNVU/8CYQ5MCL+w8mKytKz1Y74AFynvvF/U2SL/nW/Vc9sARk3OIL
+29WeWdNTlY9wAAGF/a/WL244fcxlQM7Qd7bcW7/w5xUUUUtlQOFIOUFZ/ez
2TROcO9VPqAFdP1XjTP7H0X/2bPjg9KBRyDjH57av/nUJ9NDIUoHZs0EgZP7
CxNcNm3aqXggGBxeJ/ZfDOH2vi6vCA2f4/v1il+er2hXgIbH0f0qmglxmx7K
H6gB+//I/m9mfbsSd8hB/Xt4/1G97RYRk2Wh/ju4v+FuzoXzRTJQ/xzYr/+u
O/ZOmPQBsHU79u3/y7xpWaK91AEdsHv37J/DWBzHqiN5YA7YfTv37/gW2Ssl
I3GAB+ye7fun/Pj7r5FPHGr/lv1LvPP2ljOKQe3buH/mZS8Xu08iUPPX7f/h
ldzcfkf4wAyweSv3V3cduBO0U+hAA1j/kv3GrK9bWmoEDxwAq5+3P1VYPv03
nwBUfsr+64X8UjcqeKD8lv0KRtO4Xu5jOwAAoZBGJA==
         "]]}}, {}}, {{{}, {}, 
       {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwtkHtI01EcxWckmQ9SmmKbzcd0LhsxMuuPGAWGGyaMrYTWWlH4KBhN+6fM
pFyG/RMzHGayTFCp1doyQjesnTvfmuXM3AxTXIUgbajUSmJB3t924HK53Hs/
33NO5gWdsnwLi8USbi66tz2k+oyWl9Hv+pcE5LfwjGEgOIfcDrFLkysgSjvv
zg/FHH6VhYYvanOIVeq7zrZ64cvi1vTbskmct7NKEuvF38KFpYPrfFJZQeXB
UJ3/0aiYTwaDFDiL3ivF8orLWSR9k2bnzcJU64vnPMsktWxK/ISxkHJg41sG
mWNwM4jzyjm5aRnkQD7VDA6rild7unmkaYACP0JtYF9tS9xN/ApqcBoLIZnW
VMMlMmpPOo159fNJtW8X6aK4TjcmVHxboyyVsBi5UbD4lO+xpRAHjWf/AJ9G
J49KTSbV9HnVe6xy9h4bqd9J8mgdwkm4SswJy4Ek8pXifRNoNJXV7NEkknB/
4/BKuTp3RwI5wfQ1Bsua5Ljwfmykn1HkG788ab63LdLHMMaPaGVTrVvJDSb/
EJondhSe7o2K5B3EPtGllabZfwjnc+GcqsFQem0D4TwEMdlFpuTyn2DG2Z0w
O14VWM4HIGL8voG4XPRH7/8OE+PPgaS8lJH1k/OIZ/z04cXy9lJB3RTC819j
5awk+DjaGZnXg/S1lvpAUXeEb4UjVJl2ql2PVoZnhmct5+ahxRLcYv53obrP
qLsdE3QS5n07Hihseu1RjTN8b4SF1n53/9vwuQGsiP4D/QhP6Q==
         
         "]]}}, {}}, {{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[Large], Dashing[Large], 
        LineBox[CompressedData["
1:eJwtkH1Ik1EYxYcLHG3CRmMtgy0TcYxZlsuZaElB2wrCmZW0aBE6pcCMoEkb
ZVIERalUNseSYgYtcGugOavtedxWU1Pxa86+qGl/tZmhe2MEQt5374HL5XLv
/T3nnJxzF6vqMlgslmx9kd3WRfQJbKtmVnWkFP/KTrcFqHnoTCRTQ7/2YpVX
ciuumwdq3BpRLJagSx27KnRFQWbK8lyYUyE36mgq3xiFDff41qOjxVhvJJqD
1s3N/ddCezBIEWAE3szdTz4NKFG6TvNKIsAzaZMQKkKzkBBnoZe/tCr+uBvn
adwM6MIi+/PILlQWEc2AmNO03/yzENsDBDgNrsLFMs3yTkzoiMEp4HMPu2sk
O1BD7KmnYEA/0XbghAJ7CM4xCRaD8JH0sRxZtCah5Hy3MzMmw0ESzzsB0tu1
BoEyHy+R503jUHPKF9W156Gc1CEbg1ZRSv+VysUFgo+NgvHZ94xA7XZM9zcC
ntexLsG3bXiM7msYcho/PHH7JEw/Yah0lEsrZrcyfbwHLdVvWloTo4XOHwJx
8GDHl1IRkzcIf9hxw5G7m5h8QxDm1DW8XeYzeRC4zS9/V0zzkB7n9UOjRZV1
ZyUTFbTfd5Av/ScfPsRGO+1vEF6djTvr+9aAR/sZgILcPD/nOgXp+X0wsHJS
3alLQHqeB8r0n30L/B+Q5rugo+HGGa52DKw0zwkjqexki8oNLfT/HjCyH9hS
BWZA+n03XLGrL/e+2MLcP4RiQeW+7OMaf/p8E1iM/gN0Ik+L
         "]]}, 
       {Hue[0.9060679774997897, 0.6, 0.6], Thickness[Large], Dashing[Large], 
        LineBox[CompressedData["
1:eJwtkHtIk1EYxmdMWLNcOqNC0rzlLppzGmRRYeQWMqg5/8oZKssRYS4q/7B1
Q2ckqEUlZqOwb0kjGwaJW5jv21boZNXmXN+kdVGSiNSY4DIYlufb98DhcDjn
/N7neTLqGitOruNwOKK1Rfbee0TT4PpXdrzUI8eISNvlXA6Cu16YWCmTY4U9
zfRLHQQLv1LhuFuINuVMc4qNhuT+QOB8VIYJNGXYz6chd9P6V0adDPX1RB8h
vrPXdP1+AbqWCTAAR3frnhgNuzB9jWZPC0AxrSi1K/PxYgohTkHGgZLTWzPy
MMjg/PD1c3KoKSrB4iIiP5RT9LGn02K86STASTg4lyrusItwXk0M+qDIo9Kt
9OTiEWJP6YP8UWuJp3knWgiO8sLjju7qSHUOchh5YWyhqubcoWx0kHj29yD3
uqUaURaeJc8N7+DEo9U9I4JMlJA6RB4IP6MWF1Z24CzBz0yAvuFDWct4Osb6
c4OTO9uptGxHDdPXOGja5viFbalsP2PwPTv1Wm3jNraPtyB6WNUtqN2CRib/
G8hR/dVe0m5m87pgwCwO/q4TsvleA7f8S8PAhSQ2D8IQ8ELzUgEy4+yjMOaP
XslsT8A8xu8IJN0Kx7fzeGhm/DmgSbKomrBycQPjZxhW+8zDg4Y4dv4LiJpO
Ld3AKMTmPQfafLvP/ycCMb4NfghbatRdYehheFbY119ALWX9hKvMfwvYWhPd
/OxvgMz7BxC392X+xikve38HfCGKviwdYs+tMPnp8KBecQb+A3JIU/M=
         "]]}, 
       {Hue[0.1421359549995791, 0.6, 0.6], Thickness[Large], Dashing[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGDQAGIQPWsmCNzcf/OdS81tfqMD3zRi+g99vbHfT2WzSdAk
wwNBO+RaXwfe2N/GlNhZKGp4YJ37wyqRddf3d/1QuOUy0+AA9/XFBbZc1/fH
fGFZekHW4EB6Gghc2/+1ICjQwk3/wOGvIAOv7n/bLH0zLEjvgDzQtB1yV/dn
i0Q6siboHqgWAZl4Zf+9qvW3XPJ1DtwAG3d5/8Pbk8oEGrQPmBiDwOX9/tPl
P0ZN0jow4RDIwEv7v0hyNfMu0zzwJhDkwIv7s8qVm9h3axzwADnP/eL+47WC
B6Uuqh9YAjJu8YX9vZbP5gi+UDvAAAYX9jt8mBqz9r/qgZ0g7+04t5/F7+GM
NeKqBwpBygvO7uc9MFnrlL7KAS1QcGic2Z+9lHHnNXflA49Axj88tV/ksnjR
unilA5DwO7k/NF/7k2+54oFgcHid2P91Vu+u630K0PA5vl/8p1Weoa88NDyO
7vec+Wi1QJ3sgRqw/4/sn2HM+79tozTUv4f3r6q3nsn2UhLqv4P7Xz75Fquo
JgH1z4H9s85fVcnNEjsAtm7Hvv1WKn6m6dtFDuiA3btnv26R395wPuEDc8Du
27nfoaz2g3GB4AEesHu2738/RfDj1138UPu37L/nceUazxoeqH0b9x9ITAht
2sgJNX/d/qPbdGLDj7EdmAE2b+V+9Y4Mxk8PmA80gPUv2R+/Timo9z3DgQNg
9fP2s33UaA1d8Hs/RH7K/pna3TfNyr5A+S37tzO83nnq89P9AGfDTF0=
         "]]}, 
       {Hue[0.37820393249936934`, 0.6, 0.6], Thickness[Large], Dashing[Large],
         LineBox[CompressedData["
1:eJwtkG1Ik1EYht8cha21Pli51fxOXdsyNyPWj0EuY4PQmBlGGS0rQwx1QUVb
UD8mBP0whstpKsE2RMVhn9vAeh6dw49sabq2kJEzVoEhW8NJRJbn7b3hcDic
c67nvu/smsaKKykURYnWF9k72ok+QbjnyNm4tBiTouqWkZUQdLxESeK1HCvc
Gc1L2hDMqfrTZCfl6FRHDDxnEDzH8L1pQYZbgrYmJTsI0a6k+bdehldriT5C
aTTHZ2XJ0LtCgAGIlRcdrrYUYeY6zZ0RAGWd2KEpKEIjjxDn4KJfofVdP4gh
GjcLfVbzudNthXiomGgWuFUb+EeHDuDDEQL8AOYBBdsYkeIPLTE4A7k/n7mW
N0lRQ+ypZ0AvTITvSiVoJzjbNBzPy+5f04qRojUNnQ5WoeTWfvSQeG4/6AK9
4eHHItST503vgHUtyr0NBSgmdYim4HNcUclZzMdFgo9MwrjpuV3Dysf//U3A
oGrCIcjNw1N0X+PwRDnAflSyj+lnDFIHJVmpF3KZPnywHOeeiBlz8A6dfxRG
nd5LVHs2k9cLu1VdddtdWUy+Yegr+7YkdGYyeRAu18ZaQ4l0pMe534CgZe9m
QYkQpbTfISgYq0Rd2x7spP15wHH/BvvtKh85tB8XUPqN6i81acz8F/Dg/PxU
Q2gXM+8pNPv9SX4Vj+E7oXR10rYwvxOtNK8X+i3U1r+6HXiP/m+HtYZAWbpr
GyL9vhv+/Pp6xlLPYe5bQV5veBU3pDJnE3S7b35v7EnBf7pGTrY=
         
         "]]}}, {}}, {{{}, {}, 
       {GrayLevel[0], Thickness[Large], Dashing[Large], 
        LineBox[CompressedData["
1:eJwtkH1Ik1EYxZdZgRqtGElo1krnWmZaKphN/xG1lpFTMKEiFN1SwhmxTCUk
jGBFmpjoshU5LMkWfaAbhedxKpqaOLe5WSBoRpMGaaWmBOZ99x64XC733t9z
zhHnlyoL/QQCgXR9sV3fzDQJa7zJoyiPpSXpuVrrohuPO+rbJ/7EkNIcdutH
lhvzRyIt4WUxZEqfrhCZXFiquDh28/NhCnS1auQBLmge3l4uGY8mVRHTBBwL
V54GDx2i3kUGdEKuNtp1PVG0Z51mDnPiWmJ+Sp/5IFWKGNGB/ruhy29eycjN
4ewI0dclxLcdoLijTHaEfxNhZ4uU6qwMOA7dk465bfcjyZvFDNowdUOtG6iR
UAazl27DDM7IHdoIMjJc6xj8Y/NeDBaFk4DTGB4lnniblLOfLCyeeRSzV8+G
upP3URl7rvmE3H+N3ksSMclYHdIRnM/URCwE7KUZhp8egrJY/f705G7y9fcR
X/wVnf5NIZTN9TWI3JMrRnX2Lr6fATxfqS4/vjWY76Mfp57F1d8ZEFEVl78P
qwaFX1PNDj5vL4aFsh5nmpDP14PNuZWb1sRBfB7CscbrkuaRLcSNM3ejuuuC
5+WDjRTF+f0AxXdv6Ybta2jh/Flgy5tT1RcvI4jz04Wk7tTLOap5+Oa/Q1XK
178lDbPwzXsNgzhDn9rmhI9vgja5SuyZIjRxvHZ0rs4KRwsMqOb+G6G7VzRV
O5wP4t4bUKAtlCT8+t3tu2/AT1E0pUUG8ucaCHj9B1UiUeM=
         "]]}}, {}}}, {
     InsetBox[
      TemplateBox[{
       StyleBox[
        "\"1-, 2-, 3-, or 4-step\"", StripOnInput -> False, FontFamily -> 
         "Helvetica", FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"Directive", "[", 
                RowBox[{
                  RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                  RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], 
            ",", 
            RowBox[{"{", #, "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      NCache[Scaled[{Rational[1, 4], Rational[4, 5]}], Scaled[{0.25, 0.8}]], 
      ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TemplateBox[{
       StyleBox[
        "\"1-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"2-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"3-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12],StyleBox[
        "\"4-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
         FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.5470136627990908, 0.24], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24, 0.6, 0.33692049419863584`], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.5470136627990908`", ",", "0.24`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24`", ",", "0.6`", ",", "0.33692049419863584`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      NCache[Scaled[{Rational[3, 4], Rational[1, 4]}], Scaled[{0.75, 0.25}]], 
      ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TemplateBox[{
       StyleBox[
        "\"\[Lambda]=0.005\"", StripOnInput -> False, FontFamily -> 
         "Helvetica", FontSize -> 12],StyleBox[
        "\"\[Lambda]=0.0025\"", StripOnInput -> False, FontFamily -> 
         "Helvetica", FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}],
             ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      NCache[Scaled[{Rational[1, 10], Rational[3, 5]}], Scaled[{0.1, 0.6}]], 
      ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesOrigin->{-0.4, -14.508657738524219`},
   CoordinatesToolOptions:>{"DisplayFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& ), "CopiedValueFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& )},
   Epilog->InsetBox[
     FormBox[
      StyleBox["\"A\"", Bold, 14, StripOnInput -> False], TraditionalForm], 
     Scaled[{0.05, 0.95}]],
   Frame->{True, False, False, True},
   FrameLabel->{{"", 
      FormBox["\"Probability of rescue\"", TraditionalForm]}, {
      FormBox["\"Wildtype growth rate\"", TraditionalForm], ""}},
   FrameTicks->{{None, {{-13.815510557964274`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-11.512925464970229`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-9.210340371976182, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm]}, {-6.907755278982137, 
        FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
        FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
        FormBox["0.1`", TraditionalForm]}, {0., 
        FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.716898269296165`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.429216196844383`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.206072645530174`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-12.02375108873622, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.86960040890896, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.736069016284437`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-11.618285980628055`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.819778284410283`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.414313176302118`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-10.126631103850338`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.903487552536127, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.721165995742174, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.567015315914915, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.433483923290392, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-9.315700887634009, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-8.517193191416238, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-8.111728083308073, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.824046010856292, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.600902459542082, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.418580902748127, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.264430222920869, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.1308988302963465`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-7.013115794639964, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-6.214608098422191, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.298317366548036, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.995732273553991, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.659260036932778, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.407945608651872, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.6931471805599453, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659905, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.35667494393873245`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782616`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}, {True, False}},
   GridLines->{None, None},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.4, 0}, {-14.508657738524219`, 0.}},
   PlotRangeClipping->True,
   PlotRangePadding->{{None, None}, {None, None}},
   Ticks->{Automatic, {{-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm]}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {-13.122363377404328`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.716898269296165`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.429216196844383`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.206072645530174`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-12.02375108873622, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.86960040890896, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.736069016284437`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-11.618285980628055`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.819778284410283`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.414313176302118`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-10.126631103850338`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.903487552536127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.721165995742174, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.567015315914915, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.433483923290392, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-9.315700887634009, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-8.111728083308073, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.824046010856292, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.418580902748127, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.264430222920869, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.1308988302963465`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-7.013115794639964, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.407945608651872, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}],
  InterpretTemplate[Legended[
    Graphics[{{{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJwtkF1I01EYxv9pZKhNVzOWoc6PdE7TUOdVrcKLZRTojMASpKlFBWrQRO3z
QgkinUuTirKLCdaFk2W2abXnTdPlSnHOua0LaX2wygSz1AiLdv7bA4fD4Zzz
e5/nSVTXqKpCOI6T+hfb795h8iD956pJPptJK9Iy7fCyGyM1Y2HPDBmkMsc3
zxe7kd8ywZmuy8ig9DaKDC4sVxj1OWfSKcKlr90T7kKW71d//mEpnTrJNIu8
gQLnm9w0GllmQCeWFJ3lf+JSKcFPM8c7cb7eqrFF7KALIkacwZVm4fuCv8nk
5nEO3P/RKa5eSqK8XCYHsha9+UXzidQ2zIDT6PMpfi/6JPS9mBm0Q90X1do7
lUAHmD2lHT0dsf1RnjjqZjj9FB6rNzhFX7cTx2sKC5vUu21cLA2yeOZJVBZa
S/ZKxHSOPa+dQLnePnRNuZVkrA7pW/hqDzZY6kT0geG9Nkw+fWcPN2ymQH/j
mEnZWNWzEE0lfF+voR1XZXjOCoL9WLHr9NFPFkFEsI9R7Ouqb28ZDaOLfP5X
yBq9HKq7uT6YdwRzW6Ty5IZ1wXwvodO0K3aurSGQh9CVI7vRWLQKfpzZgm3a
mDlByBIyeb/PEZ1Wqrt05Bvu8f4GETqkybZPexHJ+zHBkf3l88AtJwLznyCm
QptySDyGwDwjRMqOBzhuDPIN+KeTf2x9qMNtnvcIK0mFkv3CE7jK/+9GpLm0
rKpACOLfd+FYXWV9m6DJErjvQJ7AX3tq9YvAuQlcUP8Bo3NLMw==
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJwtkF9Ik1EYxtcKpC2W01nJUnPZmhFp2rKbNVqExhi0CRERYemqm8pZFKkX
I0wRJ2qWbZGZzBGlzYqB3yj2vk1tFpttU9saBG1+JNjoj5sjaBd5vn0PHA6H
c87vfZ6n+PxVnZ7L4XBka4vsDy1EX2CQjmwueLkbU7IzPe7VMKSs7W3nElLU
UYV3fmjDoLrmUEQOStFeHW0W2UNwu2P0ial5F/JD1kYFLwQJbdzS7CrBixeI
PkNyZtE9xi3ByVUCXIA/3KZgefVOLFqjUYULEJ7P8+WbJNgiIsR5kAsFQmOg
GMMMbg78iesu49ZiPFBJNAfBulNdyrM7sNdNgEGYUlVxp9RFGNcSgwFYCX4/
Jv1agDXEXnUAbgrSpesM23GE4Kx+OKzRWxxZYuQw8sMJm2LIOpyPThKPmoVU
3/1UhXIbGsjzRh9U8YbfeL5twT2kDpkXLtn61e/b8zBG8NGPIBdXnu7bL8JM
fx8gEXMqO6M5WMv0NQPjHXQL/4GQ7ccD5fEb+iZdNtvHNMR6636VygTYyuSf
ghVbja6b4rN5J8EtftpgP7mRzfcOBiSfNCXrs9g8CD4v39Tq2oDMOMoFxw23
6EOdXNzL+H0L6aDd463n4CPGnxPkZZO0fDANmxg/E0DfpZLL/X8hM98BDS9+
HlWPJSEz7xVcHqpVZS/9hgzfDpKJ7iVD1zKYGd4z8ONzns68CEbm/wgcGTXv
G8iNADLvH0NBRa5jvN7L3t+Dfz20P2f1NXtug7JpTXLWcwX+AxnkWJE=
           "]]}, {
          Hue[0.1421359549995791, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJwtkGtI01EYxrdRIqtV6qjZ2tbMXcwCwUV+yKhUNCRCqzWjICxXYjDFGJub
4IeK6kMXZ+h0WeaIWTTK1P23yvdNu9jQpblrtWxGLMz6EK0LRuX5+3/gcDic
c37v8zzSSl15FYfFYinnF9nbrUQRaJWEk7bcysIfyoMXhxJh6HnnuhFdloXl
lPj057IwHIr6q631SnQWxxr4zhC08qd694cVuCTUXZvPDYErT7ONla/AY1qi
IBzvv7zZ3CXH4QQBBmBvjUjRt1iOknkaJQ7AdIXMcaVahiY+IfqBvS+XShnL
xDCNmwQjW/dVnJOJqlyiSfBtdXg9zevw0hABvgJrmy0+8z0DZ8uIwQlIPQOB
R+oMLCH2iifAd3KgpZSSop3gusfBZOVb+tOlyKI1DhV3d2yUm9aim8SjfGB7
bddec0uwjjyvHQONLic52CjG9aQO5ShYVEFHTYEIpwk+5gXO4evGGHcNLvT3
Aq6WaHd5/KtxD93XCDxTP1Dru9KZfp7D25aG6IU6AdPHUzAk4vG6olVopvM/
gaYiG9UoWsnkHYbmjp0f5n7zmXyPwVN/ziJ8k8bkQXBtKjgxg6lIj6MGwSQs
FJTeTsENtN+HYNcPyz5ZV6CN9ueGfwZZZLtgOS6l/bjgW6G3KsLmMfP7oP2m
sOPAFy4z7x6opszvRwLJDN8JVXf0lUfuJ2EbzeuBXg3bAMZF2ET/twNvzpD9
MY2DSL/vhE6eJO/swF9YuG+BX6ODAH9+MudTcPTlbm72+Vn4D6fQUYY=
           "]]}, {
          Hue[0.37820393249936934`, 0.6, 0.6], 
          Thickness[Large], 
          Line[CompressedData["
1:eJxTTMoPSmViYGBQB2IQzfzn41b7Fzf22y+uP5nHonsgaIdc6+vAG/tXvXhU
UVOrc2Cd+8MqkXXX92+YMUlA6JX2Ae7riwtsua7vN99/i8coTPtAehoIXNt/
cEHEqX0HtQ4c/qoR03/o6v4M5VmBs3W0DsgDTdshd3X/tY40nbXTNA9Ui4BM
vLI//Lqv373/GgdugI27vF9qyYxZchkaB0yMQeDy/pS7d/6mnlc/MOEQyMBL
+xkUa79sNVU/8CYQ5MCL+w8mKytKz1Y74AFynvvF/U2SL/nW/Vc9sARk3OIL
+29WeWdNTlY9wAAGF/a/WL244fcxlQM7Qd7bcW7/w5xUUUUtlQOFIOUFZ/ez
2TROcO9VPqAFdP1XjTP7H0X/2bPjg9KBRyDjH57av/nUJ9NDIUoHZs0EgZP7
CxNcNm3aqXggGBxeJ/ZfDOH2vi6vCA2f4/v1il+er2hXgIbH0f0qmglxmx7K
H6gB+//I/m9mfbsSd8hB/Xt4/1G97RYRk2Wh/ju4v+FuzoXzRTJQ/xzYr/+u
O/ZOmPQBsHU79u3/y7xpWaK91AEdsHv37J/DWBzHqiN5YA7YfTv37/gW2Ssl
I3GAB+ye7fun/Pj7r5FPHGr/lv1LvPP2ljOKQe3buH/mZS8Xu08iUPPX7f/h
ldzcfkf4wAyweSv3V3cduBO0U+hAA1j/kv3GrK9bWmoEDxwAq5+3P1VYPv03
nwBUfsr+64X8UjcqeKD8lv0KRtO4Xu5jOwAAoZBGJA==
           
           "]]}}}, {}}, {{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          GrayLevel[0], 
          Thickness[Large], 
          Line[CompressedData["
1:eJwtkHtI01EcxWckmQ9SmmKbzcd0LhsxMuuPGAWGGyaMrYTWWlH4KBhN+6fM
pFyG/RMzHGayTFCp1doyQjesnTvfmuXM3AxTXIUgbajUSmJB3t924HK53Hs/
33NO5gWdsnwLi8USbi66tz2k+oyWl9Hv+pcE5LfwjGEgOIfcDrFLkysgSjvv
zg/FHH6VhYYvanOIVeq7zrZ64cvi1vTbskmct7NKEuvF38KFpYPrfFJZQeXB
UJ3/0aiYTwaDFDiL3ivF8orLWSR9k2bnzcJU64vnPMsktWxK/ISxkHJg41sG
mWNwM4jzyjm5aRnkQD7VDA6rild7unmkaYACP0JtYF9tS9xN/ApqcBoLIZnW
VMMlMmpPOo159fNJtW8X6aK4TjcmVHxboyyVsBi5UbD4lO+xpRAHjWf/AJ9G
J49KTSbV9HnVe6xy9h4bqd9J8mgdwkm4SswJy4Ek8pXifRNoNJXV7NEkknB/
4/BKuTp3RwI5wfQ1Bsua5Ljwfmykn1HkG788ab63LdLHMMaPaGVTrVvJDSb/
EJondhSe7o2K5B3EPtGllabZfwjnc+GcqsFQem0D4TwEMdlFpuTyn2DG2Z0w
O14VWM4HIGL8voG4XPRH7/8OE+PPgaS8lJH1k/OIZ/z04cXy9lJB3RTC819j
5awk+DjaGZnXg/S1lvpAUXeEb4UjVJl2ql2PVoZnhmct5+ahxRLcYv53obrP
qLsdE3QS5n07Hihseu1RjTN8b4SF1n53/9vwuQGsiP4D/QhP6Q==
           
           "]]}}}, {}}, {{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJwtkH1Ik1EYxYcLHG3CRmMtgy0TcYxZlsuZaElB2wrCmZW0aBE6pcCMoEkb
ZVIERalUNseSYgYtcGugOavtedxWU1Pxa86+qGl/tZmhe2MEQt5374HL5XLv
/T3nnJxzF6vqMlgslmx9kd3WRfQJbKtmVnWkFP/KTrcFqHnoTCRTQ7/2YpVX
ciuumwdq3BpRLJagSx27KnRFQWbK8lyYUyE36mgq3xiFDff41qOjxVhvJJqD
1s3N/ddCezBIEWAE3szdTz4NKFG6TvNKIsAzaZMQKkKzkBBnoZe/tCr+uBvn
adwM6MIi+/PILlQWEc2AmNO03/yzENsDBDgNrsLFMs3yTkzoiMEp4HMPu2sk
O1BD7KmnYEA/0XbghAJ7CM4xCRaD8JH0sRxZtCah5Hy3MzMmw0ESzzsB0tu1
BoEyHy+R503jUHPKF9W156Gc1CEbg1ZRSv+VysUFgo+NgvHZ94xA7XZM9zcC
ntexLsG3bXiM7msYcho/PHH7JEw/Yah0lEsrZrcyfbwHLdVvWloTo4XOHwJx
8GDHl1IRkzcIf9hxw5G7m5h8QxDm1DW8XeYzeRC4zS9/V0zzkB7n9UOjRZV1
ZyUTFbTfd5Av/ScfPsRGO+1vEF6djTvr+9aAR/sZgILcPD/nOgXp+X0wsHJS
3alLQHqeB8r0n30L/B+Q5rugo+HGGa52DKw0zwkjqexki8oNLfT/HjCyH9hS
BWZA+n03XLGrL/e+2MLcP4RiQeW+7OMaf/p8E1iM/gN0Ik+L
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJwtkHtIk1EYxmdMWLNcOqNC0rzlLppzGmRRYeQWMqg5/8oZKssRYS4q/7B1
Q2ckqEUlZqOwb0kjGwaJW5jv21boZNXmXN+kdVGSiNSY4DIYlufb98DhcDjn
/N7neTLqGitOruNwOKK1Rfbee0TT4PpXdrzUI8eISNvlXA6Cu16YWCmTY4U9
zfRLHQQLv1LhuFuINuVMc4qNhuT+QOB8VIYJNGXYz6chd9P6V0adDPX1RB8h
vrPXdP1+AbqWCTAAR3frnhgNuzB9jWZPC0AxrSi1K/PxYgohTkHGgZLTWzPy
MMjg/PD1c3KoKSrB4iIiP5RT9LGn02K86STASTg4lyrusItwXk0M+qDIo9Kt
9OTiEWJP6YP8UWuJp3knWgiO8sLjju7qSHUOchh5YWyhqubcoWx0kHj29yD3
uqUaURaeJc8N7+DEo9U9I4JMlJA6RB4IP6MWF1Z24CzBz0yAvuFDWct4Osb6
c4OTO9uptGxHDdPXOGja5viFbalsP2PwPTv1Wm3jNraPtyB6WNUtqN2CRib/
G8hR/dVe0m5m87pgwCwO/q4TsvleA7f8S8PAhSQ2D8IQ8ELzUgEy4+yjMOaP
XslsT8A8xu8IJN0Kx7fzeGhm/DmgSbKomrBycQPjZxhW+8zDg4Y4dv4LiJpO
Ld3AKMTmPQfafLvP/ycCMb4NfghbatRdYehheFbY119ALWX9hKvMfwvYWhPd
/OxvgMz7BxC392X+xikve38HfCGKviwdYs+tMPnp8KBecQb+A3JIU/M=
           "]]}, {
          Hue[0.1421359549995791, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGDQAGIQPWsmCNzcf/OdS81tfqMD3zRi+g99vbHfT2WzSdAk
wwNBO+RaXwfe2N/GlNhZKGp4YJ37wyqRddf3d/1QuOUy0+AA9/XFBbZc1/fH
fGFZekHW4EB6Gghc2/+1ICjQwk3/wOGvIAOv7n/bLH0zLEjvgDzQtB1yV/dn
i0Q6siboHqgWAZl4Zf+9qvW3XPJ1DtwAG3d5/8Pbk8oEGrQPmBiDwOX9/tPl
P0ZN0jow4RDIwEv7v0hyNfMu0zzwJhDkwIv7s8qVm9h3axzwADnP/eL+47WC
B6Uuqh9YAjJu8YX9vZbP5gi+UDvAAAYX9jt8mBqz9r/qgZ0g7+04t5/F7+GM
NeKqBwpBygvO7uc9MFnrlL7KAS1QcGic2Z+9lHHnNXflA49Axj88tV/ksnjR
unilA5DwO7k/NF/7k2+54oFgcHid2P91Vu+u630K0PA5vl/8p1Weoa88NDyO
7vec+Wi1QJ3sgRqw/4/sn2HM+79tozTUv4f3r6q3nsn2UhLqv4P7Xz75Fquo
JgH1z4H9s85fVcnNEjsAtm7Hvv1WKn6m6dtFDuiA3btnv26R395wPuEDc8Du
27nfoaz2g3GB4AEesHu2738/RfDj1138UPu37L/nceUazxoeqH0b9x9ITAht
2sgJNX/d/qPbdGLDj7EdmAE2b+V+9Y4Mxk8PmA80gPUv2R+/Timo9z3DgQNg
9fP2s33UaA1d8Hs/RH7K/pna3TfNyr5A+S37tzO83nnq89P9AGfDTF0=
           "]]}, {
          Hue[0.37820393249936934`, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJwtkG1Ik1EYht8cha21Pli51fxOXdsyNyPWj0EuY4PQmBlGGS0rQwx1QUVb
UD8mBP0whstpKsE2RMVhn9vAeh6dw49sabq2kJEzVoEhW8NJRJbn7b3hcDic
c67nvu/smsaKKykURYnWF9k72ok+QbjnyNm4tBiTouqWkZUQdLxESeK1HCvc
Gc1L2hDMqfrTZCfl6FRHDDxnEDzH8L1pQYZbgrYmJTsI0a6k+bdehldriT5C
aTTHZ2XJ0LtCgAGIlRcdrrYUYeY6zZ0RAGWd2KEpKEIjjxDn4KJfofVdP4gh
GjcLfVbzudNthXiomGgWuFUb+EeHDuDDEQL8AOYBBdsYkeIPLTE4A7k/n7mW
N0lRQ+ypZ0AvTITvSiVoJzjbNBzPy+5f04qRojUNnQ5WoeTWfvSQeG4/6AK9
4eHHItST503vgHUtyr0NBSgmdYim4HNcUclZzMdFgo9MwrjpuV3Dysf//U3A
oGrCIcjNw1N0X+PwRDnAflSyj+lnDFIHJVmpF3KZPnywHOeeiBlz8A6dfxRG
nd5LVHs2k9cLu1VdddtdWUy+Yegr+7YkdGYyeRAu18ZaQ4l0pMe534CgZe9m
QYkQpbTfISgYq0Rd2x7spP15wHH/BvvtKh85tB8XUPqN6i81acz8F/Dg/PxU
Q2gXM+8pNPv9SX4Vj+E7oXR10rYwvxOtNK8X+i3U1r+6HXiP/m+HtYZAWbpr
GyL9vhv+/Pp6xlLPYe5bQV5veBU3pDJnE3S7b35v7EnBf7pGTrY=
           
           "]]}}}, {}}, {{{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          GrayLevel[0], 
          Thickness[Large], 
          Dashing[Large], 
          Line[CompressedData["
1:eJwtkH1Ik1EYxZdZgRqtGElo1krnWmZaKphN/xG1lpFTMKEiFN1SwhmxTCUk
jGBFmpjoshU5LMkWfaAbhedxKpqaOLe5WSBoRpMGaaWmBOZ99x64XC733t9z
zhHnlyoL/QQCgXR9sV3fzDQJa7zJoyiPpSXpuVrrohuPO+rbJ/7EkNIcdutH
lhvzRyIt4WUxZEqfrhCZXFiquDh28/NhCnS1auQBLmge3l4uGY8mVRHTBBwL
V54GDx2i3kUGdEKuNtp1PVG0Z51mDnPiWmJ+Sp/5IFWKGNGB/ruhy29eycjN
4ewI0dclxLcdoLijTHaEfxNhZ4uU6qwMOA7dk465bfcjyZvFDNowdUOtG6iR
UAazl27DDM7IHdoIMjJc6xj8Y/NeDBaFk4DTGB4lnniblLOfLCyeeRSzV8+G
upP3URl7rvmE3H+N3ksSMclYHdIRnM/URCwE7KUZhp8egrJY/f705G7y9fcR
X/wVnf5NIZTN9TWI3JMrRnX2Lr6fATxfqS4/vjWY76Mfp57F1d8ZEFEVl78P
qwaFX1PNDj5vL4aFsh5nmpDP14PNuZWb1sRBfB7CscbrkuaRLcSNM3ejuuuC
5+WDjRTF+f0AxXdv6Ybta2jh/Flgy5tT1RcvI4jz04Wk7tTLOap5+Oa/Q1XK
178lDbPwzXsNgzhDn9rmhI9vgja5SuyZIjRxvHZ0rs4KRwsMqOb+G6G7VzRV
O5wP4t4bUKAtlCT8+t3tu2/AT1E0pUUG8ucaCHj9B1UiUeM=
           "]]}}}, {}}}, {
     Epilog -> Text[
        Style["A", Bold, 14], 
        Scaled[{0.05, 0.95}]], 
      FrameLabel -> {{Null, "Probability of rescue"}, {
        "Wildtype growth rate", Null}}, 
      Ticks -> {Automatic, {{-13.815510557964274`, 
          Superscript[10, -6]}, {-11.512925464970229`, 
          Superscript[10, -5]}, {-9.210340371976182, 
          Superscript[10, -4]}, {-6.907755278982137, 
         0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 0.1}, {
         0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 0.}, {
           Thickness[0.001]}}}}, GridLines -> {None, None}, 
      FrameTicks -> {{None, {{-13.815510557964274`, 
           Superscript[10, -6]}, {-11.512925464970229`, 
           Superscript[10, -5]}, {-9.210340371976182, 
           Superscript[10, -4]}, {-6.907755278982137, 
          0.001}, {-4.605170185988091, 0.01}, {-2.3025850929940455`, 0.1}, {
          0., 1}, {-13.122363377404328`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.716898269296165`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.429216196844383`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.206072645530174`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-12.02375108873622, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.86960040890896, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.736069016284437`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-11.618285980628055`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.819778284410283`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.414313176302118`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-10.126631103850338`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.903487552536127, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.721165995742174, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.567015315914915, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.433483923290392, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-9.315700887634009, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.517193191416238, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.407945608651872, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.35667494393873245`, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, "", {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782616`, "", {0.00375, 0.}, {
            Thickness[0.001]}}}}, {True, False}}, 
      AxesOrigin -> {-0.4, -14.508657738524219`}, 
      PlotRange -> {{-0.4, 0}, {-14.508657738524219`, 0.}}, AspectRatio -> 
      GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0, 0}, 
      CoordinatesToolOptions -> {"DisplayFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& ), "CopiedValueFunction" -> ({
          Part[#, 1], 
          Exp[
           Part[#, 2]]}& )}, Frame -> {True, False, False, True}, 
      FrameLabel -> {
       "Wildtype growth rate", Null, Null, "Probability of rescue"}, 
      FrameTicks -> {True, False, False, True}, LabelStyle -> 
      Directive[12, FontFamily -> "Helvetica"], Method -> {}, 
      PlotRange -> {{-0.4, 0}, {-14.508657738524219`, 0.}}, PlotRangeClipping -> 
      True, PlotRangePadding -> {{None, None}, {None, None}}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          Thickness[Large], 
          GrayLevel[0.5]], 
         Directive[
          Thickness[Large], 
          GrayLevel[0.5], 
          Dashing[Medium]]}, {
         Style["\[Lambda]=0.005", 12, FontFamily -> "Helvetica"], 
         Style["\[Lambda]=0.0025", 12, FontFamily -> "Helvetica"]}, 
        LegendLayout -> "Column"]], 
      Scaled[{
        Rational[1, 10], 
        Rational[3, 5]}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{3.7802628128800993`*^9, 3.780264247260795*^9, 
  3.780264836583662*^9, 3.780264873234507*^9, 3.7822647308148746`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Rescue genotype growth rate", "Subsubsection",
 CellChangeTimes->{{3.7794704634668283`*^9, 3.779470474057392*^9}, {
  3.7794710306220827`*^9, 3.779471034112606*^9}, {3.779482842010936*^9, 
  3.7794828429873037`*^9}, {3.7800683415343847`*^9, 3.7800683444466963`*^9}, {
  3.780254196766683*^9, 3.780254196925116*^9}, {3.780261750764731*^9, 
  3.780261751742078*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"-", "0.3"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"xmax", "=", "0.25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ymax", "=", "40"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xint", "=", "0.01"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"N0", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", 
   RowBox[{"-", "0.2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"U", "=", 
    RowBox[{"2", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Lambda]", "=", "0.005"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", "established", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m2", ",", 
       FractionBox[
        RowBox[{
         RowBox[{"fm", "[", 
          RowBox[{"m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}],
           "]"}], 
         RowBox[{"pest", "[", 
          RowBox[{"m2", "-", "mwt"}], "]"}]}], 
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"fm", "[", 
            RowBox[{
            "m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
            "]"}], 
           RowBox[{"pest", "[", 
            RowBox[{"m2", "-", "mwt"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"m2", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"m2", ",", "mwt", ",", "xmax", ",", "xint"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory2", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", "Gray"}], "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", "\"\<established\>\"", "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1.5", "/", "8"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"1", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        RowBox[{"g1m", "/.", 
         RowBox[{"m", "\[Rule]", "m2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "0", ",", "xmax", ",", "xint"}], "}"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"2", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"total", "=", 
      RowBox[{"Re", "[", 
       RowBox[{"g2denominator", "[", "mwt", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"m2", ",", 
         RowBox[{
          FractionBox["1", "total"], 
          RowBox[{"g2numerator", "[", 
           RowBox[{"mwt", ",", "m2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "xmax", ",", "xint"}], "}"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory2", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", "Thick", "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{"\"\<1-step\>\"", ",", "\"\<2-step\>\""}], "}"}]}], "]"}],
          ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1.5", "/", "8"}], ",", 
            RowBox[{"1", "/", "2"}]}], "}"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Lambda]", "=", 
    RowBox[{"0.005", "/", "2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", "established", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m2", ",", 
       FractionBox[
        RowBox[{
         RowBox[{"fm", "[", 
          RowBox[{"m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}],
           "]"}], 
         RowBox[{"pest", "[", 
          RowBox[{"m2", "-", "mwt"}], "]"}]}], 
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"fm", "[", 
            RowBox[{
            "m2", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
            "]"}], 
           RowBox[{"pest", "[", 
            RowBox[{"m2", "-", "mwt"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"m2", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"m2", ",", "mwt", ",", "xmax", ",", "xint"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory4", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", "Gray", ",", 
         RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"1", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m2", ",", 
        RowBox[{"g1m", "/.", 
         RowBox[{"m", "\[Rule]", "m2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"m2", ",", "0", ",", "xmax", ",", "xint"}], "}"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"2", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"total", "=", 
      RowBox[{"Re", "[", 
       RowBox[{"g2denominator", "[", "mwt", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"m2", ",", 
         RowBox[{
          FractionBox["1", "total"], 
          RowBox[{"g2numerator", "[", 
           RowBox[{"mwt", ",", "m2"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"m2", ",", "0", ",", "xmax", ",", "xint"}], "}"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "}"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"theory4", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"%", ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", 
         RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}], ",", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Directive", "[", 
              RowBox[{"Thick", ",", "Black"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
              RowBox[{"Thick", ",", "Black", ",", 
               RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{
             "\"\<\[Lambda]=0.005\>\"", ",", "\"\<\[Lambda]=0.0025\>\""}], 
             "}"}]}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"7", "/", "8"}], ",", 
            RowBox[{"3", "/", "10"}]}], "}"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "oldtheory2", ",", "theory2", ",", "oldtheory4", ",", "theory4"}], "}"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"FrameTicksStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontColor", "\[Rule]", "White"}], ",", "Automatic", ",", 
       "Automatic", ",", "Automatic"}], "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{
           RowBox[{"\"\<\!\(\*
StyleBox[SubscriptBox[\"m\", \"0\"],
FontSlant->\"Italic\"]\)=\>\"", "<>", 
            RowBox[{"ToString", "[", "mwt", "]"}]}], ",", "12", ",", 
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
         ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"7", "/", "8"}], ",", 
            RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<B\>\"", ",", "14", ",", "Bold"}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt", ",", 
   "xmin", ",", "xmax", ",", "ymax", ",", "xint"}], "]"}]}], "Input",
 CellChangeTimes->{{3.751575679958344*^9, 3.751575707856783*^9}, {
   3.751575756450697*^9, 3.7515757716167583`*^9}, {3.751575806118587*^9, 
   3.751575998358532*^9}, {3.7515761122033863`*^9, 3.751576131258815*^9}, {
   3.751576172283361*^9, 3.751576174879533*^9}, {3.7515762580970592`*^9, 
   3.751576326479478*^9}, {3.7515763695777597`*^9, 3.751576370332637*^9}, {
   3.7515764174224873`*^9, 3.751576419272636*^9}, {3.751577234452231*^9, 
   3.751577234571393*^9}, {3.751598119440303*^9, 3.7515981249463587`*^9}, 
   3.751650792683756*^9, {3.751650847039688*^9, 3.751650935724555*^9}, {
   3.751651020576578*^9, 3.751651024456732*^9}, {3.7516511744217253`*^9, 
   3.751651271292901*^9}, {3.7516514431359167`*^9, 3.751651596903675*^9}, {
   3.75165167006041*^9, 3.7516517016743317`*^9}, {3.751651837998188*^9, 
   3.751651848660565*^9}, {3.751651901804051*^9, 3.751651938743773*^9}, {
   3.75165209054011*^9, 3.751652092941709*^9}, {3.751654667780588*^9, 
   3.751654726734174*^9}, {3.751654761368635*^9, 3.751654832140562*^9}, {
   3.751654888268785*^9, 3.7516548919393587`*^9}, 3.751656018745837*^9, {
   3.751656381036447*^9, 3.7516563882551813`*^9}, {3.7565000581145897`*^9, 
   3.7565001021945477`*^9}, {3.756500617190415*^9, 3.75650065699045*^9}, 
   3.75650069938904*^9, {3.756500741026494*^9, 3.756500755155011*^9}, {
   3.756501221346011*^9, 3.75650122389799*^9}, 3.756502363067445*^9, 
   3.756502628112669*^9, 3.7565026817972727`*^9, {3.756503286102932*^9, 
   3.756503290049591*^9}, 3.756503323237875*^9, {3.756503496903769*^9, 
   3.75650353646167*^9}, {3.7565038167736483`*^9, 3.756503833330291*^9}, {
   3.7565038702319183`*^9, 3.7565038987244377`*^9}, {3.7565039623685904`*^9, 
   3.7565039995283422`*^9}, 3.756511754548572*^9, 3.756511866105935*^9, {
   3.756511901000861*^9, 3.756511903883478*^9}, {3.7565119526094627`*^9, 
   3.756511957815688*^9}, {3.756512664854374*^9, 3.756512670495578*^9}, {
   3.7565186714828672`*^9, 3.756518674830636*^9}, {3.756518724785604*^9, 
   3.7565187318397303`*^9}, {3.756518775324299*^9, 3.75651877705446*^9}, {
   3.756518831207197*^9, 3.756518836010257*^9}, {3.7565191876130047`*^9, 
   3.7565192273750753`*^9}, 3.756557317943141*^9, 3.756565191609994*^9, {
   3.756565226853438*^9, 3.756565227347921*^9}, {3.756565372407086*^9, 
   3.756565372554656*^9}, {3.7642581275023746`*^9, 3.764258130547591*^9}, {
   3.764258191591094*^9, 3.7642582094474382`*^9}, 3.769438935312201*^9, {
   3.769440382123701*^9, 3.769440472454721*^9}, 3.769440550032837*^9, {
   3.769440597811926*^9, 3.76944060297188*^9}, {3.769440831103504*^9, 
   3.769440912756571*^9}, {3.769440959415164*^9, 3.769440994826437*^9}, {
   3.769441059064315*^9, 3.769441091058297*^9}, {3.769441130350876*^9, 
   3.76944116439666*^9}, {3.7694411991785088`*^9, 3.7694412021516743`*^9}, 
   3.76996874883585*^9, 3.769968810893046*^9, {3.771262388292754*^9, 
   3.771262479562519*^9}, {3.771262525425778*^9, 3.771262540854212*^9}, {
   3.771262571282227*^9, 3.771262676392552*^9}, 3.771262708817911*^9, {
   3.771262787550537*^9, 3.77126278925319*^9}, {3.771262848265294*^9, 
   3.7712628699284153`*^9}, {3.771263092625225*^9, 3.771263094812828*^9}, 
   3.771263271500595*^9, {3.771523030703679*^9, 3.7715230467362022`*^9}, {
   3.771523079011808*^9, 3.771523152186151*^9}, {3.77152320543019*^9, 
   3.771523315803763*^9}, {3.7715233464449253`*^9, 3.771523576781527*^9}, {
   3.771523631873809*^9, 3.7715236430826683`*^9}, {3.7715241526920757`*^9, 
   3.771524155896125*^9}, {3.7715242229465923`*^9, 3.771524257316955*^9}, {
   3.771524320220757*^9, 3.771524423589848*^9}, {3.771524462952353*^9, 
   3.771524468371491*^9}, 3.771524519796175*^9, {3.771524560722151*^9, 
   3.77152458745588*^9}, {3.7715456914503183`*^9, 3.771545693694459*^9}, 
   3.7715458002283154`*^9, {3.771545911589119*^9, 3.771545926111433*^9}, {
   3.77160975420442*^9, 3.7716097651557693`*^9}, {3.7716099182331963`*^9, 
   3.77160992062647*^9}, {3.771609967213895*^9, 3.771610003678589*^9}, {
   3.771610042996176*^9, 3.771610061906077*^9}, {3.771610106603993*^9, 
   3.771610114408716*^9}, {3.771610201107335*^9, 3.771610202727501*^9}, 
   3.771610248378283*^9, {3.7794686898536158`*^9, 3.7794688301324673`*^9}, {
   3.77946886396563*^9, 3.77946888729186*^9}, {3.779468925902836*^9, 
   3.7794689413547277`*^9}, {3.779469011076345*^9, 3.779469071332287*^9}, {
   3.779469527005124*^9, 3.779469555307827*^9}, {3.779469593442951*^9, 
   3.77946961429259*^9}, {3.779469796805294*^9, 3.779469866620295*^9}, {
   3.779469901788733*^9, 3.779470016571252*^9}, {3.779470051010948*^9, 
   3.779470158052433*^9}, {3.779470201565462*^9, 3.779470241549526*^9}, 
   3.780062293224526*^9, {3.780062341271126*^9, 3.7800623697424707`*^9}, {
   3.780062860795129*^9, 3.780062861799574*^9}, {3.7800666511707067`*^9, 
   3.7800666553558607`*^9}, {3.780066708471122*^9, 3.780066726219557*^9}, 
   3.780067723259276*^9, {3.7802542082187147`*^9, 3.780254230507213*^9}, {
   3.780256302536779*^9, 3.7802564037550087`*^9}, {3.780256434238928*^9, 
   3.780256437769991*^9}, {3.7802564759340487`*^9, 3.780256509276353*^9}, {
   3.780256558450182*^9, 3.7802565601620092`*^9}, {3.7802566206630383`*^9, 
   3.780256652521289*^9}, {3.780256688622583*^9, 3.7802566887965918`*^9}, {
   3.780256734472596*^9, 3.7802567644064074`*^9}, {3.780256799980043*^9, 
   3.780256866597209*^9}, {3.780256941027989*^9, 3.7802569671663017`*^9}, {
   3.780257186954887*^9, 3.7802571871000643`*^9}, {3.7802573149393377`*^9, 
   3.780257317817444*^9}, {3.780261589636335*^9, 3.780261636437409*^9}, {
   3.7802620396438503`*^9, 3.780262073439744*^9}, {3.7802643111657867`*^9, 
   3.780264312339591*^9}, {3.780264427439519*^9, 3.780264432319816*^9}, 
   3.780264817332904*^9, 3.782263049157585*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "izero"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Integral and error estimates are 0 on all integration \
subregions. Try increasing the value of the MinRecursion option. If value of \
integral may be 0, specify a finite value for the AccuracyGoal option. \\!\\(\
\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/NIntegrate\\\", ButtonNote -> \
\\\"NIntegrate::izero\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.779470161635611*^9, 3.779470252570225*^9, 3.780062310685498*^9, 
   3.780062391464891*^9, 3.7800628772268257`*^9, 3.7800667394757233`*^9, 
   3.780067840159727*^9, 3.780254249728323*^9, 3.780256522604405*^9, 
   3.78025658103601*^9, 3.7802566633868837`*^9, 3.780256780949135*^9, {
   3.78025681293653*^9, 3.780256838349967*^9}, 3.7802568812371387`*^9, 
   3.780257197395924*^9, 3.780257336556822*^9, 3.78026282236689*^9, 
   3.780264901844789*^9, 3.7822647418318243`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "izero"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Integral and error estimates are 0 on all integration \
subregions. Try increasing the value of the MinRecursion option. If value of \
integral may be 0, specify a finite value for the AccuracyGoal option. \\!\\(\
\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/NIntegrate\\\", ButtonNote -> \
\\\"NIntegrate::izero\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.779470161635611*^9, 3.779470252570225*^9, 3.780062310685498*^9, 
   3.780062391464891*^9, 3.7800628772268257`*^9, 3.7800667394757233`*^9, 
   3.780067840159727*^9, 3.780254249728323*^9, 3.780256522604405*^9, 
   3.78025658103601*^9, 3.7802566633868837`*^9, 3.780256780949135*^9, {
   3.78025681293653*^9, 3.780256838349967*^9}, 3.7802568812371387`*^9, 
   3.780257197395924*^9, 3.780257336556822*^9, 3.78026282236689*^9, 
   3.780264901844789*^9, 3.782264760724131*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NIntegrate", "::", "slwcon"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Numerical integration converging too slowly; suspect one \
of the following: singularity, value of the integration is 0, highly \
oscillatory integrand, or WorkingPrecision too small. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/NIntegrate/slwcon\\\", ButtonNote -> \
\\\"NIntegrate::slwcon\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.779470161635611*^9, 3.779470252570225*^9, 3.780062310685498*^9, 
   3.780062391464891*^9, 3.7800628772268257`*^9, 3.7800667394757233`*^9, 
   3.780067840159727*^9, 3.780254249728323*^9, 3.780256522604405*^9, 
   3.78025658103601*^9, 3.7802566633868837`*^9, 3.780256780949135*^9, {
   3.78025681293653*^9, 3.780256838349967*^9}, 3.7802568812371387`*^9, 
   3.780257197395924*^9, 3.780257336556822*^9, 3.78026282236689*^9, 
   3.780264901844789*^9, 3.782264770630418*^9}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {{}, {}, 
       {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8HntgvvNJtOveCP/bc1xcX
2HId3192c0Ke+kJuh8NfNWL6Dx3dfyXoXW36FmGHapF17g+rjuyfqxPTsHKW
hIOJMQgc3r//wVGFJ1EyDm8CQQYe3G9xyZGj8r6cwxKgadcXH9i/Kjvnp4mw
gsNOkHU79u3Pddm60khBwUELaPpXjT37l4YH37L1k3eAuG/n/uz/E5WUamUd
IO7Zvl+/T3EFN5O0Qw3Y/i37+bPDPr0RkYDat3H/IvUZq1XeiDiAvbNj3f64
/wsql+8QdJgDNm/l/oYY5muJbrxQ/Uv2z1KvWug6lR2qft7+6h7BCsV2JocG
sPyU/fMSrx9yTf5jD+G37JcomNEdZfzVHhZuTvM7Sr7efmdfAJG3/5QV5rPg
wVP7Coh++yzDSe49xvfsoebbd8jejbzncQUqv8Re/19bR0j9KfsZEPfZd7T8
a4u8eACqfp39Ou3NK4/s2mIP9Z/9H33GeRanVthD/W+vctFNq27PHHsOSPjY
O/wt+/BLYQLUvJ32eQGsB9Y0N9prQMLXfocH59uZCUVQ8/fZ1/Rf2SI2J8ke
Gj/2fy+lH7qoGQS176D91c0ny77zO9pD49eeU/bA59xzevZVkPi3X3Zhr/3h
dVL2hyDpw9765rtZuUps9lyQ9GOfdmivbmLvRzto+rJnVWr7YNJ3yw6a/ux7
X01jeCB32O4R2MBT9jWbWO79UFllB3HvGXulr+tt3N9OsAM7r+Cs/T/2VZFB
m0rsIO4/Z++XnjPlwcVwO0hsXLDfvrRkB+d2SzsAfQxhnA==
         
         "]]}}, {}}, {{}, {{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsb+6kzfPVFnHAcKfYv+MT87zVJuR
ww651teBO+bZt28umZR/3RAqv8TejlU8deYhXYdZM0Fgpb2U5NNde5epQdWv
s38rd0f8moSCw5tAkMhG+9jq4Oqdc0Sh+rfYH9X2OeYwnduB6/riAluu7fb1
045M9z3PADVvp/35pLmyZ6d/tteM6T/0VWOP/dQXny+cuvfUHmL+PvtdO/dP
PZJ83X4JUPf1xQfs1edeCXX6ftweYt9B+/83Vh/Va9lubwwGh+2Fz71efk9k
mT3E/iP2x1i2rdC/NNn+8FcNoA1H7bULdlTO/dNgD3HPcfu5FzUt5hzMtg8C
W3jC/oN4M8PGKaH2EPedtH/U6W5y4769/cMqkIGn7G/8lef57acGde8Z+5ec
c1/sb+W1LwQ5r+CsfUx6fSlf9ic7iPvP2R8+8uqY9ayrdpBYuGCfszbh5dU9
2+0AUg3FSw==
         "]]}, 
       {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqse+9k7Vi+0YhBwh/iv0Rnp7W6jOy
DjvkWl8H7phnH5idaHqLTwkqv8T+nHK+0a0iZYdZM0FgpX2k2i7++13KUPXr
7G8tkjGw3qHk8CYQJLLRvtRBKPippyJU/xb7p6yqcx/9lXPgur64wJZru33D
8qi02wLSUPN22iekdhT4iok7aMb0H/qqsce+WSiG6bqTMNT8ffZunqt2uBfz
OywB6r6++IB9zO/0xFXynFD7DtpLT1CRCJ7P7GAMBoftmcIiriu8/WsPsf+I
feKqorU5Nt/sD3/VANpw1D5TYsH+LXwf7CHuOW6/W/Kdb0XFM/sgsIUn7GPN
3ERqYu/ZQ9x30v7k74kHjfddtn9YBTLwlL2dzOv9j+adsIe494x95fnEttWR
e+0LQc4rOGv/r593T/OaDfYQ95+zn6in+fIs4yJ7SCxcsOd73CcwK3+SPQAO
Lbi6
         "]]}}, {}}, {{}, {{}, {}, 
       {GrayLevel[0.5], Thickness[Large], Dashing[Large], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8HntjvEv/wWW8tlwP39cUF
tlzH99e2nvGYySLpcPirRkz/oaP7zzzd5vrTSNGhWmSd+8OqI/uNG96aRiSr
OJgYg8Dh/Wv/Hd/J8k3V4U0gyMCD+/PrD+9b/U/VYQnQtOuLD+zffyGO2XaX
isNOkHU79u3/dWryJrFGJQctoOlfNfbsV/Zmkv6fI+8Acd/O/ctOTbr/vVAS
6p7t+1/IpmltWyPsUAO2f8t+FUUhXTsRXqh9G/f3MLUdONTN4gD2zo51+yfc
uTGz6dBv+zlg81buX/Ky4LDq24/2EP1L9sfLnpKykH9mD1E/b/+NvT7y3YK3
7BvA8lP26+R1nLzmfxbKb9l/y3lF7dHs/fawcNNTqZjzj3ODfQFE3l4+8v7m
Werz7Ssg+u0XiPyd9Hx/D8x8+zcKG9ZO0qmEyi+xd+k1Y3rxKMV+BsR99nwx
GmeupwRA1a+zd5mttjbfz8Ie6j/7ZS3MXi/+KEDdv8W+KXH6BdMINnsOSPjY
1/99FJw387UdxLyd9pfmnF4a8vG8nQYkfO2X6TA+3uK+0Q5i/j77S9UlxjL5
E+2g8WOfzKu5fm10gR00/uyFWw7drSn3sYPGr/0D56Qy2WdqdlWQ+LdXbtBx
EvjJYHcIkj7syzb9nSIkdR1kGCj92B85WunSc2iNLTR92b+W6Tkb4ddgC01/
9vP/S7VrHQmwfQQ28JT9WRbRvpMy8rYQ956x/x1y3Fn65UsbsPMKztqL9ljv
2OS42Qbi/nP2DisNV+5NrLSBxMYF++XFiy6Il9naAAC122EP
         
         "]]}}, {}}, {{}, {{}, {}, 
       {RGBColor[0.24720000000000014`, 0.24, 0.6], Thickness[Large], Dashing[
        Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsZ+gUHPs4Ut7Bwh/in1btd7RbeI2
DjvkWl8H7phn/3rnqY8LFhlC5ZfYR2UnPfu+Tslh1kwQWGm/97AUK980Qaj6
dfZVfhwvjgj8s38TCBLZaH84Oe93wfTn9hD9W+zFGaM0fcUu2nNdX1xgy7Xd
ft7fA2bPXmyzh5i3017b1PPjrdI59pox/Ye+auyxt/jFXv81ocEeYv4++z/f
ExW2FyfaLwHqvr74gD1P4C3VCwaOUPsO2gtsWuW1zF7e3hgMDtsrXN7UYqX6
yw5i/xH7m2tnLi4RvWJ3+KsG0Iaj9nkScl7bbNfYQdxz3H7BXEWOWpkmuyCw
hSfs2bn0+PdLh9pB3HfS/mj0sQf7ndTsHlaBDDxl73X0yr+HKl9tIe49Y8/2
0c1W5P9B20KQ8wrO2m8P2yqv4tNtC3H/OftDIc4/c0KDbCGxcME+obzkEu9K
UVsA7UG9Aw==
         "]]}, 
       {RGBColor[0.6, 0.24, 0.4428931686004542], Thickness[Large], Dashing[
        Large], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsU898132/Xs1Bwh/iv0+nrrzrwr1
HXbItb4O3DHP/uyyO+sYGAyg8kvs/1mF3prbqOMwayYIrLT/t/bv0cQMdaj6
dfbfKyYdTlBUcngTCBLZaH9+zzOZPReloPq32B/O87UMEBF24Lq+uMCWa7t9
P1uu5yZLLqh5O+2VFXd/tyhhdNCM6T/0VWOP/Y3LNpP2NH2zh5i/z34Vg+ZU
D/E39kuAuq8vPmB/UvL6guNPH9hD7Dtof+jfSYVl1ZftjcHgsL31s02LGWKP
2kPsP2K/hMHjTrfYNvvDXzWANhy1t5cQYAuLWWoPcc9xe3HXhHMNBpPtg8AW
nrBfvbZRdtfNenuI+07an3S+Kq/vl2H/sApk4Cn7n5L9MeJ/Auwh7j1jnya2
0V59ual9Ich5BWft6+9f+TBFVBLq/nP2E75O3N3l/8sOEgsX7E8fVIm3eX7D
DgBKWr+v
         "]]}}, {}}}, {InsetBox[
      TagBox[GridBox[{
         {
          
          TemplateBox[{
           StyleBox[
            "\"1-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
             FontSize -> 12],StyleBox[
            "\"2-step\"", StripOnInput -> False, FontFamily -> "Helvetica", 
             FontSize -> 12]},
           "LineLegend",
           DisplayFunction->(StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.24720000000000014`, 0.24, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    RGBColor[0.6, 0.24, 0.4428931686004542], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
             False]& ),
           Editable->True,
           InterpretationFunction:>(RowBox[{"LineLegend", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.24720000000000014`", ",", "0.24`", ",", "0.6`"}], 
                    "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"RGBColor", "[", 
                    
                    RowBox[{
                    "0.6`", ",", "0.24`", ",", "0.4428931686004542`"}], "]"}],
                     ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}]}], 
                  "}"}], ",", 
                RowBox[{"{", 
                  RowBox[{#, ",", #2}], "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]},
         {
          
          TemplateBox[{
           StyleBox[
            "\"established\"", StripOnInput -> False, FontFamily -> 
             "Helvetica", FontSize -> 12]},
           "LineLegend",
           DisplayFunction->(StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0.5]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
             False]& ),
           Editable->True,
           InterpretationFunction:>(RowBox[{"LineLegend", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}]}], "]"}], "}"}], 
                ",", 
                RowBox[{"{", #, "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
                RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{0}}}],
       "Grid"], NCache[
      Scaled[{0.1875, Rational[1, 2]}], Scaled[{0.1875, 0.5}]], ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TemplateBox[{
       StyleBox[
        "\"\[Lambda]=0.005\"", StripOnInput -> False, FontFamily -> 
         "Helvetica", FontSize -> 12],StyleBox[
        "\"\[Lambda]=0.0025\"", StripOnInput -> False, FontFamily -> 
         "Helvetica", FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}],
             ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "False"}]}], "]"}]& )], 
      NCache[Scaled[{Rational[7, 8], Rational[3, 10]}], Scaled[{0.875, 0.3}]],
       ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesLabel->{None, None},
   AxesOrigin->{0., 0.},
   Epilog->{
     InsetBox[
      FormBox[
       StyleBox[
       "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=-0.2\"", 12, FontFamily -> 
        "Helvetica", StripOnInput -> False], TraditionalForm], 
      NCache[
       Scaled[{
         Rational[7, 8], 
         Rational[3, 4]}], 
       Scaled[{0.875, 0.75}]]], 
     InsetBox[
      FormBox[
       StyleBox["\"B\"", 14, Bold, StripOnInput -> False], TraditionalForm], 
      Scaled[{0.05, 0.95}]]},
   Frame->{True, False, False, False},
   FrameTicksStyle->{
    FontColor -> GrayLevel[1], Automatic, Automatic, Automatic},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.3, 0.25}, {0, 40}},
   PlotRangeClipping->True,
   PlotRangePadding->{Automatic, Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           GrayLevel[0.5]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8HntgvvNJtOveCP/bc1xcX
2HId3192c0Ke+kJuh8NfNWL6Dx3dfyXoXW36FmGHapF17g+rjuyfqxPTsHKW
hIOJMQgc3r//wVGFJ1EyDm8CQQYe3G9xyZGj8r6cwxKgadcXH9i/Kjvnp4mw
gsNOkHU79u3Pddm60khBwUELaPpXjT37l4YH37L1k3eAuG/n/uz/E5WUamUd
IO7Zvl+/T3EFN5O0Qw3Y/i37+bPDPr0RkYDat3H/IvUZq1XeiDiAvbNj3f64
/wsql+8QdJgDNm/l/oYY5muJbrxQ/Uv2z1KvWug6lR2qft7+6h7BCsV2JocG
sPyU/fMSrx9yTf5jD+G37JcomNEdZfzVHhZuTvM7Sr7efmdfAJG3/5QV5rPg
wVP7Coh++yzDSe49xvfsoebbd8jejbzncQUqv8Re/19bR0j9KfsZEPfZd7T8
a4u8eACqfp39Ou3NK4/s2mIP9Z/9H33GeRanVthD/W+vctFNq27PHHsOSPjY
O/wt+/BLYQLUvJ32eQGsB9Y0N9prQMLXfocH59uZCUVQ8/fZ1/Rf2SI2J8ke
Gj/2fy+lH7qoGQS176D91c0ny77zO9pD49eeU/bA59xzevZVkPi3X3Zhr/3h
dVL2hyDpw9765rtZuUps9lyQ9GOfdmivbmLvRzto+rJnVWr7YNJ3yw6a/ux7
X01jeCB32O4R2MBT9jWbWO79UFllB3HvGXulr+tt3N9OsAM7r+Cs/T/2VZFB
m0rsIO4/Z++XnjPlwcVwO0hsXLDfvrRkB+d2SzsAfQxhnA==
           
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           Thickness[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsb+6kzfPVFnHAcKfYv+MT87zVJuR
ww651teBO+bZt28umZR/3RAqv8TejlU8deYhXYdZM0Fgpb2U5NNde5epQdWv
s38rd0f8moSCw5tAkMhG+9jq4Oqdc0Sh+rfYH9X2OeYwnduB6/riAluu7fb1
045M9z3PADVvp/35pLmyZ6d/tteM6T/0VWOP/dQXny+cuvfUHmL+PvtdO/dP
PZJ83X4JUPf1xQfs1edeCXX6ftweYt9B+/83Vh/Va9lubwwGh+2Fz71efk9k
mT3E/iP2x1i2rdC/NNn+8FcNoA1H7bULdlTO/dNgD3HPcfu5FzUt5hzMtg8C
W3jC/oN4M8PGKaH2EPedtH/U6W5y4769/cMqkIGn7G/8lef57acGde8Z+5ec
c1/sb+W1LwQ5r+CsfUx6fSlf9ic7iPvP2R8+8uqY9ayrdpBYuGCfszbh5dU9
2+0AUg3FSw==
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Directive[
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           Thickness[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqse+9k7Vi+0YhBwh/iv0Rnp7W6jOy
DjvkWl8H7phnH5idaHqLTwkqv8T+nHK+0a0iZYdZM0FgpX2k2i7++13KUPXr
7G8tkjGw3qHk8CYQJLLRvtRBKPippyJU/xb7p6yqcx/9lXPgur64wJZru33D
8qi02wLSUPN22iekdhT4iok7aMb0H/qqsce+WSiG6bqTMNT8ffZunqt2uBfz
OywB6r6++IB9zO/0xFXynFD7DtpLT1CRCJ7P7GAMBoftmcIiriu8/WsPsf+I
feKqorU5Nt/sD3/VANpw1D5TYsH+LXwf7CHuOW6/W/Kdb0XFM/sgsIUn7GPN
3ERqYu/ZQ9x30v7k74kHjfddtn9YBTLwlL2dzOv9j+adsIe494x95fnEttWR
e+0LQc4rOGv/r593T/OaDfYQ95+zn6in+fIs4yJ7SCxcsOd73CcwK3+SPQAO
Lbi6
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           Thickness[Large], 
           GrayLevel[0.5], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGDQA2IQPWsmCJzczwAFQTvkWl8HntjvEv/wWW8tlwP39cUF
tlzH99e2nvGYySLpcPirRkz/oaP7zzzd5vrTSNGhWmSd+8OqI/uNG96aRiSr
OJgYg8Dh/Wv/Hd/J8k3V4U0gyMCD+/PrD+9b/U/VYQnQtOuLD+zffyGO2XaX
isNOkHU79u3/dWryJrFGJQctoOlfNfbsV/Zmkv6fI+8Acd/O/ctOTbr/vVAS
6p7t+1/IpmltWyPsUAO2f8t+FUUhXTsRXqh9G/f3MLUdONTN4gD2zo51+yfc
uTGz6dBv+zlg81buX/Ky4LDq24/2EP1L9sfLnpKykH9mD1E/b/+NvT7y3YK3
7BvA8lP26+R1nLzmfxbKb9l/y3lF7dHs/fawcNNTqZjzj3ODfQFE3l4+8v7m
Werz7Ssg+u0XiPyd9Hx/D8x8+zcKG9ZO0qmEyi+xd+k1Y3rxKMV+BsR99nwx
GmeupwRA1a+zd5mttjbfz8Ie6j/7ZS3MXi/+KEDdv8W+KXH6BdMINnsOSPjY
1/99FJw387UdxLyd9pfmnF4a8vG8nQYkfO2X6TA+3uK+0Q5i/j77S9UlxjL5
E+2g8WOfzKu5fm10gR00/uyFWw7drSn3sYPGr/0D56Qy2WdqdlWQ+LdXbtBx
EvjJYHcIkj7syzb9nSIkdR1kGCj92B85WunSc2iNLTR92b+W6Tkb4ddgC01/
9vP/S7VrHQmwfQQ28JT9WRbRvpMy8rYQ956x/x1y3Fn65UsbsPMKztqL9ljv
2OS42Qbi/nP2DisNV+5NrLSBxMYF++XFiy6Il9naAAC122EP
           
           "]]}}}, {}}, {{}, {{{}, {}, {
          Hue[0.67, 0.6, 0.6], 
          Directive[
           RGBColor[0.24720000000000014`, 0.24, 0.6], 
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsZ+gUHPs4Ut7Bwh/in1btd7RbeI2
DjvkWl8H7phn/3rnqY8LFhlC5ZfYR2UnPfu+Tslh1kwQWGm/97AUK980Qaj6
dfZVfhwvjgj8s38TCBLZaH84Oe93wfTn9hD9W+zFGaM0fcUu2nNdX1xgy7Xd
ft7fA2bPXmyzh5i3017b1PPjrdI59pox/Ye+auyxt/jFXv81ocEeYv4++z/f
ExW2FyfaLwHqvr74gD1P4C3VCwaOUPsO2gtsWuW1zF7e3hgMDtsrXN7UYqX6
yw5i/xH7m2tnLi4RvWJ3+KsG0Iaj9nkScl7bbNfYQdxz3H7BXEWOWpkmuyCw
hSfs2bn0+PdLh9pB3HfS/mj0sQf7ndTsHlaBDDxl73X0yr+HKl9tIe49Y8/2
0c1W5P9B20KQ8wrO2m8P2yqv4tNtC3H/OftDIc4/c0KDbCGxcME+obzkEu9K
UVsA7UG9Aw==
           "]]}, {
          Hue[0.9060679774997897, 0.6, 0.6], 
          Directive[
           RGBColor[0.6, 0.24, 0.4428931686004542], 
           Thickness[Large], 
           Dashing[Large]], 
          Line[CompressedData["
1:eJxTTMoPSmViYGCQAmIQjQ6qRda5P6xqsU898132/Xs1Bwh/iv0+nrrzrwr1
HXbItb4O3DHP/uyyO+sYGAyg8kvs/1mF3prbqOMwayYIrLT/t/bv0cQMdaj6
dfbfKyYdTlBUcngTCBLZaH9+zzOZPReloPq32B/O87UMEBF24Lq+uMCWa7t9
P1uu5yZLLqh5O+2VFXd/tyhhdNCM6T/0VWOP/Y3LNpP2NH2zh5i/z34Vg+ZU
D/E39kuAuq8vPmB/UvL6guNPH9hD7Dtof+jfSYVl1ZftjcHgsL31s02LGWKP
2kPsP2K/hMHjTrfYNvvDXzWANhy1t5cQYAuLWWoPcc9xe3HXhHMNBpPtg8AW
nrBfvbZRdtfNenuI+07an3S+Kq/vl2H/sApk4Cn7n5L9MeJ/Auwh7j1jnya2
0V59ual9Ich5BWft6+9f+TBFVBLq/nP2E75O3N3l/8sOEgsX7E8fVIm3eX7D
DgBKWr+v
           "]]}}}, {}}}, {
     PlotRange -> {{-0.3, 0.25}, {0, 40}}, 
      Frame -> {True, False, False, False}, LabelStyle -> 
      Directive[12, FontFamily -> "Helvetica"], 
      FrameTicksStyle -> {
       FontColor -> GrayLevel[1], Automatic, Automatic, Automatic}, Epilog -> {
        Text[
         Style[
         "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=-0.2", 12, FontFamily -> "Helvetica"], 
         Scaled[{
           Rational[7, 8], 
           Rational[3, 4]}]], 
        Text[
         Style["B", 14, Bold], 
         Scaled[{0.05, 0.95}]]}, AxesLabel -> {None, None}, AspectRatio -> 
      GoldenRatio^(-1), Axes -> True, AxesOrigin -> {0., 0.}, Method -> {}, 
      PlotRange -> {All, All}, PlotRangeClipping -> True, 
      PlotRangePadding -> {Automatic, Automatic}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          Thickness[Large], 
          GrayLevel[0]], 
         Directive[
          Thickness[Large], 
          GrayLevel[0], 
          Dashing[Medium]]}, {
         Style["\[Lambda]=0.005", 12, FontFamily -> "Helvetica"], 
         Style["\[Lambda]=0.0025", 12, FontFamily -> "Helvetica"]}, 
        LegendLayout -> "Column", LegendMarkers -> False]], 
      Scaled[{
        Rational[7, 8], 
        Rational[3, 10]}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{{3.779468795408979*^9, 3.779468830949634*^9}, 
   3.779468917873926*^9, {3.779469011820323*^9, 3.779469047660637*^9}, {
   3.779469821103179*^9, 3.779469830115543*^9}, {3.779470013240581*^9, 
   3.77947001697924*^9}, {3.779470060618907*^9, 3.779470094444737*^9}, 
   3.779470124926302*^9, 3.7794701689603777`*^9, 3.7794702603696213`*^9, 
   3.78006231915749*^9, 3.780062399351725*^9, 3.780062885347563*^9, 
   3.780066748143722*^9, 3.780067848691842*^9, 3.780254256385449*^9, 
   3.78025654685863*^9, 3.7802566056431427`*^9, 3.7802566879888897`*^9, 
   3.780256788170679*^9, {3.7802568199542313`*^9, 3.780256845738853*^9}, 
   3.7802569054429827`*^9, 3.780257228032707*^9, 3.780257366897098*^9, 
   3.7802628550349913`*^9, 3.7802649267704153`*^9, 3.782264770700328*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2-step intermediate growth rate", "Subsubsection",
 CellChangeTimes->{{3.779477356570382*^9, 3.779477361850051*^9}, {
   3.779482848762312*^9, 3.779482851539497*^9}, {3.780068347007688*^9, 
   3.780068352358201*^9}, 3.780254198935792*^9, {3.780261755444825*^9, 
   3.780261756169991*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xmin", "=", 
   RowBox[{"-", "0.3"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmax", "=", "0.25"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ymax", "=", "30"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"N0", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mmax", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mwt", "=", 
   RowBox[{"-", "0.2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"U", "=", 
    RowBox[{"2", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Lambda]", "=", "0.005"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"exact2", "=", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
    RowBox[{"prescuem", "[", 
     RowBox[{"m1", ",", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"allexact2", "=", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{"exact2", ",", 
     RowBox[{"{", 
      RowBox[{"m1", ",", "mwt", ",", "0.1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory2", "=", 
    FractionBox[
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"pest", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}]}], 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fm", "[", 
         RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"pest", "[", 
         RowBox[{"m1", "-", "mwt"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Lambda]", "=", 
    RowBox[{"0.005", "/", "2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"exact4", "=", 
   RowBox[{
    RowBox[{"fm", "[", 
     RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
     "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"pest", "[", "m1", "]"}]}], ")"}], 
    RowBox[{"prescuem", "[", 
     RowBox[{"m1", ",", 
      RowBox[{"\[CapitalLambda]1", "[", 
       RowBox[{"m1", ",", "mmax", ",", "\[Lambda]", ",", "n", ",", "U"}], 
       "]"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"allexact4", "=", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{"exact4", ",", 
     RowBox[{"{", 
      RowBox[{"m1", ",", "mwt", ",", "0.1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oldtheory4", "=", 
    FractionBox[
     RowBox[{
      RowBox[{"fm", "[", 
       RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
       "]"}], 
      RowBox[{"pest", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}], 
      RowBox[{"HeavisideTheta", "[", 
       RowBox[{"m1", "-", "mwt"}], "]"}]}], 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"fm", "[", 
         RowBox[{"m1", ",", "mwt", ",", "mmax", ",", "\[Lambda]", ",", "n"}], 
         "]"}], 
        RowBox[{"pest", "[", 
         RowBox[{"m1", "-", "mwt"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"m1", ",", "mwt", ",", "mmax"}], "}"}]}], "]"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"oldtheory2", ",", "oldtheory4"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{"Gray", ",", "Thick"}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Gray", ",", "Thick", ",", 
           RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}], "}"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", "\"\<established\>\"", "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "8"}], ",", 
            RowBox[{"1.25", "/", "2"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"exact2", "/", "allexact2"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", "Thick", "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"#", ",", "12", ",", 
              RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}],
             "&"}], "/@", 
           RowBox[{"{", "\"\<first-step\>\"", "}"}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "/", "8"}], ",", 
            RowBox[{"1.25", "/", "2"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"exact4", "/", "allexact4"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"m1", ",", "xmin", ",", "xmax"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", "All"}], "}"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Thick", ",", 
         RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PerformanceGoal", "\[Rule]", "\"\<Speed\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"PlotLegends", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{
         RowBox[{"LineLegend", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Directive", "[", 
              RowBox[{"Thick", ",", "Black"}], "]"}], ",", 
             RowBox[{"Directive", "[", 
              RowBox[{"Thick", ",", "Black", ",", 
               RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Style", "[", 
              RowBox[{"#", ",", "12", ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
              "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{
             "\"\<\[Lambda]=0.005\>\"", ",", "\"\<\[Lambda]=0.0025\>\""}], 
             "}"}]}]}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"7", "/", "8"}], ",", 
            RowBox[{"3", "/", "10"}]}], "}"}]}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False", ",", "False", ",", "False"}], "}"}]}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"FrameTicksStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "Automatic", ",", "Automatic", ",", "Automatic", ",", "Automatic"}], 
      "}"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", "\"\<Growth rate\>\"", "}"}]}], ",", "\[IndentingNewLine]", 
    
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xmin", ",", "xmax"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "ymax"}], "}"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"LabelStyle", "\[Rule]", "labelstyle"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{
           RowBox[{"\"\<\!\(\*
StyleBox[SubscriptBox[\"m\", \"0\"],
FontSlant->\"Italic\"]\)=\>\"", "<>", 
            RowBox[{"ToString", "[", "mwt", "]"}]}], ",", "12", ",", 
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
         ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"7", "/", "8"}], ",", 
            RowBox[{"3", "/", "4"}]}], "}"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<C\>\"", ",", "14", ",", "Bold"}], "]"}], ",", 
         RowBox[{"Scaled", "@", 
          RowBox[{"{", 
           RowBox[{"0.05", ",", "0.95"}], "}"}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{
  "mmax", ",", "\[Lambda]", ",", "Es", ",", "n", ",", "U", ",", "mwt", ",", 
   "xmin", ",", "xmax", ",", "ymax", ",", "N0"}], "]"}]}], "Input",
 CellChangeTimes->{{3.771259863315041*^9, 3.771259875817935*^9}, {
   3.77125993618959*^9, 3.7712599967791033`*^9}, {3.7712600806108303`*^9, 
   3.771260101998229*^9}, {3.7712601420091887`*^9, 3.771260164023238*^9}, {
   3.7712604866075153`*^9, 3.7712604916540623`*^9}, {3.771260596998*^9, 
   3.7712606779327497`*^9}, {3.771260742113587*^9, 3.77126078863237*^9}, {
   3.7712608356681213`*^9, 3.771260853796445*^9}, 3.77126088730492*^9, {
   3.771260950376927*^9, 3.771260951994858*^9}, {3.771260988204628*^9, 
   3.771261046264202*^9}, {3.771261095976034*^9, 3.771261100349186*^9}, {
   3.771261221602476*^9, 3.771261223165237*^9}, {3.7712612596219587`*^9, 
   3.771261376814014*^9}, {3.7712614254017878`*^9, 3.771261458422593*^9}, {
   3.771261523796259*^9, 3.771261558803645*^9}, {3.771525291980131*^9, 
   3.771525296404852*^9}, {3.771525340514213*^9, 3.771525362538801*^9}, {
   3.771525476715866*^9, 3.771525481529388*^9}, {3.771525527353706*^9, 
   3.771525572057776*^9}, {3.771525611182823*^9, 3.77152571017303*^9}, {
   3.771525850691698*^9, 3.771525923002439*^9}, {3.771525956576083*^9, 
   3.771525983790447*^9}, {3.771526019222022*^9, 3.7715260269883137`*^9}, {
   3.771526062519966*^9, 3.77152607841735*^9}, {3.771526152732314*^9, 
   3.771526160701219*^9}, {3.771526280292366*^9, 3.771526400673423*^9}, 
   3.771526440426137*^9, {3.7794773959510937`*^9, 3.7794774153789377`*^9}, 
   3.779479818451282*^9, {3.779482804081335*^9, 3.779482804522912*^9}, {
   3.780063051430872*^9, 3.78006305162116*^9}, {3.780063286850298*^9, 
   3.780063305483961*^9}, {3.780067547237227*^9, 3.780067619007799*^9}, {
   3.780254430235753*^9, 3.780254449602309*^9}, {3.7802547336341*^9, 
   3.780254734411544*^9}, {3.780257012559074*^9, 3.7802570858592567`*^9}, {
   3.780257124286892*^9, 3.7802572680528307`*^9}, {3.78025742903951*^9, 
   3.7802576687584457`*^9}, {3.780257712102442*^9, 3.780257724677702*^9}, {
   3.780257755591942*^9, 3.7802577557274637`*^9}, {3.78025778871243*^9, 
   3.7802579013536158`*^9}, {3.7802616510463943`*^9, 3.780261691559404*^9}, {
   3.7802620773822327`*^9, 3.7802621283466873`*^9}, {3.7802643189879303`*^9, 
   3.780264319976739*^9}, {3.78026444053223*^9, 3.7802644406655293`*^9}, 
   3.7802648214283123`*^9, {3.782263059015923*^9, 3.782263059367753*^9}}],

Cell[BoxData[
 TagBox[
  GraphicsBox[{{{{}, {}, 
      {GrayLevel[0.5], Thickness[Large], LineBox[CompressedData["
1:eJxFyQk01XkfBnBi7CFClhBlzZalkP/3b6kREVFMJttMblkrW6RCsmS7lhAK
RZYpXZHd/V3bvbZru5N1Sta8KEokinfec97Dc85znvM5zwFXn7OXdjExMT3+
t//bQ3PpYpqaDMT0/3w6nS/Kx7bj6pekffND/ds2828Xfnp7x1eZNgQEO/q2
7f/4S2+yUe+237ayh3KU0LddcZnW7mO14/vcUYKDq13bPmbNVlhgvGPer61L
PHOd255Ou6fnR9xx8j+s3UZvO7Ztn6fIKRCy4/1ulibjYjueUPK9Q6pp33bR
YnrtHft2pDLlbCmrMAjeFfUrlt/akGd+umBWxQJoBo2rS6a1ocz9+yPZOleB
vEu5sJ5BQ4WX/zq8K50Fl9ZIs+QIoiFxESpiO8mO33ViXrWRpKESpO6gMsKF
m9YPmsxfpqLRLM7e3xn8eMmc0YIOLxUZdP+QWvUUwHlES1PCy1tRTdjzXz4v
C+J9/hETopstaID7lkx/qzAuQ7W9Sc9qQTLcI9oExX24n/ChvWG6LahjcuoM
6boo3uq28lxrsBllJ2yRR3LFcOGq1hOzfs1IZk6b63i5OE5gT3uXJdCM6vac
zjxbLIFX27kFniE1oTteBbup4ftxriIdfhbLJuRErtEhgCTusMZWXDnfiJi9
q1rVxiTxPzP71bRjG5GZpoGUlLMU7n38cWW5UiPSrtBSedYqhd94d8XgSAcF
WUXoxAhzSONhodotpCsUxDTRMy0pLY3fl2E2V+OkoPLvyUaGytK4QszDpw7W
CBn+nBsdV5TG9ejqZfZEMvInaXP6SkjjFnvayOd6GhDjS5GYH4s0nqmwkG8u
3oBKo23uubZI4TPAH2tIqEdnbq6jPB8pXNNO69rR8jrkaJ+q+oxTCg/1trdT
2apFB8Y+a4SkSOL0eyEGsua1KD/4jKUeryQu9ihXVjS9Bg1ObxzZCt6Pl3fO
LrKqVaO3xH/EtdUk8Hdyg9UdHlWocObWguIVcZwjvDWMWFSJYt54vTTJEMMv
HnsiKCHzGv3RxKsyNLoPZy9wOKop9ArFMy3tdpEWwj0ZA0OfHcvQvZYg+Xr9
vXgv89lgUhEJOcKLCR47QVy9gRjscKMUXR18uSmbtAe3UXePtKIWIRcGd+aS
NQ/+g2ER9t25EN10ltEn1HPhzwI1Qp5sFKCSUQP7eA1O/Dt57dpX9adI6JzC
XSZgw5+4/uP5qDMP+flSxpOHWPHTbBTCSbdcJFOdvex8hwWHLN469aNZSHEf
2wOhVSac88umfpNaBvKX54lLvrAFDNPFehuFB2h9aoJqO/cDHuWMGUxLJ6OS
ZrNC/6x16F7IufXxSALyOJuk1uK1Bq6ZoXf4D0ajR6/6DMecV2H1V5cwTaFw
JOJg/Lue31fwi7u/d+YtAZ1/3y/ftLYESznBI/37DqKn6cE+YqyLEHBMv6bz
wiX4+TLBbNB0AQJ281klb/jD17Cv0XMN/wF7oLiM5YfCkSqnM+4uH2D1242s
FfNIyDDvG7HXmIYUksYb7uVYOLls1VGsPAkZWv7se+hEWF6v5P/Vchw+EK0P
ZuemgPnSvKCy6hiQ37JWfiClgVYo1Y9AG4U0pepfNRsfgtfkt/sipCHwDvQY
vt2XDYqC43arE2/gZIukR8d4DmxwXTYcucCARI4rm1xBefCl+MH7eoE+2Cg1
oqkzP4WeRAmTu9zdQDgnQTwfkw/sWpvRAY4dwNhYsQ/Z8wzMIsyinIVo4Ogw
cSUguRBSp+dZn2u1wFxtd/BVwWKg3jCI989vBH+xulj31BLoy+DP56sjA1Nw
YfafQs9BLjl6r96rWogdTnnhmPYC3offvUY+UAXCuqFke5GX8FM8q6j7ZzlY
na4kKJ4mQeKD93MB+mUgHHL46jOeMpjx5ahQz3sBT4aEcpUoZfAno54o/LwY
VLS3ekp9X0GqAXsUh8YzqE6a3ToiXw4jrt7TuOxTMPnUp1Y1Ug5y6os6PIG5
0GtW56SfUAFWLE6OAcbZ8HthfiIyfA05pd3HFTQzYJYlARmvvAavKbpx9F+p
4OscuEgrqgTNwI+hudlJcCAo7XiIRxXEPGS2iY6Mh56k1zHqqtWgfv02y+EX
0XCr5O+BqaVqEJXLVGclRoBy87Lsw/IacKlnpp8SCoPhUYFrFgG1QCnNjU48
HQJRXzXIzLp1MFDaLiftGAjau625KzfqIPEC0cL9uC9MHrpq706uB8/nun9L
JvvAeY9d9EN+DXBN4IWttIo7dJBSDccVycDjsqn6V/4lwFblKrPHyOBmGsVn
PeQCr/RrlOwfILC2UI0ZtbsIKZSCnphDFDi0myRny2sPFpOfYgihFPgyr+so
WGID7GzHTE6MUuCcjWQOO7sVNCqEbcroNIKjuat1Oo8ZxCleomVkNMKxVrdh
/noTsFc6ReTdaAQNfk6a1HUcZJVVfou42ATt/ZGU9E1d+KS8R2YdNQHR2NZV
4IYW1BxemfORaYYN0YNKu/nUIUJluHw6ohlmabpAFFMEK9WGEIcPzTDA/yZO
M04WxNXyTvSdaoEy1VjVOBtJUH0XIx1S0gJOSrJDTrEiYBh/fUOOuxUcVx+9
7dEWANvjDgN9Hq0wnaWwXMnHA4R547KQrlZw9/2tOirmFwjOPBwnr0IF0Zs0
HYFAJog/JUToj6eCFN44dFTwO5a79tPw1icqeD25oGzFuoyVF85IKJyhQfuP
+yv7axcwxY/RseeLacAFVuki7DNYzhHl9QiWNgj3Ns8z+fs9JnSDfrn8YhuY
1hgEkB8PY7ENPoPjVW3g/FmurdaLgTGzCJzkF2gH9oquyc8X6FigaUUF5tkO
Cb/Zpt4UoWIf48/LelHbYUKk6T/ERAr2B2MtKUu6AyadO8r06qqxuVVtPtfw
DthychupWyzDrov5xilM/fsfDrVImyrGvhuQOBdPdMJ7GeFQu4dPsFCXj5Gv
CzuhSPNjf1paJsZ+T4k1hLMLlIKqyhZmk7GEIkKYkUcXnExqurzadB8T7srf
5KB3gffUksnoQDj2aHH8Zo8qHfjebextdQ3G3MawyJVoOvRapYyXzl7HVHuy
iOKTdFg8NXFXft0d+0ZeyzQ06Ib6KT1alPwfGKX0XAEhvRtcJuljVgIOWMzj
Vy/jP3fDPn2NozOcNtjZBL7acvMemPUMspwrMMPEb3u2DBf0QAqj1/RhghE2
5dXevbXVA7H+2CxvlS72X5kdkLk=
        "]]}, 
      {GrayLevel[0.5], Thickness[Large], Dashing[Large], 
       LineBox[CompressedData["
1:eJxFxwk01Hsfx3HKepWdsiQZy9i3kq6Z//dflLoSKhq5N3SZsRVld8fWKiJR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        "]]}}, {{}, {}, 
      {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJwVlPc/1X0fgCkZUZmV0bD3KEnC9/0lUvaIuEVROYlKKCNZiWSG7JEc1CmS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        "]]}}, {{}, {}, 
      {Hue[0.67, 0.6, 0.6], Thickness[Large], Dashing[Large], 
       LineBox[CompressedData["
1:eJwVxXc81P8fAHBHkVHJzEhmMspKKPd5fZIkIiq60iK5MkpGdkYaEolvZCVl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        "]]}}}, {InsetBox[
      TagBox[GridBox[{
         {
          
          TemplateBox[{
           StyleBox[
            "\"first-step\"", StripOnInput -> False, FontFamily -> 
             "Helvetica", FontSize -> 12]},
           "LineLegend",
           DisplayFunction->(StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Hue[0.67, 0.6, 0.6], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
             False]& ),
           Editable->True,
           InterpretationFunction:>(RowBox[{"LineLegend", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"Hue", "[", 
                    RowBox[{"0.67`", ",", "0.6`", ",", "0.6`"}], "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], "}"}], 
                ",", 
                RowBox[{"{", #, "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], 
              "]"}]& )]},
         {
          
          TemplateBox[{
           StyleBox[
            "\"established\"", StripOnInput -> False, FontFamily -> 
             "Helvetica", FontSize -> 12]},
           "LineLegend",
           DisplayFunction->(StyleBox[
             StyleBox[
              PaneBox[
               TagBox[
                GridBox[{{
                   TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    GrayLevel[0.5], 
                    Thickness[Large]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                "Grid"], Alignment -> Left, AppearanceElements -> None, 
               ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
               "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
             FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
             False]& ),
           Editable->True,
           InterpretationFunction:>(RowBox[{"LineLegend", "[", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}]}], "]"}], ",", 
                    RowBox[{"Directive", "[", 
                    RowBox[{
                    RowBox[{"GrayLevel", "[", "0.5`", "]"}], ",", 
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Large", "]"}]}], "]"}]}], "}"}], 
                ",", 
                RowBox[{"{", #, "}"}], ",", 
                RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )]}
        },
        AutoDelete->False,
        GridBoxAlignment->{"Columns" -> {{Left}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{0}}}],
       "Grid"], NCache[
      Scaled[{Rational[1, 8], 0.625}], Scaled[{0.125, 0.625}]], ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm], InsetBox[
      TemplateBox[{
       StyleBox[
        "\"\[Lambda]=0.005\"", StripOnInput -> False, FontFamily -> 
         "Helvetica", FontSize -> 12],StyleBox[
        "\"\[Lambda]=0.0025\"", StripOnInput -> False, FontFamily -> 
         "Helvetica", FontSize -> 12]},
       "LineLegend",
       DisplayFunction->(StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Medium]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[{
                    Opacity[0.3], 
                    GrayLevel[0]}], 
                    Thickness[Large], 
                    GrayLevel[0], 
                    Dashing[Medium]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> 1, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Times"}, Background -> Automatic, StripOnInput -> 
         False]& ),
       Editable->True,
       InterpretationFunction:>(RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Thickness", "[", "Large", "]"}], ",", 
                    RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                    RowBox[{"Dashing", "[", "Medium", "]"}]}], "]"}]}], "}"}],
             ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& )], 
      NCache[Scaled[{Rational[7, 8], Rational[3, 10]}], Scaled[{0.875, 0.3}]],
       ImageScaled[{0.5, 0.5}],
      BaseStyle->{FontSize -> Larger},
      FormatType->StandardForm]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesLabel->{None, None},
   AxesOrigin->{0, 0},
   Epilog->{
     InsetBox[
      FormBox[
       StyleBox[
       "\"\\!\\(\\*\\nStyleBox[SubscriptBox[\\\"m\\\", \
\\\"0\\\"],\\nFontSlant->\\\"Italic\\\"]\\)=-0.2\"", 12, FontFamily -> 
        "Helvetica", StripOnInput -> False], TraditionalForm], 
      NCache[
       Scaled[{
         Rational[7, 8], 
         Rational[3, 4]}], 
       Scaled[{0.875, 0.75}]]], 
     InsetBox[
      FormBox[
       StyleBox["\"C\"", 14, Bold, StripOnInput -> False], TraditionalForm], 
      Scaled[{0.05, 0.95}]]},
   Frame->{True, False, False, False},
   FrameLabel->{
     FormBox["\"Growth rate\"", TraditionalForm]},
   FrameTicksStyle->{Automatic, Automatic, Automatic, Automatic},
   LabelStyle->Directive[12, FontFamily -> "Helvetica"],
   Method->{},
   PlotRange->{{-0.3, 0.25}, {0, 30}},
   PlotRangeClipping->True,
   PlotRangePadding->{
     Scaled[0.02], Automatic}],
  InterpretTemplate[Legended[
    Graphics[{{{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          GrayLevel[0.5], 
          Thickness[Large]], 
         Line[CompressedData["
1:eJxFyQk01XkfBnBi7CFClhBlzZalkP/3b6kREVFMJttMblkrW6RCsmS7lhAK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          "]]}, {
         Hue[0.9060679774997897, 0.6, 0.6], 
         Directive[
          GrayLevel[0.5], 
          Thickness[Large], 
          Dashing[Large]], 
         Line[CompressedData["
1:eJxFxwk01Hsfx3HKepWdsiQZy9i3kq6Z//dflLoSKhq5N3SZsRVld8fWKiJR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          "]]}}}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          Thickness[Large]], 
         Line[CompressedData["
1:eJwVlPc/1X0fgCkZUZmV0bD3KEnC9/0lUvaIuEVROYlKKCNZiWSG7JEc1CmS
vT84xx7nIKtQyhYlm26e+/nhel2v6x+4BO3vmd7cRUdHV/Yf/7fobAKfomIv
yjLYZArrV4YFfSLvAcZeFBnu+jrfXg3KPxQcnhvsQWS6wW7ZbzgEcNYcan7X
g8z5zqrbs2iB7oPWg1m+PYjR6tRLrXod4B7s4/Ez6UE3y0fcVY/pw8jZ79zW
Ij3oceRU5KEMY8hJW+BSXutGW1RdC/90M3Ch2+LkautGqaYyF0OOXQaF5Yq9
wkndqLXUxvTvS2tYnPLcpXirGwUFNmtx3bkGhV+UNzWVu1HxpVB8T8h1cKWu
LpoydiPRq1+MrWUIoEgumbHvo6HqxlEdNzcnWC51H3Ml0tBnKY6k+bMuUExS
HAp0o6F4wfpUKwk3eJD+hxajSUO+Q/zc4TEPgaH50/Y3bhra6Fmn7JzzBvGv
d6xsu6hot5eWXMcTXzivcLJk05WK/DkiJVIKA+BGwCp7wiEqOnrJhjTmGwSB
PZXOitVdaGpGFJUWhsArYb8W6rUutERcXbxjHQa17udEnPd0IbWYQPOukCgY
aWTyZyZ1ok2jxzcOi8RA8a3m1nvGnWiAK91pvCUOnrOGcA2sdqC+4Zr0T00J
YJd/3gZL60A7/lrC4hIpcMaEMTf7XAf6YxwWt389HfYvN/5mm21HN/KX7l7L
zISJ+Kdn3aPbEa1faalhLxGqVbSDvpxuR457HBfsUQ7EDDN0aY60odZK8GJt
fguWmZIsnD5taG7xjsFxzzw44mCoNcbXhp56UG4q0grgu5SbX0FFK3LU/6ws
L1YEb34lVPpZtqLjjoSKKkoJ3C2uXjFca0Eba/3TrEXloOg1pnA0vgU9yxYC
6noVrKszOs+fakEy6TMqJ9MR1O6Szq3ubUYdV6aHFvrq4fiJeENmr2Z0mz3r
nNI8GZ5cpV81O9qMymb2ujWqNMFkhHNaBrkJJYVW6RSgFrhQPaA1d6sJkSCb
JP+kHUizmj9P729CsckUYtazLmDjzY8NLGpEvuv3nHVmadD9IOg77zYFUd9f
eHDq7ScQarr0qDOFghqobSW6q/3gflCUO0CFgrIpNU9lPIeg0WHl/akBMgru
8lVfOzEMB8satafdycjdYzS4WewrEJjiR1M4ySixKqR+SGYMyi87eBgVNKCC
b2763ye/g/U649vSuXpUqhQa9bxhEm4k98grhdWjFE6b6Izhabirll5aJFWP
KitNLF355yDAX4lS4FiH+upPGY3v+Q3Phej15FnqkMZE4Rzx6iJIhCZlWZsg
dG7l3BfU+QcMOFpqzak1yN9huPT69AokS/wk6vHXIIZNW7UljzWYBPYwDUI1
WvB5cV+YbwP871pelt2pRJcWrwXXxf+Fzqc+6sJ6lcjvRvoTjfvbwJf2Spg3
oQKl2NRJ6MjT4UXt078Y5MtR4cqXseIzu/BRsYHyNqcyFOab18R2fTfOHNgY
EP2mFBW4rrXYJjLgNmdecwkIlaCgjCsx7CJM+LPY6OEx22Ik1eMrSPRmxgsX
fLNzU4qQwkIkfc4wC86Uba2syFOItiZuzcZQ2HDn3v7BRduPyKhomfjPif04
jd7Uu+BNAaqPLIy2Ih3AFWqiva0989G1tQbxT/Yc+AZvSM0gax7yrEldS1Ti
xBsePqazyHiHrjcc22nl4MLNFG4HGze9Qc+U7BSqfnLjf3sNAjau5SI1+qgf
D2d58ByPEz6vt7KRdoeRUezGQdyYn8dDL56I9CPC5d4cOYxv1K7fX1bIQobJ
HsK61rz4a/th57T2TDR/ZKXKqpwP12esI5x3eIWsJrSPuagJ4D/NdBpH6dPR
v+W6tAeLR3BI2V+loJyCsA9xVPfxYzjLn23VBvlEZGZ/dOaonCDee+FXtZnE
S2SuthBXmSuEp2V8VZ84HoNM9XoDctxE8K6fGY/nT0aiiiPiqSN5Yrh9sr8f
u8gzRPfkht2EtyS+qmMXoMgTiDikvw4X7JHFueaeMOaxeaLzFL0VjUoF3D38
OffkCAFtt0mKmxMU8d8Z3p97DougsfyBhHnl0/jDM6oV7f/chBGdcVE6rhP4
w30HjGO2HkCYP/3Cyx1J3BLq7L4S/cHBtOyXv7AIvrrmmbKiFwy08g+Oz2uP
4bEFJ/pYl8JgzXo6Kd2RF0889YCJozMaqvqUBKrSuPGpaBOR1FexEEvZnP01
zY7XjjCUThXEA5k4OVIdyYrHS5XrKNYnwRR1M8OJyIjf9XAa8u1OhSYpcavs
il34ecpRp7axDAjIrZ2iHd+BKGbH7b1emcC+X/is5MYGbOVrNivQZ4GjxHd5
zuoVIJgLRFuEEsEmxoxEUfkDvVsrlj4cOZBy1MSOJ3UBbK2/Oz6MyQWibCrp
a9cMzFZ2ebtwvQXGJV5yEmUCHvBVhd2OI4HDLG+cypXvQOedm3qD5z0YmbYP
nlwdhbCh2Dzb+Dwo9As4wXDoMxxU8a+1PPQBhuIe/Su/1gfG+qUESf0CKOGX
YhDw6oGDPjIuOWwfwVP6XwtJZiq8HuR5JVX3Ea4fKFwOtmgDWaUdar5bITCm
9TuRTJug/MX0zknxIjDxsk2QHW8ArYVu+bLPRUD2pV7GfiKg6VZdVY0sBvMN
uL/6sxKu5BKjkEYJdNftjvR4VwrTuyP/e8N/jcWxbbAVgds1j1/Nb0qhKSw1
tnT5Awh6xav5OJVBJNFOwsqSBNQXJaEKcuWQeOv8jjMpGx6TPvWP/y4HPuaT
eZmNmSBNXhJOKqqAzyElty2502DoC+d9g4eVcJldtGmzIgFClk/U0qtUwdLV
iZ9ShrGgtM+EtXSrCo56qF+tN4uCH6Iulrdrq2FvjsAkr2UoWDjt6hR1rwEN
2m4+t5ogaCuI0xiTrIUwwnuX8Hl/wFbFSlO/1sLKmXXZM1GPoFC1QsryJQLV
wb7x2KsPIbYumxoqWgfW2My+bQFXMPixEErwrwPDRyERcnAHmBjPaGl/qYMf
yiTp4DAC1EsEbAudrgc+M1ThO2kP4ZI3mxMT6yFJNa0y9aMNWEpdjN6/VQ/c
UYmTKdhlEJaWtQqyaQCmUnJCq6ApLEhzCG2iBvjdmvCIKq8PFTIrs/eEyBBX
eEtY95M2BMkOFU0EkUG99fTO8gAOxnI1PtZTZBB5HeTnPaEC/PKZ2t0XKZDr
YW7A1qcIcqOhx31IFGic6YjncJQDjQjXLTHWRvC7dont7llxuKRm3d/t1Aiy
ZPJ72ntBIMyd++jT0Qh/p22L89r5wDtZJlxctgk8+vP976lyQ8RFHkJPRBPU
Br1bzrm7H16t/6vxeKEJ9tmy3C5vZ4Si3EkBCaNmMDnrUpZOTw+S88/CLN42
g0vLfUHtlg0s46T0ZtDuFng1dAPRey1hPJ6dt4psWiD0Jol013AeC6u5NzBW
1gK/jdIFYtcnMPrdnOfZOVuB7KRwe+jWN8zjQnEx5twKvL2kD3udBrH5CAvh
O02tMKxEODx1uAe73rv+IuV4G6Q7yBuZlrdhs6tKB+wD24B+OCDplAgZc+Vz
C5cYbwPNt2JCTnpV2IZ6Acsv7XYQ6QtmHLApwvzt5oNLctvhcNDolqjVO4zp
qRSDD0sHSL9s6Kk5nYVFviEEaDp1QGqhO+fL4WTsYAdxm7mzA67ort05mx+D
pf0ae0SV64TWwJJ3g4OhmMNXLHjlWSeI/R0JYDQJxOSoKdH8Pzrh3kme1ZsD
Xtha7XqyhnoXGAwY+P0RccXq8s2zCQldQCij0+S/4oiFphd+iFjsgkpjt5nT
WXaYaeSByiI9KpyO6dh78LYlxu/rTBnKpoLxVJWmE80YG7/T2rWzQ4Uow1FV
UVYd7H+PAsfX
          "]]}}}, {{{}, {}, {
         Hue[0.67, 0.6, 0.6], 
         Directive[
          Thickness[Large], 
          Dashing[Large]], 
         Line[CompressedData["
1:eJwVxXc81P8fAHBHkVHJzEhmMspKKPd5fZIkIiq60iK5MkpGdkYaEolvZCVl
VcblrDLeZ5xxxjnbV3ZGdmWk+6Xf7/fH8/GUc7h9+jonBwfH5//5/0ozCZI6
Op3oyKGhfH3vUmzhZIbEdu5OZLmunzgGNKysgLJztq8DCZgSgmPv1GOhQpXi
DR86UMT+vcXHptowM+8msbf3OlC+gptYi243JtLXLRps3YG8X194p8Q9iA0e
GhOxU+xAx3T86vubx7Gs1AVhvTUWSveQZgfMzmDuHGwhYQYLcboKSM5hPzDN
5U98CokstNZvk/DKdB37PuXLqXODhYS4sNlxTwIUDuj9NtJjodSkKuIGxxbw
YK5+P83NQl+/Og4O3xEEndribw7d7airKsHtlocYLJd4jXpktKMElZ3LSw9k
oOi9Tn+YZzvaLfSx/1yuIni/+tEea9SOTm2XFXOaUINNDV0bIyLtyK8RE+C/
pg3Kw27nL7cxUd5Wx3qevfpgoqld/NuDicIbiyeGXwM4hq4KJogzUaKHjE/q
G2MI6/jsqlPRhob+EWA4d5vBa4XgRubVNtQx8ZND8Jo1VHkdVXTd3IaK5kr4
D3nZwiCdJ2TL+1YU3yTqkT1xEYpuNDTdtmpFRX6Jl9+5O8AT/kfCvastqIzc
yRvuRQb7fJNLWGoLupinH/O53A30rbmzM4+2IA4LQoNOowdsW6YvCcw0ozPb
VK50ZfrARPyDQ14xzSiokn9aJDcIKgyOhQ8cbEZ8I39GICoMYr9sajMaZKDm
hzJWujKPgJSuwisUyEA7kl+oWxtGwS4nS+NRSQYSD5ZaEboZC2OqnsGUT03I
8/uiTrh4AuQsJnwOJjWhgpiJ+V19KXCrqGLFcq0RST9LZucupYOO36imTHwj
sr1ZkG9gkAW/iNyu8wcaUXPZaTEV5w9QxamWXdHZgDoVdcdSeiggqxVvucWv
AcnQVcq1zhTB/SuE1TMyDajDh28t8E4ZTEa5pqbV1qPd/JFOr05UgmlFr/Hs
jXrUEyu1UyagGt7PGM0d3FaPZFNnlEwZdSAgkR8XRqWj7KUXmO6bRrh1XOJw
G4mOzrlOGQiJtALLO3xMYqMOURfEXeQkWCBffzagNbkOSVsTPD+ad4GXmJJI
qEEdEjnHw/mH3Qt0p5XcA721qMTizuobvS8gVko/Nu1ViwZWdoZZPxwBMk/8
ULJQLXocIFcSZzwOZeecfE5RalAz54Lkm0uTwJdzUJDLsgbdxwW22/Z9A7tf
3O9KZqvRNqfg+X3l8+CY1KGhG1mNyjoU4v3YS3DL8FUJVbUa2f2N5Zqw+gm+
QzeJ2gwaSngqEjc+vAKhIbp1lJs0ZEI2+LL27hc8kSeYa/DSkKAW9fImChv2
RiS+tbNGiMh3VujAjw2w2NFYZcOsRIet9OaahLnwpL1zGeZSlaj5RwC7dHoT
PgmCkUfIFehi6AOHO13ceMgt0rl9fz8jlJJqOTzNh1Obpxc3aZShcTlh5Yyh
HfjQnt4yhkspup5M6lGVFMa3hNFDY3JKEGay/pvHRgS/pP9GWFq+GClz+Zk7
VInhj+NivoxeLkISkdkj2VPieOHCvczsZCqSySm79nOzBM6TaaenI1qIBOwy
26/vlMJdO3v6vl/+iD4Z1dxXWZfC2wmn/Sk5FHSh+eKL2CZp/MbVJL2hrwXI
ujHuO+XxLlyzMsbfzjcfOT4qiJrXlcHXJR5V9vHnIdqTGyMiLBm85m4Qh23a
B+T1/NJB+wu78Sednkc7td+j/cVh+IOO3fgZTeeHVvU5KNDYsdxulyz+n06L
0PWr2SgXBcQ9PSGLZ/loBb5hZyKPVJKGoLssbiUl6mMen4GmOv10LsbK4utV
v+4sa75FrO/GnscLZfE3Dl9cU5vTUV94tb10hyx+kptGNnF6jbal9TtQl2Xx
uTPH6UOEV0i4h+PDy11yOCRvK9fUS0aePs3tRtZyOO+PjcM1Gi+RdadWl1KK
HN5pulhxZu8LRDwkPfONSx5PTRsmTsjGIoMu53X1F/J421xa0Lx2NKIC7pp8
VQF3SAoJFlR8jAIa8IM6AYr46nH7UB3RMMSrtZDnxlbChWfvc+cJ+KLrD1jO
T+eVca+nT0QmB8noS/Zifru+Kr6U5v9vx05FpH4w3+bJZXX8rv7hT80XroNl
HSF3xFkBv7t1u1Us2xtIwvbSz50kcRLQ7IczQsAA4+LgvSiEr675Jq+YP4TH
7Ialb0J8eBxFq5v/ZyRsPmjtndDDib884M2zozUGHF3VGasJbJiKsVZMeR0H
2gYEjgMuy1A1uKlkihIP3zC/LZTSeYhXLTuuU50IlSKs8P6aCbjl49J/j5UC
Y/KWi+ocI2BSJ+PCGE2D8+4VDu7xvfBsy80NPr90sGtc30wjs4Cdb9SgSXgL
AYSt7wiUJiDbSMfYRmSAmZbBdORSDXSyV0iBO7Kga1fS8cKxcrhsN3bzbmw2
fPuwdqYrsQhmPrf5uwu/g27NHcQnF/PBW7I80vmf9xBuOTHRaJkFHP7ZKY6i
uWAYdJhf1/Y1RPbH5V2Oz4P4mulxam8CiBmEVJHEC0BcYi1o/exzsDpZQlY5
SQGaPmtL2s4IEAtUd88S+AjdkyHRMeJh8KZP9LUq7SPcjwlgP37mD/t0/zLz
PQthN9vK3MjFE8qeT//VVqZCiu8S/dRxVzBeYGmU/kuFWPXawf4QR2g3K79y
OLoIaor9A0OSLsHF7Ixn6EgxaKTHpS6b2MA0VzQ6ulIMFTlHn773sATPqz6L
DTklkLUWK5xccAzk/OINA11KYZVvzpkxQATm8+IIzf1lkL3vITbrfgCC3nf1
fF0qA8ZWQgepSw3Uan8qJFI/we0ledOBbnnoHxC6Y3H3M4y1NZ5cJUnAo2Wt
KoJBOWxT6rRyWxYE3a3W/CXsckD/zqe2RHLDuJI7ybmqAkqs7n3NaPmD2bpw
tip5VYJRXA2tVm4ZY1D+OTKqUgV6lr9v9W2dxbDVPSUpw1VgV9CwdbfIGFZ4
+JMq6QWCAoMWiiRPHxZHy2RGKNFA21yo+XY1E7MYX4ggh9CAdUh8OnawDuPh
1jc+NkCDrOs/ssyPlmPVe0M35A9WA0kh1FOx+CP2VOV6w8uX1aCpudEdzJeF
kVRPxGxjVwMPceLPbSwZU1Dbdz78Ug2kOxRPcJbFYAtqO+R/oxr4QtLRi74S
jn1SX5m5LV8LSh3a43mZvlj4vn7qRHgtlDcE3A1KdMOs9lcG2k3VArpf8ccq
wx6T0kg/xjpRB+f0fiXqDZ/F9g9FyAa+rwMOW1+VrcgUOxLlwd7DTwcF1dwn
xruJ2FlDux6WCx12sSccWQQtjDx79GNgCx0EIkot/EsUMP8k9afK++qh5wCb
oZcrhkWdECV3RNVDYdS80bNhXuz1rz9HghbqYbLsCvpo9odIzZ6U3nuqAdxH
FuqyPJaIKvOPI23fNYAD/w/dc9vHiWnaar/DuRohSrk65e18N1HUt/UG9VIj
/O79YRbA30SMrLzdO1raCDc7J13pjhVEApeQiaBQE1g4lvup/ywg+pgWFWGu
TRDNnJr6T086cT7KVsGtvgmGS83UuOhxxGudv54nyzLgbV6C6VjFA+LMqu52
hzAGhMV5DIQ9vEv0kPR8uvcrAwTk7i+a7SYT14kU3sVjzbDnavKHPWHniCH2
8w+Ls5vBzP+vtf2H40SeB6qbAnlbYHxIfGzgpR4xOoccauTSAoF5v220zZSJ
Yi0ZG1taW+Du2TmLFpoYMXVxNIC5vxV4502w3r+biU7D2MOVx60gFZ1Rfd5i
1XA/MzlGarwVOKKlPe+RJw3Xqn4lHSG2wYNX9dTqkz2GtHybTHJCG3zXqJjc
/oduGPGqsCDqexsEvlicZvoVG56O3v6Zas4ENRk+tS/0DEOpe651/ZlMsLkl
iDlPxBl+dWtq+/uXCcr2/k2jg2GG/wWKNMjS
          "]]}}}}, {
     Frame -> {True, False, False, False}, 
      FrameTicksStyle -> {Automatic, Automatic, Automatic, Automatic}, 
      FrameLabel -> {"Growth rate"}, PlotRange -> {{-0.3, 0.25}, {0, 30}}, 
      LabelStyle -> Directive[12, FontFamily -> "Helvetica"], Epilog -> {
        Text[
         Style[
         "\!\(\*\nStyleBox[SubscriptBox[\"m\", \"0\"],\n\
FontSlant->\"Italic\"]\)=-0.2", 12, FontFamily -> "Helvetica"], 
         Scaled[{
           Rational[7, 8], 
           Rational[3, 4]}]], 
        Text[
         Style["C", 14, Bold], 
         Scaled[{0.05, 0.95}]]}, AspectRatio -> GoldenRatio^(-1), Axes -> 
      True, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Method -> {}, 
      PlotRange -> {{-0.3, 0.25}, {0, All}}, PlotRangeClipping -> True, 
      PlotRangePadding -> {
        Scaled[0.02], Automatic}}], {
     Placed[
      Unevaluated[
       LineLegend[{
         Directive[
          Thickness[Large], 
          GrayLevel[0]], 
         Directive[
          Thickness[Large], 
          GrayLevel[0], 
          Dashing[Medium]]}, {
         Style["\[Lambda]=0.005", 12, FontFamily -> "Helvetica"], 
         Style["\[Lambda]=0.0025", 12, FontFamily -> "Helvetica"]}, 
        LegendLayout -> "Column"]], 
      Scaled[{
        Rational[7, 8], 
        Rational[3, 10]}], Identity]}]& ],
  AutoDelete->True,
  Editable->True,
  SelectWithContents->False,
  Selectable->True]], "Output",
 CellChangeTimes->{{3.780257452734988*^9, 3.780257477453064*^9}, {
   3.7802575410524187`*^9, 3.780257618687738*^9}, 3.780257684159048*^9, 
   3.7802577273734303`*^9, {3.780257866716571*^9, 3.780257912914888*^9}, 
   3.780262880886407*^9, 3.780264951358284*^9, 3.782264794182538*^9}]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
WindowSize->{1616, 1259},
WindowMargins->{{Automatic, 2207}, {-159, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
ShowSelection->True,
Magnification:>1.25 Inherited,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 354, 7, 183, "Title"],
Cell[936, 31, 260, 5, 62, "Subtitle"],
Cell[1199, 38, 160, 2, 36, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1384, 44, 342, 5, 100, "Section",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1751, 53, 128, 2, 54, "Subsection",
 InitializationCell->True],
Cell[1882, 57, 1412, 31, 120, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[3331, 93, 156, 3, 43, "Subsection",
 InitializationCell->True],
Cell[3490, 98, 3708, 108, 185, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[7235, 211, 220, 3, 43, "Subsection",
 InitializationCell->True],
Cell[7458, 216, 15380, 459, 1388, "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[22887, 681, 155, 2, 62, "Section"],
Cell[CellGroupData[{
Cell[23067, 687, 160, 2, 54, "Subsection"],
Cell[CellGroupData[{
Cell[23252, 693, 387, 7, 43, "Subsubsection"],
Cell[23642, 702, 161, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[23828, 710, 8012, 171, 892, "Input"],
Cell[31843, 883, 132563, 2362, 303, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[164455, 3251, 194, 2, 34, "Subsubsection"],
Cell[164652, 3255, 193, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[164870, 3263, 8783, 186, 986, "Input"],
Cell[173656, 3451, 21015, 389, 303, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[194720, 3846, 125, 2, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[194870, 3852, 672, 16, 57, "Input"],
Cell[195545, 3870, 155580, 2747, 483, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[351186, 6624, 310, 4, 54, "Subsection"],
Cell[CellGroupData[{
Cell[351521, 6632, 208, 4, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[351754, 6640, 8557, 181, 892, "Input"],
Cell[360314, 6823, 274425, 5279, 70, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[634788, 12108, 194, 2, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[635007, 12114, 9087, 199, 837, "Input"],
Cell[644097, 12315, 41914, 776, 70, "Output"]
}, Closed]],
Cell[686026, 13094, 457, 8, 37, "Text"],
Cell[CellGroupData[{
Cell[686508, 13106, 2756, 71, 459, "Input"],
Cell[689267, 13179, 11549, 221, 308, "Output"]
}, Closed]],
Cell[700831, 13403, 204, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[701060, 13411, 8103, 180, 774, "Input"],
Cell[709166, 13593, 39562, 716, 388, "Output"],
Cell[748731, 14311, 12220, 229, 382, "Output"]
}, Closed]],
Cell[760966, 14543, 126, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[761117, 14550, 8150, 180, 774, "Input"],
Cell[769270, 14732, 42395, 760, 388, "Output"],
Cell[811668, 15494, 13094, 244, 383, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[824811, 15744, 148, 2, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[824984, 15750, 749, 17, 57, "Input"],
Cell[825736, 15769, 381495, 7023, 483, 323040, 6064, "CachedBoxData", \
"BoxData", "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1207304, 22800, 194, 3, 62, "Section"],
Cell[CellGroupData[{
Cell[1207523, 22807, 289, 5, 54, "Subsection"],
Cell[1207815, 22814, 595, 12, 48, "Text"],
Cell[1208413, 22828, 726, 20, 72, "Input"],
Cell[1209142, 22850, 574, 14, 78, "Text"],
Cell[1209719, 22866, 239, 5, 46, "Text"],
Cell[1209961, 22873, 960, 23, 45, "Input"],
Cell[1210924, 22898, 104, 1, 46, "Text"],
Cell[1211031, 22901, 2781, 73, 283, "Input"],
Cell[1213815, 22976, 250, 5, 46, "Text"],
Cell[1214068, 22983, 591, 19, 72, "Input"],
Cell[1214662, 23004, 175, 2, 46, "Text"],
Cell[CellGroupData[{
Cell[1214862, 23010, 7750, 211, 666, "Input"],
Cell[1222615, 23223, 669340, 11977, 437, 634460, 11407, "CachedBoxData", \
"BoxData", "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1892004, 35206, 189, 4, 43, "Subsection"],
Cell[1892196, 35212, 248, 5, 76, "Text"],
Cell[1892447, 35219, 295, 8, 47, "Input"],
Cell[1892745, 35229, 239, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[1893009, 35238, 689, 19, 52, "Input"],
Cell[1893701, 35259, 369, 8, 47, "Output"]
}, Closed]],
Cell[1894085, 35270, 1231, 32, 113, "Text"],
Cell[CellGroupData[{
Cell[1895341, 35306, 357, 9, 45, "Input"],
Cell[1895701, 35317, 498, 14, 75, "Output"]
}, Closed]],
Cell[1896214, 35334, 1909, 44, 112, "Text"],
Cell[1898126, 35380, 578, 14, 45, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1898741, 35399, 216, 5, 43, "Subsection"],
Cell[1898960, 35406, 867, 13, 46, "Text"],
Cell[CellGroupData[{
Cell[1899852, 35423, 413, 9, 43, "Input"],
Cell[1900268, 35434, 726, 14, 57, "Output"]
}, Closed]],
Cell[1901009, 35451, 343, 6, 46, "Text"],
Cell[1901355, 35459, 130, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[1901510, 35464, 396, 9, 43, "Input"],
Cell[1901909, 35475, 510, 10, 45, "Output"]
}, Closed]],
Cell[1902434, 35488, 99, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[1902558, 35493, 814, 22, 78, "Input"],
Cell[1903375, 35517, 495, 7, 45, "Output"]
}, Closed]],
Cell[1903885, 35527, 115, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[1904025, 35532, 351, 10, 43, "Input"],
Cell[1904379, 35544, 402, 6, 43, "Output"]
}, Closed]],
Cell[1904796, 35553, 85, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[1904906, 35558, 276, 8, 43, "Input"],
Cell[1905185, 35568, 379, 5, 43, "Output"]
}, Closed]],
Cell[1905579, 35576, 320, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[1905924, 35586, 560, 13, 43, "Input"],
Cell[1906487, 35601, 176, 5, 47, "Output"]
}, Closed]],
Cell[1906678, 35609, 110, 1, 46, "Text"],
Cell[1906791, 35612, 269, 9, 45, "Input"],
Cell[1907063, 35623, 461, 8, 76, "Text"],
Cell[CellGroupData[{
Cell[1907549, 35635, 693, 19, 43, "Input"],
Cell[1908245, 35656, 499, 8, 43, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1908781, 35669, 532, 15, 43, "Input"],
Cell[1909316, 35686, 474, 9, 45, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1909839, 35701, 182, 2, 43, "Subsection"],
Cell[CellGroupData[{
Cell[1910046, 35707, 134, 3, 43, "Subsubsection"],
Cell[1910183, 35712, 968, 15, 136, "Text"],
Cell[1911154, 35729, 690, 16, 83, "Text"],
Cell[CellGroupData[{
Cell[1911869, 35749, 1468, 38, 52, "Input"],
Cell[1913340, 35789, 4665, 102, 105, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1918054, 35897, 116, 1, 36, "Subsubsection"],
Cell[1918173, 35900, 211, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[1918409, 35908, 481, 12, 45, "Input"],
Cell[1918893, 35922, 2356, 41, 76, "Output"]
}, Closed]],
Cell[1921264, 35966, 666, 11, 76, "Text"],
Cell[CellGroupData[{
Cell[1921955, 35981, 1373, 37, 130, "Input"],
Cell[1923331, 36020, 2162, 32, 66, "Output"],
Cell[1925496, 36054, 2364, 39, 48, "Output"]
}, Closed]],
Cell[1927875, 36096, 191, 4, 46, "Text"],
Cell[1928069, 36102, 239, 3, 46, "Text"],
Cell[CellGroupData[{
Cell[1928333, 36109, 603, 16, 43, "Input"],
Cell[1928939, 36127, 1895, 27, 43, "Output"]
}, Closed]],
Cell[1930849, 36157, 290, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[1931164, 36167, 205, 4, 43, "Input"],
Cell[1931372, 36173, 1925, 36, 76, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1933346, 36215, 243, 5, 36, "Subsubsection"],
Cell[1933592, 36222, 922, 14, 76, "Text"],
Cell[CellGroupData[{
Cell[1934539, 36240, 1028, 27, 72, "Input"],
Cell[1935570, 36269, 1112, 16, 68, "Output"]
}, Closed]],
Cell[1936697, 36288, 636, 10, 46, "Text"],
Cell[CellGroupData[{
Cell[1937358, 36302, 1331, 38, 72, "Input"],
Cell[1938692, 36342, 1298, 21, 46, "Output"]
}, Closed]],
Cell[1940005, 36366, 243, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[1940273, 36375, 1645, 47, 213, "Input"],
Cell[1941921, 36424, 19617, 360, 375, "Output"]
}, Closed]],
Cell[1961553, 36787, 621, 10, 106, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[1962211, 36802, 120, 1, 36, "Subsubsection"],
Cell[1962334, 36805, 280, 3, 46, "Text"],
Cell[CellGroupData[{
Cell[1962639, 36812, 1515, 35, 72, "Input"],
Cell[1964157, 36849, 2457, 43, 86, "Output"]
}, Closed]],
Cell[1966629, 36895, 152, 2, 46, "Text"],
Cell[CellGroupData[{
Cell[1966806, 36901, 1181, 31, 72, "Input"],
Cell[1967990, 36934, 2383, 46, 90, "Output"]
}, Closed]],
Cell[1970388, 36983, 89, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[1970502, 36988, 1129, 30, 72, "Input"],
Cell[1971634, 37020, 2371, 48, 92, "Output"]
}, Closed]],
Cell[1974020, 37071, 213, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[1974258, 37080, 668, 13, 47, "Input"],
Cell[1974929, 37095, 1202, 37, 110, "Output"]
}, Closed]],
Cell[1976146, 37135, 149, 2, 46, "Text"],
Cell[CellGroupData[{
Cell[1976320, 37141, 1140, 31, 72, "Input"],
Cell[1977463, 37174, 1701, 24, 43, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1979213, 37204, 259, 5, 36, "Subsubsection"],
Cell[1979475, 37211, 474, 8, 76, "Text"],
Cell[CellGroupData[{
Cell[1979974, 37223, 686, 18, 72, "Input"],
Cell[1980663, 37243, 1411, 36, 100, "Output"]
}, Closed]],
Cell[1982089, 37282, 446, 7, 46, "Text"],
Cell[CellGroupData[{
Cell[1982560, 37293, 1234, 33, 102, "Input"],
Cell[1983797, 37328, 1992, 33, 47, "Output"],
Cell[1985792, 37363, 1804, 25, 43, "Output"]
}, Closed]],
Cell[1987611, 37391, 98, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[1987734, 37396, 246, 6, 45, "Input"],
Cell[1987983, 37404, 137, 3, 68, "Output"]
}, Closed]],
Cell[1988135, 37410, 182, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[1988342, 37418, 230, 6, 43, "Input"],
Cell[1988575, 37426, 192, 5, 68, "Output"]
}, Closed]],
Cell[1988782, 37434, 423, 7, 46, "Text"],
Cell[CellGroupData[{
Cell[1989230, 37445, 1134, 30, 73, "Input"],
Cell[1990367, 37477, 1927, 32, 47, "Output"]
}, Closed]],
Cell[1992309, 37512, 102, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[1992436, 37517, 222, 6, 45, "Input"],
Cell[1992661, 37525, 179, 5, 68, "Output"]
}, Closed]],
Cell[1992855, 37533, 359, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[1993239, 37543, 1655, 42, 150, "Input"],
Cell[1994897, 37587, 13153, 221, 358, "Output"]
}, Closed]],
Cell[2008065, 37811, 134, 3, 46, "Text"],
Cell[CellGroupData[{
Cell[2008224, 37818, 3604, 101, 302, "Input"],
Cell[2011831, 37921, 26787, 487, 377, "Output"]
}, Closed]],
Cell[2038633, 38411, 612, 10, 136, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2039306, 38428, 106, 1, 62, "Section"],
Cell[CellGroupData[{
Cell[2039437, 38433, 338, 4, 54, "Subsection"],
Cell[2039778, 38439, 806, 22, 80, "Text"],
Cell[2040587, 38463, 140, 2, 43, "Input"],
Cell[2040730, 38467, 787, 19, 45, "Input"],
Cell[2041520, 38488, 130, 1, 46, "Text"],
Cell[2041653, 38491, 805, 16, 45, "Input"],
Cell[2042461, 38509, 114, 1, 46, "Text"],
Cell[2042578, 38512, 485, 12, 45, "Input"],
Cell[2043066, 38526, 99, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[2043190, 38531, 2625, 62, 472, "Input"],
Cell[2045818, 38595, 12743, 240, 373, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2058610, 38841, 385, 5, 43, "Subsection"],
Cell[2058998, 38848, 286, 5, 76, "Text"],
Cell[2059287, 38855, 819, 24, 71, "Input"],
Cell[2060109, 38881, 197, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[2060331, 38889, 4005, 97, 472, "Input"],
Cell[2064339, 38988, 11670, 221, 373, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2076058, 39215, 320, 4, 43, "Subsection"],
Cell[2076381, 39221, 200, 4, 46, "Text"],
Cell[2076584, 39227, 887, 25, 71, "Input"],
Cell[2077474, 39254, 95, 1, 46, "Text"],
Cell[2077572, 39257, 885, 25, 71, "Input"],
Cell[2078460, 39284, 85, 1, 46, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2078582, 39290, 563, 9, 43, "Subsection"],
Cell[CellGroupData[{
Cell[2079170, 39303, 113, 1, 43, "Subsubsection"],
Cell[2079286, 39306, 610, 10, 106, "Text"],
Cell[2079899, 39318, 8859, 211, 1016, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[2088795, 39534, 131, 2, 34, "Subsubsection"],
Cell[2088929, 39538, 9040, 216, 523, "Input"],
Cell[2097972, 39756, 21309, 613, 1107, "Input"],
Cell[2119284, 40371, 5022, 148, 288, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[2124343, 40524, 148, 2, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[2124516, 40530, 20155, 582, 1900, "Input"],
Cell[2144674, 41114, 58084, 1197, 289, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2202819, 42318, 438, 6, 43, "Subsection"],
Cell[CellGroupData[{
Cell[2203282, 42328, 118, 1, 43, "Subsubsection"],
Cell[2203403, 42331, 230, 5, 46, "Text"],
Cell[2203636, 42338, 9799, 225, 1238, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[2213472, 42568, 295, 4, 34, "Subsubsection"],
Cell[2213770, 42574, 9364, 201, 500, "Input"],
Cell[2223137, 42777, 318459, 4456, 70533, "Input"],
Cell[CellGroupData[{
Cell[2541621, 47237, 184824, 2457, 41448, "Input"],
Cell[2726448, 49696, 184602, 2459, 70, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2911099, 52161, 204, 3, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[2911328, 52168, 8319, 220, 820, "Input"],
Cell[2919650, 52390, 63686, 1195, 306, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2983385, 53591, 216, 3, 34, "Subsubsection"],
Cell[2983604, 53596, 9267, 200, 598, "Input"],
Cell[2992874, 53798, 221644, 3227, 48371, "Input"],
Cell[3214521, 57027, 139410, 1882, 31440, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3353968, 58914, 152, 2, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[3354145, 58920, 5818, 156, 678, "Input"],
Cell[3359966, 59078, 29283, 567, 306, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3389298, 59651, 189, 2, 34, "Subsubsection"],
Cell[3389490, 59655, 9341, 201, 458, "Input"],
Cell[3398834, 59858, 145470, 2262, 18390, "Input"],
Cell[3544307, 62122, 95801, 1336, 13014, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3640145, 63463, 103, 1, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[3640273, 63468, 5484, 149, 657, "Input"],
Cell[3645760, 63619, 28919, 558, 309, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3674728, 64183, 100, 1, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[3674853, 64188, 547, 14, 57, "Input"],
Cell[3675403, 64204, 132580, 2427, 853, "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3808056, 66639, 285, 5, 62, "Section"],
Cell[CellGroupData[{
Cell[3808366, 66648, 231, 5, 54, "Subsection"],
Cell[CellGroupData[{
Cell[3808622, 66657, 163, 2, 43, "Subsubsection"],
Cell[3808788, 66661, 395, 7, 46, "Text"],
Cell[CellGroupData[{
Cell[3809208, 66672, 2780, 77, 181, "Input"],
Cell[3811991, 66751, 980, 13, 43, "Output"],
Cell[3812974, 66766, 980, 13, 43, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3814003, 66785, 324, 4, 36, "Subsubsection"],
Cell[3814330, 66791, 201, 4, 46, "Text"],
Cell[3814534, 66797, 248, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[3814807, 66807, 572, 13, 97, "Input"],
Cell[3815382, 66822, 119, 2, 43, "Output"]
}, Closed]],
Cell[3815516, 66827, 628, 20, 66, "Text"],
Cell[CellGroupData[{
Cell[3816169, 66851, 694, 20, 156, "Input"],
Cell[3816866, 66873, 196, 3, 43, "Output"]
}, Closed]],
Cell[3817077, 66879, 517, 17, 66, "Text"],
Cell[CellGroupData[{
Cell[3817619, 66900, 715, 20, 157, "Input"],
Cell[3818337, 66922, 215, 3, 43, "Output"]
}, Closed]],
Cell[3818567, 66928, 430, 7, 46, "Text"],
Cell[3819000, 66937, 1937, 55, 113, "Input"],
Cell[3820940, 66994, 960, 25, 96, "Text"],
Cell[CellGroupData[{
Cell[3821925, 67023, 706, 19, 83, "Input"],
Cell[3822634, 67044, 387, 11, 86, "Output"]
}, Closed]],
Cell[3823036, 67058, 1580, 55, 131, "Text"],
Cell[3824619, 67115, 294, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[3824938, 67125, 2947, 82, 290, "Input"],
Cell[3827888, 67209, 1842, 51, 105, "Output"],
Cell[3829733, 67262, 674, 9, 43, "Output"]
}, Closed]],
Cell[3830422, 67274, 152, 3, 46, "Text"],
Cell[CellGroupData[{
Cell[3830599, 67281, 4033, 112, 516, "Input"],
Cell[3834635, 67395, 76406, 1306, 407, "Output"],
Cell[3911044, 68703, 39242, 695, 420, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3950335, 69404, 112, 1, 36, "Subsubsection"],
Cell[3950450, 69407, 679, 18, 95, "Text"],
Cell[CellGroupData[{
Cell[3951154, 69429, 1324, 44, 175, "Input"],
Cell[3952481, 69475, 315, 9, 86, "Output"],
Cell[3952799, 69486, 190, 3, 43, "Output"]
}, Closed]],
Cell[3953004, 69492, 180, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[3953209, 69500, 3637, 104, 296, "Input"],
Cell[3956849, 69606, 1300, 28, 68, "Output"],
Cell[3958152, 69636, 1918, 49, 105, "Output"],
Cell[3960073, 69687, 854, 12, 43, "Output"]
}, Closed]],
Cell[3960942, 69702, 1193, 29, 102, "Text"],
Cell[CellGroupData[{
Cell[3962160, 69735, 1340, 37, 160, "Input"],
Cell[3963503, 69774, 461, 6, 43, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3964013, 69786, 505, 8, 36, "Subsubsection"],
Cell[3964521, 69796, 385, 7, 46, "Text"],
Cell[CellGroupData[{
Cell[3964931, 69807, 326, 9, 72, "Input"],
Cell[3965260, 69818, 1166, 35, 107, "Output"]
}, Closed]],
Cell[3966441, 69856, 199, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[3966665, 69864, 254, 8, 72, "Input"],
Cell[3966922, 69874, 1470, 49, 105, "Output"]
}, Closed]],
Cell[3968407, 69926, 217, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[3968649, 69934, 776, 25, 107, "Input"],
Cell[3969428, 69961, 685, 22, 102, "Output"]
}, Closed]],
Cell[3970128, 69986, 191, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[3970344, 69994, 1539, 48, 223, "Input"],
Cell[3971886, 70044, 1072, 34, 120, "Output"]
}, Closed]],
Cell[3972973, 70081, 301, 6, 76, "Text"],
Cell[CellGroupData[{
Cell[3973299, 70091, 1944, 60, 161, "Input"],
Cell[3975246, 70153, 362, 10, 56, "Output"]
}, Closed]],
Cell[3975623, 70166, 199, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[3975847, 70174, 317, 9, 43, "Input"],
Cell[3976167, 70185, 376, 11, 98, "Output"]
}, Closed]],
Cell[3976558, 70199, 157, 3, 46, "Text"],
Cell[CellGroupData[{
Cell[3976740, 70206, 2060, 64, 193, "Input"],
Cell[3978803, 70272, 221, 3, 43, "Output"]
}, Closed]],
Cell[3979039, 70278, 691, 22, 110, "Input"],
Cell[3979733, 70302, 210, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[3979968, 70310, 1073, 29, 121, "Input"],
Cell[3981044, 70341, 339, 9, 83, "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3981456, 70358, 285, 5, 62, "Section"],
Cell[CellGroupData[{
Cell[3981766, 70367, 697, 11, 54, "Subsection"],
Cell[3982466, 70380, 191, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[3982682, 70388, 164, 3, 43, "Input"],
Cell[3982849, 70393, 444, 13, 75, "Output"]
}, Closed]],
Cell[3983308, 70409, 798, 18, 47, "Text"],
Cell[CellGroupData[{
Cell[3984131, 70431, 748, 20, 77, "Input"],
Cell[3984882, 70453, 213, 4, 71, "Output"]
}, Closed]],
Cell[3985110, 70460, 831, 19, 47, "Text"],
Cell[CellGroupData[{
Cell[3985966, 70483, 814, 20, 82, "Input"],
Cell[3986783, 70505, 538, 11, 52, "Output"],
Cell[3987324, 70518, 449, 8, 50, "Output"]
}, Closed]],
Cell[3987788, 70529, 196, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[3988009, 70537, 355, 10, 60, "Input"],
Cell[3988367, 70549, 258, 7, 82, "Output"]
}, Closed]],
Cell[3988640, 70559, 419, 9, 46, "Text"],
Cell[CellGroupData[{
Cell[3989084, 70572, 2363, 67, 233, "Input"],
Cell[3991450, 70641, 41742, 757, 380, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[4033241, 71404, 546, 8, 43, "Subsection"],
Cell[CellGroupData[{
Cell[4033812, 71416, 334, 6, 43, "Subsubsection"],
Cell[4034149, 71424, 1342, 31, 111, "Text"],
Cell[CellGroupData[{
Cell[4035516, 71459, 1087, 28, 88, "Input"],
Cell[4036606, 71489, 366, 6, 43, "Output"]
}, Closed]],
Cell[4036987, 71498, 151, 2, 46, "Text"],
Cell[4037141, 71502, 159, 2, 46, "Text"],
Cell[CellGroupData[{
Cell[4037325, 71508, 2816, 84, 412, "Input"],
Cell[4040144, 71594, 658, 14, 43, "Output"],
Cell[4040805, 71610, 2530, 50, 395, "Output"]
}, Closed]],
Cell[4043350, 71663, 260, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[4043635, 71672, 5881, 161, 637, "Input"],
Cell[4049519, 71835, 15623, 304, 397, "Output"]
}, Closed]],
Cell[4065157, 72142, 291, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[4065473, 72151, 4307, 120, 682, "Input"],
Cell[4069783, 72273, 14207, 274, 363, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[4084039, 72553, 516, 8, 36, "Subsubsection"],
Cell[4084558, 72563, 220, 5, 46, "Text"],
Cell[4084781, 72570, 288, 7, 43, "Input"],
Cell[4085072, 72579, 144, 1, 46, "Text"],
Cell[4085219, 72582, 1019, 21, 112, "Text"],
Cell[CellGroupData[{
Cell[4086263, 72607, 1706, 45, 160, "Input"],
Cell[4087972, 72654, 409, 9, 83, "Output"]
}, Closed]],
Cell[4088396, 72666, 206, 4, 46, "Text"],
Cell[4088605, 72672, 402, 11, 52, "Input"],
Cell[4089010, 72685, 478, 8, 76, "Text"],
Cell[CellGroupData[{
Cell[4089513, 72697, 2414, 69, 192, "Input"],
Cell[4091930, 72768, 922, 22, 83, "Output"],
Cell[4092855, 72792, 525, 8, 43, "Output"]
}, Closed]],
Cell[4093395, 72803, 180, 2, 46, "Text"],
Cell[4093578, 72807, 126, 2, 43, "Input"],
Cell[CellGroupData[{
Cell[4093729, 72813, 9162, 259, 927, "Input"],
Cell[4102894, 73074, 18755, 368, 397, "Output"]
}, Closed]],
Cell[4121664, 73445, 198, 3, 46, "Text"],
Cell[CellGroupData[{
Cell[4121887, 73452, 7801, 202, 1075, "Input"],
Cell[4129691, 73656, 31529, 598, 371, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[4161281, 74261, 600, 9, 43, "Subsection"],
Cell[CellGroupData[{
Cell[4161906, 74274, 178, 2, 43, "Subsubsection"],
Cell[4162087, 74278, 763, 19, 61, "Text"],
Cell[4162853, 74299, 742, 25, 51, "Text"],
Cell[4163598, 74326, 256, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[4163879, 74335, 4655, 128, 632, "Input"],
Cell[4168537, 74465, 11324, 220, 392, "Output"]
}, Closed]],
Cell[4179876, 74688, 309, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[4180210, 74697, 5928, 165, 821, "Input"],
Cell[4186141, 74864, 14961, 287, 366, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[4201151, 75157, 250, 3, 36, "Subsubsection"],
Cell[4201404, 75162, 306, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[4201735, 75172, 450, 7, 43, "Input"],
Cell[4202188, 75181, 901, 26, 106, "Output"]
}, Closed]],
Cell[4203104, 75210, 157, 2, 46, "Text"],
Cell[CellGroupData[{
Cell[4203286, 75216, 7034, 186, 788, "Input"],
Cell[4210323, 75404, 14785, 288, 392, "Output"]
}, Closed]],
Cell[4225123, 75695, 106, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[4225254, 75700, 6841, 184, 788, "Input"],
Cell[4232098, 75886, 15066, 293, 392, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[4247213, 76185, 603, 9, 36, "Subsubsection"],
Cell[4247819, 76196, 176, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[4248020, 76204, 247, 6, 43, "Input"],
Cell[4248270, 76212, 1571, 49, 106, "Output"]
}, Closed]],
Cell[4249856, 76264, 153, 3, 46, "Text"],
Cell[4250012, 76269, 235, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[4250272, 76278, 3945, 120, 460, "Input"],
Cell[4254220, 76400, 1853, 54, 135, "Output"],
Cell[4256076, 76456, 461, 6, 43, "Output"]
}, Closed]],
Cell[4256552, 76465, 226, 3, 46, "Text"],
Cell[CellGroupData[{
Cell[4256803, 76472, 524, 17, 90, "Input"],
Cell[4257330, 76491, 396, 11, 85, "Output"]
}, Closed]],
Cell[4257741, 76505, 637, 17, 55, "Text"],
Cell[CellGroupData[{
Cell[4258403, 76526, 1044, 26, 71, "Input"],
Cell[4259450, 76554, 644, 16, 97, "Output"]
}, Closed]],
Cell[4260109, 76573, 326, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[4260460, 76583, 1397, 36, 101, "Input"],
Cell[4261860, 76621, 934, 24, 91, "Output"]
}, Closed]],
Cell[4262809, 76648, 245, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[4263079, 76657, 4716, 121, 473, "Input"],
Cell[4267798, 76780, 10804, 183, 395, "Output"]
}, Closed]],
Cell[4278617, 76966, 418, 8, 106, "Text"],
Cell[CellGroupData[{
Cell[4279060, 76978, 5550, 141, 543, "Input"],
Cell[4284613, 77121, 237, 3, 43, "Output"],
Cell[4284853, 77126, 8567, 167, 367, "Output"]
}, Closed]],
Cell[4293435, 77296, 98, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[4293558, 77301, 5579, 141, 543, "Input"],
Cell[4299140, 77444, 437, 7, 43, "Output"],
Cell[4299580, 77453, 13922, 267, 365, "Output"]
}, Closed]],
Cell[4313517, 77723, 151, 2, 46, "Text"],
Cell[CellGroupData[{
Cell[4313693, 77729, 3998, 120, 543, "Input"],
Cell[4317694, 77851, 313, 4, 43, "Output"],
Cell[4318010, 77857, 18160, 350, 358, "Output"]
}, Closed]],
Cell[4336185, 78210, 104, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[4336314, 78215, 3929, 120, 543, "Input"],
Cell[4340246, 78337, 247, 4, 43, "Output"],
Cell[4340496, 78343, 5325, 116, 353, "Output"]
}, Closed]],
Cell[4345836, 78462, 147, 3, 46, "Text"],
Cell[4345986, 78467, 473, 14, 103, "Input"],
Cell[4346462, 78483, 226, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[4346713, 78492, 390, 9, 45, "Input"],
Cell[4347106, 78503, 577, 16, 103, "Output"]
}, Closed]],
Cell[4347698, 78522, 140, 3, 46, "Text"],
Cell[4347841, 78527, 867, 23, 97, "Input"],
Cell[4348711, 78552, 199, 2, 46, "Text"],
Cell[4348913, 78556, 714, 23, 143, "Input"],
Cell[4349630, 78581, 120, 3, 46, "Text"],
Cell[CellGroupData[{
Cell[4349775, 78588, 285, 8, 43, "Input"],
Cell[4350063, 78598, 273, 6, 68, "Output"]
}, Closed]],
Cell[4350351, 78607, 100, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[4350476, 78612, 126, 3, 43, "Input"],
Cell[4350605, 78617, 350, 9, 77, "Output"]
}, Closed]],
Cell[4350970, 78629, 88, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[4351083, 78634, 941, 27, 127, "Input"],
Cell[4352027, 78663, 703, 20, 91, "Output"]
}, Closed]],
Cell[4352745, 78686, 99, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[4352869, 78691, 618, 17, 71, "Input"],
Cell[4353490, 78710, 4011, 74, 341, "Output"]
}, Closed]],
Cell[4357516, 78787, 178, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[4357719, 78795, 450, 11, 45, "Input"],
Cell[4358172, 78808, 498, 14, 96, "Output"]
}, Closed]],
Cell[4358685, 78825, 230, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[4358940, 78834, 1748, 49, 232, "Input"],
Cell[4360691, 78885, 942, 25, 110, "Output"],
Cell[4361636, 78912, 1705, 54, 198, "Output"]
}, Closed]],
Cell[4363356, 78969, 181, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[4363562, 78977, 1139, 31, 122, "Input"],
Cell[4364704, 79010, 893, 27, 123, "Output"],
Cell[4365600, 79039, 1424, 47, 182, "Output"]
}, Closed]],
Cell[4367039, 79089, 106, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[4367170, 79094, 2449, 70, 201, "Input"],
Cell[4369622, 79166, 520, 7, 43, "Output"],
Cell[4370145, 79175, 520, 7, 43, "Output"]
}, Closed]],
Cell[4370680, 79185, 174, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[4370879, 79193, 6561, 170, 917, "Input"],
Cell[4377443, 79365, 39847, 739, 372, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[4417339, 80110, 573, 9, 36, "Subsubsection"],
Cell[4417915, 80121, 227, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[4418167, 80130, 378, 9, 43, "Input"],
Cell[4418548, 80141, 1910, 59, 147, "Output"]
}, Closed]],
Cell[4420473, 80203, 334, 10, 48, "Text"],
Cell[4420810, 80215, 235, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[4421070, 80224, 3871, 112, 385, "Input"],
Cell[4424944, 80338, 2658, 76, 193, "Output"],
Cell[4427605, 80416, 677, 9, 43, "Output"]
}, Closed]],
Cell[4428297, 80428, 261, 3, 46, "Text"],
Cell[CellGroupData[{
Cell[4428583, 80435, 557, 16, 120, "Input"],
Cell[4429143, 80453, 408, 10, 86, "Output"]
}, Closed]],
Cell[4429566, 80466, 751, 17, 85, "Text"],
Cell[CellGroupData[{
Cell[4430342, 80487, 1046, 23, 71, "Input"],
Cell[4431391, 80512, 779, 17, 97, "Output"]
}, Closed]],
Cell[4432185, 80532, 147, 3, 46, "Text"],
Cell[4432335, 80537, 470, 14, 103, "Input"],
Cell[4432808, 80553, 185, 2, 46, "Text"],
Cell[CellGroupData[{
Cell[4433018, 80559, 497, 10, 45, "Input"],
Cell[4433518, 80571, 543, 15, 103, "Output"]
}, Closed]],
Cell[4434076, 80589, 280, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[4434381, 80599, 1750, 47, 148, "Input"],
Cell[4436134, 80648, 1005, 25, 110, "Output"],
Cell[4437142, 80675, 1793, 55, 221, "Output"]
}, Closed]],
Cell[4438950, 80733, 377, 10, 61, "Text"],
Cell[4439330, 80745, 103, 1, 46, "Text"],
Cell[CellGroupData[{
Cell[4439458, 80750, 944, 29, 103, "Input"],
Cell[4440405, 80781, 194, 3, 43, "Output"]
}, Closed]],
Cell[4440614, 80787, 174, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[4440813, 80795, 6723, 170, 891, "Input"],
Cell[4447539, 80967, 33288, 616, 375, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[4480888, 81590, 167, 2, 43, "Subsection"],
Cell[CellGroupData[{
Cell[4481080, 81596, 152, 2, 43, "Subsubsection"],
Cell[4481235, 81600, 6529, 182, 654, "Input"],
Cell[4487767, 81784, 3395, 98, 204, InheritFromParent]
}, Closed]],
Cell[CellGroupData[{
Cell[4491199, 81887, 151, 2, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[4491375, 81893, 7740, 185, 833, "Input"],
Cell[4499118, 82080, 62632, 1181, 314, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[4561799, 83267, 156, 2, 34, "Subsubsection"],
Cell[4561958, 83271, 7971, 188, 701, "Input"],
Cell[4569932, 83461, 2466, 74, 299, InheritFromParent]
}, Closed]],
Cell[CellGroupData[{
Cell[4572435, 83540, 149, 2, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[4572609, 83546, 6485, 142, 640, "Input"],
Cell[4579097, 83690, 20091, 390, 319, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[4599237, 84086, 99, 1, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[4599361, 84091, 526, 14, 57, "Input"],
Cell[4599890, 84107, 84810, 1569, 637, "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[4684773, 85684, 136, 3, 62, "Section"],
Cell[CellGroupData[{
Cell[4684934, 85691, 366, 6, 54, "Subsection"],
Cell[4685303, 85699, 180, 4, 37, "Text"],
Cell[4685486, 85705, 451, 12, 62, "Input"],
Cell[4685940, 85719, 215, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[4686180, 85727, 2305, 71, 246, "Input"],
Cell[4688488, 85800, 959, 26, 77, "Output"]
}, Closed]],
Cell[4689462, 85829, 171, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[4689658, 85837, 331, 11, 72, "Input"],
Cell[4689992, 85850, 231, 7, 71, "Output"]
}, Closed]],
Cell[4690238, 85860, 88, 1, 37, "Text"],
Cell[4690329, 85863, 116, 3, 36, "Input"],
Cell[4690448, 85868, 100, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[4690573, 85873, 4045, 95, 440, "Input"],
Cell[4694621, 85970, 22778, 407, 383, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[4717448, 86383, 439, 7, 43, "Subsection"],
Cell[4717890, 86392, 211, 4, 37, "Text"],
Cell[4718104, 86398, 1033, 29, 78, "Input"],
Cell[4719140, 86429, 156, 3, 37, "Text"],
Cell[4719299, 86434, 1002, 28, 78, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[4720338, 86467, 491, 8, 43, "Subsection"],
Cell[CellGroupData[{
Cell[4720854, 86479, 99, 1, 43, "Subsubsection"],
Cell[4720956, 86482, 270, 8, 78, "Input"],
Cell[CellGroupData[{
Cell[4721251, 86494, 18072, 453, 1308, "Input"],
Cell[4739326, 86949, 1014, 17, 29, "Message"],
Cell[4740343, 86968, 70738, 1390, 305, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4811118, 88363, 15849, 399, 1224, "Input"],
Cell[4826970, 88764, 756, 14, 29, "Message"],
Cell[4827729, 88780, 30319, 584, 305, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[4858085, 89369, 15812, 397, 1203, "Input"],
Cell[4873900, 89768, 652, 12, 29, "Message"],
Cell[4874555, 89782, 30893, 583, 327, "Output"]
}, Closed]],
Cell[4905463, 90368, 166, 3, 36, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[4905666, 90376, 101, 1, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[4905792, 90381, 542, 14, 57, "Input"],
Cell[4906337, 90397, 138826, 2655, 853, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5045224, 93059, 430, 8, 43, "Subsection"],
Cell[5045657, 93069, 215, 4, 37, "Text"],
Cell[5045875, 93075, 798, 21, 62, "Input"],
Cell[5046676, 93098, 252, 5, 37, "Text"],
Cell[5046931, 93105, 137, 3, 37, "Text"],
Cell[CellGroupData[{
Cell[5047093, 93112, 2748, 84, 352, "Input"],
Cell[5049844, 93198, 295, 7, 67, "Output"],
Cell[5050142, 93207, 991, 32, 126, "Output"]
}, Closed]],
Cell[5051148, 93242, 128, 3, 37, "Text"],
Cell[CellGroupData[{
Cell[5051301, 93249, 5759, 140, 595, "Input"],
Cell[5057063, 93391, 11737, 221, 310, "Output"]
}, Closed]],
Cell[5068815, 93615, 115, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[5068955, 93620, 3314, 98, 382, "Input"],
Cell[5072272, 93720, 965, 29, 105, "Output"],
Cell[5073240, 93751, 1536, 50, 128, "Output"]
}, Closed]],
Cell[5074791, 93804, 154, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[5074970, 93812, 6467, 159, 626, "Input"],
Cell[5081440, 93973, 17237, 312, 318, "Output"]
}, Closed]],
Cell[5098692, 94288, 134, 3, 37, "Text"],
Cell[CellGroupData[{
Cell[5098851, 94295, 1247, 42, 193, "Input"],
Cell[5100101, 94339, 350, 11, 65, "Output"]
}, Closed]],
Cell[5100466, 94353, 151, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[5100642, 94361, 6453, 159, 621, "Input"],
Cell[5107098, 94522, 6226, 132, 346, "Output"]
}, Closed]],
Cell[5113339, 94657, 135, 3, 37, "Text"],
Cell[CellGroupData[{
Cell[5113499, 94664, 2658, 78, 287, "Input"],
Cell[5116160, 94744, 172, 5, 67, "Output"],
Cell[5116335, 94751, 852, 29, 113, "Output"]
}, Closed]],
Cell[5117202, 94783, 107, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[5117334, 94788, 539, 18, 73, "Input"],
Cell[5117876, 94808, 485, 16, 71, "Output"]
}, Closed]],
Cell[5118376, 94827, 121, 3, 37, "Text"],
Cell[CellGroupData[{
Cell[5118522, 94834, 6119, 149, 623, "Input"],
Cell[5124644, 94985, 11973, 225, 305, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5136666, 95216, 131, 1, 43, "Subsection"],
Cell[CellGroupData[{
Cell[5136822, 95221, 332, 4, 43, "Subsubsection"],
Cell[5137157, 95227, 239, 7, 78, "Input"],
Cell[CellGroupData[{
Cell[5137421, 95238, 15147, 406, 1566, "Input"],
Cell[5152571, 95646, 75959, 1595, 310, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5228567, 97246, 11815, 325, 1432, "Input"],
Cell[5240385, 97573, 26850, 519, 310, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5267272, 98097, 11770, 322, 1432, "Input"],
Cell[5279045, 98421, 27162, 525, 332, "Output"]
}, Closed]],
Cell[5306222, 98949, 170, 3, 28, "Input"],
Cell[CellGroupData[{
Cell[5306417, 98956, 491, 13, 57, "Input"],
Cell[5306911, 98971, 138985, 2759, 853, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5445945, 101736, 329, 6, 34, "Subsubsection"],
Cell[5446277, 101744, 473, 11, 78, "Input"],
Cell[CellGroupData[{
Cell[5446775, 101759, 12176, 304, 1051, "Input"],
Cell[5458954, 102065, 30659, 586, 305, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5489650, 102656, 9634, 251, 925, "Input"],
Cell[5499287, 102909, 11299, 198, 305, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[5510623, 103112, 9089, 238, 883, "Input"],
Cell[5519715, 103352, 10252, 183, 326, "Output"]
}, Closed]],
Cell[5529982, 103538, 165, 3, 36, "Input"],
Cell[CellGroupData[{
Cell[5530172, 103545, 498, 13, 57, "Input"],
Cell[5530673, 103560, 52511, 955, 853, "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5583257, 104523, 93, 1, 62, "Section"],
Cell[CellGroupData[{
Cell[5583375, 104528, 127, 1, 54, "Subsection"],
Cell[5583505, 104531, 333, 6, 37, "Text"],
Cell[CellGroupData[{
Cell[5583863, 104541, 7011, 162, 413, "Input"],
Cell[5590877, 104705, 75051, 1333, 337, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5665977, 106044, 175, 2, 43, "Subsection"],
Cell[CellGroupData[{
Cell[5666177, 106050, 113, 1, 43, "Subsubsection"],
Cell[5666293, 106053, 610, 10, 85, "Text"],
Cell[5666906, 106065, 8859, 211, 938, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[5675802, 106281, 211, 4, 34, "Subsubsection"],
Cell[5676016, 106287, 9040, 216, 607, "Input"],
Cell[5685059, 106505, 21309, 613, 2157, "Input"],
Cell[5706371, 107120, 5022, 148, 477, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[5711430, 107273, 207, 4, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[5711662, 107281, 17844, 426, 1567, "Input"],
Cell[5729509, 107709, 55990, 1141, 294, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5785548, 108856, 225, 3, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[5785798, 108863, 15934, 389, 1509, "Input"],
Cell[5801735, 109254, 22426, 437, 297, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5824210, 109697, 100, 1, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[5824335, 109702, 548, 14, 57, "Input"],
Cell[5824886, 109718, 160281, 2974, 981, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5985228, 112699, 281, 3, 54, "Subsection"],
Cell[CellGroupData[{
Cell[5985534, 112706, 159, 4, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[5985718, 112714, 15859, 379, 1284, "Input"],
Cell[6001580, 113095, 605, 11, 29, "Message"],
Cell[6002188, 113108, 33977, 714, 305, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[6036214, 113828, 174, 3, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[6036413, 113835, 16181, 387, 1305, "Input"],
Cell[6052597, 114224, 871, 16, 29, "Message"],
Cell[6053471, 114242, 27959, 606, 327, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[6081479, 114854, 102, 1, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[6081606, 114859, 482, 13, 57, "Input"],
Cell[6082091, 114874, 68467, 1441, 615, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[6150619, 116322, 229, 3, 43, "Subsection"],
Cell[CellGroupData[{
Cell[6150873, 116329, 426, 7, 43, "Subsubsection"],
Cell[6151302, 116338, 239, 7, 78, "Input"],
Cell[CellGroupData[{
Cell[6151566, 116349, 15239, 428, 1713, "Input"],
Cell[6166808, 116779, 68091, 1438, 311, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[6234948, 118223, 464, 6, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[6235437, 118233, 17293, 458, 1734, "Input"],
Cell[6252733, 118693, 24138, 453, 70, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[6276920, 119152, 100, 1, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[6277045, 119157, 483, 13, 57, "Input"],
Cell[6277531, 119172, 96528, 1910, 615, "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[6374132, 121090, 151, 2, 62, "Section"],
Cell[CellGroupData[{
Cell[6374308, 121096, 699, 11, 54, "Subsection"],
Cell[CellGroupData[{
Cell[6375032, 121111, 180, 2, 43, "Subsubsection"],
Cell[6375215, 121115, 12850, 348, 1027, "Input"],
Cell[6388068, 121465, 21262, 607, 1908, "Input"],
Cell[6409333, 122074, 5011, 147, 477, "Input"],
Cell[6414347, 122223, 21388, 611, 2198, "Input"],
Cell[6435738, 122836, 5050, 146, 498, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[6440825, 122987, 94, 1, 34, "Subsubsection"],
Cell[CellGroupData[{
Cell[6440944, 122992, 8222, 198, 818, "Input"],
Cell[6449169, 123192, 56888, 1108, 297, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[6506118, 124307, 388, 7, 43, "Subsection"],
Cell[CellGroupData[{
Cell[6506531, 124318, 17620, 410, 1563, "Input"],
Cell[6524154, 124730, 1038, 18, 29, "Message"],
Cell[6525195, 124750, 1035, 18, 70, "Message"],
Cell[6526233, 124770, 24597, 533, 70, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[6550879, 125309, 312, 6, 43, "Subsection"],
Cell[CellGroupData[{
Cell[6551216, 125319, 13259, 332, 1299, "Input"],
Cell[6564478, 125653, 43134, 821, 70, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[6607661, 126480, 99, 1, 43, "Subsection"],
Cell[CellGroupData[{
Cell[6607785, 126485, 596, 15, 57, "Input"],
Cell[6608384, 126502, 131598, 2545, 982, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[6740043, 129054, 284, 5, 62, "Section"],
Cell[CellGroupData[{
Cell[6740352, 129063, 148, 2, 54, "Subsection"],
Cell[CellGroupData[{
Cell[6740525, 129069, 681, 9, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[6741231, 129082, 19147, 525, 1918, "Input"],
Cell[6760381, 129609, 829, 15, 70, "Message"],
Cell[6761213, 129626, 830, 15, 70, "Message"],
Cell[6762046, 129643, 831, 15, 70, "Message"],
Cell[6762880, 129660, 555, 11, 28, "Message"],
Cell[6763438, 129673, 830, 15, 70, "Message"],
Cell[6764271, 129690, 830, 15, 70, "Message"],
Cell[6765104, 129707, 831, 15, 70, "Message"],
Cell[6765938, 129724, 555, 11, 28, "Message"],
Cell[6766496, 129737, 829, 15, 70, "Message"],
Cell[6767328, 129754, 828, 15, 70, "Message"],
Cell[6768159, 129771, 833, 15, 70, "Message"],
Cell[6768995, 129788, 555, 11, 28, "Message"],
Cell[6769553, 129801, 829, 15, 70, "Message"],
Cell[6770385, 129818, 830, 15, 70, "Message"],
Cell[6771218, 129835, 830, 15, 70, "Message"],
Cell[6772051, 129852, 555, 11, 28, "Message"],
Cell[6772609, 129865, 834, 15, 70, "Message"],
Cell[6773446, 129882, 832, 15, 70, "Message"],
Cell[6774281, 129899, 829, 15, 70, "Message"],
Cell[6775113, 129916, 554, 11, 28, "Message"],
Cell[6775670, 129929, 829, 15, 70, "Message"],
Cell[6776502, 129946, 832, 15, 70, "Message"],
Cell[6777337, 129963, 830, 15, 70, "Message"],
Cell[6778170, 129980, 555, 11, 28, "Message"],
Cell[6778728, 129993, 54442, 1049, 300, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[6833219, 131048, 370, 5, 36, "Subsubsection"],
Cell[CellGroupData[{
Cell[6833614, 131057, 17548, 407, 1822, "Input"],
Cell[6851165, 131466, 1013, 18, 70, "Message"],
Cell[6852181, 131486, 1014, 18, 70, "Message"],
Cell[6853198, 131506, 24504, 531, 307, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[6877751, 132043, 294, 4, 36, "Subsubsection"],
Cell[CellGroupData[{
Cell[6878070, 132051, 12967, 326, 1458, "Input"],
Cell[6891040, 132379, 43078, 819, 336, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[6934179, 133205, 209, 3, 43, "Subsection"],
Cell[CellGroupData[{
Cell[6934413, 133212, 681, 9, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[6935119, 133225, 19526, 528, 1606, "Input"],
Cell[6954648, 133755, 810, 15, 52, "Message"],
Cell[6955461, 133772, 811, 15, 52, "Message"],
Cell[6956275, 133789, 806, 15, 52, "Message"],
Cell[6957084, 133806, 535, 11, 30, "Message"],
Cell[6957622, 133819, 808, 15, 52, "Message"],
Cell[6958433, 133836, 807, 15, 52, "Message"],
Cell[6959243, 133853, 807, 15, 52, "Message"],
Cell[6960053, 133870, 535, 11, 30, "Message"],
Cell[6960591, 133883, 806, 15, 52, "Message"],
Cell[6961400, 133900, 809, 15, 52, "Message"],
Cell[6962212, 133917, 807, 15, 52, "Message"],
Cell[6963022, 133934, 533, 11, 30, "Message"],
Cell[6963558, 133947, 816, 15, 52, "Message"],
Cell[6964377, 133964, 815, 15, 52, "Message"],
Cell[6965195, 133981, 813, 15, 52, "Message"],
Cell[6966011, 133998, 533, 11, 30, "Message"],
Cell[6966547, 134011, 808, 15, 52, "Message"],
Cell[6967358, 134028, 807, 15, 52, "Message"],
Cell[6968168, 134045, 808, 15, 52, "Message"],
Cell[6968979, 134062, 535, 11, 30, "Message"],
Cell[6969517, 134075, 814, 15, 52, "Message"],
Cell[6970334, 134092, 815, 15, 52, "Message"],
Cell[6971152, 134109, 812, 15, 52, "Message"],
Cell[6971967, 134126, 535, 11, 30, "Message"],
Cell[6972505, 134139, 54651, 1051, 300, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[7027205, 135196, 370, 5, 36, "Subsubsection"],
Cell[CellGroupData[{
Cell[7027600, 135205, 17607, 406, 1647, "Input"],
Cell[7045210, 135613, 1037, 18, 52, "Message"],
Cell[7046250, 135633, 1035, 18, 52, "Message"],
Cell[7047288, 135653, 1030, 18, 52, "Message"],
Cell[7048321, 135673, 24373, 528, 307, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[7072743, 136207, 294, 4, 43, "Subsubsection"],
Cell[CellGroupData[{
Cell[7073062, 136215, 13058, 325, 1376, "Input"],
Cell[7086123, 136542, 43513, 824, 336, "Output"]
}, Closed]]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
